var libopus = (function() {
    var _scriptDir = typeof document !== 'undefined' && document.currentScript ? document.currentScript.src : undefined;
    if (typeof __filename !== 'undefined') _scriptDir = _scriptDir || __filename;
    return (
        function(libopus) {
            libopus = libopus || {};

            var Module = typeof libopus !== "undefined" ? libopus : {};
            var readyPromiseResolve, readyPromiseReject;
            Module["ready"] = new Promise(function(resolve, reject) {
                readyPromiseResolve = resolve;
                readyPromiseReject = reject
            });
            var moduleOverrides = {};
            var key;
            for (key in Module) {
                if (Module.hasOwnProperty(key)) {
                    moduleOverrides[key] = Module[key]
                }
            }
            var arguments_ = [];
            var thisProgram = "./this.program";
            var quit_ = function(status, toThrow) {
                throw toThrow
            };
            var ENVIRONMENT_IS_WEB = false;
            var ENVIRONMENT_IS_WORKER = false;
            var ENVIRONMENT_IS_NODE = false;
            var ENVIRONMENT_IS_SHELL = false;
            ENVIRONMENT_IS_WEB = typeof window === "object";
            ENVIRONMENT_IS_WORKER = typeof importScripts === "function";
            ENVIRONMENT_IS_NODE = typeof process === "object" && typeof process.versions === "object" && typeof process.versions.node === "string";
            ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;
            var scriptDirectory = "";

            function locateFile(path) {
                if (Module["locateFile"]) {
                    return Module["locateFile"](path, scriptDirectory)
                }
                return scriptDirectory + path
            }
            var read_, readAsync, readBinary, setWindowTitle;
            var nodeFS;
            var nodePath;
            if (ENVIRONMENT_IS_NODE) {
                if (ENVIRONMENT_IS_WORKER) {
                    scriptDirectory = require("path").dirname(scriptDirectory) + "/"
                } else {
                    scriptDirectory = __dirname + "/"
                }
                read_ = function shell_read(filename, binary) {
                    if (!nodeFS) nodeFS = require("fs");
                    if (!nodePath) nodePath = require("path");
                    filename = nodePath["normalize"](filename);
                    return nodeFS["readFileSync"](filename, binary ? null : "utf8")
                };
                readBinary = function readBinary(filename) {
                    var ret = read_(filename, true);
                    if (!ret.buffer) {
                        ret = new Uint8Array(ret)
                    }
                    assert(ret.buffer);
                    return ret
                };
                if (process["argv"].length > 1) {
                    thisProgram = process["argv"][1].replace(/\\/g, "/")
                }
                arguments_ = process["argv"].slice(2);
                process["on"]("uncaughtException", function(ex) {
                    if (!(ex instanceof ExitStatus)) {
                        throw ex
                    }
                });
                process["on"]("unhandledRejection", abort);
                quit_ = function(status) {
                    process["exit"](status)
                };
                Module["inspect"] = function() {
                    return "[Emscripten Module object]"
                }
            } else if (ENVIRONMENT_IS_SHELL) {
                if (typeof read != "undefined") {
                    read_ = function shell_read(f) {
                        return read(f)
                    }
                }
                readBinary = function readBinary(f) {
                    var data;
                    if (typeof readbuffer === "function") {
                        return new Uint8Array(readbuffer(f))
                    }
                    data = read(f, "binary");
                    assert(typeof data === "object");
                    return data
                };
                if (typeof scriptArgs != "undefined") {
                    arguments_ = scriptArgs
                } else if (typeof arguments != "undefined") {
                    arguments_ = arguments
                }
                if (typeof quit === "function") {
                    quit_ = function(status) {
                        quit(status)
                    }
                }
                if (typeof print !== "undefined") {
                    if (typeof console === "undefined") console = {};
                    console.log = print;
                    console.warn = console.error = typeof printErr !== "undefined" ? printErr : print
                }
            } else if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
                if (ENVIRONMENT_IS_WORKER) {
                    scriptDirectory = self.location.href
                } else if (typeof document !== "undefined" && document.currentScript) {
                    scriptDirectory = document.currentScript.src
                }
                if (_scriptDir) {
                    scriptDirectory = _scriptDir
                }
                if (scriptDirectory.indexOf("blob:") !== 0) {
                    scriptDirectory = scriptDirectory.substr(0, scriptDirectory.lastIndexOf("/") + 1)
                } else {
                    scriptDirectory = ""
                } {
                    read_ = function(url) {
                        var xhr = new XMLHttpRequest;
                        xhr.open("GET", url, false);
                        xhr.send(null);
                        return xhr.responseText
                    };
                    if (ENVIRONMENT_IS_WORKER) {
                        readBinary = function(url) {
                            var xhr = new XMLHttpRequest;
                            xhr.open("GET", url, false);
                            xhr.responseType = "arraybuffer";
                            xhr.send(null);
                            return new Uint8Array(xhr.response)
                        }
                    }
                    readAsync = function(url, onload, onerror) {
                        var xhr = new XMLHttpRequest;
                        xhr.open("GET", url, true);
                        xhr.responseType = "arraybuffer";
                        xhr.onload = function() {
                            if (xhr.status == 200 || xhr.status == 0 && xhr.response) {
                                onload(xhr.response);
                                return
                            }
                            onerror()
                        };
                        xhr.onerror = onerror;
                        xhr.send(null)
                    }
                }
                setWindowTitle = function(title) {
                    document.title = title
                }
            } else {}
            var out = Module["print"] || console.log.bind(console);
            var err = Module["printErr"] || console.warn.bind(console);
            for (key in moduleOverrides) {
                if (moduleOverrides.hasOwnProperty(key)) {
                    Module[key] = moduleOverrides[key]
                }
            }
            moduleOverrides = null;
            if (Module["arguments"]) arguments_ = Module["arguments"];
            if (Module["thisProgram"]) thisProgram = Module["thisProgram"];
            if (Module["quit"]) quit_ = Module["quit"];
            var STACK_ALIGN = 16;

            function alignMemory(size, factor) {
                if (!factor) factor = STACK_ALIGN;
                return Math.ceil(size / factor) * factor
            }

            function getNativeTypeSize(type) {
                switch (type) {
                    case "i1":
                    case "i8":
                        return 1;
                    case "i16":
                        return 2;
                    case "i32":
                        return 4;
                    case "i64":
                        return 8;
                    case "float":
                        return 4;
                    case "double":
                        return 8;
                    default: {
                        if (type[type.length - 1] === "*") {
                            return 4
                        } else if (type[0] === "i") {
                            var bits = Number(type.substr(1));
                            assert(bits % 8 === 0, "getNativeTypeSize invalid bits " + bits + ", type " + type);
                            return bits / 8
                        } else {
                            return 0
                        }
                    }
                }
            }

            function warnOnce(text) {
                if (!warnOnce.shown) warnOnce.shown = {};
                if (!warnOnce.shown[text]) {
                    warnOnce.shown[text] = 1;
                    err(text)
                }
            }

            function convertJsFunctionToWasm(func, sig) {
                if (typeof WebAssembly.Function === "function") {
                    var typeNames = {
                        "i": "i32",
                        "j": "i64",
                        "f": "f32",
                        "d": "f64"
                    };
                    var type = {
                        parameters: [],
                        results: sig[0] == "v" ? [] : [typeNames[sig[0]]]
                    };
                    for (var i = 1; i < sig.length; ++i) {
                        type.parameters.push(typeNames[sig[i]])
                    }
                    return new WebAssembly.Function(type, func)
                }
                var typeSection = [1, 0, 1, 96];
                var sigRet = sig.slice(0, 1);
                var sigParam = sig.slice(1);
                var typeCodes = {
                    "i": 127,
                    "j": 126,
                    "f": 125,
                    "d": 124
                };
                typeSection.push(sigParam.length);
                for (var i = 0; i < sigParam.length; ++i) {
                    typeSection.push(typeCodes[sigParam[i]])
                }
                if (sigRet == "v") {
                    typeSection.push(0)
                } else {
                    typeSection = typeSection.concat([1, typeCodes[sigRet]])
                }
                typeSection[1] = typeSection.length - 2;
                var bytes = new Uint8Array([0, 97, 115, 109, 1, 0, 0, 0].concat(typeSection, [2, 7, 1, 1, 101, 1, 102, 0, 0, 7, 5, 1, 1, 102, 0, 0]));
                var module = new WebAssembly.Module(bytes);
                var instance = new WebAssembly.Instance(module, {
                    "e": {
                        "f": func
                    }
                });
                var wrappedFunc = instance.exports["f"];
                return wrappedFunc
            }
            var freeTableIndexes = [];
            var functionsInTableMap;

            function getEmptyTableSlot() {
                if (freeTableIndexes.length) {
                    return freeTableIndexes.pop()
                }
                try {
                    wasmTable.grow(1)
                } catch (err) {
                    if (!(err instanceof RangeError)) {
                        throw err
                    }
                    throw "Unable to grow wasm table. Set ALLOW_TABLE_GROWTH."
                }
                return wasmTable.length - 1
            }

            function addFunctionWasm(func, sig) {
                if (!functionsInTableMap) {
                    functionsInTableMap = new WeakMap;
                    for (var i = 0; i < wasmTable.length; i++) {
                        var item = wasmTable.get(i);
                        if (item) {
                            functionsInTableMap.set(item, i)
                        }
                    }
                }
                if (functionsInTableMap.has(func)) {
                    return functionsInTableMap.get(func)
                }
                var ret = getEmptyTableSlot();
                try {
                    wasmTable.set(ret, func)
                } catch (err) {
                    if (!(err instanceof TypeError)) {
                        throw err
                    }
                    var wrapped = convertJsFunctionToWasm(func, sig);
                    wasmTable.set(ret, wrapped)
                }
                functionsInTableMap.set(func, ret);
                return ret
            }

            function removeFunction(index) {
                functionsInTableMap.delete(wasmTable.get(index));
                freeTableIndexes.push(index)
            }

            function addFunction(func, sig) {
                return addFunctionWasm(func, sig)
            }
            var tempRet0 = 0;
            var setTempRet0 = function(value) {
                tempRet0 = value
            };
            var getTempRet0 = function() {
                return tempRet0
            };
            var dynamicLibraries = Module["dynamicLibraries"] || [];
            var wasmBinary;
            if (Module["wasmBinary"]) wasmBinary = Module["wasmBinary"];
            var noExitRuntime = Module["noExitRuntime"] || true;
            if (typeof WebAssembly !== "object") {
                abort("no native wasm support detected")
            }

            function setValue(ptr, value, type, noSafe) {
                type = type || "i8";
                if (type.charAt(type.length - 1) === "*") type = "i32";
                switch (type) {
                    case "i1":
                        HEAP8[ptr >> 0] = value;
                        break;
                    case "i8":
                        HEAP8[ptr >> 0] = value;
                        break;
                    case "i16":
                        HEAP16[ptr >> 1] = value;
                        break;
                    case "i32":
                        HEAP32[ptr >> 2] = value;
                        break;
                    case "i64":
                        tempI64 = [value >>> 0, (tempDouble = value, +Math.abs(tempDouble) >= 1 ? tempDouble > 0 ? (Math.min(+Math.floor(tempDouble / 4294967296), 4294967295) | 0) >>> 0 : ~~+Math.ceil((tempDouble - +(~~tempDouble >>> 0)) / 4294967296) >>> 0 : 0)], HEAP32[ptr >> 2] = tempI64[0], HEAP32[ptr + 4 >> 2] = tempI64[1];
                        break;
                    case "float":
                        HEAPF32[ptr >> 2] = value;
                        break;
                    case "double":
                        HEAPF64[ptr >> 3] = value;
                        break;
                    default:
                        abort("invalid type for setValue: " + type)
                }
            }

            function getValue(ptr, type, noSafe) {
                type = type || "i8";
                if (type.charAt(type.length - 1) === "*") type = "i32";
                switch (type) {
                    case "i1":
                        return HEAP8[ptr >> 0];
                    case "i8":
                        return HEAP8[ptr >> 0];
                    case "i16":
                        return HEAP16[ptr >> 1];
                    case "i32":
                        return HEAP32[ptr >> 2];
                    case "i64":
                        return HEAP32[ptr >> 2];
                    case "float":
                        return HEAPF32[ptr >> 2];
                    case "double":
                        return HEAPF64[ptr >> 3];
                    default:
                        abort("invalid type for getValue: " + type)
                }
                return null
            }
            var wasmMemory;
            var ABORT = false;
            var EXITSTATUS;

            function assert(condition, text) {
                if (!condition) {
                    abort("Assertion failed: " + text)
                }
            }

            function getCFunc(ident) {
                var func = Module["_" + ident];
                assert(func, "Cannot call unknown function " + ident + ", make sure it is exported");
                return func
            }

            function ccall(ident, returnType, argTypes, args, opts) {
                var toC = {
                    "string": function(str) {
                        var ret = 0;
                        if (str !== null && str !== undefined && str !== 0) {
                            var len = (str.length << 2) + 1;
                            ret = stackAlloc(len);
                            stringToUTF8(str, ret, len)
                        }
                        return ret
                    },
                    "array": function(arr) {
                        var ret = stackAlloc(arr.length);
                        writeArrayToMemory(arr, ret);
                        return ret
                    }
                };

                function convertReturnValue(ret) {
                    if (returnType === "string") return UTF8ToString(ret);
                    if (returnType === "boolean") return Boolean(ret);
                    return ret
                }
                var func = getCFunc(ident);
                var cArgs = [];
                var stack = 0;
                if (args) {
                    for (var i = 0; i < args.length; i++) {
                        var converter = toC[argTypes[i]];
                        if (converter) {
                            if (stack === 0) stack = stackSave();
                            cArgs[i] = converter(args[i])
                        } else {
                            cArgs[i] = args[i]
                        }
                    }
                }
                var ret = func.apply(null, cArgs);
                ret = convertReturnValue(ret);
                if (stack !== 0) stackRestore(stack);
                return ret
            }

            function cwrap(ident, returnType, argTypes, opts) {
                argTypes = argTypes || [];
                var numericArgs = argTypes.every(function(type) {
                    return type === "number"
                });
                var numericRet = returnType !== "string";
                if (numericRet && numericArgs && !opts) {
                    return getCFunc(ident)
                }
                return function() {
                    return ccall(ident, returnType, argTypes, arguments, opts)
                }
            }
            var ALLOC_NORMAL = 0;
            var ALLOC_STACK = 1;

            function allocate(slab, allocator) {
                var ret;
                if (allocator == ALLOC_STACK) {
                    ret = stackAlloc(slab.length)
                } else {
                    ret = _malloc(slab.length)
                }
                if (slab.subarray || slab.slice) {
                    HEAPU8.set(slab, ret)
                } else {
                    HEAPU8.set(new Uint8Array(slab), ret)
                }
                return ret
            }
            var UTF8Decoder = typeof TextDecoder !== "undefined" ? new TextDecoder("utf8") : undefined;

            function UTF8ArrayToString(heap, idx, maxBytesToRead) {
                var endIdx = idx + maxBytesToRead;
                var endPtr = idx;
                while (heap[endPtr] && !(endPtr >= endIdx)) ++endPtr;
                if (endPtr - idx > 16 && heap.subarray && UTF8Decoder) {
                    return UTF8Decoder.decode(heap.subarray(idx, endPtr))
                } else {
                    var str = "";
                    while (idx < endPtr) {
                        var u0 = heap[idx++];
                        if (!(u0 & 128)) {
                            str += String.fromCharCode(u0);
                            continue
                        }
                        var u1 = heap[idx++] & 63;
                        if ((u0 & 224) == 192) {
                            str += String.fromCharCode((u0 & 31) << 6 | u1);
                            continue
                        }
                        var u2 = heap[idx++] & 63;
                        if ((u0 & 240) == 224) {
                            u0 = (u0 & 15) << 12 | u1 << 6 | u2
                        } else {
                            u0 = (u0 & 7) << 18 | u1 << 12 | u2 << 6 | heap[idx++] & 63
                        }
                        if (u0 < 65536) {
                            str += String.fromCharCode(u0)
                        } else {
                            var ch = u0 - 65536;
                            str += String.fromCharCode(55296 | ch >> 10, 56320 | ch & 1023)
                        }
                    }
                }
                return str
            }

            function UTF8ToString(ptr, maxBytesToRead) {
                return ptr ? UTF8ArrayToString(HEAPU8, ptr, maxBytesToRead) : ""
            }

            function stringToUTF8Array(str, heap, outIdx, maxBytesToWrite) {
                if (!(maxBytesToWrite > 0)) return 0;
                var startIdx = outIdx;
                var endIdx = outIdx + maxBytesToWrite - 1;
                for (var i = 0; i < str.length; ++i) {
                    var u = str.charCodeAt(i);
                    if (u >= 55296 && u <= 57343) {
                        var u1 = str.charCodeAt(++i);
                        u = 65536 + ((u & 1023) << 10) | u1 & 1023
                    }
                    if (u <= 127) {
                        if (outIdx >= endIdx) break;
                        heap[outIdx++] = u
                    } else if (u <= 2047) {
                        if (outIdx + 1 >= endIdx) break;
                        heap[outIdx++] = 192 | u >> 6;
                        heap[outIdx++] = 128 | u & 63
                    } else if (u <= 65535) {
                        if (outIdx + 2 >= endIdx) break;
                        heap[outIdx++] = 224 | u >> 12;
                        heap[outIdx++] = 128 | u >> 6 & 63;
                        heap[outIdx++] = 128 | u & 63
                    } else {
                        if (outIdx + 3 >= endIdx) break;
                        heap[outIdx++] = 240 | u >> 18;
                        heap[outIdx++] = 128 | u >> 12 & 63;
                        heap[outIdx++] = 128 | u >> 6 & 63;
                        heap[outIdx++] = 128 | u & 63
                    }
                }
                heap[outIdx] = 0;
                return outIdx - startIdx
            }

            function stringToUTF8(str, outPtr, maxBytesToWrite) {
                return stringToUTF8Array(str, HEAPU8, outPtr, maxBytesToWrite)
            }

            function lengthBytesUTF8(str) {
                var len = 0;
                for (var i = 0; i < str.length; ++i) {
                    var u = str.charCodeAt(i);
                    if (u >= 55296 && u <= 57343) u = 65536 + ((u & 1023) << 10) | str.charCodeAt(++i) & 1023;
                    if (u <= 127) ++len;
                    else if (u <= 2047) len += 2;
                    else if (u <= 65535) len += 3;
                    else len += 4
                }
                return len
            }

            function AsciiToString(ptr) {
                var str = "";
                while (1) {
                    var ch = HEAPU8[ptr++ >> 0];
                    if (!ch) return str;
                    str += String.fromCharCode(ch)
                }
            }

            function stringToAscii(str, outPtr) {
                return writeAsciiToMemory(str, outPtr, false)
            }
            var UTF16Decoder = typeof TextDecoder !== "undefined" ? new TextDecoder("utf-16le") : undefined;

            function UTF16ToString(ptr, maxBytesToRead) {
                var endPtr = ptr;
                var idx = endPtr >> 1;
                var maxIdx = idx + maxBytesToRead / 2;
                while (!(idx >= maxIdx) && HEAPU16[idx]) ++idx;
                endPtr = idx << 1;
                if (endPtr - ptr > 32 && UTF16Decoder) {
                    return UTF16Decoder.decode(HEAPU8.subarray(ptr, endPtr))
                } else {
                    var str = "";
                    for (var i = 0; !(i >= maxBytesToRead / 2); ++i) {
                        var codeUnit = HEAP16[ptr + i * 2 >> 1];
                        if (codeUnit == 0) break;
                        str += String.fromCharCode(codeUnit)
                    }
                    return str
                }
            }

            function stringToUTF16(str, outPtr, maxBytesToWrite) {
                if (maxBytesToWrite === undefined) {
                    maxBytesToWrite = 2147483647
                }
                if (maxBytesToWrite < 2) return 0;
                maxBytesToWrite -= 2;
                var startPtr = outPtr;
                var numCharsToWrite = maxBytesToWrite < str.length * 2 ? maxBytesToWrite / 2 : str.length;
                for (var i = 0; i < numCharsToWrite; ++i) {
                    var codeUnit = str.charCodeAt(i);
                    HEAP16[outPtr >> 1] = codeUnit;
                    outPtr += 2
                }
                HEAP16[outPtr >> 1] = 0;
                return outPtr - startPtr
            }

            function lengthBytesUTF16(str) {
                return str.length * 2
            }

            function UTF32ToString(ptr, maxBytesToRead) {
                var i = 0;
                var str = "";
                while (!(i >= maxBytesToRead / 4)) {
                    var utf32 = HEAP32[ptr + i * 4 >> 2];
                    if (utf32 == 0) break;
                    ++i;
                    if (utf32 >= 65536) {
                        var ch = utf32 - 65536;
                        str += String.fromCharCode(55296 | ch >> 10, 56320 | ch & 1023)
                    } else {
                        str += String.fromCharCode(utf32)
                    }
                }
                return str
            }

            function stringToUTF32(str, outPtr, maxBytesToWrite) {
                if (maxBytesToWrite === undefined) {
                    maxBytesToWrite = 2147483647
                }
                if (maxBytesToWrite < 4) return 0;
                var startPtr = outPtr;
                var endPtr = startPtr + maxBytesToWrite - 4;
                for (var i = 0; i < str.length; ++i) {
                    var codeUnit = str.charCodeAt(i);
                    if (codeUnit >= 55296 && codeUnit <= 57343) {
                        var trailSurrogate = str.charCodeAt(++i);
                        codeUnit = 65536 + ((codeUnit & 1023) << 10) | trailSurrogate & 1023
                    }
                    HEAP32[outPtr >> 2] = codeUnit;
                    outPtr += 4;
                    if (outPtr + 4 > endPtr) break
                }
                HEAP32[outPtr >> 2] = 0;
                return outPtr - startPtr
            }

            function lengthBytesUTF32(str) {
                var len = 0;
                for (var i = 0; i < str.length; ++i) {
                    var codeUnit = str.charCodeAt(i);
                    if (codeUnit >= 55296 && codeUnit <= 57343) ++i;
                    len += 4
                }
                return len
            }

            function allocateUTF8(str) {
                var size = lengthBytesUTF8(str) + 1;
                var ret = _malloc(size);
                if (ret) stringToUTF8Array(str, HEAP8, ret, size);
                return ret
            }

            function allocateUTF8OnStack(str) {
                var size = lengthBytesUTF8(str) + 1;
                var ret = stackAlloc(size);
                stringToUTF8Array(str, HEAP8, ret, size);
                return ret
            }

            function writeStringToMemory(string, buffer, dontAddNull) {
                warnOnce("writeStringToMemory is deprecated and should not be called! Use stringToUTF8() instead!");
                var lastChar, end;
                if (dontAddNull) {
                    end = buffer + lengthBytesUTF8(string);
                    lastChar = HEAP8[end]
                }
                stringToUTF8(string, buffer, Infinity);
                if (dontAddNull) HEAP8[end] = lastChar
            }

            function writeArrayToMemory(array, buffer) {
                HEAP8.set(array, buffer)
            }

            function writeAsciiToMemory(str, buffer, dontAddNull) {
                for (var i = 0; i < str.length; ++i) {
                    HEAP8[buffer++ >> 0] = str.charCodeAt(i)
                }
                if (!dontAddNull) HEAP8[buffer >> 0] = 0
            }

            function alignUp(x, multiple) {
                if (x % multiple > 0) {
                    x += multiple - x % multiple
                }
                return x
            }
            var HEAP, buffer, HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;

            function updateGlobalBufferAndViews(buf) {
                buffer = buf;
                Module["HEAP8"] = HEAP8 = new Int8Array(buf);
                Module["HEAP16"] = HEAP16 = new Int16Array(buf);
                Module["HEAP32"] = HEAP32 = new Int32Array(buf);
                Module["HEAPU8"] = HEAPU8 = new Uint8Array(buf);
                Module["HEAPU16"] = HEAPU16 = new Uint16Array(buf);
                Module["HEAPU32"] = HEAPU32 = new Uint32Array(buf);
                Module["HEAPF32"] = HEAPF32 = new Float32Array(buf);
                Module["HEAPF64"] = HEAPF64 = new Float64Array(buf)
            }
            var TOTAL_STACK = 5242880;
            var INITIAL_MEMORY = Module["INITIAL_MEMORY"] || 16777216;
            if (Module["wasmMemory"]) {
                wasmMemory = Module["wasmMemory"]
            } else {
                wasmMemory = new WebAssembly.Memory({
                    "initial": INITIAL_MEMORY / 65536,
                    "maximum": INITIAL_MEMORY / 65536
                })
            }
            if (wasmMemory) {
                buffer = wasmMemory.buffer
            }
            INITIAL_MEMORY = buffer.byteLength;
            updateGlobalBufferAndViews(buffer);
            var wasmTable = new WebAssembly.Table({
                "initial": 979,
                "element": "anyfunc"
            });
            var __ATPRERUN__ = [];
            var __ATINIT__ = [];
            var __ATMAIN__ = [];
            var __ATEXIT__ = [];
            var __ATPOSTRUN__ = [];
            var runtimeInitialized = false;
            var runtimeExited = false;

            function preRun() {
                if (Module["preRun"]) {
                    if (typeof Module["preRun"] == "function") Module["preRun"] = [Module["preRun"]];
                    while (Module["preRun"].length) {
                        addOnPreRun(Module["preRun"].shift())
                    }
                }
                callRuntimeCallbacks(__ATPRERUN__)
            }

            function initRuntime() {
                runtimeInitialized = true;
                if (!Module["noFSInit"] && !FS.init.initialized) FS.init();
                TTY.init();
                SOCKFS.root = FS.mount(SOCKFS, {}, null);
                PIPEFS.root = FS.mount(PIPEFS, {}, null);
                callRuntimeCallbacks(__ATINIT__)
            }

            function preMain() {
                FS.ignorePermissions = false;
                callRuntimeCallbacks(__ATMAIN__)
            }

            function exitRuntime() {
                runtimeExited = true
            }

            function postRun() {
                if (Module["postRun"]) {
                    if (typeof Module["postRun"] == "function") Module["postRun"] = [Module["postRun"]];
                    while (Module["postRun"].length) {
                        addOnPostRun(Module["postRun"].shift())
                    }
                }
                callRuntimeCallbacks(__ATPOSTRUN__)
            }

            function addOnPreRun(cb) {
                __ATPRERUN__.unshift(cb)
            }

            function addOnInit(cb) {
                __ATINIT__.unshift(cb)
            }

            function addOnPreMain(cb) {
                __ATMAIN__.unshift(cb)
            }

            function addOnExit(cb) {}

            function addOnPostRun(cb) {
                __ATPOSTRUN__.unshift(cb)
            }
            var runDependencies = 0;
            var runDependencyWatcher = null;
            var dependenciesFulfilled = null;

            function getUniqueRunDependency(id) {
                return id
            }

            function addRunDependency(id) {
                runDependencies++;
                if (Module["monitorRunDependencies"]) {
                    Module["monitorRunDependencies"](runDependencies)
                }
            }

            function removeRunDependency(id) {
                runDependencies--;
                if (Module["monitorRunDependencies"]) {
                    Module["monitorRunDependencies"](runDependencies)
                }
                if (runDependencies == 0) {
                    if (runDependencyWatcher !== null) {
                        clearInterval(runDependencyWatcher);
                        runDependencyWatcher = null
                    }
                    if (dependenciesFulfilled) {
                        var callback = dependenciesFulfilled;
                        dependenciesFulfilled = null;
                        callback()
                    }
                }
            }
            Module["preloadedImages"] = {};
            Module["preloadedAudios"] = {};
            Module["preloadedWasm"] = {};

            function abort(what) {
                if (Module["onAbort"]) {
                    Module["onAbort"](what)
                }
                what += "";
                err(what);
                ABORT = true;
                EXITSTATUS = 1;
                what = "abort(" + what + "). Build with -s ASSERTIONS=1 for more info.";
                var e = new WebAssembly.RuntimeError(what);
                readyPromiseReject(e);
                throw e
            }
            var dataURIPrefix = "data:application/octet-stream;base64,";

            function isDataURI(filename) {
                return filename.startsWith(dataURIPrefix)
            }

            function isFileURI(filename) {
                return filename.startsWith("file://")
            }
            var wasmBinaryFile = "libopus.wasm";
            if (!isDataURI(wasmBinaryFile)) {
                wasmBinaryFile = locateFile(wasmBinaryFile)
            }

            function getBinary(file) {
                try {
                    if (file == wasmBinaryFile && wasmBinary) {
                        return new Uint8Array(wasmBinary)
                    }
                    if (readBinary) {
                        return readBinary(file)
                    } else {
                        throw "both async and sync fetching of the wasm failed"
                    }
                } catch (err) {
                    abort(err)
                }
            }

            function getBinaryPromise() {
                if (!wasmBinary && (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER)) {
                    if (typeof fetch === "function" && !isFileURI(wasmBinaryFile)) {
                        return fetch(wasmBinaryFile, {
                            credentials: "same-origin"
                        }).then(function(response) {
                            if (!response["ok"]) {
                                throw "failed to load wasm binary file at '" + wasmBinaryFile + "'"
                            }
                            return response["arrayBuffer"]()
                        }).catch(function() {
                            return getBinary(wasmBinaryFile)
                        })
                    } else {
                        if (readAsync) {
                            return new Promise(function(resolve, reject) {
                                readAsync(wasmBinaryFile, function(response) {
                                    resolve(new Uint8Array(response))
                                }, reject)
                            })
                        }
                    }
                }
                return Promise.resolve().then(function() {
                    return getBinary(wasmBinaryFile)
                })
            }

            function createWasm() {
                var info = {
                    "env": asmLibraryArg,
                    "wasi_snapshot_preview1": asmLibraryArg,
                    "GOT.mem": new Proxy(asmLibraryArg, GOTHandler),
                    "GOT.func": new Proxy(asmLibraryArg, GOTHandler)
                };

                function receiveInstance(instance, module) {
                    var exports = instance.exports;
                    exports = relocateExports(exports, 1024);
                    Module["asm"] = exports;
                    var metadata = getDylinkMetadata(module);
                    if (metadata.neededDynlibs) {
                        dynamicLibraries = metadata.neededDynlibs.concat(dynamicLibraries)
                    }
                    mergeLibSymbols(exports, "main");
                    addOnInit(Module["asm"]["__wasm_call_ctors"]);
                    removeRunDependency("wasm-instantiate")
                }
                addRunDependency("wasm-instantiate");

                function receiveInstantiationResult(result) {
                    receiveInstance(result["instance"], result["module"])
                }

                function instantiateArrayBuffer(receiver) {
                    return getBinaryPromise().then(function(binary) {
                        var result = WebAssembly.instantiate(binary, info);
                        return result
                    }).then(receiver, function(reason) {
                        err("failed to asynchronously prepare wasm: " + reason);
                        abort(reason)
                    })
                }

                function instantiateAsync() {
                    if (!wasmBinary && typeof WebAssembly.instantiateStreaming === "function" && !isDataURI(wasmBinaryFile) && !isFileURI(wasmBinaryFile) && typeof fetch === "function") {
                        return fetch(wasmBinaryFile, {
                            credentials: "same-origin"
                        }).then(function(response) {
                            var result = WebAssembly.instantiateStreaming(response, info);
                            return result.then(receiveInstantiationResult, function(reason) {
                                err("wasm streaming compile failed: " + reason);
                                err("falling back to ArrayBuffer instantiation");
                                return instantiateArrayBuffer(receiveInstantiationResult)
                            })
                        })
                    } else {
                        return instantiateArrayBuffer(receiveInstantiationResult)
                    }
                }
                if (Module["instantiateWasm"]) {
                    try {
                        var exports = Module["instantiateWasm"](info, receiveInstance);
                        return exports
                    } catch (e) {
                        err("Module.instantiateWasm callback failed with error: " + e);
                        return false
                    }
                }
                instantiateAsync().catch(readyPromiseReject);
                return {}
            }
            var tempDouble;
            var tempI64;
            var ASM_CONSTS = {
                270052: function($0) {
                    if (!$0) {
                        AL.alcErr = 40964;
                        return 1
                    }
                },
                270100: function($0) {
                    err("bad name in alcGetProcAddress: " + UTF8ToString($0))
                },
                270163: function($0) {
                    if (!AL.currentCtx) {
                        err("alGetProcAddress() called without a valid context");
                        return 1
                    }
                    if (!$0) {
                        AL.currentCtx.err = 40963;
                        return 1
                    }
                },
                270311: function($0) {
                    err("bad name in alGetProcAddress: " + UTF8ToString($0))
                }
            };
            var GOT = {};
            Module["GOT"] = GOT;
            var GOTHandler = {
                get: function(obj, symName) {
                    if (!GOT[symName]) {
                        GOT[symName] = new WebAssembly.Global({
                            "value": "i32",
                            "mutable": true
                        })
                    }
                    return GOT[symName]
                }
            };
            Module["GOTHandler"] = GOTHandler;

            function callRuntimeCallbacks(callbacks) {
                while (callbacks.length > 0) {
                    var callback = callbacks.shift();
                    if (typeof callback == "function") {
                        callback(Module);
                        continue
                    }
                    var func = callback.func;
                    if (typeof func === "number") {
                        if (callback.arg === undefined) {
                            wasmTable.get(func)()
                        } else {
                            wasmTable.get(func)(callback.arg)
                        }
                    } else {
                        func(callback.arg === undefined ? null : callback.arg)
                    }
                }
            }
            Module["callRuntimeCallbacks"] = callRuntimeCallbacks;

            function demangle(func) {
                return func
            }
            Module["demangle"] = demangle;

            function demangleAll(text) {
                var regex = /\b_Z[\w\d_]+/g;
                return text.replace(regex, function(x) {
                    var y = demangle(x);
                    return x === y ? x : y + " [" + x + "]"
                })
            }
            Module["demangleAll"] = demangleAll;

            function getDylinkMetadata(binary) {
                var next = 0;

                function getLEB() {
                    var ret = 0;
                    var mul = 1;
                    while (1) {
                        var byte = binary[next++];
                        ret += (byte & 127) * mul;
                        mul *= 128;
                        if (!(byte & 128)) break
                    }
                    return ret
                }
                if (binary instanceof WebAssembly.Module) {
                    var dylinkSection = WebAssembly.Module.customSections(binary, "dylink");
                    assert(dylinkSection.length != 0, "need dylink section");
                    binary = new Int8Array(dylinkSection[0])
                } else {
                    var int32View = new Uint32Array(new Uint8Array(binary.subarray(0, 24)).buffer);
                    assert(int32View[0] == 1836278016, "need to see wasm magic number");
                    assert(binary[8] === 0, "need the dylink section to be first");
                    next = 9;
                    getLEB();
                    assert(binary[next] === 6);
                    next++;
                    assert(binary[next] === "d".charCodeAt(0));
                    next++;
                    assert(binary[next] === "y".charCodeAt(0));
                    next++;
                    assert(binary[next] === "l".charCodeAt(0));
                    next++;
                    assert(binary[next] === "i".charCodeAt(0));
                    next++;
                    assert(binary[next] === "n".charCodeAt(0));
                    next++;
                    assert(binary[next] === "k".charCodeAt(0));
                    next++
                }
                var customSection = {};
                customSection.memorySize = getLEB();
                customSection.memoryAlign = getLEB();
                customSection.tableSize = getLEB();
                customSection.tableAlign = getLEB();
                var neededDynlibsCount = getLEB();
                customSection.neededDynlibs = [];
                for (var i = 0; i < neededDynlibsCount; ++i) {
                    var nameLen = getLEB();
                    var nameUTF8 = binary.subarray(next, next + nameLen);
                    next += nameLen;
                    var name = UTF8ArrayToString(nameUTF8, 0);
                    customSection.neededDynlibs.push(name)
                }
                return customSection
            }
            Module["getDylinkMetadata"] = getDylinkMetadata;

            function jsStackTrace() {
                var error = new Error;
                if (!error.stack) {
                    try {
                        throw new Error
                    } catch (e) {
                        error = e
                    }
                    if (!error.stack) {
                        return "(no stack trace available)"
                    }
                }
                return error.stack.toString()
            }
            Module["jsStackTrace"] = jsStackTrace;
            var runtimeKeepaliveCounter = 0;
            Module["runtimeKeepaliveCounter"] = runtimeKeepaliveCounter;

            function keepRuntimeAlive() {
                return noExitRuntime || runtimeKeepaliveCounter > 0
            }
            Module["keepRuntimeAlive"] = keepRuntimeAlive;

            function asmjsMangle(x) {
                var unmangledSymbols = ["stackAlloc", "stackSave", "stackRestore"];
                return x.indexOf("dynCall_") == 0 || unmangledSymbols.includes(x) ? x : "_" + x
            }
            Module["asmjsMangle"] = asmjsMangle;

            function mergeLibSymbols(exports, libName) {
                for (var sym in exports) {
                    if (!exports.hasOwnProperty(sym)) {
                        continue
                    }
                    if (!asmLibraryArg.hasOwnProperty(sym)) {
                        asmLibraryArg[sym] = exports[sym]
                    }
                    var module_sym = asmjsMangle(sym);
                    if (!Module.hasOwnProperty(module_sym)) {
                        Module[module_sym] = exports[sym]
                    }
                }
            }
            Module["mergeLibSymbols"] = mergeLibSymbols;
            var LDSO = {
                nextHandle: 1,
                loadedLibs: {},
                loadedLibNames: {}
            };
            Module["LDSO"] = LDSO;

            function dynCallLegacy(sig, ptr, args) {
                var f = Module["dynCall_" + sig];
                return args && args.length ? f.apply(null, [ptr].concat(args)) : f.call(null, ptr)
            }
            Module["dynCallLegacy"] = dynCallLegacy;

            function dynCall(sig, ptr, args) {
                if (sig.includes("j")) {
                    return dynCallLegacy(sig, ptr, args)
                }
                return wasmTable.get(ptr).apply(null, args)
            }
            Module["dynCall"] = dynCall;

            function createInvokeFunction(sig) {
                return function() {
                    var sp = stackSave();
                    try {
                        return dynCall(sig, arguments[0], Array.prototype.slice.call(arguments, 1))
                    } catch (e) {
                        stackRestore(sp);
                        if (e !== e + 0 && e !== "longjmp") throw e;
                        _setThrew(1, 0)
                    }
                }
            }
            Module["createInvokeFunction"] = createInvokeFunction;
            var ___heap_base = 5529680;
            Module["___heap_base"] = ___heap_base;

            function getMemory(size) {
                if (runtimeInitialized) return _malloc(size);
                var ret = ___heap_base;
                var end = ret + size + 15 & -16;
                ___heap_base = end;
                GOT["__heap_base"].value = end;
                return ret
            }
            Module["getMemory"] = getMemory;

            function isInternalSym(symName) {
                return ["__cpp_exception", "__wasm_apply_data_relocs", "__dso_handle", "__set_stack_limits"].includes(symName)
            }
            Module["isInternalSym"] = isInternalSym;

            function updateGOT(exports) {
                for (var symName in exports) {
                    if (isInternalSym(symName)) {
                        continue
                    }
                    var replace = false;
                    var value = exports[symName];
                    if (symName.startsWith("orig$")) {
                        symName = symName.split("$")[1];
                        replace = true
                    }
                    if (!GOT[symName]) {
                        GOT[symName] = new WebAssembly.Global({
                            "value": "i32",
                            "mutable": true
                        })
                    }
                    if (replace || GOT[symName].value == 0) {
                        if (typeof value === "function") {
                            GOT[symName].value = addFunctionWasm(value)
                        } else if (typeof value === "number") {
                            GOT[symName].value = value
                        } else {
                            err("unhandled export type for `" + symName + "`: " + typeof value)
                        }
                    }
                }
            }
            Module["updateGOT"] = updateGOT;

            function relocateExports(exports, memoryBase) {
                var relocated = {};
                for (var e in exports) {
                    var value = exports[e];
                    if (typeof value === "object") {
                        value = value.value
                    }
                    if (typeof value === "number") {
                        value += memoryBase
                    }
                    relocated[e] = value
                }
                updateGOT(relocated);
                return relocated
            }
            Module["relocateExports"] = relocateExports;

            function resolveGlobalSymbol(symName, direct) {
                var sym;
                if (direct) {
                    sym = asmLibraryArg["orig$" + symName]
                }
                if (!sym) {
                    sym = asmLibraryArg[symName]
                }
                if (!sym) {
                    sym = Module[asmjsMangle(symName)]
                }
                if (!sym && symName.startsWith("invoke_")) {
                    sym = createInvokeFunction(symName.split("_")[1])
                }
                return sym
            }
            Module["resolveGlobalSymbol"] = resolveGlobalSymbol;

            function loadWebAssemblyModule(binary, flags) {
                var metadata = getDylinkMetadata(binary);

                function loadModule() {
                    var memAlign = Math.pow(2, metadata.memoryAlign);
                    memAlign = Math.max(memAlign, STACK_ALIGN);
                    var memoryBase = alignMemory(getMemory(metadata.memorySize + memAlign), memAlign);
                    var tableBase = wasmTable.length;
                    wasmTable.grow(metadata.tableSize);
                    for (var i = memoryBase; i < memoryBase + metadata.memorySize; i++) {
                        HEAP8[i] = 0
                    }
                    for (var i = tableBase; i < tableBase + metadata.tableSize; i++) {
                        wasmTable.set(i, null)
                    }
                    var moduleExports;

                    function resolveSymbol(sym) {
                        var resolved = resolveGlobalSymbol(sym, false);
                        if (!resolved) {
                            resolved = moduleExports[sym]
                        }
                        return resolved
                    }
                    var proxyHandler = {
                        "get": function(stubs, prop) {
                            switch (prop) {
                                case "__memory_base":
                                    return memoryBase;
                                case "__table_base":
                                    return tableBase
                            }
                            if (prop in asmLibraryArg) {
                                return asmLibraryArg[prop]
                            }
                            if (!(prop in stubs)) {
                                var resolved;
                                stubs[prop] = function() {
                                    if (!resolved) resolved = resolveSymbol(prop, true);
                                    return resolved.apply(null, arguments)
                                }
                            }
                            return stubs[prop]
                        }
                    };
                    var proxy = new Proxy({}, proxyHandler);
                    var info = {
                        "GOT.mem": new Proxy({}, GOTHandler),
                        "GOT.func": new Proxy({}, GOTHandler),
                        "env": proxy,
                        wasi_snapshot_preview1: proxy
                    };

                    function postInstantiation(instance) {
                        for (var i = 0; i < metadata.tableSize; i++) {
                            var item = wasmTable.get(tableBase + i);
                            if (item) {
                                functionsInTableMap.set(item, tableBase + i)
                            }
                        }
                        moduleExports = relocateExports(instance.exports, memoryBase);
                        if (!flags.allowUndefined) {
                            reportUndefinedSymbols()
                        }
                        var init = moduleExports["__wasm_call_ctors"];
                        if (!init) {
                            init = moduleExports["__post_instantiate"]
                        }
                        if (init) {
                            if (runtimeInitialized) {
                                init()
                            } else {
                                __ATINIT__.push(init)
                            }
                        }
                        return moduleExports
                    }
                    if (flags.loadAsync) {
                        if (binary instanceof WebAssembly.Module) {
                            var instance = new WebAssembly.Instance(binary, info);
                            return Promise.resolve(postInstantiation(instance))
                        }
                        return WebAssembly.instantiate(binary, info).then(function(result) {
                            return postInstantiation(result.instance)
                        })
                    }
                    var module = binary instanceof WebAssembly.Module ? binary : new WebAssembly.Module(binary);
                    var instance = new WebAssembly.Instance(module, info);
                    return postInstantiation(instance)
                }
                if (flags.loadAsync) {
                    return metadata.neededDynlibs.reduce(function(chain, dynNeeded) {
                        return chain.then(function() {
                            return loadDynamicLibrary(dynNeeded, flags)
                        })
                    }, Promise.resolve()).then(function() {
                        return loadModule()
                    })
                }
                metadata.neededDynlibs.forEach(function(dynNeeded) {
                    loadDynamicLibrary(dynNeeded, flags)
                });
                return loadModule()
            }
            Module["loadWebAssemblyModule"] = loadWebAssemblyModule;

            function fetchBinary(url) {
                return fetch(url, {
                    credentials: "same-origin"
                }).then(function(response) {
                    if (!response["ok"]) {
                        throw "failed to load binary file at '" + url + "'"
                    }
                    return response["arrayBuffer"]()
                }).then(function(buffer) {
                    return new Uint8Array(buffer)
                })
            }
            Module["fetchBinary"] = fetchBinary;

            function loadDynamicLibrary(lib, flags) {
                if (lib == "__main__" && !LDSO.loadedLibNames[lib]) {
                    LDSO.loadedLibs[-1] = {
                        refcount: Infinity,
                        name: "__main__",
                        module: Module["asm"],
                        global: true
                    };
                    LDSO.loadedLibNames["__main__"] = -1
                }
                flags = flags || {
                    global: true,
                    nodelete: true
                };
                var handle = LDSO.loadedLibNames[lib];
                var dso;
                if (handle) {
                    dso = LDSO.loadedLibs[handle];
                    if (flags.global && !dso.global) {
                        dso.global = true;
                        if (dso.module !== "loading") {
                            mergeLibSymbols(dso.module, lib)
                        }
                    }
                    if (flags.nodelete && dso.refcount !== Infinity) {
                        dso.refcount = Infinity
                    }
                    dso.refcount++;
                    return flags.loadAsync ? Promise.resolve(handle) : handle
                }
                handle = LDSO.nextHandle++;
                dso = {
                    refcount: flags.nodelete ? Infinity : 1,
                    name: lib,
                    module: "loading",
                    global: flags.global
                };
                LDSO.loadedLibNames[lib] = handle;
                LDSO.loadedLibs[handle] = dso;

                function loadLibData(libFile) {
                    if (flags.fs) {
                        var libData = flags.fs.readFile(libFile, {
                            encoding: "binary"
                        });
                        if (!(libData instanceof Uint8Array)) {
                            libData = new Uint8Array(libData)
                        }
                        return flags.loadAsync ? Promise.resolve(libData) : libData
                    }
                    if (flags.loadAsync) {
                        return fetchBinary(libFile)
                    }
                    return readBinary(libFile)
                }

                function getLibModule() {
                    if (Module["preloadedWasm"] !== undefined && Module["preloadedWasm"][lib] !== undefined) {
                        var libModule = Module["preloadedWasm"][lib];
                        return flags.loadAsync ? Promise.resolve(libModule) : libModule
                    }
                    if (flags.loadAsync) {
                        return loadLibData(lib).then(function(libData) {
                            return loadWebAssemblyModule(libData, flags)
                        })
                    }
                    return loadWebAssemblyModule(loadLibData(lib), flags)
                }

                function moduleLoaded(libModule) {
                    if (dso.global) {
                        mergeLibSymbols(libModule, lib)
                    }
                    dso.module = libModule
                }
                if (flags.loadAsync) {
                    return getLibModule().then(function(libModule) {
                        moduleLoaded(libModule);
                        return handle
                    })
                }
                moduleLoaded(getLibModule());
                return handle
            }
            Module["loadDynamicLibrary"] = loadDynamicLibrary;

            function reportUndefinedSymbols() {
                for (var symName in GOT) {
                    if (GOT[symName].value == 0) {
                        var value = resolveGlobalSymbol(symName, true);
                        if (typeof value === "function") {
                            GOT[symName].value = addFunctionWasm(value, value.sig)
                        } else if (typeof value === "number") {
                            GOT[symName].value = value
                        } else {
                            assert(false, "bad export type for `" + symName + "`: " + typeof value)
                        }
                    }
                }
            }
            Module["reportUndefinedSymbols"] = reportUndefinedSymbols;

            function preloadDylibs() {
                if (!dynamicLibraries.length) {
                    reportUndefinedSymbols();
                    return
                }
                if (!readBinary) {
                    addRunDependency("preloadDylibs");
                    dynamicLibraries.reduce(function(chain, lib) {
                        return chain.then(function() {
                            return loadDynamicLibrary(lib, {
                                loadAsync: true,
                                global: true,
                                nodelete: true,
                                allowUndefined: true
                            })
                        })
                    }, Promise.resolve()).then(function() {
                        removeRunDependency("preloadDylibs");
                        reportUndefinedSymbols()
                    });
                    return
                }
                dynamicLibraries.forEach(function(lib) {
                    loadDynamicLibrary(lib, {
                        global: true,
                        nodelete: true,
                        allowUndefined: true
                    })
                });
                reportUndefinedSymbols()
            }
            Module["preloadDylibs"] = preloadDylibs;

            function stackTrace() {
                var js = jsStackTrace();
                if (Module["extraStackTrace"]) js += "\n" + Module["extraStackTrace"]();
                return demangleAll(js)
            }
            Module["stackTrace"] = stackTrace;

            function _tzset() {
                if (_tzset.called) return;
                _tzset.called = true;
                var currentYear = (new Date).getFullYear();
                var winter = new Date(currentYear, 0, 1);
                var summer = new Date(currentYear, 6, 1);
                var winterOffset = winter.getTimezoneOffset();
                var summerOffset = summer.getTimezoneOffset();
                var stdTimezoneOffset = Math.max(winterOffset, summerOffset);
                HEAP32[__get_timezone() >> 2] = stdTimezoneOffset * 60;
                HEAP32[__get_daylight() >> 2] = Number(winterOffset != summerOffset);

                function extractZone(date) {
                    var match = date.toTimeString().match(/\(([A-Za-z ]+)\)$/);
                    return match ? match[1] : "GMT"
                }
                var winterName = extractZone(winter);
                var summerName = extractZone(summer);
                var winterNamePtr = allocateUTF8(winterName);
                var summerNamePtr = allocateUTF8(summerName);
                if (summerOffset < winterOffset) {
                    HEAP32[__get_tzname() >> 2] = winterNamePtr;
                    HEAP32[__get_tzname() + 4 >> 2] = summerNamePtr
                } else {
                    HEAP32[__get_tzname() >> 2] = summerNamePtr;
                    HEAP32[__get_tzname() + 4 >> 2] = winterNamePtr
                }
            }
            Module["_tzset"] = _tzset;
            _tzset.sig = "v";

            function _mktime(tmPtr) {
                _tzset();
                var date = new Date(HEAP32[tmPtr + 20 >> 2] + 1900, HEAP32[tmPtr + 16 >> 2], HEAP32[tmPtr + 12 >> 2], HEAP32[tmPtr + 8 >> 2], HEAP32[tmPtr + 4 >> 2], HEAP32[tmPtr >> 2], 0);
                var dst = HEAP32[tmPtr + 32 >> 2];
                var guessedOffset = date.getTimezoneOffset();
                var start = new Date(date.getFullYear(), 0, 1);
                var summerOffset = new Date(date.getFullYear(), 6, 1).getTimezoneOffset();
                var winterOffset = start.getTimezoneOffset();
                var dstOffset = Math.min(winterOffset, summerOffset);
                if (dst < 0) {
                    HEAP32[tmPtr + 32 >> 2] = Number(summerOffset != winterOffset && dstOffset == guessedOffset)
                } else if (dst > 0 != (dstOffset == guessedOffset)) {
                    var nonDstOffset = Math.max(winterOffset, summerOffset);
                    var trueOffset = dst > 0 ? dstOffset : nonDstOffset;
                    date.setTime(date.getTime() + (trueOffset - guessedOffset) * 6e4)
                }
                HEAP32[tmPtr + 24 >> 2] = date.getDay();
                var yday = (date.getTime() - start.getTime()) / (1e3 * 60 * 60 * 24) | 0;
                HEAP32[tmPtr + 28 >> 2] = yday;
                HEAP32[tmPtr >> 2] = date.getSeconds();
                HEAP32[tmPtr + 4 >> 2] = date.getMinutes();
                HEAP32[tmPtr + 8 >> 2] = date.getHours();
                HEAP32[tmPtr + 12 >> 2] = date.getDate();
                HEAP32[tmPtr + 16 >> 2] = date.getMonth();
                return date.getTime() / 1e3 | 0
            }
            Module["_mktime"] = _mktime;
            _mktime.sig = "ii";

            function ___asctime(tmPtr, buf) {
                var date = {
                    tm_sec: HEAP32[tmPtr >> 2],
                    tm_min: HEAP32[tmPtr + 4 >> 2],
                    tm_hour: HEAP32[tmPtr + 8 >> 2],
                    tm_mday: HEAP32[tmPtr + 12 >> 2],
                    tm_mon: HEAP32[tmPtr + 16 >> 2],
                    tm_year: HEAP32[tmPtr + 20 >> 2],
                    tm_wday: HEAP32[tmPtr + 24 >> 2]
                };
                var days = ["Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"];
                var months = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"];
                var s = days[date.tm_wday] + " " + months[date.tm_mon] + (date.tm_mday < 10 ? "  " : " ") + date.tm_mday + (date.tm_hour < 10 ? " 0" : " ") + date.tm_hour + (date.tm_min < 10 ? ":0" : ":") + date.tm_min + (date.tm_sec < 10 ? ":0" : ":") + date.tm_sec + " " + (1900 + date.tm_year) + "\n";
                stringToUTF8(s, buf, 26);
                return buf
            }
            Module["___asctime"] = ___asctime;
            ___asctime.sig = "iii";
            var _emscripten_get_now;
            if (ENVIRONMENT_IS_NODE) {
                _emscripten_get_now = function() {
                    var t = process["hrtime"]();
                    return t[0] * 1e3 + t[1] / 1e6
                }
            } else if (typeof dateNow !== "undefined") {
                _emscripten_get_now = dateNow
            } else _emscripten_get_now = function() {
                return performance.now()
            };
            Module["_emscripten_get_now"] = _emscripten_get_now;
            var _emscripten_get_now_is_monotonic = true;
            Module["_emscripten_get_now_is_monotonic"] = _emscripten_get_now_is_monotonic;

            function setErrNo(value) {
                HEAP32[___errno_location() >> 2] = value;
                return value
            }
            Module["setErrNo"] = setErrNo;

            function _clock_gettime(clk_id, tp) {
                var now;
                if (clk_id === 0) {
                    now = Date.now()
                } else if ((clk_id === 1 || clk_id === 4) && _emscripten_get_now_is_monotonic) {
                    now = _emscripten_get_now()
                } else {
                    setErrNo(28);
                    return -1
                }
                HEAP32[tp >> 2] = now / 1e3 | 0;
                HEAP32[tp + 4 >> 2] = now % 1e3 * 1e3 * 1e3 | 0;
                return 0
            }
            Module["_clock_gettime"] = _clock_gettime;
            _clock_gettime.sig = "iii";

            function ___clock_gettime(a0, a1) {
                return _clock_gettime(a0, a1)
            }
            Module["___clock_gettime"] = ___clock_gettime;
            ___clock_gettime.sig = "iii";

            function _atexit(func, arg) {}
            Module["_atexit"] = _atexit;
            _atexit.sig = "iii";

            function ___cxa_atexit(a0, a1) {
                return _atexit(a0, a1)
            }
            Module["___cxa_atexit"] = ___cxa_atexit;
            ___cxa_atexit.sig = "iii";

            function _gmtime_r(time, tmPtr) {
                var date = new Date(HEAP32[time >> 2] * 1e3);
                HEAP32[tmPtr >> 2] = date.getUTCSeconds();
                HEAP32[tmPtr + 4 >> 2] = date.getUTCMinutes();
                HEAP32[tmPtr + 8 >> 2] = date.getUTCHours();
                HEAP32[tmPtr + 12 >> 2] = date.getUTCDate();
                HEAP32[tmPtr + 16 >> 2] = date.getUTCMonth();
                HEAP32[tmPtr + 20 >> 2] = date.getUTCFullYear() - 1900;
                HEAP32[tmPtr + 24 >> 2] = date.getUTCDay();
                HEAP32[tmPtr + 36 >> 2] = 0;
                HEAP32[tmPtr + 32 >> 2] = 0;
                var start = Date.UTC(date.getUTCFullYear(), 0, 1, 0, 0, 0, 0);
                var yday = (date.getTime() - start) / (1e3 * 60 * 60 * 24) | 0;
                HEAP32[tmPtr + 28 >> 2] = yday;
                if (!_gmtime_r.GMTString) _gmtime_r.GMTString = allocateUTF8("GMT");
                HEAP32[tmPtr + 40 >> 2] = _gmtime_r.GMTString;
                return tmPtr
            }
            Module["_gmtime_r"] = _gmtime_r;
            _gmtime_r.sig = "iii";

            function ___gmtime_r(a0, a1) {
                return _gmtime_r(a0, a1)
            }
            Module["___gmtime_r"] = ___gmtime_r;
            ___gmtime_r.sig = "iii";

            function _localtime_r(time, tmPtr) {
                _tzset();
                var date = new Date(HEAP32[time >> 2] * 1e3);
                HEAP32[tmPtr >> 2] = date.getSeconds();
                HEAP32[tmPtr + 4 >> 2] = date.getMinutes();
                HEAP32[tmPtr + 8 >> 2] = date.getHours();
                HEAP32[tmPtr + 12 >> 2] = date.getDate();
                HEAP32[tmPtr + 16 >> 2] = date.getMonth();
                HEAP32[tmPtr + 20 >> 2] = date.getFullYear() - 1900;
                HEAP32[tmPtr + 24 >> 2] = date.getDay();
                var start = new Date(date.getFullYear(), 0, 1);
                var yday = (date.getTime() - start.getTime()) / (1e3 * 60 * 60 * 24) | 0;
                HEAP32[tmPtr + 28 >> 2] = yday;
                HEAP32[tmPtr + 36 >> 2] = -(date.getTimezoneOffset() * 60);
                var summerOffset = new Date(date.getFullYear(), 6, 1).getTimezoneOffset();
                var winterOffset = start.getTimezoneOffset();
                var dst = (summerOffset != winterOffset && date.getTimezoneOffset() == Math.min(winterOffset, summerOffset)) | 0;
                HEAP32[tmPtr + 32 >> 2] = dst;
                var zonePtr = HEAP32[__get_tzname() + (dst ? 4 : 0) >> 2];
                HEAP32[tmPtr + 40 >> 2] = zonePtr;
                return tmPtr
            }
            Module["_localtime_r"] = _localtime_r;
            _localtime_r.sig = "iii";

            function ___localtime_r(a0, a1) {
                return _localtime_r(a0, a1)
            }
            Module["___localtime_r"] = ___localtime_r;
            ___localtime_r.sig = "iii";

            function ___map_file(pathname, size) {
                setErrNo(63);
                return -1
            }
            Module["___map_file"] = ___map_file;
            var ___stack_pointer = new WebAssembly.Global({
                "value": "i32",
                "mutable": true
            }, 5529680);
            Module["___stack_pointer"] = ___stack_pointer;
            var PATH = {
                splitPath: function(filename) {
                    var splitPathRe = /^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/;
                    return splitPathRe.exec(filename).slice(1)
                },
                normalizeArray: function(parts, allowAboveRoot) {
                    var up = 0;
                    for (var i = parts.length - 1; i >= 0; i--) {
                        var last = parts[i];
                        if (last === ".") {
                            parts.splice(i, 1)
                        } else if (last === "..") {
                            parts.splice(i, 1);
                            up++
                        } else if (up) {
                            parts.splice(i, 1);
                            up--
                        }
                    }
                    if (allowAboveRoot) {
                        for (; up; up--) {
                            parts.unshift("..")
                        }
                    }
                    return parts
                },
                normalize: function(path) {
                    var isAbsolute = path.charAt(0) === "/",
                        trailingSlash = path.substr(-1) === "/";
                    path = PATH.normalizeArray(path.split("/").filter(function(p) {
                        return !!p
                    }), !isAbsolute).join("/");
                    if (!path && !isAbsolute) {
                        path = "."
                    }
                    if (path && trailingSlash) {
                        path += "/"
                    }
                    return (isAbsolute ? "/" : "") + path
                },
                dirname: function(path) {
                    var result = PATH.splitPath(path),
                        root = result[0],
                        dir = result[1];
                    if (!root && !dir) {
                        return "."
                    }
                    if (dir) {
                        dir = dir.substr(0, dir.length - 1)
                    }
                    return root + dir
                },
                basename: function(path) {
                    if (path === "/") return "/";
                    path = PATH.normalize(path);
                    path = path.replace(/\/$/, "");
                    var lastSlash = path.lastIndexOf("/");
                    if (lastSlash === -1) return path;
                    return path.substr(lastSlash + 1)
                },
                extname: function(path) {
                    return PATH.splitPath(path)[3]
                },
                join: function() {
                    var paths = Array.prototype.slice.call(arguments, 0);
                    return PATH.normalize(paths.join("/"))
                },
                join2: function(l, r) {
                    return PATH.normalize(l + "/" + r)
                }
            };
            Module["PATH"] = PATH;

            function getRandomDevice() {
                if (typeof crypto === "object" && typeof crypto["getRandomValues"] === "function") {
                    var randomBuffer = new Uint8Array(1);
                    return function() {
                        crypto.getRandomValues(randomBuffer);
                        return randomBuffer[0]
                    }
                } else if (ENVIRONMENT_IS_NODE) {
                    try {
                        var crypto_module = require("crypto");
                        return function() {
                            return crypto_module["randomBytes"](1)[0]
                        }
                    } catch (e) {}
                }
                return function() {
                    abort("randomDevice")
                }
            }
            Module["getRandomDevice"] = getRandomDevice;
            var PATH_FS = {
                resolve: function() {
                    var resolvedPath = "",
                        resolvedAbsolute = false;
                    for (var i = arguments.length - 1; i >= -1 && !resolvedAbsolute; i--) {
                        var path = i >= 0 ? arguments[i] : FS.cwd();
                        if (typeof path !== "string") {
                            throw new TypeError("Arguments to path.resolve must be strings")
                        } else if (!path) {
                            return ""
                        }
                        resolvedPath = path + "/" + resolvedPath;
                        resolvedAbsolute = path.charAt(0) === "/"
                    }
                    resolvedPath = PATH.normalizeArray(resolvedPath.split("/").filter(function(p) {
                        return !!p
                    }), !resolvedAbsolute).join("/");
                    return (resolvedAbsolute ? "/" : "") + resolvedPath || "."
                },
                relative: function(from, to) {
                    from = PATH_FS.resolve(from).substr(1);
                    to = PATH_FS.resolve(to).substr(1);

                    function trim(arr) {
                        var start = 0;
                        for (; start < arr.length; start++) {
                            if (arr[start] !== "") break
                        }
                        var end = arr.length - 1;
                        for (; end >= 0; end--) {
                            if (arr[end] !== "") break
                        }
                        if (start > end) return [];
                        return arr.slice(start, end - start + 1)
                    }
                    var fromParts = trim(from.split("/"));
                    var toParts = trim(to.split("/"));
                    var length = Math.min(fromParts.length, toParts.length);
                    var samePartsLength = length;
                    for (var i = 0; i < length; i++) {
                        if (fromParts[i] !== toParts[i]) {
                            samePartsLength = i;
                            break
                        }
                    }
                    var outputParts = [];
                    for (var i = samePartsLength; i < fromParts.length; i++) {
                        outputParts.push("..")
                    }
                    outputParts = outputParts.concat(toParts.slice(samePartsLength));
                    return outputParts.join("/")
                }
            };
            Module["PATH_FS"] = PATH_FS;
            var TTY = {
                ttys: [],
                init: function() {},
                shutdown: function() {},
                register: function(dev, ops) {
                    TTY.ttys[dev] = {
                        input: [],
                        output: [],
                        ops: ops
                    };
                    FS.registerDevice(dev, TTY.stream_ops)
                },
                stream_ops: {
                    open: function(stream) {
                        var tty = TTY.ttys[stream.node.rdev];
                        if (!tty) {
                            throw new FS.ErrnoError(43)
                        }
                        stream.tty = tty;
                        stream.seekable = false
                    },
                    close: function(stream) {
                        stream.tty.ops.flush(stream.tty)
                    },
                    flush: function(stream) {
                        stream.tty.ops.flush(stream.tty)
                    },
                    read: function(stream, buffer, offset, length, pos) {
                        if (!stream.tty || !stream.tty.ops.get_char) {
                            throw new FS.ErrnoError(60)
                        }
                        var bytesRead = 0;
                        for (var i = 0; i < length; i++) {
                            var result;
                            try {
                                result = stream.tty.ops.get_char(stream.tty)
                            } catch (e) {
                                throw new FS.ErrnoError(29)
                            }
                            if (result === undefined && bytesRead === 0) {
                                throw new FS.ErrnoError(6)
                            }
                            if (result === null || result === undefined) break;
                            bytesRead++;
                            buffer[offset + i] = result
                        }
                        if (bytesRead) {
                            stream.node.timestamp = Date.now()
                        }
                        return bytesRead
                    },
                    write: function(stream, buffer, offset, length, pos) {
                        if (!stream.tty || !stream.tty.ops.put_char) {
                            throw new FS.ErrnoError(60)
                        }
                        try {
                            for (var i = 0; i < length; i++) {
                                stream.tty.ops.put_char(stream.tty, buffer[offset + i])
                            }
                        } catch (e) {
                            throw new FS.ErrnoError(29)
                        }
                        if (length) {
                            stream.node.timestamp = Date.now()
                        }
                        return i
                    }
                },
                default_tty_ops: {
                    get_char: function(tty) {
                        if (!tty.input.length) {
                            var result = null;
                            if (ENVIRONMENT_IS_NODE) {
                                var BUFSIZE = 256;
                                var buf = Buffer.alloc ? Buffer.alloc(BUFSIZE) : new Buffer(BUFSIZE);
                                var bytesRead = 0;
                                try {
                                    bytesRead = nodeFS.readSync(process.stdin.fd, buf, 0, BUFSIZE, null)
                                } catch (e) {
                                    if (e.toString().includes("EOF")) bytesRead = 0;
                                    else throw e
                                }
                                if (bytesRead > 0) {
                                    result = buf.slice(0, bytesRead).toString("utf-8")
                                } else {
                                    result = null
                                }
                            } else if (typeof window != "undefined" && typeof window.prompt == "function") {
                                result = window.prompt("Input: ");
                                if (result !== null) {
                                    result += "\n"
                                }
                            } else if (typeof readline == "function") {
                                result = readline();
                                if (result !== null) {
                                    result += "\n"
                                }
                            }
                            if (!result) {
                                return null
                            }
                            tty.input = intArrayFromString(result, true)
                        }
                        return tty.input.shift()
                    },
                    put_char: function(tty, val) {
                        if (val === null || val === 10) {
                            out(UTF8ArrayToString(tty.output, 0));
                            tty.output = []
                        } else {
                            if (val != 0) tty.output.push(val)
                        }
                    },
                    flush: function(tty) {
                        if (tty.output && tty.output.length > 0) {
                            out(UTF8ArrayToString(tty.output, 0));
                            tty.output = []
                        }
                    }
                },
                default_tty1_ops: {
                    put_char: function(tty, val) {
                        if (val === null || val === 10) {
                            err(UTF8ArrayToString(tty.output, 0));
                            tty.output = []
                        } else {
                            if (val != 0) tty.output.push(val)
                        }
                    },
                    flush: function(tty) {
                        if (tty.output && tty.output.length > 0) {
                            err(UTF8ArrayToString(tty.output, 0));
                            tty.output = []
                        }
                    }
                }
            };
            Module["TTY"] = TTY;

            function mmapAlloc(size) {
                var alignedSize = alignMemory(size, 65536);
                var ptr = _malloc(alignedSize);
                while (size < alignedSize) HEAP8[ptr + size++] = 0;
                return ptr
            }
            Module["mmapAlloc"] = mmapAlloc;
            var MEMFS = {
                ops_table: null,
                mount: function(mount) {
                    return MEMFS.createNode(null, "/", 16384 | 511, 0)
                },
                createNode: function(parent, name, mode, dev) {
                    if (FS.isBlkdev(mode) || FS.isFIFO(mode)) {
                        throw new FS.ErrnoError(63)
                    }
                    if (!MEMFS.ops_table) {
                        MEMFS.ops_table = {
                            dir: {
                                node: {
                                    getattr: MEMFS.node_ops.getattr,
                                    setattr: MEMFS.node_ops.setattr,
                                    lookup: MEMFS.node_ops.lookup,
                                    mknod: MEMFS.node_ops.mknod,
                                    rename: MEMFS.node_ops.rename,
                                    unlink: MEMFS.node_ops.unlink,
                                    rmdir: MEMFS.node_ops.rmdir,
                                    readdir: MEMFS.node_ops.readdir,
                                    symlink: MEMFS.node_ops.symlink
                                },
                                stream: {
                                    llseek: MEMFS.stream_ops.llseek
                                }
                            },
                            file: {
                                node: {
                                    getattr: MEMFS.node_ops.getattr,
                                    setattr: MEMFS.node_ops.setattr
                                },
                                stream: {
                                    llseek: MEMFS.stream_ops.llseek,
                                    read: MEMFS.stream_ops.read,
                                    write: MEMFS.stream_ops.write,
                                    allocate: MEMFS.stream_ops.allocate,
                                    mmap: MEMFS.stream_ops.mmap,
                                    msync: MEMFS.stream_ops.msync
                                }
                            },
                            link: {
                                node: {
                                    getattr: MEMFS.node_ops.getattr,
                                    setattr: MEMFS.node_ops.setattr,
                                    readlink: MEMFS.node_ops.readlink
                                },
                                stream: {}
                            },
                            chrdev: {
                                node: {
                                    getattr: MEMFS.node_ops.getattr,
                                    setattr: MEMFS.node_ops.setattr
                                },
                                stream: FS.chrdev_stream_ops
                            }
                        }
                    }
                    var node = FS.createNode(parent, name, mode, dev);
                    if (FS.isDir(node.mode)) {
                        node.node_ops = MEMFS.ops_table.dir.node;
                        node.stream_ops = MEMFS.ops_table.dir.stream;
                        node.contents = {}
                    } else if (FS.isFile(node.mode)) {
                        node.node_ops = MEMFS.ops_table.file.node;
                        node.stream_ops = MEMFS.ops_table.file.stream;
                        node.usedBytes = 0;
                        node.contents = null
                    } else if (FS.isLink(node.mode)) {
                        node.node_ops = MEMFS.ops_table.link.node;
                        node.stream_ops = MEMFS.ops_table.link.stream
                    } else if (FS.isChrdev(node.mode)) {
                        node.node_ops = MEMFS.ops_table.chrdev.node;
                        node.stream_ops = MEMFS.ops_table.chrdev.stream
                    }
                    node.timestamp = Date.now();
                    if (parent) {
                        parent.contents[name] = node;
                        parent.timestamp = node.timestamp
                    }
                    return node
                },
                getFileDataAsTypedArray: function(node) {
                    if (!node.contents) return new Uint8Array(0);
                    if (node.contents.subarray) return node.contents.subarray(0, node.usedBytes);
                    return new Uint8Array(node.contents)
                },
                expandFileStorage: function(node, newCapacity) {
                    var prevCapacity = node.contents ? node.contents.length : 0;
                    if (prevCapacity >= newCapacity) return;
                    var CAPACITY_DOUBLING_MAX = 1024 * 1024;
                    newCapacity = Math.max(newCapacity, prevCapacity * (prevCapacity < CAPACITY_DOUBLING_MAX ? 2 : 1.125) >>> 0);
                    if (prevCapacity != 0) newCapacity = Math.max(newCapacity, 256);
                    var oldContents = node.contents;
                    node.contents = new Uint8Array(newCapacity);
                    if (node.usedBytes > 0) node.contents.set(oldContents.subarray(0, node.usedBytes), 0)
                },
                resizeFileStorage: function(node, newSize) {
                    if (node.usedBytes == newSize) return;
                    if (newSize == 0) {
                        node.contents = null;
                        node.usedBytes = 0
                    } else {
                        var oldContents = node.contents;
                        node.contents = new Uint8Array(newSize);
                        if (oldContents) {
                            node.contents.set(oldContents.subarray(0, Math.min(newSize, node.usedBytes)))
                        }
                        node.usedBytes = newSize
                    }
                },
                node_ops: {
                    getattr: function(node) {
                        var attr = {};
                        attr.dev = FS.isChrdev(node.mode) ? node.id : 1;
                        attr.ino = node.id;
                        attr.mode = node.mode;
                        attr.nlink = 1;
                        attr.uid = 0;
                        attr.gid = 0;
                        attr.rdev = node.rdev;
                        if (FS.isDir(node.mode)) {
                            attr.size = 4096
                        } else if (FS.isFile(node.mode)) {
                            attr.size = node.usedBytes
                        } else if (FS.isLink(node.mode)) {
                            attr.size = node.link.length
                        } else {
                            attr.size = 0
                        }
                        attr.atime = new Date(node.timestamp);
                        attr.mtime = new Date(node.timestamp);
                        attr.ctime = new Date(node.timestamp);
                        attr.blksize = 4096;
                        attr.blocks = Math.ceil(attr.size / attr.blksize);
                        return attr
                    },
                    setattr: function(node, attr) {
                        if (attr.mode !== undefined) {
                            node.mode = attr.mode
                        }
                        if (attr.timestamp !== undefined) {
                            node.timestamp = attr.timestamp
                        }
                        if (attr.size !== undefined) {
                            MEMFS.resizeFileStorage(node, attr.size)
                        }
                    },
                    lookup: function(parent, name) {
                        throw FS.genericErrors[44]
                    },
                    mknod: function(parent, name, mode, dev) {
                        return MEMFS.createNode(parent, name, mode, dev)
                    },
                    rename: function(old_node, new_dir, new_name) {
                        if (FS.isDir(old_node.mode)) {
                            var new_node;
                            try {
                                new_node = FS.lookupNode(new_dir, new_name)
                            } catch (e) {}
                            if (new_node) {
                                for (var i in new_node.contents) {
                                    throw new FS.ErrnoError(55)
                                }
                            }
                        }
                        delete old_node.parent.contents[old_node.name];
                        old_node.parent.timestamp = Date.now();
                        old_node.name = new_name;
                        new_dir.contents[new_name] = old_node;
                        new_dir.timestamp = old_node.parent.timestamp;
                        old_node.parent = new_dir
                    },
                    unlink: function(parent, name) {
                        delete parent.contents[name];
                        parent.timestamp = Date.now()
                    },
                    rmdir: function(parent, name) {
                        var node = FS.lookupNode(parent, name);
                        for (var i in node.contents) {
                            throw new FS.ErrnoError(55)
                        }
                        delete parent.contents[name];
                        parent.timestamp = Date.now()
                    },
                    readdir: function(node) {
                        var entries = [".", ".."];
                        for (var key in node.contents) {
                            if (!node.contents.hasOwnProperty(key)) {
                                continue
                            }
                            entries.push(key)
                        }
                        return entries
                    },
                    symlink: function(parent, newname, oldpath) {
                        var node = MEMFS.createNode(parent, newname, 511 | 40960, 0);
                        node.link = oldpath;
                        return node
                    },
                    readlink: function(node) {
                        if (!FS.isLink(node.mode)) {
                            throw new FS.ErrnoError(28)
                        }
                        return node.link
                    }
                },
                stream_ops: {
                    read: function(stream, buffer, offset, length, position) {
                        var contents = stream.node.contents;
                        if (position >= stream.node.usedBytes) return 0;
                        var size = Math.min(stream.node.usedBytes - position, length);
                        if (size > 8 && contents.subarray) {
                            buffer.set(contents.subarray(position, position + size), offset)
                        } else {
                            for (var i = 0; i < size; i++) buffer[offset + i] = contents[position + i]
                        }
                        return size
                    },
                    write: function(stream, buffer, offset, length, position, canOwn) {
                        if (!length) return 0;
                        var node = stream.node;
                        node.timestamp = Date.now();
                        if (buffer.subarray && (!node.contents || node.contents.subarray)) {
                            if (canOwn) {
                                node.contents = buffer.subarray(offset, offset + length);
                                node.usedBytes = length;
                                return length
                            } else if (node.usedBytes === 0 && position === 0) {
                                node.contents = buffer.slice(offset, offset + length);
                                node.usedBytes = length;
                                return length
                            } else if (position + length <= node.usedBytes) {
                                node.contents.set(buffer.subarray(offset, offset + length), position);
                                return length
                            }
                        }
                        MEMFS.expandFileStorage(node, position + length);
                        if (node.contents.subarray && buffer.subarray) {
                            node.contents.set(buffer.subarray(offset, offset + length), position)
                        } else {
                            for (var i = 0; i < length; i++) {
                                node.contents[position + i] = buffer[offset + i]
                            }
                        }
                        node.usedBytes = Math.max(node.usedBytes, position + length);
                        return length
                    },
                    llseek: function(stream, offset, whence) {
                        var position = offset;
                        if (whence === 1) {
                            position += stream.position
                        } else if (whence === 2) {
                            if (FS.isFile(stream.node.mode)) {
                                position += stream.node.usedBytes
                            }
                        }
                        if (position < 0) {
                            throw new FS.ErrnoError(28)
                        }
                        return position
                    },
                    allocate: function(stream, offset, length) {
                        MEMFS.expandFileStorage(stream.node, offset + length);
                        stream.node.usedBytes = Math.max(stream.node.usedBytes, offset + length)
                    },
                    mmap: function(stream, address, length, position, prot, flags) {
                        if (address !== 0) {
                            throw new FS.ErrnoError(28)
                        }
                        if (!FS.isFile(stream.node.mode)) {
                            throw new FS.ErrnoError(43)
                        }
                        var ptr;
                        var allocated;
                        var contents = stream.node.contents;
                        if (!(flags & 2) && contents.buffer === buffer) {
                            allocated = false;
                            ptr = contents.byteOffset
                        } else {
                            if (position > 0 || position + length < contents.length) {
                                if (contents.subarray) {
                                    contents = contents.subarray(position, position + length)
                                } else {
                                    contents = Array.prototype.slice.call(contents, position, position + length)
                                }
                            }
                            allocated = true;
                            ptr = mmapAlloc(length);
                            if (!ptr) {
                                throw new FS.ErrnoError(48)
                            }
                            HEAP8.set(contents, ptr)
                        }
                        return {
                            ptr: ptr,
                            allocated: allocated
                        }
                    },
                    msync: function(stream, buffer, offset, length, mmapFlags) {
                        if (!FS.isFile(stream.node.mode)) {
                            throw new FS.ErrnoError(43)
                        }
                        if (mmapFlags & 2) {
                            return 0
                        }
                        var bytesWritten = MEMFS.stream_ops.write(stream, buffer, 0, length, offset, false);
                        return 0
                    }
                }
            };
            Module["MEMFS"] = MEMFS;
            var FS = {
                root: null,
                mounts: [],
                devices: {},
                streams: [],
                nextInode: 1,
                nameTable: null,
                currentPath: "/",
                initialized: false,
                ignorePermissions: true,
                trackingDelegate: {},
                tracking: {
                    openFlags: {
                        READ: 1,
                        WRITE: 2
                    }
                },
                ErrnoError: null,
                genericErrors: {},
                filesystems: null,
                syncFSRequests: 0,
                lookupPath: function(path, opts) {
                    path = PATH_FS.resolve(FS.cwd(), path);
                    opts = opts || {};
                    if (!path) return {
                        path: "",
                        node: null
                    };
                    var defaults = {
                        follow_mount: true,
                        recurse_count: 0
                    };
                    for (var key in defaults) {
                        if (opts[key] === undefined) {
                            opts[key] = defaults[key]
                        }
                    }
                    if (opts.recurse_count > 8) {
                        throw new FS.ErrnoError(32)
                    }
                    var parts = PATH.normalizeArray(path.split("/").filter(function(p) {
                        return !!p
                    }), false);
                    var current = FS.root;
                    var current_path = "/";
                    for (var i = 0; i < parts.length; i++) {
                        var islast = i === parts.length - 1;
                        if (islast && opts.parent) {
                            break
                        }
                        current = FS.lookupNode(current, parts[i]);
                        current_path = PATH.join2(current_path, parts[i]);
                        if (FS.isMountpoint(current)) {
                            if (!islast || islast && opts.follow_mount) {
                                current = current.mounted.root
                            }
                        }
                        if (!islast || opts.follow) {
                            var count = 0;
                            while (FS.isLink(current.mode)) {
                                var link = FS.readlink(current_path);
                                current_path = PATH_FS.resolve(PATH.dirname(current_path), link);
                                var lookup = FS.lookupPath(current_path, {
                                    recurse_count: opts.recurse_count
                                });
                                current = lookup.node;
                                if (count++ > 40) {
                                    throw new FS.ErrnoError(32)
                                }
                            }
                        }
                    }
                    return {
                        path: current_path,
                        node: current
                    }
                },
                getPath: function(node) {
                    var path;
                    while (true) {
                        if (FS.isRoot(node)) {
                            var mount = node.mount.mountpoint;
                            if (!path) return mount;
                            return mount[mount.length - 1] !== "/" ? mount + "/" + path : mount + path
                        }
                        path = path ? node.name + "/" + path : node.name;
                        node = node.parent
                    }
                },
                hashName: function(parentid, name) {
                    var hash = 0;
                    for (var i = 0; i < name.length; i++) {
                        hash = (hash << 5) - hash + name.charCodeAt(i) | 0
                    }
                    return (parentid + hash >>> 0) % FS.nameTable.length
                },
                hashAddNode: function(node) {
                    var hash = FS.hashName(node.parent.id, node.name);
                    node.name_next = FS.nameTable[hash];
                    FS.nameTable[hash] = node
                },
                hashRemoveNode: function(node) {
                    var hash = FS.hashName(node.parent.id, node.name);
                    if (FS.nameTable[hash] === node) {
                        FS.nameTable[hash] = node.name_next
                    } else {
                        var current = FS.nameTable[hash];
                        while (current) {
                            if (current.name_next === node) {
                                current.name_next = node.name_next;
                                break
                            }
                            current = current.name_next
                        }
                    }
                },
                lookupNode: function(parent, name) {
                    var errCode = FS.mayLookup(parent);
                    if (errCode) {
                        throw new FS.ErrnoError(errCode, parent)
                    }
                    var hash = FS.hashName(parent.id, name);
                    for (var node = FS.nameTable[hash]; node; node = node.name_next) {
                        var nodeName = node.name;
                        if (node.parent.id === parent.id && nodeName === name) {
                            return node
                        }
                    }
                    return FS.lookup(parent, name)
                },
                createNode: function(parent, name, mode, rdev) {
                    var node = new FS.FSNode(parent, name, mode, rdev);
                    FS.hashAddNode(node);
                    return node
                },
                destroyNode: function(node) {
                    FS.hashRemoveNode(node)
                },
                isRoot: function(node) {
                    return node === node.parent
                },
                isMountpoint: function(node) {
                    return !!node.mounted
                },
                isFile: function(mode) {
                    return (mode & 61440) === 32768
                },
                isDir: function(mode) {
                    return (mode & 61440) === 16384
                },
                isLink: function(mode) {
                    return (mode & 61440) === 40960
                },
                isChrdev: function(mode) {
                    return (mode & 61440) === 8192
                },
                isBlkdev: function(mode) {
                    return (mode & 61440) === 24576
                },
                isFIFO: function(mode) {
                    return (mode & 61440) === 4096
                },
                isSocket: function(mode) {
                    return (mode & 49152) === 49152
                },
                flagModes: {
                    "r": 0,
                    "r+": 2,
                    "w": 577,
                    "w+": 578,
                    "a": 1089,
                    "a+": 1090
                },
                modeStringToFlags: function(str) {
                    var flags = FS.flagModes[str];
                    if (typeof flags === "undefined") {
                        throw new Error("Unknown file open mode: " + str)
                    }
                    return flags
                },
                flagsToPermissionString: function(flag) {
                    var perms = ["r", "w", "rw"][flag & 3];
                    if (flag & 512) {
                        perms += "w"
                    }
                    return perms
                },
                nodePermissions: function(node, perms) {
                    if (FS.ignorePermissions) {
                        return 0
                    }
                    if (perms.includes("r") && !(node.mode & 292)) {
                        return 2
                    } else if (perms.includes("w") && !(node.mode & 146)) {
                        return 2
                    } else if (perms.includes("x") && !(node.mode & 73)) {
                        return 2
                    }
                    return 0
                },
                mayLookup: function(dir) {
                    var errCode = FS.nodePermissions(dir, "x");
                    if (errCode) return errCode;
                    if (!dir.node_ops.lookup) return 2;
                    return 0
                },
                mayCreate: function(dir, name) {
                    try {
                        var node = FS.lookupNode(dir, name);
                        return 20
                    } catch (e) {}
                    return FS.nodePermissions(dir, "wx")
                },
                mayDelete: function(dir, name, isdir) {
                    var node;
                    try {
                        node = FS.lookupNode(dir, name)
                    } catch (e) {
                        return e.errno
                    }
                    var errCode = FS.nodePermissions(dir, "wx");
                    if (errCode) {
                        return errCode
                    }
                    if (isdir) {
                        if (!FS.isDir(node.mode)) {
                            return 54
                        }
                        if (FS.isRoot(node) || FS.getPath(node) === FS.cwd()) {
                            return 10
                        }
                    } else {
                        if (FS.isDir(node.mode)) {
                            return 31
                        }
                    }
                    return 0
                },
                mayOpen: function(node, flags) {
                    if (!node) {
                        return 44
                    }
                    if (FS.isLink(node.mode)) {
                        return 32
                    } else if (FS.isDir(node.mode)) {
                        if (FS.flagsToPermissionString(flags) !== "r" || flags & 512) {
                            return 31
                        }
                    }
                    return FS.nodePermissions(node, FS.flagsToPermissionString(flags))
                },
                MAX_OPEN_FDS: 4096,
                nextfd: function(fd_start, fd_end) {
                    fd_start = fd_start || 0;
                    fd_end = fd_end || FS.MAX_OPEN_FDS;
                    for (var fd = fd_start; fd <= fd_end; fd++) {
                        if (!FS.streams[fd]) {
                            return fd
                        }
                    }
                    throw new FS.ErrnoError(33)
                },
                getStream: function(fd) {
                    return FS.streams[fd]
                },
                createStream: function(stream, fd_start, fd_end) {
                    if (!FS.FSStream) {
                        FS.FSStream = function() {};
                        FS.FSStream.prototype = {
                            object: {
                                get: function() {
                                    return this.node
                                },
                                set: function(val) {
                                    this.node = val
                                }
                            },
                            isRead: {
                                get: function() {
                                    return (this.flags & 2097155) !== 1
                                }
                            },
                            isWrite: {
                                get: function() {
                                    return (this.flags & 2097155) !== 0
                                }
                            },
                            isAppend: {
                                get: function() {
                                    return this.flags & 1024
                                }
                            }
                        }
                    }
                    var newStream = new FS.FSStream;
                    for (var p in stream) {
                        newStream[p] = stream[p]
                    }
                    stream = newStream;
                    var fd = FS.nextfd(fd_start, fd_end);
                    stream.fd = fd;
                    FS.streams[fd] = stream;
                    return stream
                },
                closeStream: function(fd) {
                    FS.streams[fd] = null
                },
                chrdev_stream_ops: {
                    open: function(stream) {
                        var device = FS.getDevice(stream.node.rdev);
                        stream.stream_ops = device.stream_ops;
                        if (stream.stream_ops.open) {
                            stream.stream_ops.open(stream)
                        }
                    },
                    llseek: function() {
                        throw new FS.ErrnoError(70)
                    }
                },
                major: function(dev) {
                    return dev >> 8
                },
                minor: function(dev) {
                    return dev & 255
                },
                makedev: function(ma, mi) {
                    return ma << 8 | mi
                },
                registerDevice: function(dev, ops) {
                    FS.devices[dev] = {
                        stream_ops: ops
                    }
                },
                getDevice: function(dev) {
                    return FS.devices[dev]
                },
                getMounts: function(mount) {
                    var mounts = [];
                    var check = [mount];
                    while (check.length) {
                        var m = check.pop();
                        mounts.push(m);
                        check.push.apply(check, m.mounts)
                    }
                    return mounts
                },
                syncfs: function(populate, callback) {
                    if (typeof populate === "function") {
                        callback = populate;
                        populate = false
                    }
                    FS.syncFSRequests++;
                    if (FS.syncFSRequests > 1) {
                        err("warning: " + FS.syncFSRequests + " FS.syncfs operations in flight at once, probably just doing extra work")
                    }
                    var mounts = FS.getMounts(FS.root.mount);
                    var completed = 0;

                    function doCallback(errCode) {
                        FS.syncFSRequests--;
                        return callback(errCode)
                    }

                    function done(errCode) {
                        if (errCode) {
                            if (!done.errored) {
                                done.errored = true;
                                return doCallback(errCode)
                            }
                            return
                        }
                        if (++completed >= mounts.length) {
                            doCallback(null)
                        }
                    }
                    mounts.forEach(function(mount) {
                        if (!mount.type.syncfs) {
                            return done(null)
                        }
                        mount.type.syncfs(mount, populate, done)
                    })
                },
                mount: function(type, opts, mountpoint) {
                    var root = mountpoint === "/";
                    var pseudo = !mountpoint;
                    var node;
                    if (root && FS.root) {
                        throw new FS.ErrnoError(10)
                    } else if (!root && !pseudo) {
                        var lookup = FS.lookupPath(mountpoint, {
                            follow_mount: false
                        });
                        mountpoint = lookup.path;
                        node = lookup.node;
                        if (FS.isMountpoint(node)) {
                            throw new FS.ErrnoError(10)
                        }
                        if (!FS.isDir(node.mode)) {
                            throw new FS.ErrnoError(54)
                        }
                    }
                    var mount = {
                        type: type,
                        opts: opts,
                        mountpoint: mountpoint,
                        mounts: []
                    };
                    var mountRoot = type.mount(mount);
                    mountRoot.mount = mount;
                    mount.root = mountRoot;
                    if (root) {
                        FS.root = mountRoot
                    } else if (node) {
                        node.mounted = mount;
                        if (node.mount) {
                            node.mount.mounts.push(mount)
                        }
                    }
                    return mountRoot
                },
                unmount: function(mountpoint) {
                    var lookup = FS.lookupPath(mountpoint, {
                        follow_mount: false
                    });
                    if (!FS.isMountpoint(lookup.node)) {
                        throw new FS.ErrnoError(28)
                    }
                    var node = lookup.node;
                    var mount = node.mounted;
                    var mounts = FS.getMounts(mount);
                    Object.keys(FS.nameTable).forEach(function(hash) {
                        var current = FS.nameTable[hash];
                        while (current) {
                            var next = current.name_next;
                            if (mounts.includes(current.mount)) {
                                FS.destroyNode(current)
                            }
                            current = next
                        }
                    });
                    node.mounted = null;
                    var idx = node.mount.mounts.indexOf(mount);
                    node.mount.mounts.splice(idx, 1)
                },
                lookup: function(parent, name) {
                    return parent.node_ops.lookup(parent, name)
                },
                mknod: function(path, mode, dev) {
                    var lookup = FS.lookupPath(path, {
                        parent: true
                    });
                    var parent = lookup.node;
                    var name = PATH.basename(path);
                    if (!name || name === "." || name === "..") {
                        throw new FS.ErrnoError(28)
                    }
                    var errCode = FS.mayCreate(parent, name);
                    if (errCode) {
                        throw new FS.ErrnoError(errCode)
                    }
                    if (!parent.node_ops.mknod) {
                        throw new FS.ErrnoError(63)
                    }
                    return parent.node_ops.mknod(parent, name, mode, dev)
                },
                create: function(path, mode) {
                    mode = mode !== undefined ? mode : 438;
                    mode &= 4095;
                    mode |= 32768;
                    return FS.mknod(path, mode, 0)
                },
                mkdir: function(path, mode) {
                    mode = mode !== undefined ? mode : 511;
                    mode &= 511 | 512;
                    mode |= 16384;
                    return FS.mknod(path, mode, 0)
                },
                mkdirTree: function(path, mode) {
                    var dirs = path.split("/");
                    var d = "";
                    for (var i = 0; i < dirs.length; ++i) {
                        if (!dirs[i]) continue;
                        d += "/" + dirs[i];
                        try {
                            FS.mkdir(d, mode)
                        } catch (e) {
                            if (e.errno != 20) throw e
                        }
                    }
                },
                mkdev: function(path, mode, dev) {
                    if (typeof dev === "undefined") {
                        dev = mode;
                        mode = 438
                    }
                    mode |= 8192;
                    return FS.mknod(path, mode, dev)
                },
                symlink: function(oldpath, newpath) {
                    if (!PATH_FS.resolve(oldpath)) {
                        throw new FS.ErrnoError(44)
                    }
                    var lookup = FS.lookupPath(newpath, {
                        parent: true
                    });
                    var parent = lookup.node;
                    if (!parent) {
                        throw new FS.ErrnoError(44)
                    }
                    var newname = PATH.basename(newpath);
                    var errCode = FS.mayCreate(parent, newname);
                    if (errCode) {
                        throw new FS.ErrnoError(errCode)
                    }
                    if (!parent.node_ops.symlink) {
                        throw new FS.ErrnoError(63)
                    }
                    return parent.node_ops.symlink(parent, newname, oldpath)
                },
                rename: function(old_path, new_path) {
                    var old_dirname = PATH.dirname(old_path);
                    var new_dirname = PATH.dirname(new_path);
                    var old_name = PATH.basename(old_path);
                    var new_name = PATH.basename(new_path);
                    var lookup, old_dir, new_dir;
                    lookup = FS.lookupPath(old_path, {
                        parent: true
                    });
                    old_dir = lookup.node;
                    lookup = FS.lookupPath(new_path, {
                        parent: true
                    });
                    new_dir = lookup.node;
                    if (!old_dir || !new_dir) throw new FS.ErrnoError(44);
                    if (old_dir.mount !== new_dir.mount) {
                        throw new FS.ErrnoError(75)
                    }
                    var old_node = FS.lookupNode(old_dir, old_name);
                    var relative = PATH_FS.relative(old_path, new_dirname);
                    if (relative.charAt(0) !== ".") {
                        throw new FS.ErrnoError(28)
                    }
                    relative = PATH_FS.relative(new_path, old_dirname);
                    if (relative.charAt(0) !== ".") {
                        throw new FS.ErrnoError(55)
                    }
                    var new_node;
                    try {
                        new_node = FS.lookupNode(new_dir, new_name)
                    } catch (e) {}
                    if (old_node === new_node) {
                        return
                    }
                    var isdir = FS.isDir(old_node.mode);
                    var errCode = FS.mayDelete(old_dir, old_name, isdir);
                    if (errCode) {
                        throw new FS.ErrnoError(errCode)
                    }
                    errCode = new_node ? FS.mayDelete(new_dir, new_name, isdir) : FS.mayCreate(new_dir, new_name);
                    if (errCode) {
                        throw new FS.ErrnoError(errCode)
                    }
                    if (!old_dir.node_ops.rename) {
                        throw new FS.ErrnoError(63)
                    }
                    if (FS.isMountpoint(old_node) || new_node && FS.isMountpoint(new_node)) {
                        throw new FS.ErrnoError(10)
                    }
                    if (new_dir !== old_dir) {
                        errCode = FS.nodePermissions(old_dir, "w");
                        if (errCode) {
                            throw new FS.ErrnoError(errCode)
                        }
                    }
                    try {
                        if (FS.trackingDelegate["willMovePath"]) {
                            FS.trackingDelegate["willMovePath"](old_path, new_path)
                        }
                    } catch (e) {
                        err("FS.trackingDelegate['willMovePath']('" + old_path + "', '" + new_path + "') threw an exception: " + e.message)
                    }
                    FS.hashRemoveNode(old_node);
                    try {
                        old_dir.node_ops.rename(old_node, new_dir, new_name)
                    } catch (e) {
                        throw e
                    } finally {
                        FS.hashAddNode(old_node)
                    }
                    try {
                        if (FS.trackingDelegate["onMovePath"]) FS.trackingDelegate["onMovePath"](old_path, new_path)
                    } catch (e) {
                        err("FS.trackingDelegate['onMovePath']('" + old_path + "', '" + new_path + "') threw an exception: " + e.message)
                    }
                },
                rmdir: function(path) {
                    var lookup = FS.lookupPath(path, {
                        parent: true
                    });
                    var parent = lookup.node;
                    var name = PATH.basename(path);
                    var node = FS.lookupNode(parent, name);
                    var errCode = FS.mayDelete(parent, name, true);
                    if (errCode) {
                        throw new FS.ErrnoError(errCode)
                    }
                    if (!parent.node_ops.rmdir) {
                        throw new FS.ErrnoError(63)
                    }
                    if (FS.isMountpoint(node)) {
                        throw new FS.ErrnoError(10)
                    }
                    try {
                        if (FS.trackingDelegate["willDeletePath"]) {
                            FS.trackingDelegate["willDeletePath"](path)
                        }
                    } catch (e) {
                        err("FS.trackingDelegate['willDeletePath']('" + path + "') threw an exception: " + e.message)
                    }
                    parent.node_ops.rmdir(parent, name);
                    FS.destroyNode(node);
                    try {
                        if (FS.trackingDelegate["onDeletePath"]) FS.trackingDelegate["onDeletePath"](path)
                    } catch (e) {
                        err("FS.trackingDelegate['onDeletePath']('" + path + "') threw an exception: " + e.message)
                    }
                },
                readdir: function(path) {
                    var lookup = FS.lookupPath(path, {
                        follow: true
                    });
                    var node = lookup.node;
                    if (!node.node_ops.readdir) {
                        throw new FS.ErrnoError(54)
                    }
                    return node.node_ops.readdir(node)
                },
                unlink: function(path) {
                    var lookup = FS.lookupPath(path, {
                        parent: true
                    });
                    var parent = lookup.node;
                    var name = PATH.basename(path);
                    var node = FS.lookupNode(parent, name);
                    var errCode = FS.mayDelete(parent, name, false);
                    if (errCode) {
                        throw new FS.ErrnoError(errCode)
                    }
                    if (!parent.node_ops.unlink) {
                        throw new FS.ErrnoError(63)
                    }
                    if (FS.isMountpoint(node)) {
                        throw new FS.ErrnoError(10)
                    }
                    try {
                        if (FS.trackingDelegate["willDeletePath"]) {
                            FS.trackingDelegate["willDeletePath"](path)
                        }
                    } catch (e) {
                        err("FS.trackingDelegate['willDeletePath']('" + path + "') threw an exception: " + e.message)
                    }
                    parent.node_ops.unlink(parent, name);
                    FS.destroyNode(node);
                    try {
                        if (FS.trackingDelegate["onDeletePath"]) FS.trackingDelegate["onDeletePath"](path)
                    } catch (e) {
                        err("FS.trackingDelegate['onDeletePath']('" + path + "') threw an exception: " + e.message)
                    }
                },
                readlink: function(path) {
                    var lookup = FS.lookupPath(path);
                    var link = lookup.node;
                    if (!link) {
                        throw new FS.ErrnoError(44)
                    }
                    if (!link.node_ops.readlink) {
                        throw new FS.ErrnoError(28)
                    }
                    return PATH_FS.resolve(FS.getPath(link.parent), link.node_ops.readlink(link))
                },
                stat: function(path, dontFollow) {
                    var lookup = FS.lookupPath(path, {
                        follow: !dontFollow
                    });
                    var node = lookup.node;
                    if (!node) {
                        throw new FS.ErrnoError(44)
                    }
                    if (!node.node_ops.getattr) {
                        throw new FS.ErrnoError(63)
                    }
                    return node.node_ops.getattr(node)
                },
                lstat: function(path) {
                    return FS.stat(path, true)
                },
                chmod: function(path, mode, dontFollow) {
                    var node;
                    if (typeof path === "string") {
                        var lookup = FS.lookupPath(path, {
                            follow: !dontFollow
                        });
                        node = lookup.node
                    } else {
                        node = path
                    }
                    if (!node.node_ops.setattr) {
                        throw new FS.ErrnoError(63)
                    }
                    node.node_ops.setattr(node, {
                        mode: mode & 4095 | node.mode & ~4095,
                        timestamp: Date.now()
                    })
                },
                lchmod: function(path, mode) {
                    FS.chmod(path, mode, true)
                },
                fchmod: function(fd, mode) {
                    var stream = FS.getStream(fd);
                    if (!stream) {
                        throw new FS.ErrnoError(8)
                    }
                    FS.chmod(stream.node, mode)
                },
                chown: function(path, uid, gid, dontFollow) {
                    var node;
                    if (typeof path === "string") {
                        var lookup = FS.lookupPath(path, {
                            follow: !dontFollow
                        });
                        node = lookup.node
                    } else {
                        node = path
                    }
                    if (!node.node_ops.setattr) {
                        throw new FS.ErrnoError(63)
                    }
                    node.node_ops.setattr(node, {
                        timestamp: Date.now()
                    })
                },
                lchown: function(path, uid, gid) {
                    FS.chown(path, uid, gid, true)
                },
                fchown: function(fd, uid, gid) {
                    var stream = FS.getStream(fd);
                    if (!stream) {
                        throw new FS.ErrnoError(8)
                    }
                    FS.chown(stream.node, uid, gid)
                },
                truncate: function(path, len) {
                    if (len < 0) {
                        throw new FS.ErrnoError(28)
                    }
                    var node;
                    if (typeof path === "string") {
                        var lookup = FS.lookupPath(path, {
                            follow: true
                        });
                        node = lookup.node
                    } else {
                        node = path
                    }
                    if (!node.node_ops.setattr) {
                        throw new FS.ErrnoError(63)
                    }
                    if (FS.isDir(node.mode)) {
                        throw new FS.ErrnoError(31)
                    }
                    if (!FS.isFile(node.mode)) {
                        throw new FS.ErrnoError(28)
                    }
                    var errCode = FS.nodePermissions(node, "w");
                    if (errCode) {
                        throw new FS.ErrnoError(errCode)
                    }
                    node.node_ops.setattr(node, {
                        size: len,
                        timestamp: Date.now()
                    })
                },
                ftruncate: function(fd, len) {
                    var stream = FS.getStream(fd);
                    if (!stream) {
                        throw new FS.ErrnoError(8)
                    }
                    if ((stream.flags & 2097155) === 0) {
                        throw new FS.ErrnoError(28)
                    }
                    FS.truncate(stream.node, len)
                },
                utime: function(path, atime, mtime) {
                    var lookup = FS.lookupPath(path, {
                        follow: true
                    });
                    var node = lookup.node;
                    node.node_ops.setattr(node, {
                        timestamp: Math.max(atime, mtime)
                    })
                },
                open: function(path, flags, mode, fd_start, fd_end) {
                    if (path === "") {
                        throw new FS.ErrnoError(44)
                    }
                    flags = typeof flags === "string" ? FS.modeStringToFlags(flags) : flags;
                    mode = typeof mode === "undefined" ? 438 : mode;
                    if (flags & 64) {
                        mode = mode & 4095 | 32768
                    } else {
                        mode = 0
                    }
                    var node;
                    if (typeof path === "object") {
                        node = path
                    } else {
                        path = PATH.normalize(path);
                        try {
                            var lookup = FS.lookupPath(path, {
                                follow: !(flags & 131072)
                            });
                            node = lookup.node
                        } catch (e) {}
                    }
                    var created = false;
                    if (flags & 64) {
                        if (node) {
                            if (flags & 128) {
                                throw new FS.ErrnoError(20)
                            }
                        } else {
                            node = FS.mknod(path, mode, 0);
                            created = true
                        }
                    }
                    if (!node) {
                        throw new FS.ErrnoError(44)
                    }
                    if (FS.isChrdev(node.mode)) {
                        flags &= ~512
                    }
                    if (flags & 65536 && !FS.isDir(node.mode)) {
                        throw new FS.ErrnoError(54)
                    }
                    if (!created) {
                        var errCode = FS.mayOpen(node, flags);
                        if (errCode) {
                            throw new FS.ErrnoError(errCode)
                        }
                    }
                    if (flags & 512) {
                        FS.truncate(node, 0)
                    }
                    flags &= ~(128 | 512 | 131072);
                    var stream = FS.createStream({
                        node: node,
                        path: FS.getPath(node),
                        flags: flags,
                        seekable: true,
                        position: 0,
                        stream_ops: node.stream_ops,
                        ungotten: [],
                        error: false
                    }, fd_start, fd_end);
                    if (stream.stream_ops.open) {
                        stream.stream_ops.open(stream)
                    }
                    if (Module["logReadFiles"] && !(flags & 1)) {
                        if (!FS.readFiles) FS.readFiles = {};
                        if (!(path in FS.readFiles)) {
                            FS.readFiles[path] = 1;
                            err("FS.trackingDelegate error on read file: " + path)
                        }
                    }
                    try {
                        if (FS.trackingDelegate["onOpenFile"]) {
                            var trackingFlags = 0;
                            if ((flags & 2097155) !== 1) {
                                trackingFlags |= FS.tracking.openFlags.READ
                            }
                            if ((flags & 2097155) !== 0) {
                                trackingFlags |= FS.tracking.openFlags.WRITE
                            }
                            FS.trackingDelegate["onOpenFile"](path, trackingFlags)
                        }
                    } catch (e) {
                        err("FS.trackingDelegate['onOpenFile']('" + path + "', flags) threw an exception: " + e.message)
                    }
                    return stream
                },
                close: function(stream) {
                    if (FS.isClosed(stream)) {
                        throw new FS.ErrnoError(8)
                    }
                    if (stream.getdents) stream.getdents = null;
                    try {
                        if (stream.stream_ops.close) {
                            stream.stream_ops.close(stream)
                        }
                    } catch (e) {
                        throw e
                    } finally {
                        FS.closeStream(stream.fd)
                    }
                    stream.fd = null
                },
                isClosed: function(stream) {
                    return stream.fd === null
                },
                llseek: function(stream, offset, whence) {
                    if (FS.isClosed(stream)) {
                        throw new FS.ErrnoError(8)
                    }
                    if (!stream.seekable || !stream.stream_ops.llseek) {
                        throw new FS.ErrnoError(70)
                    }
                    if (whence != 0 && whence != 1 && whence != 2) {
                        throw new FS.ErrnoError(28)
                    }
                    stream.position = stream.stream_ops.llseek(stream, offset, whence);
                    stream.ungotten = [];
                    return stream.position
                },
                read: function(stream, buffer, offset, length, position) {
                    if (length < 0 || position < 0) {
                        throw new FS.ErrnoError(28)
                    }
                    if (FS.isClosed(stream)) {
                        throw new FS.ErrnoError(8)
                    }
                    if ((stream.flags & 2097155) === 1) {
                        throw new FS.ErrnoError(8)
                    }
                    if (FS.isDir(stream.node.mode)) {
                        throw new FS.ErrnoError(31)
                    }
                    if (!stream.stream_ops.read) {
                        throw new FS.ErrnoError(28)
                    }
                    var seeking = typeof position !== "undefined";
                    if (!seeking) {
                        position = stream.position
                    } else if (!stream.seekable) {
                        throw new FS.ErrnoError(70)
                    }
                    var bytesRead = stream.stream_ops.read(stream, buffer, offset, length, position);
                    if (!seeking) stream.position += bytesRead;
                    return bytesRead
                },
                write: function(stream, buffer, offset, length, position, canOwn) {
                    if (length < 0 || position < 0) {
                        throw new FS.ErrnoError(28)
                    }
                    if (FS.isClosed(stream)) {
                        throw new FS.ErrnoError(8)
                    }
                    if ((stream.flags & 2097155) === 0) {
                        throw new FS.ErrnoError(8)
                    }
                    if (FS.isDir(stream.node.mode)) {
                        throw new FS.ErrnoError(31)
                    }
                    if (!stream.stream_ops.write) {
                        throw new FS.ErrnoError(28)
                    }
                    if (stream.seekable && stream.flags & 1024) {
                        FS.llseek(stream, 0, 2)
                    }
                    var seeking = typeof position !== "undefined";
                    if (!seeking) {
                        position = stream.position
                    } else if (!stream.seekable) {
                        throw new FS.ErrnoError(70)
                    }
                    var bytesWritten = stream.stream_ops.write(stream, buffer, offset, length, position, canOwn);
                    if (!seeking) stream.position += bytesWritten;
                    try {
                        if (stream.path && FS.trackingDelegate["onWriteToFile"]) FS.trackingDelegate["onWriteToFile"](stream.path)
                    } catch (e) {
                        err("FS.trackingDelegate['onWriteToFile']('" + stream.path + "') threw an exception: " + e.message)
                    }
                    return bytesWritten
                },
                allocate: function(stream, offset, length) {
                    if (FS.isClosed(stream)) {
                        throw new FS.ErrnoError(8)
                    }
                    if (offset < 0 || length <= 0) {
                        throw new FS.ErrnoError(28)
                    }
                    if ((stream.flags & 2097155) === 0) {
                        throw new FS.ErrnoError(8)
                    }
                    if (!FS.isFile(stream.node.mode) && !FS.isDir(stream.node.mode)) {
                        throw new FS.ErrnoError(43)
                    }
                    if (!stream.stream_ops.allocate) {
                        throw new FS.ErrnoError(138)
                    }
                    stream.stream_ops.allocate(stream, offset, length)
                },
                mmap: function(stream, address, length, position, prot, flags) {
                    if ((prot & 2) !== 0 && (flags & 2) === 0 && (stream.flags & 2097155) !== 2) {
                        throw new FS.ErrnoError(2)
                    }
                    if ((stream.flags & 2097155) === 1) {
                        throw new FS.ErrnoError(2)
                    }
                    if (!stream.stream_ops.mmap) {
                        throw new FS.ErrnoError(43)
                    }
                    return stream.stream_ops.mmap(stream, address, length, position, prot, flags)
                },
                msync: function(stream, buffer, offset, length, mmapFlags) {
                    if (!stream || !stream.stream_ops.msync) {
                        return 0
                    }
                    return stream.stream_ops.msync(stream, buffer, offset, length, mmapFlags)
                },
                munmap: function(stream) {
                    return 0
                },
                ioctl: function(stream, cmd, arg) {
                    if (!stream.stream_ops.ioctl) {
                        throw new FS.ErrnoError(59)
                    }
                    return stream.stream_ops.ioctl(stream, cmd, arg)
                },
                readFile: function(path, opts) {
                    opts = opts || {};
                    opts.flags = opts.flags || 0;
                    opts.encoding = opts.encoding || "binary";
                    if (opts.encoding !== "utf8" && opts.encoding !== "binary") {
                        throw new Error('Invalid encoding type "' + opts.encoding + '"')
                    }
                    var ret;
                    var stream = FS.open(path, opts.flags);
                    var stat = FS.stat(path);
                    var length = stat.size;
                    var buf = new Uint8Array(length);
                    FS.read(stream, buf, 0, length, 0);
                    if (opts.encoding === "utf8") {
                        ret = UTF8ArrayToString(buf, 0)
                    } else if (opts.encoding === "binary") {
                        ret = buf
                    }
                    FS.close(stream);
                    return ret
                },
                writeFile: function(path, data, opts) {
                    opts = opts || {};
                    opts.flags = opts.flags || 577;
                    var stream = FS.open(path, opts.flags, opts.mode);
                    if (typeof data === "string") {
                        var buf = new Uint8Array(lengthBytesUTF8(data) + 1);
                        var actualNumBytes = stringToUTF8Array(data, buf, 0, buf.length);
                        FS.write(stream, buf, 0, actualNumBytes, undefined, opts.canOwn)
                    } else if (ArrayBuffer.isView(data)) {
                        FS.write(stream, data, 0, data.byteLength, undefined, opts.canOwn)
                    } else {
                        throw new Error("Unsupported data type")
                    }
                    FS.close(stream)
                },
                cwd: function() {
                    return FS.currentPath
                },
                chdir: function(path) {
                    var lookup = FS.lookupPath(path, {
                        follow: true
                    });
                    if (lookup.node === null) {
                        throw new FS.ErrnoError(44)
                    }
                    if (!FS.isDir(lookup.node.mode)) {
                        throw new FS.ErrnoError(54)
                    }
                    var errCode = FS.nodePermissions(lookup.node, "x");
                    if (errCode) {
                        throw new FS.ErrnoError(errCode)
                    }
                    FS.currentPath = lookup.path
                },
                createDefaultDirectories: function() {
                    FS.mkdir("/tmp");
                    FS.mkdir("/home");
                    FS.mkdir("/home/web_user")
                },
                createDefaultDevices: function() {
                    FS.mkdir("/dev");
                    FS.registerDevice(FS.makedev(1, 3), {
                        read: function() {
                            return 0
                        },
                        write: function(stream, buffer, offset, length, pos) {
                            return length
                        }
                    });
                    FS.mkdev("/dev/null", FS.makedev(1, 3));
                    TTY.register(FS.makedev(5, 0), TTY.default_tty_ops);
                    TTY.register(FS.makedev(6, 0), TTY.default_tty1_ops);
                    FS.mkdev("/dev/tty", FS.makedev(5, 0));
                    FS.mkdev("/dev/tty1", FS.makedev(6, 0));
                    var random_device = getRandomDevice();
                    FS.createDevice("/dev", "random", random_device);
                    FS.createDevice("/dev", "urandom", random_device);
                    FS.mkdir("/dev/shm");
                    FS.mkdir("/dev/shm/tmp")
                },
                createSpecialDirectories: function() {
                    FS.mkdir("/proc");
                    var proc_self = FS.mkdir("/proc/self");
                    FS.mkdir("/proc/self/fd");
                    FS.mount({
                        mount: function() {
                            var node = FS.createNode(proc_self, "fd", 16384 | 511, 73);
                            node.node_ops = {
                                lookup: function(parent, name) {
                                    var fd = +name;
                                    var stream = FS.getStream(fd);
                                    if (!stream) throw new FS.ErrnoError(8);
                                    var ret = {
                                        parent: null,
                                        mount: {
                                            mountpoint: "fake"
                                        },
                                        node_ops: {
                                            readlink: function() {
                                                return stream.path
                                            }
                                        }
                                    };
                                    ret.parent = ret;
                                    return ret
                                }
                            };
                            return node
                        }
                    }, {}, "/proc/self/fd")
                },
                createStandardStreams: function() {
                    if (Module["stdin"]) {
                        FS.createDevice("/dev", "stdin", Module["stdin"])
                    } else {
                        FS.symlink("/dev/tty", "/dev/stdin")
                    }
                    if (Module["stdout"]) {
                        FS.createDevice("/dev", "stdout", null, Module["stdout"])
                    } else {
                        FS.symlink("/dev/tty", "/dev/stdout")
                    }
                    if (Module["stderr"]) {
                        FS.createDevice("/dev", "stderr", null, Module["stderr"])
                    } else {
                        FS.symlink("/dev/tty1", "/dev/stderr")
                    }
                    var stdin = FS.open("/dev/stdin", 0);
                    var stdout = FS.open("/dev/stdout", 1);
                    var stderr = FS.open("/dev/stderr", 1)
                },
                ensureErrnoError: function() {
                    if (FS.ErrnoError) return;
                    FS.ErrnoError = function ErrnoError(errno, node) {
                        this.node = node;
                        this.setErrno = function(errno) {
                            this.errno = errno
                        };
                        this.setErrno(errno);
                        this.message = "FS error"
                    };
                    FS.ErrnoError.prototype = new Error;
                    FS.ErrnoError.prototype.constructor = FS.ErrnoError;
                    [44].forEach(function(code) {
                        FS.genericErrors[code] = new FS.ErrnoError(code);
                        FS.genericErrors[code].stack = "<generic error, no stack>"
                    })
                },
                staticInit: function() {
                    FS.ensureErrnoError();
                    FS.nameTable = new Array(4096);
                    FS.mount(MEMFS, {}, "/");
                    FS.createDefaultDirectories();
                    FS.createDefaultDevices();
                    FS.createSpecialDirectories();
                    FS.filesystems = {
                        "MEMFS": MEMFS
                    }
                },
                init: function(input, output, error) {
                    FS.init.initialized = true;
                    FS.ensureErrnoError();
                    Module["stdin"] = input || Module["stdin"];
                    Module["stdout"] = output || Module["stdout"];
                    Module["stderr"] = error || Module["stderr"];
                    FS.createStandardStreams()
                },
                quit: function() {
                    FS.init.initialized = false;
                    var fflush = Module["_fflush"];
                    if (fflush) fflush(0);
                    for (var i = 0; i < FS.streams.length; i++) {
                        var stream = FS.streams[i];
                        if (!stream) {
                            continue
                        }
                        FS.close(stream)
                    }
                },
                getMode: function(canRead, canWrite) {
                    var mode = 0;
                    if (canRead) mode |= 292 | 73;
                    if (canWrite) mode |= 146;
                    return mode
                },
                findObject: function(path, dontResolveLastLink) {
                    var ret = FS.analyzePath(path, dontResolveLastLink);
                    if (ret.exists) {
                        return ret.object
                    } else {
                        return null
                    }
                },
                analyzePath: function(path, dontResolveLastLink) {
                    try {
                        var lookup = FS.lookupPath(path, {
                            follow: !dontResolveLastLink
                        });
                        path = lookup.path
                    } catch (e) {}
                    var ret = {
                        isRoot: false,
                        exists: false,
                        error: 0,
                        name: null,
                        path: null,
                        object: null,
                        parentExists: false,
                        parentPath: null,
                        parentObject: null
                    };
                    try {
                        var lookup = FS.lookupPath(path, {
                            parent: true
                        });
                        ret.parentExists = true;
                        ret.parentPath = lookup.path;
                        ret.parentObject = lookup.node;
                        ret.name = PATH.basename(path);
                        lookup = FS.lookupPath(path, {
                            follow: !dontResolveLastLink
                        });
                        ret.exists = true;
                        ret.path = lookup.path;
                        ret.object = lookup.node;
                        ret.name = lookup.node.name;
                        ret.isRoot = lookup.path === "/"
                    } catch (e) {
                        ret.error = e.errno
                    }
                    return ret
                },
                createPath: function(parent, path, canRead, canWrite) {
                    parent = typeof parent === "string" ? parent : FS.getPath(parent);
                    var parts = path.split("/").reverse();
                    while (parts.length) {
                        var part = parts.pop();
                        if (!part) continue;
                        var current = PATH.join2(parent, part);
                        try {
                            FS.mkdir(current)
                        } catch (e) {}
                        parent = current
                    }
                    return current
                },
                createFile: function(parent, name, properties, canRead, canWrite) {
                    var path = PATH.join2(typeof parent === "string" ? parent : FS.getPath(parent), name);
                    var mode = FS.getMode(canRead, canWrite);
                    return FS.create(path, mode)
                },
                createDataFile: function(parent, name, data, canRead, canWrite, canOwn) {
                    var path = name ? PATH.join2(typeof parent === "string" ? parent : FS.getPath(parent), name) : parent;
                    var mode = FS.getMode(canRead, canWrite);
                    var node = FS.create(path, mode);
                    if (data) {
                        if (typeof data === "string") {
                            var arr = new Array(data.length);
                            for (var i = 0, len = data.length; i < len; ++i) arr[i] = data.charCodeAt(i);
                            data = arr
                        }
                        FS.chmod(node, mode | 146);
                        var stream = FS.open(node, 577);
                        FS.write(stream, data, 0, data.length, 0, canOwn);
                        FS.close(stream);
                        FS.chmod(node, mode)
                    }
                    return node
                },
                createDevice: function(parent, name, input, output) {
                    var path = PATH.join2(typeof parent === "string" ? parent : FS.getPath(parent), name);
                    var mode = FS.getMode(!!input, !!output);
                    if (!FS.createDevice.major) FS.createDevice.major = 64;
                    var dev = FS.makedev(FS.createDevice.major++, 0);
                    FS.registerDevice(dev, {
                        open: function(stream) {
                            stream.seekable = false
                        },
                        close: function(stream) {
                            if (output && output.buffer && output.buffer.length) {
                                output(10)
                            }
                        },
                        read: function(stream, buffer, offset, length, pos) {
                            var bytesRead = 0;
                            for (var i = 0; i < length; i++) {
                                var result;
                                try {
                                    result = input()
                                } catch (e) {
                                    throw new FS.ErrnoError(29)
                                }
                                if (result === undefined && bytesRead === 0) {
                                    throw new FS.ErrnoError(6)
                                }
                                if (result === null || result === undefined) break;
                                bytesRead++;
                                buffer[offset + i] = result
                            }
                            if (bytesRead) {
                                stream.node.timestamp = Date.now()
                            }
                            return bytesRead
                        },
                        write: function(stream, buffer, offset, length, pos) {
                            for (var i = 0; i < length; i++) {
                                try {
                                    output(buffer[offset + i])
                                } catch (e) {
                                    throw new FS.ErrnoError(29)
                                }
                            }
                            if (length) {
                                stream.node.timestamp = Date.now()
                            }
                            return i
                        }
                    });
                    return FS.mkdev(path, mode, dev)
                },
                forceLoadFile: function(obj) {
                    if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
                    if (typeof XMLHttpRequest !== "undefined") {
                        throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.")
                    } else if (read_) {
                        try {
                            obj.contents = intArrayFromString(read_(obj.url), true);
                            obj.usedBytes = obj.contents.length
                        } catch (e) {
                            throw new FS.ErrnoError(29)
                        }
                    } else {
                        throw new Error("Cannot load without read() or XMLHttpRequest.")
                    }
                },
                createLazyFile: function(parent, name, url, canRead, canWrite) {
                    function LazyUint8Array() {
                        this.lengthKnown = false;
                        this.chunks = []
                    }
                    LazyUint8Array.prototype.get = function LazyUint8Array_get(idx) {
                        if (idx > this.length - 1 || idx < 0) {
                            return undefined
                        }
                        var chunkOffset = idx % this.chunkSize;
                        var chunkNum = idx / this.chunkSize | 0;
                        return this.getter(chunkNum)[chunkOffset]
                    };
                    LazyUint8Array.prototype.setDataGetter = function LazyUint8Array_setDataGetter(getter) {
                        this.getter = getter
                    };
                    LazyUint8Array.prototype.cacheLength = function LazyUint8Array_cacheLength() {
                        var xhr = new XMLHttpRequest;
                        xhr.open("HEAD", url, false);
                        xhr.send(null);
                        if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
                        var datalength = Number(xhr.getResponseHeader("Content-length"));
                        var header;
                        var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
                        var usesGzip = (header = xhr.getResponseHeader("Content-Encoding")) && header === "gzip";
                        var chunkSize = 1024 * 1024;
                        if (!hasByteServing) chunkSize = datalength;
                        var doXHR = function(from, to) {
                            if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
                            if (to > datalength - 1) throw new Error("only " + datalength + " bytes available! programmer error!");
                            var xhr = new XMLHttpRequest;
                            xhr.open("GET", url, false);
                            if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
                            if (typeof Uint8Array != "undefined") xhr.responseType = "arraybuffer";
                            if (xhr.overrideMimeType) {
                                xhr.overrideMimeType("text/plain; charset=x-user-defined")
                            }
                            xhr.send(null);
                            if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
                            if (xhr.response !== undefined) {
                                return new Uint8Array(xhr.response || [])
                            } else {
                                return intArrayFromString(xhr.responseText || "", true)
                            }
                        };
                        var lazyArray = this;
                        lazyArray.setDataGetter(function(chunkNum) {
                            var start = chunkNum * chunkSize;
                            var end = (chunkNum + 1) * chunkSize - 1;
                            end = Math.min(end, datalength - 1);
                            if (typeof lazyArray.chunks[chunkNum] === "undefined") {
                                lazyArray.chunks[chunkNum] = doXHR(start, end)
                            }
                            if (typeof lazyArray.chunks[chunkNum] === "undefined") throw new Error("doXHR failed!");
                            return lazyArray.chunks[chunkNum]
                        });
                        if (usesGzip || !datalength) {
                            chunkSize = datalength = 1;
                            datalength = this.getter(0).length;
                            chunkSize = datalength;
                            out("LazyFiles on gzip forces download of the whole file when length is accessed")
                        }
                        this._length = datalength;
                        this._chunkSize = chunkSize;
                        this.lengthKnown = true
                    };
                    if (typeof XMLHttpRequest !== "undefined") {
                        if (!ENVIRONMENT_IS_WORKER) throw "Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc";
                        var lazyArray = new LazyUint8Array;
                        Object.defineProperties(lazyArray, {
                            length: {
                                get: function() {
                                    if (!this.lengthKnown) {
                                        this.cacheLength()
                                    }
                                    return this._length
                                }
                            },
                            chunkSize: {
                                get: function() {
                                    if (!this.lengthKnown) {
                                        this.cacheLength()
                                    }
                                    return this._chunkSize
                                }
                            }
                        });
                        var properties = {
                            isDevice: false,
                            contents: lazyArray
                        }
                    } else {
                        var properties = {
                            isDevice: false,
                            url: url
                        }
                    }
                    var node = FS.createFile(parent, name, properties, canRead, canWrite);
                    if (properties.contents) {
                        node.contents = properties.contents
                    } else if (properties.url) {
                        node.contents = null;
                        node.url = properties.url
                    }
                    Object.defineProperties(node, {
                        usedBytes: {
                            get: function() {
                                return this.contents.length
                            }
                        }
                    });
                    var stream_ops = {};
                    var keys = Object.keys(node.stream_ops);
                    keys.forEach(function(key) {
                        var fn = node.stream_ops[key];
                        stream_ops[key] = function forceLoadLazyFile() {
                            FS.forceLoadFile(node);
                            return fn.apply(null, arguments)
                        }
                    });
                    stream_ops.read = function stream_ops_read(stream, buffer, offset, length, position) {
                        FS.forceLoadFile(node);
                        var contents = stream.node.contents;
                        if (position >= contents.length) return 0;
                        var size = Math.min(contents.length - position, length);
                        if (contents.slice) {
                            for (var i = 0; i < size; i++) {
                                buffer[offset + i] = contents[position + i]
                            }
                        } else {
                            for (var i = 0; i < size; i++) {
                                buffer[offset + i] = contents.get(position + i)
                            }
                        }
                        return size
                    };
                    node.stream_ops = stream_ops;
                    return node
                },
                createPreloadedFile: function(parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile, canOwn, preFinish) {
                    Browser.init();
                    var fullname = name ? PATH_FS.resolve(PATH.join2(parent, name)) : parent;
                    var dep = getUniqueRunDependency("cp " + fullname);

                    function processData(byteArray) {
                        function finish(byteArray) {
                            if (preFinish) preFinish();
                            if (!dontCreateFile) {
                                FS.createDataFile(parent, name, byteArray, canRead, canWrite, canOwn)
                            }
                            if (onload) onload();
                            removeRunDependency(dep)
                        }
                        var handled = false;
                        Module["preloadPlugins"].forEach(function(plugin) {
                            if (handled) return;
                            if (plugin["canHandle"](fullname)) {
                                plugin["handle"](byteArray, fullname, finish, function() {
                                    if (onerror) onerror();
                                    removeRunDependency(dep)
                                });
                                handled = true
                            }
                        });
                        if (!handled) finish(byteArray)
                    }
                    addRunDependency(dep);
                    if (typeof url == "string") {
                        Browser.asyncLoad(url, function(byteArray) {
                            processData(byteArray)
                        }, onerror)
                    } else {
                        processData(url)
                    }
                },
                indexedDB: function() {
                    return window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB
                },
                DB_NAME: function() {
                    return "EM_FS_" + window.location.pathname
                },
                DB_VERSION: 20,
                DB_STORE_NAME: "FILE_DATA",
                saveFilesToDB: function(paths, onload, onerror) {
                    onload = onload || function() {};
                    onerror = onerror || function() {};
                    var indexedDB = FS.indexedDB();
                    try {
                        var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION)
                    } catch (e) {
                        return onerror(e)
                    }
                    openRequest.onupgradeneeded = function openRequest_onupgradeneeded() {
                        out("creating db");
                        var db = openRequest.result;
                        db.createObjectStore(FS.DB_STORE_NAME)
                    };
                    openRequest.onsuccess = function openRequest_onsuccess() {
                        var db = openRequest.result;
                        var transaction = db.transaction([FS.DB_STORE_NAME], "readwrite");
                        var files = transaction.objectStore(FS.DB_STORE_NAME);
                        var ok = 0,
                            fail = 0,
                            total = paths.length;

                        function finish() {
                            if (fail == 0) onload();
                            else onerror()
                        }
                        paths.forEach(function(path) {
                            var putRequest = files.put(FS.analyzePath(path).object.contents, path);
                            putRequest.onsuccess = function putRequest_onsuccess() {
                                ok++;
                                if (ok + fail == total) finish()
                            };
                            putRequest.onerror = function putRequest_onerror() {
                                fail++;
                                if (ok + fail == total) finish()
                            }
                        });
                        transaction.onerror = onerror
                    };
                    openRequest.onerror = onerror
                },
                loadFilesFromDB: function(paths, onload, onerror) {
                    onload = onload || function() {};
                    onerror = onerror || function() {};
                    var indexedDB = FS.indexedDB();
                    try {
                        var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION)
                    } catch (e) {
                        return onerror(e)
                    }
                    openRequest.onupgradeneeded = onerror;
                    openRequest.onsuccess = function openRequest_onsuccess() {
                        var db = openRequest.result;
                        try {
                            var transaction = db.transaction([FS.DB_STORE_NAME], "readonly")
                        } catch (e) {
                            onerror(e);
                            return
                        }
                        var files = transaction.objectStore(FS.DB_STORE_NAME);
                        var ok = 0,
                            fail = 0,
                            total = paths.length;

                        function finish() {
                            if (fail == 0) onload();
                            else onerror()
                        }
                        paths.forEach(function(path) {
                            var getRequest = files.get(path);
                            getRequest.onsuccess = function getRequest_onsuccess() {
                                if (FS.analyzePath(path).exists) {
                                    FS.unlink(path)
                                }
                                FS.createDataFile(PATH.dirname(path), PATH.basename(path), getRequest.result, true, true, true);
                                ok++;
                                if (ok + fail == total) finish()
                            };
                            getRequest.onerror = function getRequest_onerror() {
                                fail++;
                                if (ok + fail == total) finish()
                            }
                        });
                        transaction.onerror = onerror
                    };
                    openRequest.onerror = onerror
                }
            };
            Module["FS"] = FS;
            var SYSCALLS = {
                mappings: {},
                DEFAULT_POLLMASK: 5,
                umask: 511,
                calculateAt: function(dirfd, path, allowEmpty) {
                    if (path[0] === "/") {
                        return path
                    }
                    var dir;
                    if (dirfd === -100) {
                        dir = FS.cwd()
                    } else {
                        var dirstream = FS.getStream(dirfd);
                        if (!dirstream) throw new FS.ErrnoError(8);
                        dir = dirstream.path
                    }
                    if (path.length == 0) {
                        if (!allowEmpty) {
                            throw new FS.ErrnoError(44)
                        }
                        return dir
                    }
                    return PATH.join2(dir, path)
                },
                doStat: function(func, path, buf) {
                    try {
                        var stat = func(path)
                    } catch (e) {
                        if (e && e.node && PATH.normalize(path) !== PATH.normalize(FS.getPath(e.node))) {
                            return -54
                        }
                        throw e
                    }
                    HEAP32[buf >> 2] = stat.dev;
                    HEAP32[buf + 4 >> 2] = 0;
                    HEAP32[buf + 8 >> 2] = stat.ino;
                    HEAP32[buf + 12 >> 2] = stat.mode;
                    HEAP32[buf + 16 >> 2] = stat.nlink;
                    HEAP32[buf + 20 >> 2] = stat.uid;
                    HEAP32[buf + 24 >> 2] = stat.gid;
                    HEAP32[buf + 28 >> 2] = stat.rdev;
                    HEAP32[buf + 32 >> 2] = 0;
                    tempI64 = [stat.size >>> 0, (tempDouble = stat.size, +Math.abs(tempDouble) >= 1 ? tempDouble > 0 ? (Math.min(+Math.floor(tempDouble / 4294967296), 4294967295) | 0) >>> 0 : ~~+Math.ceil((tempDouble - +(~~tempDouble >>> 0)) / 4294967296) >>> 0 : 0)], HEAP32[buf + 40 >> 2] = tempI64[0], HEAP32[buf + 44 >> 2] = tempI64[1];
                    HEAP32[buf + 48 >> 2] = 4096;
                    HEAP32[buf + 52 >> 2] = stat.blocks;
                    HEAP32[buf + 56 >> 2] = stat.atime.getTime() / 1e3 | 0;
                    HEAP32[buf + 60 >> 2] = 0;
                    HEAP32[buf + 64 >> 2] = stat.mtime.getTime() / 1e3 | 0;
                    HEAP32[buf + 68 >> 2] = 0;
                    HEAP32[buf + 72 >> 2] = stat.ctime.getTime() / 1e3 | 0;
                    HEAP32[buf + 76 >> 2] = 0;
                    tempI64 = [stat.ino >>> 0, (tempDouble = stat.ino, +Math.abs(tempDouble) >= 1 ? tempDouble > 0 ? (Math.min(+Math.floor(tempDouble / 4294967296), 4294967295) | 0) >>> 0 : ~~+Math.ceil((tempDouble - +(~~tempDouble >>> 0)) / 4294967296) >>> 0 : 0)], HEAP32[buf + 80 >> 2] = tempI64[0], HEAP32[buf + 84 >> 2] = tempI64[1];
                    return 0
                },
                doMsync: function(addr, stream, len, flags, offset) {
                    var buffer = HEAPU8.slice(addr, addr + len);
                    FS.msync(stream, buffer, offset, len, flags)
                },
                doMkdir: function(path, mode) {
                    path = PATH.normalize(path);
                    if (path[path.length - 1] === "/") path = path.substr(0, path.length - 1);
                    FS.mkdir(path, mode, 0);
                    return 0
                },
                doMknod: function(path, mode, dev) {
                    switch (mode & 61440) {
                        case 32768:
                        case 8192:
                        case 24576:
                        case 4096:
                        case 49152:
                            break;
                        default:
                            return -28
                    }
                    FS.mknod(path, mode, dev);
                    return 0
                },
                doReadlink: function(path, buf, bufsize) {
                    if (bufsize <= 0) return -28;
                    var ret = FS.readlink(path);
                    var len = Math.min(bufsize, lengthBytesUTF8(ret));
                    var endChar = HEAP8[buf + len];
                    stringToUTF8(ret, buf, bufsize + 1);
                    HEAP8[buf + len] = endChar;
                    return len
                },
                doAccess: function(path, amode) {
                    if (amode & ~7) {
                        return -28
                    }
                    var node;
                    var lookup = FS.lookupPath(path, {
                        follow: true
                    });
                    node = lookup.node;
                    if (!node) {
                        return -44
                    }
                    var perms = "";
                    if (amode & 4) perms += "r";
                    if (amode & 2) perms += "w";
                    if (amode & 1) perms += "x";
                    if (perms && FS.nodePermissions(node, perms)) {
                        return -2
                    }
                    return 0
                },
                doDup: function(path, flags, suggestFD) {
                    var suggest = FS.getStream(suggestFD);
                    if (suggest) FS.close(suggest);
                    return FS.open(path, flags, 0, suggestFD, suggestFD).fd
                },
                doReadv: function(stream, iov, iovcnt, offset) {
                    var ret = 0;
                    for (var i = 0; i < iovcnt; i++) {
                        var ptr = HEAP32[iov + i * 8 >> 2];
                        var len = HEAP32[iov + (i * 8 + 4) >> 2];
                        var curr = FS.read(stream, HEAP8, ptr, len, offset);
                        if (curr < 0) return -1;
                        ret += curr;
                        if (curr < len) break
                    }
                    return ret
                },
                doWritev: function(stream, iov, iovcnt, offset) {
                    var ret = 0;
                    for (var i = 0; i < iovcnt; i++) {
                        var ptr = HEAP32[iov + i * 8 >> 2];
                        var len = HEAP32[iov + (i * 8 + 4) >> 2];
                        var curr = FS.write(stream, HEAP8, ptr, len, offset);
                        if (curr < 0) return -1;
                        ret += curr
                    }
                    return ret
                },
                varargs: undefined,
                get: function() {
                    SYSCALLS.varargs += 4;
                    var ret = HEAP32[SYSCALLS.varargs - 4 >> 2];
                    return ret
                },
                getStr: function(ptr) {
                    var ret = UTF8ToString(ptr);
                    return ret
                },
                getStreamFromFD: function(fd) {
                    var stream = FS.getStream(fd);
                    if (!stream) throw new FS.ErrnoError(8);
                    return stream
                },
                get64: function(low, high) {
                    return low
                }
            };
            Module["SYSCALLS"] = SYSCALLS;

            function ___sys__newselect(nfds, readfds, writefds, exceptfds, timeout) {
                try {
                    var total = 0;
                    var srcReadLow = readfds ? HEAP32[readfds >> 2] : 0,
                        srcReadHigh = readfds ? HEAP32[readfds + 4 >> 2] : 0;
                    var srcWriteLow = writefds ? HEAP32[writefds >> 2] : 0,
                        srcWriteHigh = writefds ? HEAP32[writefds + 4 >> 2] : 0;
                    var srcExceptLow = exceptfds ? HEAP32[exceptfds >> 2] : 0,
                        srcExceptHigh = exceptfds ? HEAP32[exceptfds + 4 >> 2] : 0;
                    var dstReadLow = 0,
                        dstReadHigh = 0;
                    var dstWriteLow = 0,
                        dstWriteHigh = 0;
                    var dstExceptLow = 0,
                        dstExceptHigh = 0;
                    var allLow = (readfds ? HEAP32[readfds >> 2] : 0) | (writefds ? HEAP32[writefds >> 2] : 0) | (exceptfds ? HEAP32[exceptfds >> 2] : 0);
                    var allHigh = (readfds ? HEAP32[readfds + 4 >> 2] : 0) | (writefds ? HEAP32[writefds + 4 >> 2] : 0) | (exceptfds ? HEAP32[exceptfds + 4 >> 2] : 0);
                    var check = function(fd, low, high, val) {
                        return fd < 32 ? low & val : high & val
                    };
                    for (var fd = 0; fd < nfds; fd++) {
                        var mask = 1 << fd % 32;
                        if (!check(fd, allLow, allHigh, mask)) {
                            continue
                        }
                        var stream = FS.getStream(fd);
                        if (!stream) throw new FS.ErrnoError(8);
                        var flags = SYSCALLS.DEFAULT_POLLMASK;
                        if (stream.stream_ops.poll) {
                            flags = stream.stream_ops.poll(stream)
                        }
                        if (flags & 1 && check(fd, srcReadLow, srcReadHigh, mask)) {
                            fd < 32 ? dstReadLow = dstReadLow | mask : dstReadHigh = dstReadHigh | mask;
                            total++
                        }
                        if (flags & 4 && check(fd, srcWriteLow, srcWriteHigh, mask)) {
                            fd < 32 ? dstWriteLow = dstWriteLow | mask : dstWriteHigh = dstWriteHigh | mask;
                            total++
                        }
                        if (flags & 2 && check(fd, srcExceptLow, srcExceptHigh, mask)) {
                            fd < 32 ? dstExceptLow = dstExceptLow | mask : dstExceptHigh = dstExceptHigh | mask;
                            total++
                        }
                    }
                    if (readfds) {
                        HEAP32[readfds >> 2] = dstReadLow;
                        HEAP32[readfds + 4 >> 2] = dstReadHigh
                    }
                    if (writefds) {
                        HEAP32[writefds >> 2] = dstWriteLow;
                        HEAP32[writefds + 4 >> 2] = dstWriteHigh
                    }
                    if (exceptfds) {
                        HEAP32[exceptfds >> 2] = dstExceptLow;
                        HEAP32[exceptfds + 4 >> 2] = dstExceptHigh
                    }
                    return total
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys__newselect"] = ___sys__newselect;
            var ERRNO_CODES = {
                EPERM: 63,
                ENOENT: 44,
                ESRCH: 71,
                EINTR: 27,
                EIO: 29,
                ENXIO: 60,
                E2BIG: 1,
                ENOEXEC: 45,
                EBADF: 8,
                ECHILD: 12,
                EAGAIN: 6,
                EWOULDBLOCK: 6,
                ENOMEM: 48,
                EACCES: 2,
                EFAULT: 21,
                ENOTBLK: 105,
                EBUSY: 10,
                EEXIST: 20,
                EXDEV: 75,
                ENODEV: 43,
                ENOTDIR: 54,
                EISDIR: 31,
                EINVAL: 28,
                ENFILE: 41,
                EMFILE: 33,
                ENOTTY: 59,
                ETXTBSY: 74,
                EFBIG: 22,
                ENOSPC: 51,
                ESPIPE: 70,
                EROFS: 69,
                EMLINK: 34,
                EPIPE: 64,
                EDOM: 18,
                ERANGE: 68,
                ENOMSG: 49,
                EIDRM: 24,
                ECHRNG: 106,
                EL2NSYNC: 156,
                EL3HLT: 107,
                EL3RST: 108,
                ELNRNG: 109,
                EUNATCH: 110,
                ENOCSI: 111,
                EL2HLT: 112,
                EDEADLK: 16,
                ENOLCK: 46,
                EBADE: 113,
                EBADR: 114,
                EXFULL: 115,
                ENOANO: 104,
                EBADRQC: 103,
                EBADSLT: 102,
                EDEADLOCK: 16,
                EBFONT: 101,
                ENOSTR: 100,
                ENODATA: 116,
                ETIME: 117,
                ENOSR: 118,
                ENONET: 119,
                ENOPKG: 120,
                EREMOTE: 121,
                ENOLINK: 47,
                EADV: 122,
                ESRMNT: 123,
                ECOMM: 124,
                EPROTO: 65,
                EMULTIHOP: 36,
                EDOTDOT: 125,
                EBADMSG: 9,
                ENOTUNIQ: 126,
                EBADFD: 127,
                EREMCHG: 128,
                ELIBACC: 129,
                ELIBBAD: 130,
                ELIBSCN: 131,
                ELIBMAX: 132,
                ELIBEXEC: 133,
                ENOSYS: 52,
                ENOTEMPTY: 55,
                ENAMETOOLONG: 37,
                ELOOP: 32,
                EOPNOTSUPP: 138,
                EPFNOSUPPORT: 139,
                ECONNRESET: 15,
                ENOBUFS: 42,
                EAFNOSUPPORT: 5,
                EPROTOTYPE: 67,
                ENOTSOCK: 57,
                ENOPROTOOPT: 50,
                ESHUTDOWN: 140,
                ECONNREFUSED: 14,
                EADDRINUSE: 3,
                ECONNABORTED: 13,
                ENETUNREACH: 40,
                ENETDOWN: 38,
                ETIMEDOUT: 73,
                EHOSTDOWN: 142,
                EHOSTUNREACH: 23,
                EINPROGRESS: 26,
                EALREADY: 7,
                EDESTADDRREQ: 17,
                EMSGSIZE: 35,
                EPROTONOSUPPORT: 66,
                ESOCKTNOSUPPORT: 137,
                EADDRNOTAVAIL: 4,
                ENETRESET: 39,
                EISCONN: 30,
                ENOTCONN: 53,
                ETOOMANYREFS: 141,
                EUSERS: 136,
                EDQUOT: 19,
                ESTALE: 72,
                ENOTSUP: 138,
                ENOMEDIUM: 148,
                EILSEQ: 25,
                EOVERFLOW: 61,
                ECANCELED: 11,
                ENOTRECOVERABLE: 56,
                EOWNERDEAD: 62,
                ESTRPIPE: 135
            };
            Module["ERRNO_CODES"] = ERRNO_CODES;
            var SOCKFS = {
                mount: function(mount) {
                    Module["websocket"] = Module["websocket"] && "object" === typeof Module["websocket"] ? Module["websocket"] : {};
                    Module["websocket"]._callbacks = {};
                    Module["websocket"]["on"] = function(event, callback) {
                        if ("function" === typeof callback) {
                            this._callbacks[event] = callback
                        }
                        return this
                    };
                    Module["websocket"].emit = function(event, param) {
                        if ("function" === typeof this._callbacks[event]) {
                            this._callbacks[event].call(this, param)
                        }
                    };
                    return FS.createNode(null, "/", 16384 | 511, 0)
                },
                createSocket: function(family, type, protocol) {
                    type &= ~526336;
                    var streaming = type == 1;
                    if (protocol) {
                        assert(streaming == (protocol == 6))
                    }
                    var sock = {
                        family: family,
                        type: type,
                        protocol: protocol,
                        server: null,
                        error: null,
                        peers: {},
                        pending: [],
                        recv_queue: [],
                        sock_ops: SOCKFS.websocket_sock_ops
                    };
                    var name = SOCKFS.nextname();
                    var node = FS.createNode(SOCKFS.root, name, 49152, 0);
                    node.sock = sock;
                    var stream = FS.createStream({
                        path: name,
                        node: node,
                        flags: 2,
                        seekable: false,
                        stream_ops: SOCKFS.stream_ops
                    });
                    sock.stream = stream;
                    return sock
                },
                getSocket: function(fd) {
                    var stream = FS.getStream(fd);
                    if (!stream || !FS.isSocket(stream.node.mode)) {
                        return null
                    }
                    return stream.node.sock
                },
                stream_ops: {
                    poll: function(stream) {
                        var sock = stream.node.sock;
                        return sock.sock_ops.poll(sock)
                    },
                    ioctl: function(stream, request, varargs) {
                        var sock = stream.node.sock;
                        return sock.sock_ops.ioctl(sock, request, varargs)
                    },
                    read: function(stream, buffer, offset, length, position) {
                        var sock = stream.node.sock;
                        var msg = sock.sock_ops.recvmsg(sock, length);
                        if (!msg) {
                            return 0
                        }
                        buffer.set(msg.buffer, offset);
                        return msg.buffer.length
                    },
                    write: function(stream, buffer, offset, length, position) {
                        var sock = stream.node.sock;
                        return sock.sock_ops.sendmsg(sock, buffer, offset, length)
                    },
                    close: function(stream) {
                        var sock = stream.node.sock;
                        sock.sock_ops.close(sock)
                    }
                },
                nextname: function() {
                    if (!SOCKFS.nextname.current) {
                        SOCKFS.nextname.current = 0
                    }
                    return "socket[" + SOCKFS.nextname.current++ + "]"
                },
                websocket_sock_ops: {
                    createPeer: function(sock, addr, port) {
                        var ws;
                        if (typeof addr === "object") {
                            ws = addr;
                            addr = null;
                            port = null
                        }
                        if (ws) {
                            if (ws._socket) {
                                addr = ws._socket.remoteAddress;
                                port = ws._socket.remotePort
                            } else {
                                var result = /ws[s]?:\/\/([^:]+):(\d+)/.exec(ws.url);
                                if (!result) {
                                    throw new Error("WebSocket URL must be in the format ws(s)://address:port")
                                }
                                addr = result[1];
                                port = parseInt(result[2], 10)
                            }
                        } else {
                            try {
                                var runtimeConfig = Module["websocket"] && "object" === typeof Module["websocket"];
                                var url = "ws:#".replace("#", "//");
                                if (runtimeConfig) {
                                    if ("string" === typeof Module["websocket"]["url"]) {
                                        url = Module["websocket"]["url"]
                                    }
                                }
                                if (url === "ws://" || url === "wss://") {
                                    var parts = addr.split("/");
                                    url = url + parts[0] + ":" + port + "/" + parts.slice(1).join("/")
                                }
                                var subProtocols = "binary";
                                if (runtimeConfig) {
                                    if ("string" === typeof Module["websocket"]["subprotocol"]) {
                                        subProtocols = Module["websocket"]["subprotocol"]
                                    }
                                }
                                var opts = undefined;
                                if (subProtocols !== "null") {
                                    subProtocols = subProtocols.replace(/^ +| +$/g, "").split(/ *, */);
                                    opts = ENVIRONMENT_IS_NODE ? {
                                        "protocol": subProtocols.toString()
                                    } : subProtocols
                                }
                                if (runtimeConfig && null === Module["websocket"]["subprotocol"]) {
                                    subProtocols = "null";
                                    opts = undefined
                                }
                                var WebSocketConstructor;
                                if (ENVIRONMENT_IS_NODE) {
                                    WebSocketConstructor = require("ws")
                                } else {
                                    WebSocketConstructor = WebSocket
                                }
                                ws = new WebSocketConstructor(url, opts);
                                ws.binaryType = "arraybuffer"
                            } catch (e) {
                                throw new FS.ErrnoError(ERRNO_CODES.EHOSTUNREACH)
                            }
                        }
                        var peer = {
                            addr: addr,
                            port: port,
                            socket: ws,
                            dgram_send_queue: []
                        };
                        SOCKFS.websocket_sock_ops.addPeer(sock, peer);
                        SOCKFS.websocket_sock_ops.handlePeerEvents(sock, peer);
                        if (sock.type === 2 && typeof sock.sport !== "undefined") {
                            peer.dgram_send_queue.push(new Uint8Array([255, 255, 255, 255, "p".charCodeAt(0), "o".charCodeAt(0), "r".charCodeAt(0), "t".charCodeAt(0), (sock.sport & 65280) >> 8, sock.sport & 255]))
                        }
                        return peer
                    },
                    getPeer: function(sock, addr, port) {
                        return sock.peers[addr + ":" + port]
                    },
                    addPeer: function(sock, peer) {
                        sock.peers[peer.addr + ":" + peer.port] = peer
                    },
                    removePeer: function(sock, peer) {
                        delete sock.peers[peer.addr + ":" + peer.port]
                    },
                    handlePeerEvents: function(sock, peer) {
                        var first = true;
                        var handleOpen = function() {
                            Module["websocket"].emit("open", sock.stream.fd);
                            try {
                                var queued = peer.dgram_send_queue.shift();
                                while (queued) {
                                    peer.socket.send(queued);
                                    queued = peer.dgram_send_queue.shift()
                                }
                            } catch (e) {
                                peer.socket.close()
                            }
                        };

                        function handleMessage(data) {
                            if (typeof data === "string") {
                                var encoder = new TextEncoder;
                                data = encoder.encode(data)
                            } else {
                                assert(data.byteLength !== undefined);
                                if (data.byteLength == 0) {
                                    return
                                } else {
                                    data = new Uint8Array(data)
                                }
                            }
                            var wasfirst = first;
                            first = false;
                            if (wasfirst && data.length === 10 && data[0] === 255 && data[1] === 255 && data[2] === 255 && data[3] === 255 && data[4] === "p".charCodeAt(0) && data[5] === "o".charCodeAt(0) && data[6] === "r".charCodeAt(0) && data[7] === "t".charCodeAt(0)) {
                                var newport = data[8] << 8 | data[9];
                                SOCKFS.websocket_sock_ops.removePeer(sock, peer);
                                peer.port = newport;
                                SOCKFS.websocket_sock_ops.addPeer(sock, peer);
                                return
                            }
                            sock.recv_queue.push({
                                addr: peer.addr,
                                port: peer.port,
                                data: data
                            });
                            Module["websocket"].emit("message", sock.stream.fd)
                        }
                        if (ENVIRONMENT_IS_NODE) {
                            peer.socket.on("open", handleOpen);
                            peer.socket.on("message", function(data, flags) {
                                if (!flags.binary) {
                                    return
                                }
                                handleMessage(new Uint8Array(data).buffer)
                            });
                            peer.socket.on("close", function() {
                                Module["websocket"].emit("close", sock.stream.fd)
                            });
                            peer.socket.on("error", function(error) {
                                sock.error = ERRNO_CODES.ECONNREFUSED;
                                Module["websocket"].emit("error", [sock.stream.fd, sock.error, "ECONNREFUSED: Connection refused"])
                            })
                        } else {
                            peer.socket.onopen = handleOpen;
                            peer.socket.onclose = function() {
                                Module["websocket"].emit("close", sock.stream.fd)
                            };
                            peer.socket.onmessage = function peer_socket_onmessage(event) {
                                handleMessage(event.data)
                            };
                            peer.socket.onerror = function(error) {
                                sock.error = ERRNO_CODES.ECONNREFUSED;
                                Module["websocket"].emit("error", [sock.stream.fd, sock.error, "ECONNREFUSED: Connection refused"])
                            }
                        }
                    },
                    poll: function(sock) {
                        if (sock.type === 1 && sock.server) {
                            return sock.pending.length ? 64 | 1 : 0
                        }
                        var mask = 0;
                        var dest = sock.type === 1 ? SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport) : null;
                        if (sock.recv_queue.length || !dest || dest && dest.socket.readyState === dest.socket.CLOSING || dest && dest.socket.readyState === dest.socket.CLOSED) {
                            mask |= 64 | 1
                        }
                        if (!dest || dest && dest.socket.readyState === dest.socket.OPEN) {
                            mask |= 4
                        }
                        if (dest && dest.socket.readyState === dest.socket.CLOSING || dest && dest.socket.readyState === dest.socket.CLOSED) {
                            mask |= 16
                        }
                        return mask
                    },
                    ioctl: function(sock, request, arg) {
                        switch (request) {
                            case 21531:
                                var bytes = 0;
                                if (sock.recv_queue.length) {
                                    bytes = sock.recv_queue[0].data.length
                                }
                                HEAP32[arg >> 2] = bytes;
                                return 0;
                            default:
                                return ERRNO_CODES.EINVAL
                        }
                    },
                    close: function(sock) {
                        if (sock.server) {
                            try {
                                sock.server.close()
                            } catch (e) {}
                            sock.server = null
                        }
                        var peers = Object.keys(sock.peers);
                        for (var i = 0; i < peers.length; i++) {
                            var peer = sock.peers[peers[i]];
                            try {
                                peer.socket.close()
                            } catch (e) {}
                            SOCKFS.websocket_sock_ops.removePeer(sock, peer)
                        }
                        return 0
                    },
                    bind: function(sock, addr, port) {
                        if (typeof sock.saddr !== "undefined" || typeof sock.sport !== "undefined") {
                            throw new FS.ErrnoError(ERRNO_CODES.EINVAL)
                        }
                        sock.saddr = addr;
                        sock.sport = port;
                        if (sock.type === 2) {
                            if (sock.server) {
                                sock.server.close();
                                sock.server = null
                            }
                            try {
                                sock.sock_ops.listen(sock, 0)
                            } catch (e) {
                                if (!(e instanceof FS.ErrnoError)) throw e;
                                if (e.errno !== ERRNO_CODES.EOPNOTSUPP) throw e
                            }
                        }
                    },
                    connect: function(sock, addr, port) {
                        if (sock.server) {
                            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP)
                        }
                        if (typeof sock.daddr !== "undefined" && typeof sock.dport !== "undefined") {
                            var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
                            if (dest) {
                                if (dest.socket.readyState === dest.socket.CONNECTING) {
                                    throw new FS.ErrnoError(ERRNO_CODES.EALREADY)
                                } else {
                                    throw new FS.ErrnoError(ERRNO_CODES.EISCONN)
                                }
                            }
                        }
                        var peer = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
                        sock.daddr = peer.addr;
                        sock.dport = peer.port;
                        throw new FS.ErrnoError(ERRNO_CODES.EINPROGRESS)
                    },
                    listen: function(sock, backlog) {
                        if (!ENVIRONMENT_IS_NODE) {
                            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP)
                        }
                        if (sock.server) {
                            throw new FS.ErrnoError(ERRNO_CODES.EINVAL)
                        }
                        var WebSocketServer = require("ws").Server;
                        var host = sock.saddr;
                        sock.server = new WebSocketServer({
                            host: host,
                            port: sock.sport
                        });
                        Module["websocket"].emit("listen", sock.stream.fd);
                        sock.server.on("connection", function(ws) {
                            if (sock.type === 1) {
                                var newsock = SOCKFS.createSocket(sock.family, sock.type, sock.protocol);
                                var peer = SOCKFS.websocket_sock_ops.createPeer(newsock, ws);
                                newsock.daddr = peer.addr;
                                newsock.dport = peer.port;
                                sock.pending.push(newsock);
                                Module["websocket"].emit("connection", newsock.stream.fd)
                            } else {
                                SOCKFS.websocket_sock_ops.createPeer(sock, ws);
                                Module["websocket"].emit("connection", sock.stream.fd)
                            }
                        });
                        sock.server.on("closed", function() {
                            Module["websocket"].emit("close", sock.stream.fd);
                            sock.server = null
                        });
                        sock.server.on("error", function(error) {
                            sock.error = ERRNO_CODES.EHOSTUNREACH;
                            Module["websocket"].emit("error", [sock.stream.fd, sock.error, "EHOSTUNREACH: Host is unreachable"])
                        })
                    },
                    accept: function(listensock) {
                        if (!listensock.server) {
                            throw new FS.ErrnoError(ERRNO_CODES.EINVAL)
                        }
                        var newsock = listensock.pending.shift();
                        newsock.stream.flags = listensock.stream.flags;
                        return newsock
                    },
                    getname: function(sock, peer) {
                        var addr, port;
                        if (peer) {
                            if (sock.daddr === undefined || sock.dport === undefined) {
                                throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN)
                            }
                            addr = sock.daddr;
                            port = sock.dport
                        } else {
                            addr = sock.saddr || 0;
                            port = sock.sport || 0
                        }
                        return {
                            addr: addr,
                            port: port
                        }
                    },
                    sendmsg: function(sock, buffer, offset, length, addr, port) {
                        if (sock.type === 2) {
                            if (addr === undefined || port === undefined) {
                                addr = sock.daddr;
                                port = sock.dport
                            }
                            if (addr === undefined || port === undefined) {
                                throw new FS.ErrnoError(ERRNO_CODES.EDESTADDRREQ)
                            }
                        } else {
                            addr = sock.daddr;
                            port = sock.dport
                        }
                        var dest = SOCKFS.websocket_sock_ops.getPeer(sock, addr, port);
                        if (sock.type === 1) {
                            if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                                throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN)
                            } else if (dest.socket.readyState === dest.socket.CONNECTING) {
                                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN)
                            }
                        }
                        if (ArrayBuffer.isView(buffer)) {
                            offset += buffer.byteOffset;
                            buffer = buffer.buffer
                        }
                        var data;
                        data = buffer.slice(offset, offset + length);
                        if (sock.type === 2) {
                            if (!dest || dest.socket.readyState !== dest.socket.OPEN) {
                                if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                                    dest = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port)
                                }
                                dest.dgram_send_queue.push(data);
                                return length
                            }
                        }
                        try {
                            dest.socket.send(data);
                            return length
                        } catch (e) {
                            throw new FS.ErrnoError(ERRNO_CODES.EINVAL)
                        }
                    },
                    recvmsg: function(sock, length) {
                        if (sock.type === 1 && sock.server) {
                            throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN)
                        }
                        var queued = sock.recv_queue.shift();
                        if (!queued) {
                            if (sock.type === 1) {
                                var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
                                if (!dest) {
                                    throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN)
                                } else if (dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                                    return null
                                } else {
                                    throw new FS.ErrnoError(ERRNO_CODES.EAGAIN)
                                }
                            } else {
                                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN)
                            }
                        }
                        var queuedLength = queued.data.byteLength || queued.data.length;
                        var queuedOffset = queued.data.byteOffset || 0;
                        var queuedBuffer = queued.data.buffer || queued.data;
                        var bytesRead = Math.min(length, queuedLength);
                        var res = {
                            buffer: new Uint8Array(queuedBuffer, queuedOffset, bytesRead),
                            addr: queued.addr,
                            port: queued.port
                        };
                        if (sock.type === 1 && bytesRead < queuedLength) {
                            var bytesRemaining = queuedLength - bytesRead;
                            queued.data = new Uint8Array(queuedBuffer, queuedOffset + bytesRead, bytesRemaining);
                            sock.recv_queue.unshift(queued)
                        }
                        return res
                    }
                }
            };
            Module["SOCKFS"] = SOCKFS;

            function getSocketFromFD(fd) {
                var socket = SOCKFS.getSocket(fd);
                if (!socket) throw new FS.ErrnoError(8);
                return socket
            }
            Module["getSocketFromFD"] = getSocketFromFD;
            var Sockets = {
                BUFFER_SIZE: 10240,
                MAX_BUFFER_SIZE: 10485760,
                nextFd: 1,
                fds: {},
                nextport: 1,
                maxport: 65535,
                peer: null,
                connections: {},
                portmap: {},
                localAddr: 4261412874,
                addrPool: [33554442, 50331658, 67108874, 83886090, 100663306, 117440522, 134217738, 150994954, 167772170, 184549386, 201326602, 218103818, 234881034]
            };
            Module["Sockets"] = Sockets;

            function inetPton4(str) {
                var b = str.split(".");
                for (var i = 0; i < 4; i++) {
                    var tmp = Number(b[i]);
                    if (isNaN(tmp)) return null;
                    b[i] = tmp
                }
                return (b[0] | b[1] << 8 | b[2] << 16 | b[3] << 24) >>> 0
            }
            Module["inetPton4"] = inetPton4;

            function jstoi_q(str) {
                return parseInt(str)
            }
            Module["jstoi_q"] = jstoi_q;

            function inetPton6(str) {
                var words;
                var w, offset, z, i;
                var valid6regx = /^((?=.*::)(?!.*::.+::)(::)?([\dA-F]{1,4}:(:|\b)|){5}|([\dA-F]{1,4}:){6})((([\dA-F]{1,4}((?!\3)::|:\b|$))|(?!\2\3)){2}|(((2[0-4]|1\d|[1-9])?\d|25[0-5])\.?\b){4})$/i;
                var parts = [];
                if (!valid6regx.test(str)) {
                    return null
                }
                if (str === "::") {
                    return [0, 0, 0, 0, 0, 0, 0, 0]
                }
                if (str.startsWith("::")) {
                    str = str.replace("::", "Z:")
                } else {
                    str = str.replace("::", ":Z:")
                }
                if (str.indexOf(".") > 0) {
                    str = str.replace(new RegExp("[.]", "g"), ":");
                    words = str.split(":");
                    words[words.length - 4] = jstoi_q(words[words.length - 4]) + jstoi_q(words[words.length - 3]) * 256;
                    words[words.length - 3] = jstoi_q(words[words.length - 2]) + jstoi_q(words[words.length - 1]) * 256;
                    words = words.slice(0, words.length - 2)
                } else {
                    words = str.split(":")
                }
                offset = 0;
                z = 0;
                for (w = 0; w < words.length; w++) {
                    if (typeof words[w] === "string") {
                        if (words[w] === "Z") {
                            for (z = 0; z < 8 - words.length + 1; z++) {
                                parts[w + z] = 0
                            }
                            offset = z - 1
                        } else {
                            parts[w + offset] = _htons(parseInt(words[w], 16))
                        }
                    } else {
                        parts[w + offset] = words[w]
                    }
                }
                return [parts[1] << 16 | parts[0], parts[3] << 16 | parts[2], parts[5] << 16 | parts[4], parts[7] << 16 | parts[6]]
            }
            Module["inetPton6"] = inetPton6;

            function writeSockaddr(sa, family, addr, port, addrlen) {
                switch (family) {
                    case 2:
                        addr = inetPton4(addr);
                        if (addrlen) {
                            HEAP32[addrlen >> 2] = 16
                        }
                        HEAP16[sa >> 1] = family;
                        HEAP32[sa + 4 >> 2] = addr;
                        HEAP16[sa + 2 >> 1] = _htons(port);
                        tempI64 = [0 >>> 0, (tempDouble = 0, +Math.abs(tempDouble) >= 1 ? tempDouble > 0 ? (Math.min(+Math.floor(tempDouble / 4294967296), 4294967295) | 0) >>> 0 : ~~+Math.ceil((tempDouble - +(~~tempDouble >>> 0)) / 4294967296) >>> 0 : 0)], HEAP32[sa + 8 >> 2] = tempI64[0], HEAP32[sa + 12 >> 2] = tempI64[1];
                        break;
                    case 10:
                        addr = inetPton6(addr);
                        if (addrlen) {
                            HEAP32[addrlen >> 2] = 28
                        }
                        HEAP32[sa >> 2] = family;
                        HEAP32[sa + 8 >> 2] = addr[0];
                        HEAP32[sa + 12 >> 2] = addr[1];
                        HEAP32[sa + 16 >> 2] = addr[2];
                        HEAP32[sa + 20 >> 2] = addr[3];
                        HEAP16[sa + 2 >> 1] = _htons(port);
                        HEAP32[sa + 4 >> 2] = 0;
                        HEAP32[sa + 24 >> 2] = 0;
                        break;
                    default:
                        return 5
                }
                return 0
            }
            Module["writeSockaddr"] = writeSockaddr;
            var DNS = {
                address_map: {
                    id: 1,
                    addrs: {},
                    names: {}
                },
                lookup_name: function(name) {
                    var res = inetPton4(name);
                    if (res !== null) {
                        return name
                    }
                    res = inetPton6(name);
                    if (res !== null) {
                        return name
                    }
                    var addr;
                    if (DNS.address_map.addrs[name]) {
                        addr = DNS.address_map.addrs[name]
                    } else {
                        var id = DNS.address_map.id++;
                        assert(id < 65535, "exceeded max address mappings of 65535");
                        addr = "172.29." + (id & 255) + "." + (id & 65280);
                        DNS.address_map.names[addr] = name;
                        DNS.address_map.addrs[name] = addr
                    }
                    return addr
                },
                lookup_addr: function(addr) {
                    if (DNS.address_map.names[addr]) {
                        return DNS.address_map.names[addr]
                    }
                    return null
                }
            };
            Module["DNS"] = DNS;

            function ___sys_accept4(fd, addr, addrlen, flags) {
                try {
                    var sock = getSocketFromFD(fd);
                    var newsock = sock.sock_ops.accept(sock);
                    if (addr) {
                        var errno = writeSockaddr(addr, newsock.family, DNS.lookup_name(newsock.daddr), newsock.dport, addrlen)
                    }
                    return newsock.stream.fd
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_accept4"] = ___sys_accept4;

            function ___sys_access(path, amode) {
                try {
                    path = SYSCALLS.getStr(path);
                    return SYSCALLS.doAccess(path, amode)
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_access"] = ___sys_access;

            function ___sys_acct(filename) {
                return -52
            }
            Module["___sys_acct"] = ___sys_acct;

            function inetNtop4(addr) {
                return (addr & 255) + "." + (addr >> 8 & 255) + "." + (addr >> 16 & 255) + "." + (addr >> 24 & 255)
            }
            Module["inetNtop4"] = inetNtop4;

            function inetNtop6(ints) {
                var str = "";
                var word = 0;
                var longest = 0;
                var lastzero = 0;
                var zstart = 0;
                var len = 0;
                var i = 0;
                var parts = [ints[0] & 65535, ints[0] >> 16, ints[1] & 65535, ints[1] >> 16, ints[2] & 65535, ints[2] >> 16, ints[3] & 65535, ints[3] >> 16];
                var hasipv4 = true;
                var v4part = "";
                for (i = 0; i < 5; i++) {
                    if (parts[i] !== 0) {
                        hasipv4 = false;
                        break
                    }
                }
                if (hasipv4) {
                    v4part = inetNtop4(parts[6] | parts[7] << 16);
                    if (parts[5] === -1) {
                        str = "::ffff:";
                        str += v4part;
                        return str
                    }
                    if (parts[5] === 0) {
                        str = "::";
                        if (v4part === "0.0.0.0") v4part = "";
                        if (v4part === "0.0.0.1") v4part = "1";
                        str += v4part;
                        return str
                    }
                }
                for (word = 0; word < 8; word++) {
                    if (parts[word] === 0) {
                        if (word - lastzero > 1) {
                            len = 0
                        }
                        lastzero = word;
                        len++
                    }
                    if (len > longest) {
                        longest = len;
                        zstart = word - longest + 1
                    }
                }
                for (word = 0; word < 8; word++) {
                    if (longest > 1) {
                        if (parts[word] === 0 && word >= zstart && word < zstart + longest) {
                            if (word === zstart) {
                                str += ":";
                                if (zstart === 0) str += ":"
                            }
                            continue
                        }
                    }
                    str += Number(_ntohs(parts[word] & 65535)).toString(16);
                    str += word < 7 ? ":" : ""
                }
                return str
            }
            Module["inetNtop6"] = inetNtop6;

            function readSockaddr(sa, salen) {
                var family = HEAP16[sa >> 1];
                var port = _ntohs(HEAPU16[sa + 2 >> 1]);
                var addr;
                switch (family) {
                    case 2:
                        if (salen !== 16) {
                            return {
                                errno: 28
                            }
                        }
                        addr = HEAP32[sa + 4 >> 2];
                        addr = inetNtop4(addr);
                        break;
                    case 10:
                        if (salen !== 28) {
                            return {
                                errno: 28
                            }
                        }
                        addr = [HEAP32[sa + 8 >> 2], HEAP32[sa + 12 >> 2], HEAP32[sa + 16 >> 2], HEAP32[sa + 20 >> 2]];
                        addr = inetNtop6(addr);
                        break;
                    default:
                        return {
                            errno: 5
                        }
                }
                return {
                    family: family,
                    addr: addr,
                    port: port
                }
            }
            Module["readSockaddr"] = readSockaddr;

            function getSocketAddress(addrp, addrlen, allowNull) {
                if (allowNull && addrp === 0) return null;
                var info = readSockaddr(addrp, addrlen);
                if (info.errno) throw new FS.ErrnoError(info.errno);
                info.addr = DNS.lookup_addr(info.addr) || info.addr;
                return info
            }
            Module["getSocketAddress"] = getSocketAddress;

            function ___sys_bind(fd, addr, addrlen) {
                try {
                    var sock = getSocketFromFD(fd);
                    var info = getSocketAddress(addr, addrlen);
                    sock.sock_ops.bind(sock, info.addr, info.port);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_bind"] = ___sys_bind;

            function ___sys_chdir(path) {
                try {
                    path = SYSCALLS.getStr(path);
                    FS.chdir(path);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_chdir"] = ___sys_chdir;

            function ___sys_chmod(path, mode) {
                try {
                    path = SYSCALLS.getStr(path);
                    FS.chmod(path, mode);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_chmod"] = ___sys_chmod;

            function ___sys_chown32(path, owner, group) {
                try {
                    path = SYSCALLS.getStr(path);
                    FS.chown(path, owner, group);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_chown32"] = ___sys_chown32;

            function ___sys_connect(fd, addr, addrlen) {
                try {
                    var sock = getSocketFromFD(fd);
                    var info = getSocketAddress(addr, addrlen);
                    sock.sock_ops.connect(sock, info.addr, info.port);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_connect"] = ___sys_connect;

            function ___sys_dup(fd) {
                try {
                    var old = SYSCALLS.getStreamFromFD(fd);
                    return FS.open(old.path, old.flags, 0).fd
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_dup"] = ___sys_dup;

            function ___sys_dup2(oldfd, suggestFD) {
                try {
                    var old = SYSCALLS.getStreamFromFD(oldfd);
                    if (old.fd === suggestFD) return suggestFD;
                    return SYSCALLS.doDup(old.path, old.flags, suggestFD)
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_dup2"] = ___sys_dup2;

            function ___sys_dup3(fd, suggestFD, flags) {
                try {
                    var old = SYSCALLS.getStreamFromFD(fd);
                    if (old.fd === suggestFD) return -28;
                    return SYSCALLS.doDup(old.path, old.flags, suggestFD)
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_dup3"] = ___sys_dup3;

            function ___sys_fadvise64_64(fd, offset, len, advice) {
                return 0
            }
            Module["___sys_fadvise64_64"] = ___sys_fadvise64_64;

            function ___sys_fallocate(fd, mode, off_low, off_high, len_low, len_high) {
                try {
                    var stream = SYSCALLS.getStreamFromFD(fd);
                    var offset = SYSCALLS.get64(off_low, off_high);
                    var len = SYSCALLS.get64(len_low, len_high);
                    FS.allocate(stream, offset, len);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_fallocate"] = ___sys_fallocate;

            function ___sys_fchdir(fd) {
                try {
                    var stream = SYSCALLS.getStreamFromFD(fd);
                    FS.chdir(stream.path);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_fchdir"] = ___sys_fchdir;

            function ___sys_fchmod(fd, mode) {
                try {
                    FS.fchmod(fd, mode);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_fchmod"] = ___sys_fchmod;

            function ___sys_fchmodat(dirfd, path, mode, varargs) {
                SYSCALLS.varargs = varargs;
                try {
                    path = SYSCALLS.getStr(path);
                    path = SYSCALLS.calculateAt(dirfd, path);
                    FS.chmod(path, mode);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_fchmodat"] = ___sys_fchmodat;

            function ___sys_fchown32(fd, owner, group) {
                try {
                    FS.fchown(fd, owner, group);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_fchown32"] = ___sys_fchown32;

            function ___sys_fchownat(dirfd, path, owner, group, flags) {
                try {
                    path = SYSCALLS.getStr(path);
                    path = SYSCALLS.calculateAt(dirfd, path);
                    FS.chown(path, owner, group);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_fchownat"] = ___sys_fchownat;

            function ___sys_fcntl64(fd, cmd, varargs) {
                SYSCALLS.varargs = varargs;
                try {
                    var stream = SYSCALLS.getStreamFromFD(fd);
                    switch (cmd) {
                        case 0: {
                            var arg = SYSCALLS.get();
                            if (arg < 0) {
                                return -28
                            }
                            var newStream;
                            newStream = FS.open(stream.path, stream.flags, 0, arg);
                            return newStream.fd
                        }
                        case 1:
                        case 2:
                            return 0;
                        case 3:
                            return stream.flags;
                        case 4: {
                            var arg = SYSCALLS.get();
                            stream.flags |= arg;
                            return 0
                        }
                        case 12: {
                            var arg = SYSCALLS.get();
                            var offset = 0;
                            HEAP16[arg + offset >> 1] = 2;
                            return 0
                        }
                        case 13:
                        case 14:
                            return 0;
                        case 16:
                        case 8:
                            return -28;
                        case 9:
                            setErrNo(28);
                            return -1;
                        default: {
                            return -28
                        }
                    }
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_fcntl64"] = ___sys_fcntl64;

            function ___sys_fdatasync(fd) {
                try {
                    var stream = SYSCALLS.getStreamFromFD(fd);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_fdatasync"] = ___sys_fdatasync;

            function ___sys_fstat64(fd, buf) {
                try {
                    var stream = SYSCALLS.getStreamFromFD(fd);
                    return SYSCALLS.doStat(FS.stat, stream.path, buf)
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_fstat64"] = ___sys_fstat64;

            function ___sys_fstatat64(dirfd, path, buf, flags) {
                try {
                    path = SYSCALLS.getStr(path);
                    var nofollow = flags & 256;
                    var allowEmpty = flags & 4096;
                    flags = flags & ~4352;
                    path = SYSCALLS.calculateAt(dirfd, path, allowEmpty);
                    return SYSCALLS.doStat(nofollow ? FS.lstat : FS.stat, path, buf)
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_fstatat64"] = ___sys_fstatat64;

            function ___sys_fstatfs64(fd, size, buf) {
                try {
                    var stream = SYSCALLS.getStreamFromFD(fd);
                    return ___sys_statfs64(0, size, buf)
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_fstatfs64"] = ___sys_fstatfs64;

            function ___sys_ftruncate64(fd, zero, low, high) {
                try {
                    var length = SYSCALLS.get64(low, high);
                    FS.ftruncate(fd, length);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_ftruncate64"] = ___sys_ftruncate64;

            function ___sys_getcwd(buf, size) {
                try {
                    if (size === 0) return -28;
                    var cwd = FS.cwd();
                    var cwdLengthInBytes = lengthBytesUTF8(cwd);
                    if (size < cwdLengthInBytes + 1) return -68;
                    stringToUTF8(cwd, buf, size);
                    return buf
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_getcwd"] = ___sys_getcwd;

            function ___sys_getdents64(fd, dirp, count) {
                try {
                    var stream = SYSCALLS.getStreamFromFD(fd);
                    if (!stream.getdents) {
                        stream.getdents = FS.readdir(stream.path)
                    }
                    var struct_size = 280;
                    var pos = 0;
                    var off = FS.llseek(stream, 0, 1);
                    var idx = Math.floor(off / struct_size);
                    while (idx < stream.getdents.length && pos + struct_size <= count) {
                        var id;
                        var type;
                        var name = stream.getdents[idx];
                        if (name[0] === ".") {
                            id = 1;
                            type = 4
                        } else {
                            var child = FS.lookupNode(stream.node, name);
                            id = child.id;
                            type = FS.isChrdev(child.mode) ? 2 : FS.isDir(child.mode) ? 4 : FS.isLink(child.mode) ? 10 : 8
                        }
                        tempI64 = [id >>> 0, (tempDouble = id, +Math.abs(tempDouble) >= 1 ? tempDouble > 0 ? (Math.min(+Math.floor(tempDouble / 4294967296), 4294967295) | 0) >>> 0 : ~~+Math.ceil((tempDouble - +(~~tempDouble >>> 0)) / 4294967296) >>> 0 : 0)], HEAP32[dirp + pos >> 2] = tempI64[0], HEAP32[dirp + pos + 4 >> 2] = tempI64[1];
                        tempI64 = [(idx + 1) * struct_size >>> 0, (tempDouble = (idx + 1) * struct_size, +Math.abs(tempDouble) >= 1 ? tempDouble > 0 ? (Math.min(+Math.floor(tempDouble / 4294967296), 4294967295) | 0) >>> 0 : ~~+Math.ceil((tempDouble - +(~~tempDouble >>> 0)) / 4294967296) >>> 0 : 0)], HEAP32[dirp + pos + 8 >> 2] = tempI64[0], HEAP32[dirp + pos + 12 >> 2] = tempI64[1];
                        HEAP16[dirp + pos + 16 >> 1] = 280;
                        HEAP8[dirp + pos + 18 >> 0] = type;
                        stringToUTF8(name, dirp + pos + 19, 256);
                        pos += struct_size;
                        idx += 1
                    }
                    FS.llseek(stream, idx * struct_size, 0);
                    return pos
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_getdents64"] = ___sys_getdents64;

            function ___sys_getegid32() {
                return 0
            }
            Module["___sys_getegid32"] = ___sys_getegid32;
            ___sys_getegid32.sig = "i";

            function ___sys_geteuid32() {
                return ___sys_getegid32()
            }
            Module["___sys_geteuid32"] = ___sys_geteuid32;
            ___sys_geteuid32.sig = "i";

            function ___sys_getgid32() {
                return ___sys_getegid32()
            }
            Module["___sys_getgid32"] = ___sys_getgid32;
            ___sys_getgid32.sig = "i";

            function ___sys_getgroups32(size, list) {
                if (size < 1) return -28;
                HEAP32[list >> 2] = 0;
                return 1
            }
            Module["___sys_getgroups32"] = ___sys_getgroups32;

            function ___sys_getpeername(fd, addr, addrlen) {
                try {
                    var sock = getSocketFromFD(fd);
                    if (!sock.daddr) {
                        return -53
                    }
                    var errno = writeSockaddr(addr, sock.family, DNS.lookup_name(sock.daddr), sock.dport, addrlen);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_getpeername"] = ___sys_getpeername;

            function ___sys_getpgid(pid) {
                if (pid && pid !== 42) return -71;
                return 42
            }
            Module["___sys_getpgid"] = ___sys_getpgid;

            function ___sys_getpid() {
                return 42
            }
            Module["___sys_getpid"] = ___sys_getpid;

            function ___sys_getppid() {
                return 1
            }
            Module["___sys_getppid"] = ___sys_getppid;

            function ___sys_getpriority() {
                return 0
            }
            Module["___sys_getpriority"] = ___sys_getpriority;

            function ___sys_getresgid32(ruid, euid, suid) {
                HEAP32[ruid >> 2] = 0;
                HEAP32[euid >> 2] = 0;
                HEAP32[suid >> 2] = 0;
                return 0
            }
            Module["___sys_getresgid32"] = ___sys_getresgid32;
            ___sys_getresgid32.sig = "iiii";

            function ___sys_getresuid32(a0, a1, a2) {
                return ___sys_getresgid32(a0, a1, a2)
            }
            Module["___sys_getresuid32"] = ___sys_getresuid32;
            ___sys_getresuid32.sig = "iiii";

            function ___sys_getrusage(who, usage) {
                try {
                    _memset(usage, 0, 136);
                    HEAP32[usage >> 2] = 1;
                    HEAP32[usage + 4 >> 2] = 2;
                    HEAP32[usage + 8 >> 2] = 3;
                    HEAP32[usage + 12 >> 2] = 4;
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_getrusage"] = ___sys_getrusage;

            function ___sys_getsid(pid) {
                if (pid && pid !== 42) return -71;
                return 42
            }
            Module["___sys_getsid"] = ___sys_getsid;

            function ___sys_getsockname(fd, addr, addrlen) {
                try {
                    err("__sys_getsockname " + fd);
                    var sock = getSocketFromFD(fd);
                    var errno = writeSockaddr(addr, sock.family, DNS.lookup_name(sock.saddr || "0.0.0.0"), sock.sport, addrlen);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_getsockname"] = ___sys_getsockname;

            function ___sys_getsockopt(fd, level, optname, optval, optlen) {
                try {
                    var sock = getSocketFromFD(fd);
                    if (level === 1) {
                        if (optname === 4) {
                            HEAP32[optval >> 2] = sock.error;
                            HEAP32[optlen >> 2] = 4;
                            sock.error = null;
                            return 0
                        }
                    }
                    return -50
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_getsockopt"] = ___sys_getsockopt;

            function ___sys_getuid32() {
                return ___sys_getegid32()
            }
            Module["___sys_getuid32"] = ___sys_getuid32;
            ___sys_getuid32.sig = "i";

            function ___sys_ioctl(fd, op, varargs) {
                SYSCALLS.varargs = varargs;
                try {
                    var stream = SYSCALLS.getStreamFromFD(fd);
                    switch (op) {
                        case 21509:
                        case 21505: {
                            if (!stream.tty) return -59;
                            return 0
                        }
                        case 21510:
                        case 21511:
                        case 21512:
                        case 21506:
                        case 21507:
                        case 21508: {
                            if (!stream.tty) return -59;
                            return 0
                        }
                        case 21519: {
                            if (!stream.tty) return -59;
                            var argp = SYSCALLS.get();
                            HEAP32[argp >> 2] = 0;
                            return 0
                        }
                        case 21520: {
                            if (!stream.tty) return -59;
                            return -28
                        }
                        case 21531: {
                            var argp = SYSCALLS.get();
                            return FS.ioctl(stream, op, argp)
                        }
                        case 21523: {
                            if (!stream.tty) return -59;
                            return 0
                        }
                        case 21524: {
                            if (!stream.tty) return -59;
                            return 0
                        }
                        default:
                            abort("bad ioctl syscall " + op)
                    }
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_ioctl"] = ___sys_ioctl;

            function ___sys_lchown32(path, owner, group) {
                try {
                    path = SYSCALLS.getStr(path);
                    FS.chown(path, owner, group);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_lchown32"] = ___sys_lchown32;

            function ___sys_link(oldpath, newpath) {
                return -34
            }
            Module["___sys_link"] = ___sys_link;

            function ___sys_linkat(olddirfd, oldpath, newdirfd, newpath, flags) {
                return -34
            }
            Module["___sys_linkat"] = ___sys_linkat;

            function ___sys_listen(fd, backlog) {
                try {
                    var sock = getSocketFromFD(fd);
                    sock.sock_ops.listen(sock, backlog);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_listen"] = ___sys_listen;

            function ___sys_lstat64(path, buf) {
                try {
                    path = SYSCALLS.getStr(path);
                    return SYSCALLS.doStat(FS.lstat, path, buf)
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_lstat64"] = ___sys_lstat64;

            function ___sys_madvise1(addr, length, advice) {
                return 0
            }
            Module["___sys_madvise1"] = ___sys_madvise1;

            function ___sys_mincore(addr, length, vec) {
                return -52
            }
            Module["___sys_mincore"] = ___sys_mincore;

            function ___sys_mkdir(path, mode) {
                try {
                    path = SYSCALLS.getStr(path);
                    return SYSCALLS.doMkdir(path, mode)
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_mkdir"] = ___sys_mkdir;

            function ___sys_mkdirat(dirfd, path, mode) {
                try {
                    path = SYSCALLS.getStr(path);
                    path = SYSCALLS.calculateAt(dirfd, path);
                    return SYSCALLS.doMkdir(path, mode)
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_mkdirat"] = ___sys_mkdirat;

            function ___sys_mknod(path, mode, dev) {
                try {
                    path = SYSCALLS.getStr(path);
                    return SYSCALLS.doMknod(path, mode, dev)
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_mknod"] = ___sys_mknod;

            function ___sys_mknodat(dirfd, path, mode, dev) {
                try {
                    path = SYSCALLS.getStr(path);
                    path = SYSCALLS.calculateAt(dirfd, path);
                    return SYSCALLS.doMknod(path, mode, dev)
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_mknodat"] = ___sys_mknodat;

            function ___sys_mlock(addr, len) {
                return 0
            }
            Module["___sys_mlock"] = ___sys_mlock;
            ___sys_mlock.sig = "iii";

            function ___sys_mlockall(flags) {
                return 0
            }
            Module["___sys_mlockall"] = ___sys_mlockall;
            ___sys_mlockall.sig = "ii";

            function syscallMmap2(addr, len, prot, flags, fd, off) {
                off <<= 12;
                var ptr;
                var allocated = false;
                if ((flags & 16) !== 0 && addr % 65536 !== 0) {
                    return -28
                }
                if ((flags & 32) !== 0) {
                    ptr = _memalign(65536, len);
                    if (!ptr) return -48;
                    _memset(ptr, 0, len);
                    allocated = true
                } else {
                    var info = FS.getStream(fd);
                    if (!info) return -8;
                    var res = FS.mmap(info, addr, len, off, prot, flags);
                    ptr = res.ptr;
                    allocated = res.allocated
                }
                SYSCALLS.mappings[ptr] = {
                    malloc: ptr,
                    len: len,
                    allocated: allocated,
                    fd: fd,
                    prot: prot,
                    flags: flags,
                    offset: off
                };
                return ptr
            }
            Module["syscallMmap2"] = syscallMmap2;

            function ___sys_mmap2(addr, len, prot, flags, fd, off) {
                try {
                    return syscallMmap2(addr, len, prot, flags, fd, off)
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_mmap2"] = ___sys_mmap2;

            function ___sys_mprotect(addr, len, size) {
                return 0
            }
            Module["___sys_mprotect"] = ___sys_mprotect;

            function ___sys_mremap(old_addr, old_size, new_size, flags) {
                return -48
            }
            Module["___sys_mremap"] = ___sys_mremap;

            function ___sys_msync(addr, len, flags) {
                try {
                    var info = SYSCALLS.mappings[addr];
                    if (!info) return 0;
                    SYSCALLS.doMsync(addr, FS.getStream(info.fd), len, info.flags, 0);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_msync"] = ___sys_msync;

            function ___sys_munlock(addr, len) {
                return 0
            }
            Module["___sys_munlock"] = ___sys_munlock;
            ___sys_munlock.sig = "iii";

            function ___sys_munlockall() {
                return 0
            }
            Module["___sys_munlockall"] = ___sys_munlockall;
            ___sys_munlockall.sig = "i";

            function syscallMunmap(addr, len) {
                if ((addr | 0) === -1 || len === 0) {
                    return -28
                }
                var info = SYSCALLS.mappings[addr];
                if (!info) return 0;
                if (len === info.len) {
                    var stream = FS.getStream(info.fd);
                    if (stream) {
                        if (info.prot & 2) {
                            SYSCALLS.doMsync(addr, stream, len, info.flags, info.offset)
                        }
                        FS.munmap(stream)
                    }
                    SYSCALLS.mappings[addr] = null;
                    if (info.allocated) {
                        _free(info.malloc)
                    }
                }
                return 0
            }
            Module["syscallMunmap"] = syscallMunmap;

            function ___sys_munmap(addr, len) {
                try {
                    return syscallMunmap(addr, len)
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_munmap"] = ___sys_munmap;

            function ___sys_nice(inc) {
                return -63
            }
            Module["___sys_nice"] = ___sys_nice;

            function ___sys_open(path, flags, varargs) {
                SYSCALLS.varargs = varargs;
                try {
                    var pathname = SYSCALLS.getStr(path);
                    var mode = varargs ? SYSCALLS.get() : 0;
                    var stream = FS.open(pathname, flags, mode);
                    return stream.fd
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_open"] = ___sys_open;

            function ___sys_openat(dirfd, path, flags, varargs) {
                SYSCALLS.varargs = varargs;
                try {
                    path = SYSCALLS.getStr(path);
                    path = SYSCALLS.calculateAt(dirfd, path);
                    var mode = varargs ? SYSCALLS.get() : 0;
                    return FS.open(path, flags, mode).fd
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_openat"] = ___sys_openat;

            function ___sys_pause() {
                return -27
            }
            Module["___sys_pause"] = ___sys_pause;
            var PIPEFS = {
                BUCKET_BUFFER_SIZE: 8192,
                mount: function(mount) {
                    return FS.createNode(null, "/", 16384 | 511, 0)
                },
                createPipe: function() {
                    var pipe = {
                        buckets: []
                    };
                    pipe.buckets.push({
                        buffer: new Uint8Array(PIPEFS.BUCKET_BUFFER_SIZE),
                        offset: 0,
                        roffset: 0
                    });
                    var rName = PIPEFS.nextname();
                    var wName = PIPEFS.nextname();
                    var rNode = FS.createNode(PIPEFS.root, rName, 4096, 0);
                    var wNode = FS.createNode(PIPEFS.root, wName, 4096, 0);
                    rNode.pipe = pipe;
                    wNode.pipe = pipe;
                    var readableStream = FS.createStream({
                        path: rName,
                        node: rNode,
                        flags: 0,
                        seekable: false,
                        stream_ops: PIPEFS.stream_ops
                    });
                    rNode.stream = readableStream;
                    var writableStream = FS.createStream({
                        path: wName,
                        node: wNode,
                        flags: 1,
                        seekable: false,
                        stream_ops: PIPEFS.stream_ops
                    });
                    wNode.stream = writableStream;
                    return {
                        readable_fd: readableStream.fd,
                        writable_fd: writableStream.fd
                    }
                },
                stream_ops: {
                    poll: function(stream) {
                        var pipe = stream.node.pipe;
                        if ((stream.flags & 2097155) === 1) {
                            return 256 | 4
                        } else {
                            if (pipe.buckets.length > 0) {
                                for (var i = 0; i < pipe.buckets.length; i++) {
                                    var bucket = pipe.buckets[i];
                                    if (bucket.offset - bucket.roffset > 0) {
                                        return 64 | 1
                                    }
                                }
                            }
                        }
                        return 0
                    },
                    ioctl: function(stream, request, varargs) {
                        return ERRNO_CODES.EINVAL
                    },
                    fsync: function(stream) {
                        return ERRNO_CODES.EINVAL
                    },
                    read: function(stream, buffer, offset, length, position) {
                        var pipe = stream.node.pipe;
                        var currentLength = 0;
                        for (var i = 0; i < pipe.buckets.length; i++) {
                            var bucket = pipe.buckets[i];
                            currentLength += bucket.offset - bucket.roffset
                        }
                        assert(buffer instanceof ArrayBuffer || ArrayBuffer.isView(buffer));
                        var data = buffer.subarray(offset, offset + length);
                        if (length <= 0) {
                            return 0
                        }
                        if (currentLength == 0) {
                            throw new FS.ErrnoError(ERRNO_CODES.EAGAIN)
                        }
                        var toRead = Math.min(currentLength, length);
                        var totalRead = toRead;
                        var toRemove = 0;
                        for (var i = 0; i < pipe.buckets.length; i++) {
                            var currBucket = pipe.buckets[i];
                            var bucketSize = currBucket.offset - currBucket.roffset;
                            if (toRead <= bucketSize) {
                                var tmpSlice = currBucket.buffer.subarray(currBucket.roffset, currBucket.offset);
                                if (toRead < bucketSize) {
                                    tmpSlice = tmpSlice.subarray(0, toRead);
                                    currBucket.roffset += toRead
                                } else {
                                    toRemove++
                                }
                                data.set(tmpSlice);
                                break
                            } else {
                                var tmpSlice = currBucket.buffer.subarray(currBucket.roffset, currBucket.offset);
                                data.set(tmpSlice);
                                data = data.subarray(tmpSlice.byteLength);
                                toRead -= tmpSlice.byteLength;
                                toRemove++
                            }
                        }
                        if (toRemove && toRemove == pipe.buckets.length) {
                            toRemove--;
                            pipe.buckets[toRemove].offset = 0;
                            pipe.buckets[toRemove].roffset = 0
                        }
                        pipe.buckets.splice(0, toRemove);
                        return totalRead
                    },
                    write: function(stream, buffer, offset, length, position) {
                        var pipe = stream.node.pipe;
                        assert(buffer instanceof ArrayBuffer || ArrayBuffer.isView(buffer));
                        var data = buffer.subarray(offset, offset + length);
                        var dataLen = data.byteLength;
                        if (dataLen <= 0) {
                            return 0
                        }
                        var currBucket = null;
                        if (pipe.buckets.length == 0) {
                            currBucket = {
                                buffer: new Uint8Array(PIPEFS.BUCKET_BUFFER_SIZE),
                                offset: 0,
                                roffset: 0
                            };
                            pipe.buckets.push(currBucket)
                        } else {
                            currBucket = pipe.buckets[pipe.buckets.length - 1]
                        }
                        assert(currBucket.offset <= PIPEFS.BUCKET_BUFFER_SIZE);
                        var freeBytesInCurrBuffer = PIPEFS.BUCKET_BUFFER_SIZE - currBucket.offset;
                        if (freeBytesInCurrBuffer >= dataLen) {
                            currBucket.buffer.set(data, currBucket.offset);
                            currBucket.offset += dataLen;
                            return dataLen
                        } else if (freeBytesInCurrBuffer > 0) {
                            currBucket.buffer.set(data.subarray(0, freeBytesInCurrBuffer), currBucket.offset);
                            currBucket.offset += freeBytesInCurrBuffer;
                            data = data.subarray(freeBytesInCurrBuffer, data.byteLength)
                        }
                        var numBuckets = data.byteLength / PIPEFS.BUCKET_BUFFER_SIZE | 0;
                        var remElements = data.byteLength % PIPEFS.BUCKET_BUFFER_SIZE;
                        for (var i = 0; i < numBuckets; i++) {
                            var newBucket = {
                                buffer: new Uint8Array(PIPEFS.BUCKET_BUFFER_SIZE),
                                offset: PIPEFS.BUCKET_BUFFER_SIZE,
                                roffset: 0
                            };
                            pipe.buckets.push(newBucket);
                            newBucket.buffer.set(data.subarray(0, PIPEFS.BUCKET_BUFFER_SIZE));
                            data = data.subarray(PIPEFS.BUCKET_BUFFER_SIZE, data.byteLength)
                        }
                        if (remElements > 0) {
                            var newBucket = {
                                buffer: new Uint8Array(PIPEFS.BUCKET_BUFFER_SIZE),
                                offset: data.byteLength,
                                roffset: 0
                            };
                            pipe.buckets.push(newBucket);
                            newBucket.buffer.set(data)
                        }
                        return dataLen
                    },
                    close: function(stream) {
                        var pipe = stream.node.pipe;
                        pipe.buckets = null
                    }
                },
                nextname: function() {
                    if (!PIPEFS.nextname.current) {
                        PIPEFS.nextname.current = 0
                    }
                    return "pipe[" + PIPEFS.nextname.current++ + "]"
                }
            };
            Module["PIPEFS"] = PIPEFS;

            function ___sys_pipe(fdPtr) {
                try {
                    if (fdPtr == 0) {
                        throw new FS.ErrnoError(21)
                    }
                    var res = PIPEFS.createPipe();
                    HEAP32[fdPtr >> 2] = res.readable_fd;
                    HEAP32[fdPtr + 4 >> 2] = res.writable_fd;
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_pipe"] = ___sys_pipe;

            function ___sys_pipe2(fds, flags) {
                return -52
            }
            Module["___sys_pipe2"] = ___sys_pipe2;

            function ___sys_poll(fds, nfds, timeout) {
                try {
                    var nonzero = 0;
                    for (var i = 0; i < nfds; i++) {
                        var pollfd = fds + 8 * i;
                        var fd = HEAP32[pollfd >> 2];
                        var events = HEAP16[pollfd + 4 >> 1];
                        var mask = 32;
                        var stream = FS.getStream(fd);
                        if (stream) {
                            mask = SYSCALLS.DEFAULT_POLLMASK;
                            if (stream.stream_ops.poll) {
                                mask = stream.stream_ops.poll(stream)
                            }
                        }
                        mask &= events | 8 | 16;
                        if (mask) nonzero++;
                        HEAP16[pollfd + 6 >> 1] = mask
                    }
                    return nonzero
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_poll"] = ___sys_poll;

            function ___sys_prlimit64(pid, resource, new_limit, old_limit) {
                try {
                    if (old_limit) {
                        HEAP32[old_limit >> 2] = -1;
                        HEAP32[old_limit + 4 >> 2] = -1;
                        HEAP32[old_limit + 8 >> 2] = -1;
                        HEAP32[old_limit + 12 >> 2] = -1
                    }
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_prlimit64"] = ___sys_prlimit64;

            function ___sys_pselect6() {
                return -52
            }
            Module["___sys_pselect6"] = ___sys_pselect6;

            function ___sys_readlink(path, buf, bufsize) {
                try {
                    path = SYSCALLS.getStr(path);
                    return SYSCALLS.doReadlink(path, buf, bufsize)
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_readlink"] = ___sys_readlink;

            function ___sys_readlinkat(dirfd, path, buf, bufsize) {
                try {
                    path = SYSCALLS.getStr(path);
                    path = SYSCALLS.calculateAt(dirfd, path);
                    return SYSCALLS.doReadlink(path, buf, bufsize)
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_readlinkat"] = ___sys_readlinkat;

            function ___sys_recvfrom(fd, buf, len, flags, addr, addrlen) {
                try {
                    var sock = getSocketFromFD(fd);
                    var msg = sock.sock_ops.recvmsg(sock, len);
                    if (!msg) return 0;
                    if (addr) {
                        var errno = writeSockaddr(addr, sock.family, DNS.lookup_name(msg.addr), msg.port, addrlen)
                    }
                    HEAPU8.set(msg.buffer, buf);
                    return msg.buffer.byteLength
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_recvfrom"] = ___sys_recvfrom;

            function ___sys_recvmmsg(sockfd, msgvec, vlen, flags) {
                return 0
            }
            Module["___sys_recvmmsg"] = ___sys_recvmmsg;

            function ___sys_recvmsg(fd, message, flags) {
                try {
                    var sock = getSocketFromFD(fd);
                    var iov = HEAP32[message + 8 >> 2];
                    var num = HEAP32[message + 12 >> 2];
                    var total = 0;
                    for (var i = 0; i < num; i++) {
                        total += HEAP32[iov + (8 * i + 4) >> 2]
                    }
                    var msg = sock.sock_ops.recvmsg(sock, total);
                    if (!msg) return 0;
                    var name = HEAP32[message >> 2];
                    if (name) {
                        var errno = writeSockaddr(name, sock.family, DNS.lookup_name(msg.addr), msg.port)
                    }
                    var bytesRead = 0;
                    var bytesRemaining = msg.buffer.byteLength;
                    for (var i = 0; bytesRemaining > 0 && i < num; i++) {
                        var iovbase = HEAP32[iov + (8 * i + 0) >> 2];
                        var iovlen = HEAP32[iov + (8 * i + 4) >> 2];
                        if (!iovlen) {
                            continue
                        }
                        var length = Math.min(iovlen, bytesRemaining);
                        var buf = msg.buffer.subarray(bytesRead, bytesRead + length);
                        HEAPU8.set(buf, iovbase + bytesRead);
                        bytesRead += length;
                        bytesRemaining -= length
                    }
                    return bytesRead
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_recvmsg"] = ___sys_recvmsg;

            function ___sys_rename(old_path, new_path) {
                try {
                    old_path = SYSCALLS.getStr(old_path);
                    new_path = SYSCALLS.getStr(new_path);
                    FS.rename(old_path, new_path);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_rename"] = ___sys_rename;

            function ___sys_renameat(olddirfd, oldpath, newdirfd, newpath) {
                try {
                    oldpath = SYSCALLS.getStr(oldpath);
                    newpath = SYSCALLS.getStr(newpath);
                    oldpath = SYSCALLS.calculateAt(olddirfd, oldpath);
                    newpath = SYSCALLS.calculateAt(newdirfd, newpath);
                    FS.rename(oldpath, newpath);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_renameat"] = ___sys_renameat;

            function ___sys_rmdir(path) {
                try {
                    path = SYSCALLS.getStr(path);
                    FS.rmdir(path);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_rmdir"] = ___sys_rmdir;

            function ___sys_sendmmsg(sockfd, msg, flags) {
                return 0
            }
            Module["___sys_sendmmsg"] = ___sys_sendmmsg;

            function ___sys_sendmsg(fd, message, flags) {
                try {
                    var sock = getSocketFromFD(fd);
                    var iov = HEAP32[message + 8 >> 2];
                    var num = HEAP32[message + 12 >> 2];
                    var addr, port;
                    var name = HEAP32[message >> 2];
                    var namelen = HEAP32[message + 4 >> 2];
                    if (name) {
                        var info = readSockaddr(name, namelen);
                        if (info.errno) return -info.errno;
                        port = info.port;
                        addr = DNS.lookup_addr(info.addr) || info.addr
                    }
                    var total = 0;
                    for (var i = 0; i < num; i++) {
                        total += HEAP32[iov + (8 * i + 4) >> 2]
                    }
                    var view = new Uint8Array(total);
                    var offset = 0;
                    for (var i = 0; i < num; i++) {
                        var iovbase = HEAP32[iov + (8 * i + 0) >> 2];
                        var iovlen = HEAP32[iov + (8 * i + 4) >> 2];
                        for (var j = 0; j < iovlen; j++) {
                            view[offset++] = HEAP8[iovbase + j >> 0]
                        }
                    }
                    return sock.sock_ops.sendmsg(sock, view, 0, total, addr, port)
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_sendmsg"] = ___sys_sendmsg;

            function ___sys_sendto(fd, message, length, flags, addr, addr_len) {
                try {
                    var sock = getSocketFromFD(fd);
                    var dest = getSocketAddress(addr, addr_len, true);
                    if (!dest) {
                        return FS.write(sock.stream, HEAP8, message, length)
                    } else {
                        return sock.sock_ops.sendmsg(sock, HEAP8, message, length, dest.addr, dest.port)
                    }
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_sendto"] = ___sys_sendto;

            function ___sys_setdomainname(name, size) {
                return -63
            }
            Module["___sys_setdomainname"] = ___sys_setdomainname;

            function ___sys_setpgid(pid, pgid) {
                if (pid && pid !== 42) return -71;
                if (pgid && pgid !== 42) return -63;
                return 0
            }
            Module["___sys_setpgid"] = ___sys_setpgid;

            function ___sys_setpriority() {
                return -63
            }
            Module["___sys_setpriority"] = ___sys_setpriority;

            function ___sys_setrlimit(varargs) {
                return 0
            }
            Module["___sys_setrlimit"] = ___sys_setrlimit;

            function ___sys_setsid() {
                return 0
            }
            Module["___sys_setsid"] = ___sys_setsid;

            function ___sys_setsockopt(fd) {
                try {
                    return -50
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_setsockopt"] = ___sys_setsockopt;

            function ___sys_shutdown(fd, how) {
                try {
                    getSocketFromFD(fd);
                    return -52
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_shutdown"] = ___sys_shutdown;

            function ___sys_socket(domain, type, protocol) {
                try {
                    var sock = SOCKFS.createSocket(domain, type, protocol);
                    return sock.stream.fd
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_socket"] = ___sys_socket;

            function ___sys_socketpair() {
                try {
                    return -52
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_socketpair"] = ___sys_socketpair;

            function ___sys_stat64(path, buf) {
                try {
                    path = SYSCALLS.getStr(path);
                    return SYSCALLS.doStat(FS.stat, path, buf)
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_stat64"] = ___sys_stat64;

            function ___sys_statfs64(path, size, buf) {
                try {
                    path = SYSCALLS.getStr(path);
                    HEAP32[buf + 4 >> 2] = 4096;
                    HEAP32[buf + 40 >> 2] = 4096;
                    HEAP32[buf + 8 >> 2] = 1e6;
                    HEAP32[buf + 12 >> 2] = 5e5;
                    HEAP32[buf + 16 >> 2] = 5e5;
                    HEAP32[buf + 20 >> 2] = FS.nextInode;
                    HEAP32[buf + 24 >> 2] = 1e6;
                    HEAP32[buf + 28 >> 2] = 42;
                    HEAP32[buf + 44 >> 2] = 2;
                    HEAP32[buf + 36 >> 2] = 255;
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_statfs64"] = ___sys_statfs64;

            function ___sys_symlink(target, linkpath) {
                try {
                    target = SYSCALLS.getStr(target);
                    linkpath = SYSCALLS.getStr(linkpath);
                    FS.symlink(target, linkpath);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_symlink"] = ___sys_symlink;

            function ___sys_symlinkat(target, newdirfd, linkpath) {
                try {
                    linkpath = SYSCALLS.calculateAt(newdirfd, linkpath);
                    FS.symlink(target, linkpath);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_symlinkat"] = ___sys_symlinkat;

            function ___sys_sync() {
                return 0
            }
            Module["___sys_sync"] = ___sys_sync;

            function ___sys_truncate64(path, zero, low, high) {
                try {
                    path = SYSCALLS.getStr(path);
                    var length = SYSCALLS.get64(low, high);
                    FS.truncate(path, length);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_truncate64"] = ___sys_truncate64;

            function ___sys_ugetrlimit(resource, rlim) {
                try {
                    HEAP32[rlim >> 2] = -1;
                    HEAP32[rlim + 4 >> 2] = -1;
                    HEAP32[rlim + 8 >> 2] = -1;
                    HEAP32[rlim + 12 >> 2] = -1;
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_ugetrlimit"] = ___sys_ugetrlimit;

            function ___sys_umask(mask) {
                try {
                    var old = SYSCALLS.umask;
                    SYSCALLS.umask = mask;
                    return old
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_umask"] = ___sys_umask;

            function ___sys_uname(buf) {
                try {
                    if (!buf) return -21;
                    var layout = {
                        "__size__": 390,
                        "domainname": 325,
                        "machine": 260,
                        "nodename": 65,
                        "release": 130,
                        "sysname": 0,
                        "version": 195
                    };
                    var copyString = function(element, value) {
                        var offset = layout[element];
                        writeAsciiToMemory(value, buf + offset)
                    };
                    copyString("sysname", "Emscripten");
                    copyString("nodename", "emscripten");
                    copyString("release", "1.0");
                    copyString("version", "#1");
                    copyString("machine", "wasm32");
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_uname"] = ___sys_uname;

            function ___sys_unlink(path) {
                try {
                    path = SYSCALLS.getStr(path);
                    FS.unlink(path);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_unlink"] = ___sys_unlink;

            function ___sys_unlinkat(dirfd, path, flags) {
                try {
                    path = SYSCALLS.getStr(path);
                    path = SYSCALLS.calculateAt(dirfd, path);
                    if (flags === 0) {
                        FS.unlink(path)
                    } else if (flags === 512) {
                        FS.rmdir(path)
                    } else {
                        abort("Invalid flags passed to unlinkat")
                    }
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_unlinkat"] = ___sys_unlinkat;

            function ___sys_utimensat(dirfd, path, times, flags) {
                try {
                    path = SYSCALLS.getStr(path);
                    path = SYSCALLS.calculateAt(dirfd, path, true);
                    var seconds = HEAP32[times >> 2];
                    var nanoseconds = HEAP32[times + 4 >> 2];
                    var atime = seconds * 1e3 + nanoseconds / (1e3 * 1e3);
                    times += 8;
                    seconds = HEAP32[times >> 2];
                    nanoseconds = HEAP32[times + 4 >> 2];
                    var mtime = seconds * 1e3 + nanoseconds / (1e3 * 1e3);
                    FS.utime(path, atime, mtime);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_utimensat"] = ___sys_utimensat;

            function ___sys_wait4(pid, wstart, options, rusage) {
                try {
                    return -52
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_wait4"] = ___sys_wait4;

            function _exit(status) {
                exit(status)
            }
            Module["_exit"] = _exit;
            _exit.sig = "vi";

            function __exit(a0) {
                return _exit(a0)
            }
            Module["__exit"] = __exit;
            __exit.sig = "vi";

            function _abort() {
                abort()
            }
            Module["_abort"] = _abort;
            _abort.sig = "v";

            function _emscripten_set_main_loop_timing(mode, value) {
                Browser.mainLoop.timingMode = mode;
                Browser.mainLoop.timingValue = value;
                if (!Browser.mainLoop.func) {
                    return 1
                }
                if (!Browser.mainLoop.running) {
                    Browser.mainLoop.running = true
                }
                if (mode == 0) {
                    Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler_setTimeout() {
                        var timeUntilNextTick = Math.max(0, Browser.mainLoop.tickStartTime + value - _emscripten_get_now()) | 0;
                        setTimeout(Browser.mainLoop.runner, timeUntilNextTick)
                    };
                    Browser.mainLoop.method = "timeout"
                } else if (mode == 1) {
                    Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler_rAF() {
                        Browser.requestAnimationFrame(Browser.mainLoop.runner)
                    };
                    Browser.mainLoop.method = "rAF"
                } else if (mode == 2) {
                    if (typeof setImmediate === "undefined") {
                        var setImmediates = [];
                        var emscriptenMainLoopMessageId = "setimmediate";
                        var Browser_setImmediate_messageHandler = function(event) {
                            if (event.data === emscriptenMainLoopMessageId || event.data.target === emscriptenMainLoopMessageId) {
                                event.stopPropagation();
                                setImmediates.shift()()
                            }
                        };
                        addEventListener("message", Browser_setImmediate_messageHandler, true);
                        setImmediate = function Browser_emulated_setImmediate(func) {
                            setImmediates.push(func);
                            if (ENVIRONMENT_IS_WORKER) {
                                if (Module["setImmediates"] === undefined) Module["setImmediates"] = [];
                                Module["setImmediates"].push(func);
                                postMessage({
                                    target: emscriptenMainLoopMessageId
                                })
                            } else postMessage(emscriptenMainLoopMessageId, "*")
                        }
                    }
                    Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler_setImmediate() {
                        setImmediate(Browser.mainLoop.runner)
                    };
                    Browser.mainLoop.method = "immediate"
                }
                return 0
            }
            Module["_emscripten_set_main_loop_timing"] = _emscripten_set_main_loop_timing;
            _emscripten_set_main_loop_timing.sig = "iii";

            function runtimeKeepalivePush() {
                runtimeKeepaliveCounter += 1
            }
            Module["runtimeKeepalivePush"] = runtimeKeepalivePush;
            runtimeKeepalivePush.sig = "v";

            function maybeExit() {
                if (!keepRuntimeAlive()) {
                    try {
                        _exit(EXITSTATUS)
                    } catch (e) {
                        if (e instanceof ExitStatus) {
                            return
                        }
                        throw e
                    }
                }
            }
            Module["maybeExit"] = maybeExit;

            function setMainLoop(browserIterationFunc, fps, simulateInfiniteLoop, arg, noSetTiming) {
                assert(!Browser.mainLoop.func, "emscripten_set_main_loop: there can only be one main loop function at once: call emscripten_cancel_main_loop to cancel the previous one before setting a new one with different parameters.");
                Browser.mainLoop.func = browserIterationFunc;
                Browser.mainLoop.arg = arg;
                var thisMainLoopId = Browser.mainLoop.currentlyRunningMainloop;

                function checkIsRunning() {
                    if (thisMainLoopId < Browser.mainLoop.currentlyRunningMainloop) {
                        maybeExit();
                        return false
                    }
                    return true
                }
                Browser.mainLoop.running = false;
                Browser.mainLoop.runner = function Browser_mainLoop_runner() {
                    if (ABORT) return;
                    if (Browser.mainLoop.queue.length > 0) {
                        var start = Date.now();
                        var blocker = Browser.mainLoop.queue.shift();
                        blocker.func(blocker.arg);
                        if (Browser.mainLoop.remainingBlockers) {
                            var remaining = Browser.mainLoop.remainingBlockers;
                            var next = remaining % 1 == 0 ? remaining - 1 : Math.floor(remaining);
                            if (blocker.counted) {
                                Browser.mainLoop.remainingBlockers = next
                            } else {
                                next = next + .5;
                                Browser.mainLoop.remainingBlockers = (8 * remaining + next) / 9
                            }
                        }
                        console.log('main loop blocker "' + blocker.name + '" took ' + (Date.now() - start) + " ms");
                        Browser.mainLoop.updateStatus();
                        if (!checkIsRunning()) return;
                        setTimeout(Browser.mainLoop.runner, 0);
                        return
                    }
                    if (!checkIsRunning()) return;
                    Browser.mainLoop.currentFrameNumber = Browser.mainLoop.currentFrameNumber + 1 | 0;
                    if (Browser.mainLoop.timingMode == 1 && Browser.mainLoop.timingValue > 1 && Browser.mainLoop.currentFrameNumber % Browser.mainLoop.timingValue != 0) {
                        Browser.mainLoop.scheduler();
                        return
                    } else if (Browser.mainLoop.timingMode == 0) {
                        Browser.mainLoop.tickStartTime = _emscripten_get_now()
                    }
                    Browser.mainLoop.runIter(browserIterationFunc);
                    if (!checkIsRunning()) return;
                    if (typeof SDL === "object" && SDL.audio && SDL.audio.queueNewAudioData) SDL.audio.queueNewAudioData();
                    Browser.mainLoop.scheduler()
                };
                if (!noSetTiming) {
                    if (fps && fps > 0) _emscripten_set_main_loop_timing(0, 1e3 / fps);
                    else _emscripten_set_main_loop_timing(1, 1);
                    Browser.mainLoop.scheduler()
                }
                if (simulateInfiniteLoop) {
                    throw "unwind"
                }
            }
            Module["setMainLoop"] = setMainLoop;

            function callUserCallback(func, synchronous) {
                if (ABORT) {
                    return
                }
                if (synchronous) {
                    func();
                    return
                }
                try {
                    func()
                } catch (e) {
                    if (e instanceof ExitStatus) {
                        return
                    } else if (e !== "unwind") {
                        if (e && typeof e === "object" && e.stack) err("exception thrown: " + [e, e.stack]);
                        throw e
                    }
                }
            }
            Module["callUserCallback"] = callUserCallback;

            function runtimeKeepalivePop() {
                runtimeKeepaliveCounter -= 1
            }
            Module["runtimeKeepalivePop"] = runtimeKeepalivePop;
            runtimeKeepalivePop.sig = "v";
            var Browser = {
                mainLoop: {
                    running: false,
                    scheduler: null,
                    method: "",
                    currentlyRunningMainloop: 0,
                    func: null,
                    arg: 0,
                    timingMode: 0,
                    timingValue: 0,
                    currentFrameNumber: 0,
                    queue: [],
                    pause: function() {
                        Browser.mainLoop.scheduler = null;
                        Browser.mainLoop.currentlyRunningMainloop++
                    },
                    resume: function() {
                        Browser.mainLoop.currentlyRunningMainloop++;
                        var timingMode = Browser.mainLoop.timingMode;
                        var timingValue = Browser.mainLoop.timingValue;
                        var func = Browser.mainLoop.func;
                        Browser.mainLoop.func = null;
                        setMainLoop(func, 0, false, Browser.mainLoop.arg, true);
                        _emscripten_set_main_loop_timing(timingMode, timingValue);
                        Browser.mainLoop.scheduler()
                    },
                    updateStatus: function() {
                        if (Module["setStatus"]) {
                            var message = Module["statusMessage"] || "Please wait...";
                            var remaining = Browser.mainLoop.remainingBlockers;
                            var expected = Browser.mainLoop.expectedBlockers;
                            if (remaining) {
                                if (remaining < expected) {
                                    Module["setStatus"](message + " (" + (expected - remaining) + "/" + expected + ")")
                                } else {
                                    Module["setStatus"](message)
                                }
                            } else {
                                Module["setStatus"]("")
                            }
                        }
                    },
                    runIter: function(func) {
                        if (ABORT) return;
                        if (Module["preMainLoop"]) {
                            var preRet = Module["preMainLoop"]();
                            if (preRet === false) {
                                return
                            }
                        }
                        callUserCallback(func);
                        if (Module["postMainLoop"]) Module["postMainLoop"]()
                    }
                },
                isFullscreen: false,
                pointerLock: false,
                moduleContextCreatedCallbacks: [],
                workers: [],
                init: function() {
                    if (!Module["preloadPlugins"]) Module["preloadPlugins"] = [];
                    if (Browser.initted) return;
                    Browser.initted = true;
                    try {
                        new Blob;
                        Browser.hasBlobConstructor = true
                    } catch (e) {
                        Browser.hasBlobConstructor = false;
                        console.log("warning: no blob constructor, cannot create blobs with mimetypes")
                    }
                    Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : !Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null;
                    Browser.URLObject = typeof window != "undefined" ? window.URL ? window.URL : window.webkitURL : undefined;
                    if (!Module.noImageDecoding && typeof Browser.URLObject === "undefined") {
                        console.log("warning: Browser does not support creating object URLs. Built-in browser image decoding will not be available.");
                        Module.noImageDecoding = true
                    }
                    var imagePlugin = {};
                    imagePlugin["canHandle"] = function imagePlugin_canHandle(name) {
                        return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/i.test(name)
                    };
                    imagePlugin["handle"] = function imagePlugin_handle(byteArray, name, onload, onerror) {
                        var b = null;
                        if (Browser.hasBlobConstructor) {
                            try {
                                b = new Blob([byteArray], {
                                    type: Browser.getMimetype(name)
                                });
                                if (b.size !== byteArray.length) {
                                    b = new Blob([new Uint8Array(byteArray).buffer], {
                                        type: Browser.getMimetype(name)
                                    })
                                }
                            } catch (e) {
                                warnOnce("Blob constructor present but fails: " + e + "; falling back to blob builder")
                            }
                        }
                        if (!b) {
                            var bb = new Browser.BlobBuilder;
                            bb.append(new Uint8Array(byteArray).buffer);
                            b = bb.getBlob()
                        }
                        var url = Browser.URLObject.createObjectURL(b);
                        var img = new Image;
                        img.onload = function img_onload() {
                            assert(img.complete, "Image " + name + " could not be decoded");
                            var canvas = document.createElement("canvas");
                            canvas.width = img.width;
                            canvas.height = img.height;
                            var ctx = canvas.getContext("2d");
                            ctx.drawImage(img, 0, 0);
                            Module["preloadedImages"][name] = canvas;
                            Browser.URLObject.revokeObjectURL(url);
                            if (onload) onload(byteArray)
                        };
                        img.onerror = function img_onerror(event) {
                            console.log("Image " + url + " could not be decoded");
                            if (onerror) onerror()
                        };
                        img.src = url
                    };
                    Module["preloadPlugins"].push(imagePlugin);
                    var audioPlugin = {};
                    audioPlugin["canHandle"] = function audioPlugin_canHandle(name) {
                        return !Module.noAudioDecoding && name.substr(-4) in {
                            ".ogg": 1,
                            ".wav": 1,
                            ".mp3": 1
                        }
                    };
                    audioPlugin["handle"] = function audioPlugin_handle(byteArray, name, onload, onerror) {
                        var done = false;

                        function finish(audio) {
                            if (done) return;
                            done = true;
                            Module["preloadedAudios"][name] = audio;
                            if (onload) onload(byteArray)
                        }

                        function fail() {
                            if (done) return;
                            done = true;
                            Module["preloadedAudios"][name] = new Audio;
                            if (onerror) onerror()
                        }
                        if (Browser.hasBlobConstructor) {
                            try {
                                var b = new Blob([byteArray], {
                                    type: Browser.getMimetype(name)
                                })
                            } catch (e) {
                                return fail()
                            }
                            var url = Browser.URLObject.createObjectURL(b);
                            var audio = new Audio;
                            audio.addEventListener("canplaythrough", function() {
                                finish(audio)
                            }, false);
                            audio.onerror = function audio_onerror(event) {
                                if (done) return;
                                console.log("warning: browser could not fully decode audio " + name + ", trying slower base64 approach");

                                function encode64(data) {
                                    var BASE = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
                                    var PAD = "=";
                                    var ret = "";
                                    var leftchar = 0;
                                    var leftbits = 0;
                                    for (var i = 0; i < data.length; i++) {
                                        leftchar = leftchar << 8 | data[i];
                                        leftbits += 8;
                                        while (leftbits >= 6) {
                                            var curr = leftchar >> leftbits - 6 & 63;
                                            leftbits -= 6;
                                            ret += BASE[curr]
                                        }
                                    }
                                    if (leftbits == 2) {
                                        ret += BASE[(leftchar & 3) << 4];
                                        ret += PAD + PAD
                                    } else if (leftbits == 4) {
                                        ret += BASE[(leftchar & 15) << 2];
                                        ret += PAD
                                    }
                                    return ret
                                }
                                audio.src = "data:audio/x-" + name.substr(-3) + ";base64," + encode64(byteArray);
                                finish(audio)
                            };
                            audio.src = url;
                            Browser.safeSetTimeout(function() {
                                finish(audio)
                            }, 1e4)
                        } else {
                            return fail()
                        }
                    };
                    Module["preloadPlugins"].push(audioPlugin);
                    var wasmPlugin = {
                        "asyncWasmLoadPromise": new Promise(function(resolve, reject) {
                            return resolve()
                        }),
                        "canHandle": function(name) {
                            return !Module.noWasmDecoding && name.endsWith(".so")
                        },
                        "handle": function(byteArray, name, onload, onerror) {
                            this["asyncWasmLoadPromise"] = this["asyncWasmLoadPromise"].then(function() {
                                return loadWebAssemblyModule(byteArray, {
                                    loadAsync: true,
                                    nodelete: true
                                })
                            }).then(function(module) {
                                Module["preloadedWasm"][name] = module;
                                onload()
                            }, function(err) {
                                console.warn("Couldn't instantiate wasm: " + name + " '" + err + "'");
                                onerror()
                            })
                        }
                    };
                    Module["preloadPlugins"].push(wasmPlugin);

                    function pointerLockChange() {
                        Browser.pointerLock = document["pointerLockElement"] === Module["canvas"] || document["mozPointerLockElement"] === Module["canvas"] || document["webkitPointerLockElement"] === Module["canvas"] || document["msPointerLockElement"] === Module["canvas"]
                    }
                    var canvas = Module["canvas"];
                    if (canvas) {
                        canvas.requestPointerLock = canvas["requestPointerLock"] || canvas["mozRequestPointerLock"] || canvas["webkitRequestPointerLock"] || canvas["msRequestPointerLock"] || function() {};
                        canvas.exitPointerLock = document["exitPointerLock"] || document["mozExitPointerLock"] || document["webkitExitPointerLock"] || document["msExitPointerLock"] || function() {};
                        canvas.exitPointerLock = canvas.exitPointerLock.bind(document);
                        document.addEventListener("pointerlockchange", pointerLockChange, false);
                        document.addEventListener("mozpointerlockchange", pointerLockChange, false);
                        document.addEventListener("webkitpointerlockchange", pointerLockChange, false);
                        document.addEventListener("mspointerlockchange", pointerLockChange, false);
                        if (Module["elementPointerLock"]) {
                            canvas.addEventListener("click", function(ev) {
                                if (!Browser.pointerLock && Module["canvas"].requestPointerLock) {
                                    Module["canvas"].requestPointerLock();
                                    ev.preventDefault()
                                }
                            }, false)
                        }
                    }
                },
                createContext: function(canvas, useWebGL, setInModule, webGLContextAttributes) {
                    if (useWebGL && Module.ctx && canvas == Module.canvas) return Module.ctx;
                    var ctx;
                    var contextHandle;
                    if (useWebGL) {
                        var contextAttributes = {
                            antialias: false,
                            alpha: false,
                            majorVersion: 1
                        };
                        if (webGLContextAttributes) {
                            for (var attribute in webGLContextAttributes) {
                                contextAttributes[attribute] = webGLContextAttributes[attribute]
                            }
                        }
                        if (typeof GL !== "undefined") {
                            contextHandle = GL.createContext(canvas, contextAttributes);
                            if (contextHandle) {
                                ctx = GL.getContext(contextHandle).GLctx
                            }
                        }
                    } else {
                        ctx = canvas.getContext("2d")
                    }
                    if (!ctx) return null;
                    if (setInModule) {
                        if (!useWebGL) assert(typeof GLctx === "undefined", "cannot set in module if GLctx is used, but we are a non-GL context that would replace it");
                        Module.ctx = ctx;
                        if (useWebGL) GL.makeContextCurrent(contextHandle);
                        Module.useWebGL = useWebGL;
                        Browser.moduleContextCreatedCallbacks.forEach(function(callback) {
                            callback()
                        });
                        Browser.init()
                    }
                    return ctx
                },
                destroyContext: function(canvas, useWebGL, setInModule) {},
                fullscreenHandlersInstalled: false,
                lockPointer: undefined,
                resizeCanvas: undefined,
                requestFullscreen: function(lockPointer, resizeCanvas) {
                    Browser.lockPointer = lockPointer;
                    Browser.resizeCanvas = resizeCanvas;
                    if (typeof Browser.lockPointer === "undefined") Browser.lockPointer = true;
                    if (typeof Browser.resizeCanvas === "undefined") Browser.resizeCanvas = false;
                    var canvas = Module["canvas"];

                    function fullscreenChange() {
                        Browser.isFullscreen = false;
                        var canvasContainer = canvas.parentNode;
                        if ((document["fullscreenElement"] || document["mozFullScreenElement"] || document["msFullscreenElement"] || document["webkitFullscreenElement"] || document["webkitCurrentFullScreenElement"]) === canvasContainer) {
                            canvas.exitFullscreen = Browser.exitFullscreen;
                            if (Browser.lockPointer) canvas.requestPointerLock();
                            Browser.isFullscreen = true;
                            if (Browser.resizeCanvas) {
                                Browser.setFullscreenCanvasSize()
                            } else {
                                Browser.updateCanvasDimensions(canvas)
                            }
                        } else {
                            canvasContainer.parentNode.insertBefore(canvas, canvasContainer);
                            canvasContainer.parentNode.removeChild(canvasContainer);
                            if (Browser.resizeCanvas) {
                                Browser.setWindowedCanvasSize()
                            } else {
                                Browser.updateCanvasDimensions(canvas)
                            }
                        }
                        if (Module["onFullScreen"]) Module["onFullScreen"](Browser.isFullscreen);
                        if (Module["onFullscreen"]) Module["onFullscreen"](Browser.isFullscreen)
                    }
                    if (!Browser.fullscreenHandlersInstalled) {
                        Browser.fullscreenHandlersInstalled = true;
                        document.addEventListener("fullscreenchange", fullscreenChange, false);
                        document.addEventListener("mozfullscreenchange", fullscreenChange, false);
                        document.addEventListener("webkitfullscreenchange", fullscreenChange, false);
                        document.addEventListener("MSFullscreenChange", fullscreenChange, false)
                    }
                    var canvasContainer = document.createElement("div");
                    canvas.parentNode.insertBefore(canvasContainer, canvas);
                    canvasContainer.appendChild(canvas);
                    canvasContainer.requestFullscreen = canvasContainer["requestFullscreen"] || canvasContainer["mozRequestFullScreen"] || canvasContainer["msRequestFullscreen"] || (canvasContainer["webkitRequestFullscreen"] ? function() {
                        canvasContainer["webkitRequestFullscreen"](Element["ALLOW_KEYBOARD_INPUT"])
                    } : null) || (canvasContainer["webkitRequestFullScreen"] ? function() {
                        canvasContainer["webkitRequestFullScreen"](Element["ALLOW_KEYBOARD_INPUT"])
                    } : null);
                    canvasContainer.requestFullscreen()
                },
                exitFullscreen: function() {
                    if (!Browser.isFullscreen) {
                        return false
                    }
                    var CFS = document["exitFullscreen"] || document["cancelFullScreen"] || document["mozCancelFullScreen"] || document["msExitFullscreen"] || document["webkitCancelFullScreen"] || function() {};
                    CFS.apply(document, []);
                    return true
                },
                nextRAF: 0,
                fakeRequestAnimationFrame: function(func) {
                    var now = Date.now();
                    if (Browser.nextRAF === 0) {
                        Browser.nextRAF = now + 1e3 / 60
                    } else {
                        while (now + 2 >= Browser.nextRAF) {
                            Browser.nextRAF += 1e3 / 60
                        }
                    }
                    var delay = Math.max(Browser.nextRAF - now, 0);
                    setTimeout(func, delay)
                },
                requestAnimationFrame: function(func) {
                    if (typeof requestAnimationFrame === "function") {
                        requestAnimationFrame(func);
                        return
                    }
                    var RAF = Browser.fakeRequestAnimationFrame;
                    RAF(func)
                },
                safeRequestAnimationFrame: function(func) {
                    return Browser.requestAnimationFrame(function() {
                        callUserCallback(func)
                    })
                },
                safeSetTimeout: function(func, timeout) {
                    return setTimeout(function() {
                        callUserCallback(func)
                    }, timeout)
                },
                getMimetype: function(name) {
                    return {
                        "jpg": "image/jpeg",
                        "jpeg": "image/jpeg",
                        "png": "image/png",
                        "bmp": "image/bmp",
                        "ogg": "audio/ogg",
                        "wav": "audio/wav",
                        "mp3": "audio/mpeg"
                    } [name.substr(name.lastIndexOf(".") + 1)]
                },
                getUserMedia: function(func) {
                    if (!window.getUserMedia) {
                        window.getUserMedia = navigator["getUserMedia"] || navigator["mozGetUserMedia"]
                    }
                    window.getUserMedia(func)
                },
                getMovementX: function(event) {
                    return event["movementX"] || event["mozMovementX"] || event["webkitMovementX"] || 0
                },
                getMovementY: function(event) {
                    return event["movementY"] || event["mozMovementY"] || event["webkitMovementY"] || 0
                },
                getMouseWheelDelta: function(event) {
                    var delta = 0;
                    switch (event.type) {
                        case "DOMMouseScroll":
                            delta = event.detail / 3;
                            break;
                        case "mousewheel":
                            delta = event.wheelDelta / 120;
                            break;
                        case "wheel":
                            delta = event.deltaY;
                            switch (event.deltaMode) {
                                case 0:
                                    delta /= 100;
                                    break;
                                case 1:
                                    delta /= 3;
                                    break;
                                case 2:
                                    delta *= 80;
                                    break;
                                default:
                                    throw "unrecognized mouse wheel delta mode: " + event.deltaMode
                            }
                            break;
                        default:
                            throw "unrecognized mouse wheel event: " + event.type
                    }
                    return delta
                },
                mouseX: 0,
                mouseY: 0,
                mouseMovementX: 0,
                mouseMovementY: 0,
                touches: {},
                lastTouches: {},
                calculateMouseEvent: function(event) {
                    if (Browser.pointerLock) {
                        if (event.type != "mousemove" && "mozMovementX" in event) {
                            Browser.mouseMovementX = Browser.mouseMovementY = 0
                        } else {
                            Browser.mouseMovementX = Browser.getMovementX(event);
                            Browser.mouseMovementY = Browser.getMovementY(event)
                        }
                        if (typeof SDL != "undefined") {
                            Browser.mouseX = SDL.mouseX + Browser.mouseMovementX;
                            Browser.mouseY = SDL.mouseY + Browser.mouseMovementY
                        } else {
                            Browser.mouseX += Browser.mouseMovementX;
                            Browser.mouseY += Browser.mouseMovementY
                        }
                    } else {
                        var rect = Module["canvas"].getBoundingClientRect();
                        var cw = Module["canvas"].width;
                        var ch = Module["canvas"].height;
                        var scrollX = typeof window.scrollX !== "undefined" ? window.scrollX : window.pageXOffset;
                        var scrollY = typeof window.scrollY !== "undefined" ? window.scrollY : window.pageYOffset;
                        if (event.type === "touchstart" || event.type === "touchend" || event.type === "touchmove") {
                            var touch = event.touch;
                            if (touch === undefined) {
                                return
                            }
                            var adjustedX = touch.pageX - (scrollX + rect.left);
                            var adjustedY = touch.pageY - (scrollY + rect.top);
                            adjustedX = adjustedX * (cw / rect.width);
                            adjustedY = adjustedY * (ch / rect.height);
                            var coords = {
                                x: adjustedX,
                                y: adjustedY
                            };
                            if (event.type === "touchstart") {
                                Browser.lastTouches[touch.identifier] = coords;
                                Browser.touches[touch.identifier] = coords
                            } else if (event.type === "touchend" || event.type === "touchmove") {
                                var last = Browser.touches[touch.identifier];
                                if (!last) last = coords;
                                Browser.lastTouches[touch.identifier] = last;
                                Browser.touches[touch.identifier] = coords
                            }
                            return
                        }
                        var x = event.pageX - (scrollX + rect.left);
                        var y = event.pageY - (scrollY + rect.top);
                        x = x * (cw / rect.width);
                        y = y * (ch / rect.height);
                        Browser.mouseMovementX = x - Browser.mouseX;
                        Browser.mouseMovementY = y - Browser.mouseY;
                        Browser.mouseX = x;
                        Browser.mouseY = y
                    }
                },
                asyncLoad: function(url, onload, onerror, noRunDep) {
                    var dep = !noRunDep ? getUniqueRunDependency("al " + url) : "";
                    readAsync(url, function(arrayBuffer) {
                        assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
                        onload(new Uint8Array(arrayBuffer));
                        if (dep) removeRunDependency(dep)
                    }, function(event) {
                        if (onerror) {
                            onerror()
                        } else {
                            throw 'Loading data file "' + url + '" failed.'
                        }
                    });
                    if (dep) addRunDependency(dep)
                },
                resizeListeners: [],
                updateResizeListeners: function() {
                    var canvas = Module["canvas"];
                    Browser.resizeListeners.forEach(function(listener) {
                        listener(canvas.width, canvas.height)
                    })
                },
                setCanvasSize: function(width, height, noUpdates) {
                    var canvas = Module["canvas"];
                    Browser.updateCanvasDimensions(canvas, width, height);
                    if (!noUpdates) Browser.updateResizeListeners()
                },
                windowedWidth: 0,
                windowedHeight: 0,
                setFullscreenCanvasSize: function() {
                    if (typeof SDL != "undefined") {
                        var flags = HEAPU32[SDL.screen >> 2];
                        flags = flags | 8388608;
                        HEAP32[SDL.screen >> 2] = flags
                    }
                    Browser.updateCanvasDimensions(Module["canvas"]);
                    Browser.updateResizeListeners()
                },
                setWindowedCanvasSize: function() {
                    if (typeof SDL != "undefined") {
                        var flags = HEAPU32[SDL.screen >> 2];
                        flags = flags & ~8388608;
                        HEAP32[SDL.screen >> 2] = flags
                    }
                    Browser.updateCanvasDimensions(Module["canvas"]);
                    Browser.updateResizeListeners()
                },
                updateCanvasDimensions: function(canvas, wNative, hNative) {
                    if (wNative && hNative) {
                        canvas.widthNative = wNative;
                        canvas.heightNative = hNative
                    } else {
                        wNative = canvas.widthNative;
                        hNative = canvas.heightNative
                    }
                    var w = wNative;
                    var h = hNative;
                    if (Module["forcedAspectRatio"] && Module["forcedAspectRatio"] > 0) {
                        if (w / h < Module["forcedAspectRatio"]) {
                            w = Math.round(h * Module["forcedAspectRatio"])
                        } else {
                            h = Math.round(w / Module["forcedAspectRatio"])
                        }
                    }
                    if ((document["fullscreenElement"] || document["mozFullScreenElement"] || document["msFullscreenElement"] || document["webkitFullscreenElement"] || document["webkitCurrentFullScreenElement"]) === canvas.parentNode && typeof screen != "undefined") {
                        var factor = Math.min(screen.width / w, screen.height / h);
                        w = Math.round(w * factor);
                        h = Math.round(h * factor)
                    }
                    if (Browser.resizeCanvas) {
                        if (canvas.width != w) canvas.width = w;
                        if (canvas.height != h) canvas.height = h;
                        if (typeof canvas.style != "undefined") {
                            canvas.style.removeProperty("width");
                            canvas.style.removeProperty("height")
                        }
                    } else {
                        if (canvas.width != wNative) canvas.width = wNative;
                        if (canvas.height != hNative) canvas.height = hNative;
                        if (typeof canvas.style != "undefined") {
                            if (w != wNative || h != hNative) {
                                canvas.style.setProperty("width", w + "px", "important");
                                canvas.style.setProperty("height", h + "px", "important")
                            } else {
                                canvas.style.removeProperty("width");
                                canvas.style.removeProperty("height")
                            }
                        }
                    }
                },
                wgetRequests: {},
                nextWgetRequestHandle: 0,
                getNextWgetRequestHandle: function() {
                    var handle = Browser.nextWgetRequestHandle;
                    Browser.nextWgetRequestHandle++;
                    return handle
                }
            };
            Module["Browser"] = Browser;
            var AL = {
                QUEUE_INTERVAL: 25,
                QUEUE_LOOKAHEAD: .1,
                DEVICE_NAME: "Emscripten OpenAL",
                CAPTURE_DEVICE_NAME: "Emscripten OpenAL capture",
                ALC_EXTENSIONS: {
                    ALC_SOFT_pause_device: true,
                    ALC_SOFT_HRTF: true
                },
                AL_EXTENSIONS: {
                    AL_EXT_float32: true,
                    AL_SOFT_loop_points: true,
                    AL_SOFT_source_length: true,
                    AL_EXT_source_distance_model: true,
                    AL_SOFT_source_spatialize: true
                },
                _alcErr: 0,
                alcErr: 0,
                deviceRefCounts: {},
                alcStringCache: {},
                paused: false,
                stringCache: {},
                contexts: {},
                currentCtx: null,
                buffers: {
                    0: {
                        id: 0,
                        refCount: 0,
                        audioBuf: null,
                        frequency: 0,
                        bytesPerSample: 2,
                        channels: 1,
                        length: 0
                    }
                },
                paramArray: [],
                _nextId: 1,
                newId: function() {
                    return AL.freeIds.length > 0 ? AL.freeIds.pop() : AL._nextId++
                },
                freeIds: [],
                scheduleContextAudio: function(ctx) {
                    if (Browser.mainLoop.timingMode === 1 && document["visibilityState"] != "visible") {
                        return
                    }
                    for (var i in ctx.sources) {
                        AL.scheduleSourceAudio(ctx.sources[i])
                    }
                },
                scheduleSourceAudio: function(src, lookahead) {
                    if (Browser.mainLoop.timingMode === 1 && document["visibilityState"] != "visible") {
                        return
                    }
                    if (src.state !== 4114) {
                        return
                    }
                    var currentTime = AL.updateSourceTime(src);
                    var startTime = src.bufStartTime;
                    var startOffset = src.bufOffset;
                    var bufCursor = src.bufsProcessed;
                    for (var i = 0; i < src.audioQueue.length; i++) {
                        var audioSrc = src.audioQueue[i];
                        startTime = audioSrc._startTime + audioSrc._duration;
                        startOffset = 0;
                        bufCursor += audioSrc._skipCount + 1
                    }
                    if (!lookahead) {
                        lookahead = AL.QUEUE_LOOKAHEAD
                    }
                    var lookaheadTime = currentTime + lookahead;
                    var skipCount = 0;
                    while (startTime < lookaheadTime) {
                        if (bufCursor >= src.bufQueue.length) {
                            if (src.looping) {
                                bufCursor %= src.bufQueue.length
                            } else {
                                break
                            }
                        }
                        var buf = src.bufQueue[bufCursor % src.bufQueue.length];
                        if (buf.length === 0) {
                            skipCount++;
                            if (skipCount === src.bufQueue.length) {
                                break
                            }
                        } else {
                            var audioSrc = src.context.audioCtx.createBufferSource();
                            audioSrc.buffer = buf.audioBuf;
                            audioSrc.playbackRate.value = src.playbackRate;
                            if (buf.audioBuf._loopStart || buf.audioBuf._loopEnd) {
                                audioSrc.loopStart = buf.audioBuf._loopStart;
                                audioSrc.loopEnd = buf.audioBuf._loopEnd
                            }
                            var duration = 0;
                            if (src.type === 4136 && src.looping) {
                                duration = Number.POSITIVE_INFINITY;
                                audioSrc.loop = true;
                                if (buf.audioBuf._loopStart) {
                                    audioSrc.loopStart = buf.audioBuf._loopStart
                                }
                                if (buf.audioBuf._loopEnd) {
                                    audioSrc.loopEnd = buf.audioBuf._loopEnd
                                }
                            } else {
                                duration = (buf.audioBuf.duration - startOffset) / src.playbackRate
                            }
                            audioSrc._startOffset = startOffset;
                            audioSrc._duration = duration;
                            audioSrc._skipCount = skipCount;
                            skipCount = 0;
                            audioSrc.connect(src.gain);
                            if (typeof audioSrc.start !== "undefined") {
                                startTime = Math.max(startTime, src.context.audioCtx.currentTime);
                                audioSrc.start(startTime, startOffset)
                            } else if (typeof audioSrc.noteOn !== "undefined") {
                                startTime = Math.max(startTime, src.context.audioCtx.currentTime);
                                audioSrc.noteOn(startTime)
                            }
                            audioSrc._startTime = startTime;
                            src.audioQueue.push(audioSrc);
                            startTime += duration
                        }
                        startOffset = 0;
                        bufCursor++
                    }
                },
                updateSourceTime: function(src) {
                    var currentTime = src.context.audioCtx.currentTime;
                    if (src.state !== 4114) {
                        return currentTime
                    }
                    if (!isFinite(src.bufStartTime)) {
                        src.bufStartTime = currentTime - src.bufOffset / src.playbackRate;
                        src.bufOffset = 0
                    }
                    var nextStartTime = 0;
                    while (src.audioQueue.length) {
                        var audioSrc = src.audioQueue[0];
                        src.bufsProcessed += audioSrc._skipCount;
                        nextStartTime = audioSrc._startTime + audioSrc._duration;
                        if (currentTime < nextStartTime) {
                            break
                        }
                        src.audioQueue.shift();
                        src.bufStartTime = nextStartTime;
                        src.bufOffset = 0;
                        src.bufsProcessed++
                    }
                    if (src.bufsProcessed >= src.bufQueue.length && !src.looping) {
                        AL.setSourceState(src, 4116)
                    } else if (src.type === 4136 && src.looping) {
                        var buf = src.bufQueue[0];
                        if (buf.length === 0) {
                            src.bufOffset = 0
                        } else {
                            var delta = (currentTime - src.bufStartTime) * src.playbackRate;
                            var loopStart = buf.audioBuf._loopStart || 0;
                            var loopEnd = buf.audioBuf._loopEnd || buf.audioBuf.duration;
                            if (loopEnd <= loopStart) {
                                loopEnd = buf.audioBuf.duration
                            }
                            if (delta < loopEnd) {
                                src.bufOffset = delta
                            } else {
                                src.bufOffset = loopStart + (delta - loopStart) % (loopEnd - loopStart)
                            }
                        }
                    } else if (src.audioQueue[0]) {
                        src.bufOffset = (currentTime - src.audioQueue[0]._startTime) * src.playbackRate
                    } else {
                        if (src.type !== 4136 && src.looping) {
                            var srcDuration = AL.sourceDuration(src) / src.playbackRate;
                            if (srcDuration > 0) {
                                src.bufStartTime += Math.floor((currentTime - src.bufStartTime) / srcDuration) * srcDuration
                            }
                        }
                        for (var i = 0; i < src.bufQueue.length; i++) {
                            if (src.bufsProcessed >= src.bufQueue.length) {
                                if (src.looping) {
                                    src.bufsProcessed %= src.bufQueue.length
                                } else {
                                    AL.setSourceState(src, 4116);
                                    break
                                }
                            }
                            var buf = src.bufQueue[src.bufsProcessed];
                            if (buf.length > 0) {
                                nextStartTime = src.bufStartTime + buf.audioBuf.duration / src.playbackRate;
                                if (currentTime < nextStartTime) {
                                    src.bufOffset = (currentTime - src.bufStartTime) * src.playbackRate;
                                    break
                                }
                                src.bufStartTime = nextStartTime
                            }
                            src.bufOffset = 0;
                            src.bufsProcessed++
                        }
                    }
                    return currentTime
                },
                cancelPendingSourceAudio: function(src) {
                    AL.updateSourceTime(src);
                    for (var i = 1; i < src.audioQueue.length; i++) {
                        var audioSrc = src.audioQueue[i];
                        audioSrc.stop()
                    }
                    if (src.audioQueue.length > 1) {
                        src.audioQueue.length = 1
                    }
                },
                stopSourceAudio: function(src) {
                    for (var i = 0; i < src.audioQueue.length; i++) {
                        src.audioQueue[i].stop()
                    }
                    src.audioQueue.length = 0
                },
                setSourceState: function(src, state) {
                    if (state === 4114) {
                        if (src.state === 4114 || src.state == 4116) {
                            src.bufsProcessed = 0;
                            src.bufOffset = 0
                        } else {}
                        AL.stopSourceAudio(src);
                        src.state = 4114;
                        src.bufStartTime = Number.NEGATIVE_INFINITY;
                        AL.scheduleSourceAudio(src)
                    } else if (state === 4115) {
                        if (src.state === 4114) {
                            AL.updateSourceTime(src);
                            AL.stopSourceAudio(src);
                            src.state = 4115
                        }
                    } else if (state === 4116) {
                        if (src.state !== 4113) {
                            src.state = 4116;
                            src.bufsProcessed = src.bufQueue.length;
                            src.bufStartTime = Number.NEGATIVE_INFINITY;
                            src.bufOffset = 0;
                            AL.stopSourceAudio(src)
                        }
                    } else if (state === 4113) {
                        if (src.state !== 4113) {
                            src.state = 4113;
                            src.bufsProcessed = 0;
                            src.bufStartTime = Number.NEGATIVE_INFINITY;
                            src.bufOffset = 0;
                            AL.stopSourceAudio(src)
                        }
                    }
                },
                initSourcePanner: function(src) {
                    if (src.type === 4144) {
                        return
                    }
                    var templateBuf = AL.buffers[0];
                    for (var i = 0; i < src.bufQueue.length; i++) {
                        if (src.bufQueue[i].id !== 0) {
                            templateBuf = src.bufQueue[i];
                            break
                        }
                    }
                    if (src.spatialize === 1 || src.spatialize === 2 && templateBuf.channels === 1) {
                        if (src.panner) {
                            return
                        }
                        src.panner = src.context.audioCtx.createPanner();
                        AL.updateSourceGlobal(src);
                        AL.updateSourceSpace(src);
                        src.panner.connect(src.context.gain);
                        src.gain.disconnect();
                        src.gain.connect(src.panner)
                    } else {
                        if (!src.panner) {
                            return
                        }
                        src.panner.disconnect();
                        src.gain.disconnect();
                        src.gain.connect(src.context.gain);
                        src.panner = null
                    }
                },
                updateContextGlobal: function(ctx) {
                    for (var i in ctx.sources) {
                        AL.updateSourceGlobal(ctx.sources[i])
                    }
                },
                updateSourceGlobal: function(src) {
                    var panner = src.panner;
                    if (!panner) {
                        return
                    }
                    panner.refDistance = src.refDistance;
                    panner.maxDistance = src.maxDistance;
                    panner.rolloffFactor = src.rolloffFactor;
                    panner.panningModel = src.context.hrtf ? "HRTF" : "equalpower";
                    var distanceModel = src.context.sourceDistanceModel ? src.distanceModel : src.context.distanceModel;
                    switch (distanceModel) {
                        case 0:
                            panner.distanceModel = "inverse";
                            panner.refDistance = 3.40282e38;
                            break;
                        case 53249:
                        case 53250:
                            panner.distanceModel = "inverse";
                            break;
                        case 53251:
                        case 53252:
                            panner.distanceModel = "linear";
                            break;
                        case 53253:
                        case 53254:
                            panner.distanceModel = "exponential";
                            break
                    }
                },
                updateListenerSpace: function(ctx) {
                    var listener = ctx.audioCtx.listener;
                    if (listener.positionX) {
                        listener.positionX.value = ctx.listener.position[0];
                        listener.positionY.value = ctx.listener.position[1];
                        listener.positionZ.value = ctx.listener.position[2]
                    } else {
                        listener.setPosition(ctx.listener.position[0], ctx.listener.position[1], ctx.listener.position[2])
                    }
                    if (listener.forwardX) {
                        listener.forwardX.value = ctx.listener.direction[0];
                        listener.forwardY.value = ctx.listener.direction[1];
                        listener.forwardZ.value = ctx.listener.direction[2];
                        listener.upX.value = ctx.listener.up[0];
                        listener.upY.value = ctx.listener.up[1];
                        listener.upZ.value = ctx.listener.up[2]
                    } else {
                        listener.setOrientation(ctx.listener.direction[0], ctx.listener.direction[1], ctx.listener.direction[2], ctx.listener.up[0], ctx.listener.up[1], ctx.listener.up[2])
                    }
                    for (var i in ctx.sources) {
                        AL.updateSourceSpace(ctx.sources[i])
                    }
                },
                updateSourceSpace: function(src) {
                    if (!src.panner) {
                        return
                    }
                    var panner = src.panner;
                    var posX = src.position[0];
                    var posY = src.position[1];
                    var posZ = src.position[2];
                    var dirX = src.direction[0];
                    var dirY = src.direction[1];
                    var dirZ = src.direction[2];
                    var listener = src.context.listener;
                    var lPosX = listener.position[0];
                    var lPosY = listener.position[1];
                    var lPosZ = listener.position[2];
                    if (src.relative) {
                        var lBackX = -listener.direction[0];
                        var lBackY = -listener.direction[1];
                        var lBackZ = -listener.direction[2];
                        var lUpX = listener.up[0];
                        var lUpY = listener.up[1];
                        var lUpZ = listener.up[2];
                        var inverseMagnitude = function(x, y, z) {
                            var length = Math.sqrt(x * x + y * y + z * z);
                            if (length < Number.EPSILON) {
                                return 0
                            }
                            return 1 / length
                        };
                        var invMag = inverseMagnitude(lBackX, lBackY, lBackZ);
                        lBackX *= invMag;
                        lBackY *= invMag;
                        lBackZ *= invMag;
                        invMag = inverseMagnitude(lUpX, lUpY, lUpZ);
                        lUpX *= invMag;
                        lUpY *= invMag;
                        lUpZ *= invMag;
                        var lRightX = lUpY * lBackZ - lUpZ * lBackY;
                        var lRightY = lUpZ * lBackX - lUpX * lBackZ;
                        var lRightZ = lUpX * lBackY - lUpY * lBackX;
                        invMag = inverseMagnitude(lRightX, lRightY, lRightZ);
                        lRightX *= invMag;
                        lRightY *= invMag;
                        lRightZ *= invMag;
                        lUpX = lBackY * lRightZ - lBackZ * lRightY;
                        lUpY = lBackZ * lRightX - lBackX * lRightZ;
                        lUpZ = lBackX * lRightY - lBackY * lRightX;
                        var oldX = dirX;
                        var oldY = dirY;
                        var oldZ = dirZ;
                        dirX = oldX * lRightX + oldY * lUpX + oldZ * lBackX;
                        dirY = oldX * lRightY + oldY * lUpY + oldZ * lBackY;
                        dirZ = oldX * lRightZ + oldY * lUpZ + oldZ * lBackZ;
                        oldX = posX;
                        oldY = posY;
                        oldZ = posZ;
                        posX = oldX * lRightX + oldY * lUpX + oldZ * lBackX;
                        posY = oldX * lRightY + oldY * lUpY + oldZ * lBackY;
                        posZ = oldX * lRightZ + oldY * lUpZ + oldZ * lBackZ;
                        posX += lPosX;
                        posY += lPosY;
                        posZ += lPosZ
                    }
                    if (panner.positionX) {
                        panner.positionX.value = posX;
                        panner.positionY.value = posY;
                        panner.positionZ.value = posZ
                    } else {
                        panner.setPosition(posX, posY, posZ)
                    }
                    if (panner.orientationX) {
                        panner.orientationX.value = dirX;
                        panner.orientationY.value = dirY;
                        panner.orientationZ.value = dirZ
                    } else {
                        panner.setOrientation(dirX, dirY, dirZ)
                    }
                    var oldShift = src.dopplerShift;
                    var velX = src.velocity[0];
                    var velY = src.velocity[1];
                    var velZ = src.velocity[2];
                    var lVelX = listener.velocity[0];
                    var lVelY = listener.velocity[1];
                    var lVelZ = listener.velocity[2];
                    if (posX === lPosX && posY === lPosY && posZ === lPosZ || velX === lVelX && velY === lVelY && velZ === lVelZ) {
                        src.dopplerShift = 1
                    } else {
                        var speedOfSound = src.context.speedOfSound;
                        var dopplerFactor = src.context.dopplerFactor;
                        var slX = lPosX - posX;
                        var slY = lPosY - posY;
                        var slZ = lPosZ - posZ;
                        var magSl = Math.sqrt(slX * slX + slY * slY + slZ * slZ);
                        var vls = (slX * lVelX + slY * lVelY + slZ * lVelZ) / magSl;
                        var vss = (slX * velX + slY * velY + slZ * velZ) / magSl;
                        vls = Math.min(vls, speedOfSound / dopplerFactor);
                        vss = Math.min(vss, speedOfSound / dopplerFactor);
                        src.dopplerShift = (speedOfSound - dopplerFactor * vls) / (speedOfSound - dopplerFactor * vss)
                    }
                    if (src.dopplerShift !== oldShift) {
                        AL.updateSourceRate(src)
                    }
                },
                updateSourceRate: function(src) {
                    if (src.state === 4114) {
                        AL.cancelPendingSourceAudio(src);
                        var audioSrc = src.audioQueue[0];
                        if (!audioSrc) {
                            return
                        }
                        var duration;
                        if (src.type === 4136 && src.looping) {
                            duration = Number.POSITIVE_INFINITY
                        } else {
                            duration = (audioSrc.buffer.duration - audioSrc._startOffset) / src.playbackRate
                        }
                        audioSrc._duration = duration;
                        audioSrc.playbackRate.value = src.playbackRate;
                        AL.scheduleSourceAudio(src)
                    }
                },
                sourceDuration: function(src) {
                    var length = 0;
                    for (var i = 0; i < src.bufQueue.length; i++) {
                        var audioBuf = src.bufQueue[i].audioBuf;
                        length += audioBuf ? audioBuf.duration : 0
                    }
                    return length
                },
                sourceTell: function(src) {
                    AL.updateSourceTime(src);
                    var offset = 0;
                    for (var i = 0; i < src.bufsProcessed; i++) {
                        offset += src.bufQueue[i].audioBuf.duration
                    }
                    offset += src.bufOffset;
                    return offset
                },
                sourceSeek: function(src, offset) {
                    var playing = src.state == 4114;
                    if (playing) {
                        AL.setSourceState(src, 4113)
                    }
                    if (src.bufQueue[src.bufsProcessed].audioBuf !== null) {
                        src.bufsProcessed = 0;
                        while (offset > src.bufQueue[src.bufsProcessed].audioBuf.duration) {
                            offset -= src.bufQueue[src.bufsProcessed].audiobuf.duration;
                            src.bufsProcessed++
                        }
                        src.bufOffset = offset
                    }
                    if (playing) {
                        AL.setSourceState(src, 4114)
                    }
                },
                getGlobalParam: function(funcname, param) {
                    if (!AL.currentCtx) {
                        return null
                    }
                    switch (param) {
                        case 49152:
                            return AL.currentCtx.dopplerFactor;
                        case 49155:
                            return AL.currentCtx.speedOfSound;
                        case 53248:
                            return AL.currentCtx.distanceModel;
                        default:
                            AL.currentCtx.err = 40962;
                            return null
                    }
                },
                setGlobalParam: function(funcname, param, value) {
                    if (!AL.currentCtx) {
                        return
                    }
                    switch (param) {
                        case 49152:
                            if (!Number.isFinite(value) || value < 0) {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            AL.currentCtx.dopplerFactor = value;
                            AL.updateListenerSpace(AL.currentCtx);
                            break;
                        case 49155:
                            if (!Number.isFinite(value) || value <= 0) {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            AL.currentCtx.speedOfSound = value;
                            AL.updateListenerSpace(AL.currentCtx);
                            break;
                        case 53248:
                            switch (value) {
                                case 0:
                                case 53249:
                                case 53250:
                                case 53251:
                                case 53252:
                                case 53253:
                                case 53254:
                                    AL.currentCtx.distanceModel = value;
                                    AL.updateContextGlobal(AL.currentCtx);
                                    break;
                                default:
                                    AL.currentCtx.err = 40963;
                                    return
                            }
                            break;
                        default:
                            AL.currentCtx.err = 40962;
                            return
                    }
                },
                getListenerParam: function(funcname, param) {
                    if (!AL.currentCtx) {
                        return null
                    }
                    switch (param) {
                        case 4100:
                            return AL.currentCtx.listener.position;
                        case 4102:
                            return AL.currentCtx.listener.velocity;
                        case 4111:
                            return AL.currentCtx.listener.direction.concat(AL.currentCtx.listener.up);
                        case 4106:
                            return AL.currentCtx.gain.gain.value;
                        default:
                            AL.currentCtx.err = 40962;
                            return null
                    }
                },
                setListenerParam: function(funcname, param, value) {
                    if (!AL.currentCtx) {
                        return
                    }
                    if (value === null) {
                        AL.currentCtx.err = 40962;
                        return
                    }
                    var listener = AL.currentCtx.listener;
                    switch (param) {
                        case 4100:
                            if (!Number.isFinite(value[0]) || !Number.isFinite(value[1]) || !Number.isFinite(value[2])) {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            listener.position[0] = value[0];
                            listener.position[1] = value[1];
                            listener.position[2] = value[2];
                            AL.updateListenerSpace(AL.currentCtx);
                            break;
                        case 4102:
                            if (!Number.isFinite(value[0]) || !Number.isFinite(value[1]) || !Number.isFinite(value[2])) {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            listener.velocity[0] = value[0];
                            listener.velocity[1] = value[1];
                            listener.velocity[2] = value[2];
                            AL.updateListenerSpace(AL.currentCtx);
                            break;
                        case 4106:
                            if (!Number.isFinite(value) || value < 0) {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            AL.currentCtx.gain.gain.value = value;
                            break;
                        case 4111:
                            if (!Number.isFinite(value[0]) || !Number.isFinite(value[1]) || !Number.isFinite(value[2]) || !Number.isFinite(value[3]) || !Number.isFinite(value[4]) || !Number.isFinite(value[5])) {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            listener.direction[0] = value[0];
                            listener.direction[1] = value[1];
                            listener.direction[2] = value[2];
                            listener.up[0] = value[3];
                            listener.up[1] = value[4];
                            listener.up[2] = value[5];
                            AL.updateListenerSpace(AL.currentCtx);
                            break;
                        default:
                            AL.currentCtx.err = 40962;
                            return
                    }
                },
                getBufferParam: function(funcname, bufferId, param) {
                    if (!AL.currentCtx) {
                        return
                    }
                    var buf = AL.buffers[bufferId];
                    if (!buf || bufferId === 0) {
                        AL.currentCtx.err = 40961;
                        return
                    }
                    switch (param) {
                        case 8193:
                            return buf.frequency;
                        case 8194:
                            return buf.bytesPerSample * 8;
                        case 8195:
                            return buf.channels;
                        case 8196:
                            return buf.length * buf.bytesPerSample * buf.channels;
                        case 8213:
                            if (buf.length === 0) {
                                return [0, 0]
                            } else {
                                return [(buf.audioBuf._loopStart || 0) * buf.frequency, (buf.audioBuf._loopEnd || buf.length) * buf.frequency]
                            }
                            default:
                                AL.currentCtx.err = 40962;
                                return null
                    }
                },
                setBufferParam: function(funcname, bufferId, param, value) {
                    if (!AL.currentCtx) {
                        return
                    }
                    var buf = AL.buffers[bufferId];
                    if (!buf || bufferId === 0) {
                        AL.currentCtx.err = 40961;
                        return
                    }
                    if (value === null) {
                        AL.currentCtx.err = 40962;
                        return
                    }
                    switch (param) {
                        case 8196:
                            if (value !== 0) {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            break;
                        case 8213:
                            if (value[0] < 0 || value[0] > buf.length || value[1] < 0 || value[1] > buf.Length || value[0] >= value[1]) {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            if (buf.refCount > 0) {
                                AL.currentCtx.err = 40964;
                                return
                            }
                            if (buf.audioBuf) {
                                buf.audioBuf._loopStart = value[0] / buf.frequency;
                                buf.audioBuf._loopEnd = value[1] / buf.frequency
                            }
                            break;
                        default:
                            AL.currentCtx.err = 40962;
                            return
                    }
                },
                getSourceParam: function(funcname, sourceId, param) {
                    if (!AL.currentCtx) {
                        return null
                    }
                    var src = AL.currentCtx.sources[sourceId];
                    if (!src) {
                        AL.currentCtx.err = 40961;
                        return null
                    }
                    switch (param) {
                        case 514:
                            return src.relative;
                        case 4097:
                            return src.coneInnerAngle;
                        case 4098:
                            return src.coneOuterAngle;
                        case 4099:
                            return src.pitch;
                        case 4100:
                            return src.position;
                        case 4101:
                            return src.direction;
                        case 4102:
                            return src.velocity;
                        case 4103:
                            return src.looping;
                        case 4105:
                            if (src.type === 4136) {
                                return src.bufQueue[0].id
                            } else {
                                return 0
                            }
                            case 4106:
                                return src.gain.gain.value;
                            case 4109:
                                return src.minGain;
                            case 4110:
                                return src.maxGain;
                            case 4112:
                                return src.state;
                            case 4117:
                                if (src.bufQueue.length === 1 && src.bufQueue[0].id === 0) {
                                    return 0
                                } else {
                                    return src.bufQueue.length
                                }
                                case 4118:
                                    if (src.bufQueue.length === 1 && src.bufQueue[0].id === 0 || src.looping) {
                                        return 0
                                    } else {
                                        return src.bufsProcessed
                                    }
                                    case 4128:
                                        return src.refDistance;
                                    case 4129:
                                        return src.rolloffFactor;
                                    case 4130:
                                        return src.coneOuterGain;
                                    case 4131:
                                        return src.maxDistance;
                                    case 4132:
                                        return AL.sourceTell(src);
                                    case 4133:
                                        var offset = AL.sourceTell(src);
                                        if (offset > 0) {
                                            offset *= src.bufQueue[0].frequency
                                        }
                                        return offset;
                                    case 4134:
                                        var offset = AL.sourceTell(src);
                                        if (offset > 0) {
                                            offset *= src.bufQueue[0].frequency * src.bufQueue[0].bytesPerSample
                                        }
                                        return offset;
                                    case 4135:
                                        return src.type;
                                    case 4628:
                                        return src.spatialize;
                                    case 8201:
                                        var length = 0;
                                        var bytesPerFrame = 0;
                                        for (var i = 0; i < src.bufQueue.length; i++) {
                                            length += src.bufQueue[i].length;
                                            if (src.bufQueue[i].id !== 0) {
                                                bytesPerFrame = src.bufQueue[i].bytesPerSample * src.bufQueue[i].channels
                                            }
                                        }
                                        return length * bytesPerFrame;
                                    case 8202:
                                        var length = 0;
                                        for (var i = 0; i < src.bufQueue.length; i++) {
                                            length += src.bufQueue[i].length
                                        }
                                        return length;
                                    case 8203:
                                        return AL.sourceDuration(src);
                                    case 53248:
                                        return src.distanceModel;
                                    default:
                                        AL.currentCtx.err = 40962;
                                        return null
                    }
                },
                setSourceParam: function(funcname, sourceId, param, value) {
                    if (!AL.currentCtx) {
                        return
                    }
                    var src = AL.currentCtx.sources[sourceId];
                    if (!src) {
                        AL.currentCtx.err = 40961;
                        return
                    }
                    if (value === null) {
                        AL.currentCtx.err = 40962;
                        return
                    }
                    switch (param) {
                        case 514:
                            if (value === 1) {
                                src.relative = true;
                                AL.updateSourceSpace(src)
                            } else if (value === 0) {
                                src.relative = false;
                                AL.updateSourceSpace(src)
                            } else {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            break;
                        case 4097:
                            if (!Number.isFinite(value)) {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            src.coneInnerAngle = value;
                            if (src.panner) {
                                src.panner.coneInnerAngle = value % 360
                            }
                            break;
                        case 4098:
                            if (!Number.isFinite(value)) {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            src.coneOuterAngle = value;
                            if (src.panner) {
                                src.panner.coneOuterAngle = value % 360
                            }
                            break;
                        case 4099:
                            if (!Number.isFinite(value) || value <= 0) {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            if (src.pitch === value) {
                                break
                            }
                            src.pitch = value;
                            AL.updateSourceRate(src);
                            break;
                        case 4100:
                            if (!Number.isFinite(value[0]) || !Number.isFinite(value[1]) || !Number.isFinite(value[2])) {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            src.position[0] = value[0];
                            src.position[1] = value[1];
                            src.position[2] = value[2];
                            AL.updateSourceSpace(src);
                            break;
                        case 4101:
                            if (!Number.isFinite(value[0]) || !Number.isFinite(value[1]) || !Number.isFinite(value[2])) {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            src.direction[0] = value[0];
                            src.direction[1] = value[1];
                            src.direction[2] = value[2];
                            AL.updateSourceSpace(src);
                            break;
                        case 4102:
                            if (!Number.isFinite(value[0]) || !Number.isFinite(value[1]) || !Number.isFinite(value[2])) {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            src.velocity[0] = value[0];
                            src.velocity[1] = value[1];
                            src.velocity[2] = value[2];
                            AL.updateSourceSpace(src);
                            break;
                        case 4103:
                            if (value === 1) {
                                src.looping = true;
                                AL.updateSourceTime(src);
                                if (src.type === 4136 && src.audioQueue.length > 0) {
                                    var audioSrc = src.audioQueue[0];
                                    audioSrc.loop = true;
                                    audioSrc._duration = Number.POSITIVE_INFINITY
                                }
                            } else if (value === 0) {
                                src.looping = false;
                                var currentTime = AL.updateSourceTime(src);
                                if (src.type === 4136 && src.audioQueue.length > 0) {
                                    var audioSrc = src.audioQueue[0];
                                    audioSrc.loop = false;
                                    audioSrc._duration = src.bufQueue[0].audioBuf.duration / src.playbackRate;
                                    audioSrc._startTime = currentTime - src.bufOffset / src.playbackRate
                                }
                            } else {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            break;
                        case 4105:
                            if (src.state === 4114 || src.state === 4115) {
                                AL.currentCtx.err = 40964;
                                return
                            }
                            if (value === 0) {
                                for (var i in src.bufQueue) {
                                    src.bufQueue[i].refCount--
                                }
                                src.bufQueue.length = 1;
                                src.bufQueue[0] = AL.buffers[0];
                                src.bufsProcessed = 0;
                                src.type = 4144
                            } else {
                                var buf = AL.buffers[value];
                                if (!buf) {
                                    AL.currentCtx.err = 40963;
                                    return
                                }
                                for (var i in src.bufQueue) {
                                    src.bufQueue[i].refCount--
                                }
                                src.bufQueue.length = 0;
                                buf.refCount++;
                                src.bufQueue = [buf];
                                src.bufsProcessed = 0;
                                src.type = 4136
                            }
                            AL.initSourcePanner(src);
                            AL.scheduleSourceAudio(src);
                            break;
                        case 4106:
                            if (!Number.isFinite(value) || value < 0) {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            src.gain.gain.value = value;
                            break;
                        case 4109:
                            if (!Number.isFinite(value) || value < 0 || value > Math.min(src.maxGain, 1)) {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            src.minGain = value;
                            break;
                        case 4110:
                            if (!Number.isFinite(value) || value < Math.max(0, src.minGain) || value > 1) {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            src.maxGain = value;
                            break;
                        case 4128:
                            if (!Number.isFinite(value) || value < 0) {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            src.refDistance = value;
                            if (src.panner) {
                                src.panner.refDistance = value
                            }
                            break;
                        case 4129:
                            if (!Number.isFinite(value) || value < 0) {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            src.rolloffFactor = value;
                            if (src.panner) {
                                src.panner.rolloffFactor = value
                            }
                            break;
                        case 4130:
                            if (!Number.isFinite(value) || value < 0 || value > 1) {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            src.coneOuterGain = value;
                            if (src.panner) {
                                src.panner.coneOuterGain = value
                            }
                            break;
                        case 4131:
                            if (!Number.isFinite(value) || value < 0) {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            src.maxDistance = value;
                            if (src.panner) {
                                src.panner.maxDistance = value
                            }
                            break;
                        case 4132:
                            if (value < 0 || value > AL.sourceDuration(src)) {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            AL.sourceSeek(src, value);
                            break;
                        case 4133:
                            var srcLen = AL.sourceDuration(src);
                            if (srcLen > 0) {
                                var frequency;
                                for (var bufId in src.bufQueue) {
                                    if (bufId) {
                                        frequency = src.bufQueue[bufId].frequency;
                                        break
                                    }
                                }
                                value /= frequency
                            }
                            if (value < 0 || value > srcLen) {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            AL.sourceSeek(src, value);
                            break;
                        case 4134:
                            var srcLen = AL.sourceDuration(src);
                            if (srcLen > 0) {
                                var bytesPerSec;
                                for (var bufId in src.bufQueue) {
                                    if (bufId) {
                                        var buf = src.bufQueue[bufId];
                                        bytesPerSec = buf.frequency * buf.bytesPerSample * buf.channels;
                                        break
                                    }
                                }
                                value /= bytesPerSec
                            }
                            if (value < 0 || value > srcLen) {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            AL.sourceSeek(src, value);
                            break;
                        case 4628:
                            if (value !== 0 && value !== 1 && value !== 2) {
                                AL.currentCtx.err = 40963;
                                return
                            }
                            src.spatialize = value;
                            AL.initSourcePanner(src);
                            break;
                        case 8201:
                        case 8202:
                        case 8203:
                            AL.currentCtx.err = 40964;
                            break;
                        case 53248:
                            switch (value) {
                                case 0:
                                case 53249:
                                case 53250:
                                case 53251:
                                case 53252:
                                case 53253:
                                case 53254:
                                    src.distanceModel = value;
                                    if (AL.currentCtx.sourceDistanceModel) {
                                        AL.updateContextGlobal(AL.currentCtx)
                                    }
                                    break;
                                default:
                                    AL.currentCtx.err = 40963;
                                    return
                            }
                            break;
                        default:
                            AL.currentCtx.err = 40962;
                            return
                    }
                },
                captures: {},
                sharedCaptureAudioCtx: null,
                requireValidCaptureDevice: function(deviceId, funcname) {
                    if (deviceId === 0) {
                        AL.alcErr = 40961;
                        return null
                    }
                    var c = AL.captures[deviceId];
                    if (!c) {
                        AL.alcErr = 40961;
                        return null
                    }
                    var err = c.mediaStreamError;
                    if (err) {
                        AL.alcErr = 40961;
                        return null
                    }
                    return c
                }
            };
            Module["AL"] = AL;

            function _alBuffer3f(bufferId, param, value0, value1, value2) {
                AL.setBufferParam("alBuffer3f", bufferId, param, null)
            }
            Module["_alBuffer3f"] = _alBuffer3f;
            _alBuffer3f.sig = "viifff";

            function _alBuffer3i(bufferId, param, value0, value1, value2) {
                AL.setBufferParam("alBuffer3i", bufferId, param, null)
            }
            Module["_alBuffer3i"] = _alBuffer3i;
            _alBuffer3i.sig = "viiiii";

            function _alBufferData(bufferId, format, pData, size, freq) {
                if (!AL.currentCtx) {
                    return
                }
                var buf = AL.buffers[bufferId];
                if (!buf) {
                    AL.currentCtx.err = 40963;
                    return
                }
                if (freq <= 0) {
                    AL.currentCtx.err = 40963;
                    return
                }
                var audioBuf = null;
                try {
                    switch (format) {
                        case 4352:
                            if (size > 0) {
                                audioBuf = AL.currentCtx.audioCtx.createBuffer(1, size, freq);
                                var channel0 = audioBuf.getChannelData(0);
                                for (var i = 0; i < size; ++i) {
                                    channel0[i] = HEAPU8[pData++] * .0078125 - 1
                                }
                            }
                            buf.bytesPerSample = 1;
                            buf.channels = 1;
                            buf.length = size;
                            break;
                        case 4353:
                            if (size > 0) {
                                audioBuf = AL.currentCtx.audioCtx.createBuffer(1, size >> 1, freq);
                                var channel0 = audioBuf.getChannelData(0);
                                pData >>= 1;
                                for (var i = 0; i < size >> 1; ++i) {
                                    channel0[i] = HEAP16[pData++] * 30517578125e-15
                                }
                            }
                            buf.bytesPerSample = 2;
                            buf.channels = 1;
                            buf.length = size >> 1;
                            break;
                        case 4354:
                            if (size > 0) {
                                audioBuf = AL.currentCtx.audioCtx.createBuffer(2, size >> 1, freq);
                                var channel0 = audioBuf.getChannelData(0);
                                var channel1 = audioBuf.getChannelData(1);
                                for (var i = 0; i < size >> 1; ++i) {
                                    channel0[i] = HEAPU8[pData++] * .0078125 - 1;
                                    channel1[i] = HEAPU8[pData++] * .0078125 - 1
                                }
                            }
                            buf.bytesPerSample = 1;
                            buf.channels = 2;
                            buf.length = size >> 1;
                            break;
                        case 4355:
                            if (size > 0) {
                                audioBuf = AL.currentCtx.audioCtx.createBuffer(2, size >> 2, freq);
                                var channel0 = audioBuf.getChannelData(0);
                                var channel1 = audioBuf.getChannelData(1);
                                pData >>= 1;
                                for (var i = 0; i < size >> 2; ++i) {
                                    channel0[i] = HEAP16[pData++] * 30517578125e-15;
                                    channel1[i] = HEAP16[pData++] * 30517578125e-15
                                }
                            }
                            buf.bytesPerSample = 2;
                            buf.channels = 2;
                            buf.length = size >> 2;
                            break;
                        case 65552:
                            if (size > 0) {
                                audioBuf = AL.currentCtx.audioCtx.createBuffer(1, size >> 2, freq);
                                var channel0 = audioBuf.getChannelData(0);
                                pData >>= 2;
                                for (var i = 0; i < size >> 2; ++i) {
                                    channel0[i] = HEAPF32[pData++]
                                }
                            }
                            buf.bytesPerSample = 4;
                            buf.channels = 1;
                            buf.length = size >> 2;
                            break;
                        case 65553:
                            if (size > 0) {
                                audioBuf = AL.currentCtx.audioCtx.createBuffer(2, size >> 3, freq);
                                var channel0 = audioBuf.getChannelData(0);
                                var channel1 = audioBuf.getChannelData(1);
                                pData >>= 2;
                                for (var i = 0; i < size >> 3; ++i) {
                                    channel0[i] = HEAPF32[pData++];
                                    channel1[i] = HEAPF32[pData++]
                                }
                            }
                            buf.bytesPerSample = 4;
                            buf.channels = 2;
                            buf.length = size >> 3;
                            break;
                        default:
                            AL.currentCtx.err = 40963;
                            return
                    }
                    buf.frequency = freq;
                    buf.audioBuf = audioBuf
                } catch (e) {
                    AL.currentCtx.err = 40963;
                    return
                }
            }
            Module["_alBufferData"] = _alBufferData;
            _alBufferData.sig = "viiiii";

            function _alBufferf(bufferId, param, value) {
                AL.setBufferParam("alBufferf", bufferId, param, null)
            }
            Module["_alBufferf"] = _alBufferf;
            _alBufferf.sig = "viif";

            function _alBufferfv(bufferId, param, pValues) {
                if (!AL.currentCtx) {
                    return
                }
                if (!pValues) {
                    AL.currentCtx.err = 40963;
                    return
                }
                AL.setBufferParam("alBufferfv", bufferId, param, null)
            }
            Module["_alBufferfv"] = _alBufferfv;
            _alBufferfv.sig = "viii";

            function _alBufferi(bufferId, param, value) {
                AL.setBufferParam("alBufferi", bufferId, param, null)
            }
            Module["_alBufferi"] = _alBufferi;
            _alBufferi.sig = "viii";

            function _alBufferiv(bufferId, param, pValues) {
                if (!AL.currentCtx) {
                    return
                }
                if (!pValues) {
                    AL.currentCtx.err = 40963;
                    return
                }
                switch (param) {
                    case 8213:
                        AL.paramArray[0] = HEAP32[pValues >> 2];
                        AL.paramArray[1] = HEAP32[pValues + 4 >> 2];
                        AL.setBufferParam("alBufferiv", bufferId, param, AL.paramArray);
                        break;
                    default:
                        AL.setBufferParam("alBufferiv", bufferId, param, null);
                        break
                }
            }
            Module["_alBufferiv"] = _alBufferiv;
            _alBufferiv.sig = "viii";

            function _alDeleteBuffers(count, pBufferIds) {
                if (!AL.currentCtx) {
                    return
                }
                for (var i = 0; i < count; ++i) {
                    var bufId = HEAP32[pBufferIds + i * 4 >> 2];
                    if (bufId === 0) {
                        continue
                    }
                    if (!AL.buffers[bufId]) {
                        AL.currentCtx.err = 40961;
                        return
                    }
                    if (AL.buffers[bufId].refCount) {
                        AL.currentCtx.err = 40964;
                        return
                    }
                }
                for (var i = 0; i < count; ++i) {
                    var bufId = HEAP32[pBufferIds + i * 4 >> 2];
                    if (bufId === 0) {
                        continue
                    }
                    AL.deviceRefCounts[AL.buffers[bufId].deviceId]--;
                    delete AL.buffers[bufId];
                    AL.freeIds.push(bufId)
                }
            }
            Module["_alDeleteBuffers"] = _alDeleteBuffers;
            _alDeleteBuffers.sig = "vii";

            function _alSourcei(sourceId, param, value) {
                switch (param) {
                    case 514:
                    case 4097:
                    case 4098:
                    case 4103:
                    case 4105:
                    case 4128:
                    case 4129:
                    case 4131:
                    case 4132:
                    case 4133:
                    case 4134:
                    case 4628:
                    case 8201:
                    case 8202:
                    case 53248:
                        AL.setSourceParam("alSourcei", sourceId, param, value);
                        break;
                    default:
                        AL.setSourceParam("alSourcei", sourceId, param, null);
                        break
                }
            }
            Module["_alSourcei"] = _alSourcei;
            _alSourcei.sig = "viii";

            function _alDeleteSources(count, pSourceIds) {
                if (!AL.currentCtx) {
                    return
                }
                for (var i = 0; i < count; ++i) {
                    var srcId = HEAP32[pSourceIds + i * 4 >> 2];
                    if (!AL.currentCtx.sources[srcId]) {
                        AL.currentCtx.err = 40961;
                        return
                    }
                }
                for (var i = 0; i < count; ++i) {
                    var srcId = HEAP32[pSourceIds + i * 4 >> 2];
                    AL.setSourceState(AL.currentCtx.sources[srcId], 4116);
                    _alSourcei(srcId, 4105, 0);
                    delete AL.currentCtx.sources[srcId];
                    AL.freeIds.push(srcId)
                }
            }
            Module["_alDeleteSources"] = _alDeleteSources;
            _alDeleteSources.sig = "vii";

            function _alDisable(param) {
                if (!AL.currentCtx) {
                    return
                }
                switch (param) {
                    case "AL_SOURCE_DISTANCE_MODEL":
                        AL.currentCtx.sourceDistanceModel = false;
                        AL.updateContextGlobal(AL.currentCtx);
                        break;
                    default:
                        AL.currentCtx.err = 40962;
                        return
                }
            }
            Module["_alDisable"] = _alDisable;
            _alDisable.sig = "vi";

            function _alDistanceModel(model) {
                AL.setGlobalParam("alDistanceModel", 53248, model)
            }
            Module["_alDistanceModel"] = _alDistanceModel;
            _alDistanceModel.sig = "vi";

            function _alDopplerFactor(value) {
                AL.setGlobalParam("alDopplerFactor", 49152, value)
            }
            Module["_alDopplerFactor"] = _alDopplerFactor;
            _alDopplerFactor.sig = "vi";

            function _alDopplerVelocity(value) {
                warnOnce("alDopplerVelocity() is deprecated, and only kept for compatibility with OpenAL 1.0. Use alSpeedOfSound() instead.");
                if (!AL.currentCtx) {
                    return
                }
                if (value <= 0) {
                    AL.currentCtx.err = 40963;
                    return
                }
            }
            Module["_alDopplerVelocity"] = _alDopplerVelocity;
            _alDopplerVelocity.sig = "vi";

            function _alEnable(param) {
                if (!AL.currentCtx) {
                    return
                }
                switch (param) {
                    case "AL_SOURCE_DISTANCE_MODEL":
                        AL.currentCtx.sourceDistanceModel = true;
                        AL.updateContextGlobal(AL.currentCtx);
                        break;
                    default:
                        AL.currentCtx.err = 40962;
                        return
                }
            }
            Module["_alEnable"] = _alEnable;
            _alEnable.sig = "vi";

            function _alGenBuffers(count, pBufferIds) {
                if (!AL.currentCtx) {
                    return
                }
                for (var i = 0; i < count; ++i) {
                    var buf = {
                        deviceId: AL.currentCtx.deviceId,
                        id: AL.newId(),
                        refCount: 0,
                        audioBuf: null,
                        frequency: 0,
                        bytesPerSample: 2,
                        channels: 1,
                        length: 0
                    };
                    AL.deviceRefCounts[buf.deviceId]++;
                    AL.buffers[buf.id] = buf;
                    HEAP32[pBufferIds + i * 4 >> 2] = buf.id
                }
            }
            Module["_alGenBuffers"] = _alGenBuffers;
            _alGenBuffers.sig = "vii";

            function _alGenSources(count, pSourceIds) {
                if (!AL.currentCtx) {
                    return
                }
                for (var i = 0; i < count; ++i) {
                    var gain = AL.currentCtx.audioCtx.createGain();
                    gain.connect(AL.currentCtx.gain);
                    var src = {
                        context: AL.currentCtx,
                        id: AL.newId(),
                        type: 4144,
                        state: 4113,
                        bufQueue: [AL.buffers[0]],
                        audioQueue: [],
                        looping: false,
                        pitch: 1,
                        dopplerShift: 1,
                        gain: gain,
                        minGain: 0,
                        maxGain: 1,
                        panner: null,
                        bufsProcessed: 0,
                        bufStartTime: Number.NEGATIVE_INFINITY,
                        bufOffset: 0,
                        relative: false,
                        refDistance: 1,
                        maxDistance: 3.40282e38,
                        rolloffFactor: 1,
                        position: [0, 0, 0],
                        velocity: [0, 0, 0],
                        direction: [0, 0, 0],
                        coneOuterGain: 0,
                        coneInnerAngle: 360,
                        coneOuterAngle: 360,
                        distanceModel: 53250,
                        spatialize: 2,
                        get playbackRate() {
                            return this.pitch * this.dopplerShift
                        }
                    };
                    AL.currentCtx.sources[src.id] = src;
                    HEAP32[pSourceIds + i * 4 >> 2] = src.id
                }
            }
            Module["_alGenSources"] = _alGenSources;
            _alGenSources.sig = "vii";

            function _alGetBoolean(param) {
                var val = AL.getGlobalParam("alGetBoolean", param);
                if (val === null) {
                    return 0
                }
                switch (param) {
                    case 49152:
                    case 49155:
                    case 53248:
                        return val !== 0 ? 1 : 0;
                    default:
                        AL.currentCtx.err = 40962;
                        return 0
                }
            }
            Module["_alGetBoolean"] = _alGetBoolean;
            _alGetBoolean.sig = "ii";

            function _alGetBooleanv(param, pValues) {
                var val = AL.getGlobalParam("alGetBooleanv", param);
                if (val === null || !pValues) {
                    return
                }
                switch (param) {
                    case 49152:
                    case 49155:
                    case 53248:
                        HEAP8[pValues >> 0] = val;
                        break;
                    default:
                        AL.currentCtx.err = 40962;
                        return
                }
            }
            Module["_alGetBooleanv"] = _alGetBooleanv;
            _alGetBooleanv.sig = "vii";

            function _alGetBuffer3f(bufferId, param, pValue0, pValue1, pValue2) {
                var val = AL.getBufferParam("alGetBuffer3f", bufferId, param);
                if (val === null) {
                    return
                }
                if (!pValue0 || !pValue1 || !pValue2) {
                    AL.currentCtx.err = 40963;
                    return
                }
                AL.currentCtx.err = 40962
            }
            Module["_alGetBuffer3f"] = _alGetBuffer3f;
            _alGetBuffer3f.sig = "viiiii";

            function _alGetBuffer3i(bufferId, param, pValue0, pValue1, pValue2) {
                var val = AL.getBufferParam("alGetBuffer3i", bufferId, param);
                if (val === null) {
                    return
                }
                if (!pValue0 || !pValue1 || !pValue2) {
                    AL.currentCtx.err = 40963;
                    return
                }
                AL.currentCtx.err = 40962
            }
            Module["_alGetBuffer3i"] = _alGetBuffer3i;
            _alGetBuffer3i.sig = "viiiii";

            function _alGetBufferf(bufferId, param, pValue) {
                var val = AL.getBufferParam("alGetBufferf", bufferId, param);
                if (val === null) {
                    return
                }
                if (!pValue) {
                    AL.currentCtx.err = 40963;
                    return
                }
                AL.currentCtx.err = 40962
            }
            Module["_alGetBufferf"] = _alGetBufferf;
            _alGetBufferf.sig = "viii";

            function _alGetBufferfv(bufferId, param, pValues) {
                var val = AL.getBufferParam("alGetBufferfv", bufferId, param);
                if (val === null) {
                    return
                }
                if (!pValues) {
                    AL.currentCtx.err = 40963;
                    return
                }
                AL.currentCtx.err = 40962
            }
            Module["_alGetBufferfv"] = _alGetBufferfv;
            _alGetBufferfv.sig = "viii";

            function _alGetBufferi(bufferId, param, pValue) {
                var val = AL.getBufferParam("alGetBufferi", bufferId, param);
                if (val === null) {
                    return
                }
                if (!pValue) {
                    AL.currentCtx.err = 40963;
                    return
                }
                switch (param) {
                    case 8193:
                    case 8194:
                    case 8195:
                    case 8196:
                        HEAP32[pValue >> 2] = val;
                        break;
                    default:
                        AL.currentCtx.err = 40962;
                        return
                }
            }
            Module["_alGetBufferi"] = _alGetBufferi;
            _alGetBufferi.sig = "viii";

            function _alGetBufferiv(bufferId, param, pValues) {
                var val = AL.getBufferParam("alGetBufferiv", bufferId, param);
                if (val === null) {
                    return
                }
                if (!pValues) {
                    AL.currentCtx.err = 40963;
                    return
                }
                switch (param) {
                    case 8193:
                    case 8194:
                    case 8195:
                    case 8196:
                        HEAP32[pValues >> 2] = val;
                        break;
                    case 8213:
                        HEAP32[pValues >> 2] = val[0];
                        HEAP32[pValues + 4 >> 2] = val[1];
                        break;
                    default:
                        AL.currentCtx.err = 40962;
                        return
                }
            }
            Module["_alGetBufferiv"] = _alGetBufferiv;
            _alGetBufferiv.sig = "viii";

            function _alGetDouble(param) {
                var val = AL.getGlobalParam("alGetDouble", param);
                if (val === null) {
                    return 0
                }
                switch (param) {
                    case 49152:
                    case 49155:
                    case 53248:
                        return val;
                    default:
                        AL.currentCtx.err = 40962;
                        return 0
                }
            }
            Module["_alGetDouble"] = _alGetDouble;
            _alGetDouble.sig = "di";

            function _alGetDoublev(param, pValues) {
                var val = AL.getGlobalParam("alGetDoublev", param);
                if (val === null || !pValues) {
                    return
                }
                switch (param) {
                    case 49152:
                    case 49155:
                    case 53248:
                        HEAPF64[pValues >> 3] = val;
                        break;
                    default:
                        AL.currentCtx.err = 40962;
                        return
                }
            }
            Module["_alGetDoublev"] = _alGetDoublev;
            _alGetDoublev.sig = "vii";

            function _alGetEnumValue(pEnumName) {
                if (!AL.currentCtx) {
                    return 0
                }
                if (!pEnumName) {
                    AL.currentCtx.err = 40963;
                    return 0
                }
                var name = UTF8ToString(pEnumName);
                switch (name) {
                    case "AL_BITS":
                        return 8194;
                    case "AL_BUFFER":
                        return 4105;
                    case "AL_BUFFERS_PROCESSED":
                        return 4118;
                    case "AL_BUFFERS_QUEUED":
                        return 4117;
                    case "AL_BYTE_OFFSET":
                        return 4134;
                    case "AL_CHANNELS":
                        return 8195;
                    case "AL_CONE_INNER_ANGLE":
                        return 4097;
                    case "AL_CONE_OUTER_ANGLE":
                        return 4098;
                    case "AL_CONE_OUTER_GAIN":
                        return 4130;
                    case "AL_DIRECTION":
                        return 4101;
                    case "AL_DISTANCE_MODEL":
                        return 53248;
                    case "AL_DOPPLER_FACTOR":
                        return 49152;
                    case "AL_DOPPLER_VELOCITY":
                        return 49153;
                    case "AL_EXPONENT_DISTANCE":
                        return 53253;
                    case "AL_EXPONENT_DISTANCE_CLAMPED":
                        return 53254;
                    case "AL_EXTENSIONS":
                        return 45060;
                    case "AL_FORMAT_MONO16":
                        return 4353;
                    case "AL_FORMAT_MONO8":
                        return 4352;
                    case "AL_FORMAT_STEREO16":
                        return 4355;
                    case "AL_FORMAT_STEREO8":
                        return 4354;
                    case "AL_FREQUENCY":
                        return 8193;
                    case "AL_GAIN":
                        return 4106;
                    case "AL_INITIAL":
                        return 4113;
                    case "AL_INVALID":
                        return -1;
                    case "AL_ILLEGAL_ENUM":
                    case "AL_INVALID_ENUM":
                        return 40962;
                    case "AL_INVALID_NAME":
                        return 40961;
                    case "AL_ILLEGAL_COMMAND":
                    case "AL_INVALID_OPERATION":
                        return 40964;
                    case "AL_INVALID_VALUE":
                        return 40963;
                    case "AL_INVERSE_DISTANCE":
                        return 53249;
                    case "AL_INVERSE_DISTANCE_CLAMPED":
                        return 53250;
                    case "AL_LINEAR_DISTANCE":
                        return 53251;
                    case "AL_LINEAR_DISTANCE_CLAMPED":
                        return 53252;
                    case "AL_LOOPING":
                        return 4103;
                    case "AL_MAX_DISTANCE":
                        return 4131;
                    case "AL_MAX_GAIN":
                        return 4110;
                    case "AL_MIN_GAIN":
                        return 4109;
                    case "AL_NONE":
                        return 0;
                    case "AL_NO_ERROR":
                        return 0;
                    case "AL_ORIENTATION":
                        return 4111;
                    case "AL_OUT_OF_MEMORY":
                        return 40965;
                    case "AL_PAUSED":
                        return 4115;
                    case "AL_PENDING":
                        return 8209;
                    case "AL_PITCH":
                        return 4099;
                    case "AL_PLAYING":
                        return 4114;
                    case "AL_POSITION":
                        return 4100;
                    case "AL_PROCESSED":
                        return 8210;
                    case "AL_REFERENCE_DISTANCE":
                        return 4128;
                    case "AL_RENDERER":
                        return 45059;
                    case "AL_ROLLOFF_FACTOR":
                        return 4129;
                    case "AL_SAMPLE_OFFSET":
                        return 4133;
                    case "AL_SEC_OFFSET":
                        return 4132;
                    case "AL_SIZE":
                        return 8196;
                    case "AL_SOURCE_RELATIVE":
                        return 514;
                    case "AL_SOURCE_STATE":
                        return 4112;
                    case "AL_SOURCE_TYPE":
                        return 4135;
                    case "AL_SPEED_OF_SOUND":
                        return 49155;
                    case "AL_STATIC":
                        return 4136;
                    case "AL_STOPPED":
                        return 4116;
                    case "AL_STREAMING":
                        return 4137;
                    case "AL_UNDETERMINED":
                        return 4144;
                    case "AL_UNUSED":
                        return 8208;
                    case "AL_VELOCITY":
                        return 4102;
                    case "AL_VENDOR":
                        return 45057;
                    case "AL_VERSION":
                        return 45058;
                    case "AL_AUTO_SOFT":
                        return 2;
                    case "AL_SOURCE_DISTANCE_MODEL":
                        return 512;
                    case "AL_SOURCE_SPATIALIZE_SOFT":
                        return 4628;
                    case "AL_LOOP_POINTS_SOFT":
                        return 8213;
                    case "AL_BYTE_LENGTH_SOFT":
                        return 8201;
                    case "AL_SAMPLE_LENGTH_SOFT":
                        return 8202;
                    case "AL_SEC_LENGTH_SOFT":
                        return 8203;
                    case "AL_FORMAT_MONO_FLOAT32":
                        return 65552;
                    case "AL_FORMAT_STEREO_FLOAT32":
                        return 65553;
                    default:
                        AL.currentCtx.err = 40963;
                        return 0
                }
            }
            Module["_alGetEnumValue"] = _alGetEnumValue;
            _alGetEnumValue.sig = "ii";

            function _alGetError() {
                if (!AL.currentCtx) {
                    return 40964
                } else {
                    var err = AL.currentCtx.err;
                    AL.currentCtx.err = 0;
                    return err
                }
            }
            Module["_alGetError"] = _alGetError;
            _alGetError.sig = "i";

            function _alGetFloat(param) {
                var val = AL.getGlobalParam("alGetFloat", param);
                if (val === null) {
                    return 0
                }
                switch (param) {
                    case 49152:
                    case 49155:
                    case 53248:
                        return val;
                    default:
                        return 0
                }
            }
            Module["_alGetFloat"] = _alGetFloat;
            _alGetFloat.sig = "fi";

            function _alGetFloatv(param, pValues) {
                var val = AL.getGlobalParam("alGetFloatv", param);
                if (val === null || !pValues) {
                    return
                }
                switch (param) {
                    case 49152:
                    case 49155:
                    case 53248:
                        HEAPF32[pValues >> 2] = val;
                        break;
                    default:
                        AL.currentCtx.err = 40962;
                        return
                }
            }
            Module["_alGetFloatv"] = _alGetFloatv;
            _alGetFloatv.sig = "vii";

            function _alGetInteger(param) {
                var val = AL.getGlobalParam("alGetInteger", param);
                if (val === null) {
                    return 0
                }
                switch (param) {
                    case 49152:
                    case 49155:
                    case 53248:
                        return val;
                    default:
                        AL.currentCtx.err = 40962;
                        return 0
                }
            }
            Module["_alGetInteger"] = _alGetInteger;
            _alGetInteger.sig = "ii";

            function _alGetIntegerv(param, pValues) {
                var val = AL.getGlobalParam("alGetIntegerv", param);
                if (val === null || !pValues) {
                    return
                }
                switch (param) {
                    case 49152:
                    case 49155:
                    case 53248:
                        HEAP32[pValues >> 2] = val;
                        break;
                    default:
                        AL.currentCtx.err = 40962;
                        return
                }
            }
            Module["_alGetIntegerv"] = _alGetIntegerv;
            _alGetIntegerv.sig = "vii";

            function _alGetListener3f(param, pValue0, pValue1, pValue2) {
                var val = AL.getListenerParam("alGetListener3f", param);
                if (val === null) {
                    return
                }
                if (!pValue0 || !pValue1 || !pValue2) {
                    AL.currentCtx.err = 40963;
                    return
                }
                switch (param) {
                    case 4100:
                    case 4102:
                        HEAPF32[pValue0 >> 2] = val[0];
                        HEAPF32[pValue1 >> 2] = val[1];
                        HEAPF32[pValue2 >> 2] = val[2];
                        break;
                    default:
                        AL.currentCtx.err = 40962;
                        return
                }
            }
            Module["_alGetListener3f"] = _alGetListener3f;
            _alGetListener3f.sig = "viiii";

            function _alGetListener3i(param, pValue0, pValue1, pValue2) {
                var val = AL.getListenerParam("alGetListener3i", param);
                if (val === null) {
                    return
                }
                if (!pValue0 || !pValue1 || !pValue2) {
                    AL.currentCtx.err = 40963;
                    return
                }
                switch (param) {
                    case 4100:
                    case 4102:
                        HEAP32[pValue0 >> 2] = val[0];
                        HEAP32[pValue1 >> 2] = val[1];
                        HEAP32[pValue2 >> 2] = val[2];
                        break;
                    default:
                        AL.currentCtx.err = 40962;
                        return
                }
            }
            Module["_alGetListener3i"] = _alGetListener3i;
            _alGetListener3i.sig = "viiii";

            function _alGetListenerf(param, pValue) {
                var val = AL.getListenerParam("alGetListenerf", param);
                if (val === null) {
                    return
                }
                if (!pValue) {
                    AL.currentCtx.err = 40963;
                    return
                }
                switch (param) {
                    case 4106:
                        HEAPF32[pValue >> 2] = val;
                        break;
                    default:
                        AL.currentCtx.err = 40962;
                        return
                }
            }
            Module["_alGetListenerf"] = _alGetListenerf;
            _alGetListenerf.sig = "vii";

            function _alGetListenerfv(param, pValues) {
                var val = AL.getListenerParam("alGetListenerfv", param);
                if (val === null) {
                    return
                }
                if (!pValues) {
                    AL.currentCtx.err = 40963;
                    return
                }
                switch (param) {
                    case 4100:
                    case 4102:
                        HEAPF32[pValues >> 2] = val[0];
                        HEAPF32[pValues + 4 >> 2] = val[1];
                        HEAPF32[pValues + 8 >> 2] = val[2];
                        break;
                    case 4111:
                        HEAPF32[pValues >> 2] = val[0];
                        HEAPF32[pValues + 4 >> 2] = val[1];
                        HEAPF32[pValues + 8 >> 2] = val[2];
                        HEAPF32[pValues + 12 >> 2] = val[3];
                        HEAPF32[pValues + 16 >> 2] = val[4];
                        HEAPF32[pValues + 20 >> 2] = val[5];
                        break;
                    default:
                        AL.currentCtx.err = 40962;
                        return
                }
            }
            Module["_alGetListenerfv"] = _alGetListenerfv;
            _alGetListenerfv.sig = "vii";

            function _alGetListeneri(param, pValue) {
                var val = AL.getListenerParam("alGetListeneri", param);
                if (val === null) {
                    return
                }
                if (!pValue) {
                    AL.currentCtx.err = 40963;
                    return
                }
                AL.currentCtx.err = 40962
            }
            Module["_alGetListeneri"] = _alGetListeneri;
            _alGetListeneri.sig = "vii";

            function _alGetListeneriv(param, pValues) {
                var val = AL.getListenerParam("alGetListeneriv", param);
                if (val === null) {
                    return
                }
                if (!pValues) {
                    AL.currentCtx.err = 40963;
                    return
                }
                switch (param) {
                    case 4100:
                    case 4102:
                        HEAP32[pValues >> 2] = val[0];
                        HEAP32[pValues + 4 >> 2] = val[1];
                        HEAP32[pValues + 8 >> 2] = val[2];
                        break;
                    case 4111:
                        HEAP32[pValues >> 2] = val[0];
                        HEAP32[pValues + 4 >> 2] = val[1];
                        HEAP32[pValues + 8 >> 2] = val[2];
                        HEAP32[pValues + 12 >> 2] = val[3];
                        HEAP32[pValues + 16 >> 2] = val[4];
                        HEAP32[pValues + 20 >> 2] = val[5];
                        break;
                    default:
                        AL.currentCtx.err = 40962;
                        return
                }
            }
            Module["_alGetListeneriv"] = _alGetListeneriv;
            _alGetListeneriv.sig = "vii";

            function _alGetSource3f(sourceId, param, pValue0, pValue1, pValue2) {
                var val = AL.getSourceParam("alGetSource3f", sourceId, param);
                if (val === null) {
                    return
                }
                if (!pValue0 || !pValue1 || !pValue2) {
                    AL.currentCtx.err = 40963;
                    return
                }
                switch (param) {
                    case 4100:
                    case 4101:
                    case 4102:
                        HEAPF32[pValue0 >> 2] = val[0];
                        HEAPF32[pValue1 >> 2] = val[1];
                        HEAPF32[pValue2 >> 2] = val[2];
                        break;
                    default:
                        AL.currentCtx.err = 40962;
                        return
                }
            }
            Module["_alGetSource3f"] = _alGetSource3f;
            _alGetSource3f.sig = "viiiii";

            function _alGetSource3i(sourceId, param, pValue0, pValue1, pValue2) {
                var val = AL.getSourceParam("alGetSource3i", sourceId, param);
                if (val === null) {
                    return
                }
                if (!pValue0 || !pValue1 || !pValue2) {
                    AL.currentCtx.err = 40963;
                    return
                }
                switch (param) {
                    case 4100:
                    case 4101:
                    case 4102:
                        HEAP32[pValue0 >> 2] = val[0];
                        HEAP32[pValue1 >> 2] = val[1];
                        HEAP32[pValue2 >> 2] = val[2];
                        break;
                    default:
                        AL.currentCtx.err = 40962;
                        return
                }
            }
            Module["_alGetSource3i"] = _alGetSource3i;
            _alGetSource3i.sig = "viiiii";

            function _alGetSourcef(sourceId, param, pValue) {
                var val = AL.getSourceParam("alGetSourcef", sourceId, param);
                if (val === null) {
                    return
                }
                if (!pValue) {
                    AL.currentCtx.err = 40963;
                    return
                }
                switch (param) {
                    case 4097:
                    case 4098:
                    case 4099:
                    case 4106:
                    case 4109:
                    case 4110:
                    case 4128:
                    case 4129:
                    case 4130:
                    case 4131:
                    case 4132:
                    case 4133:
                    case 4134:
                    case 8203:
                        HEAPF32[pValue >> 2] = val;
                        break;
                    default:
                        AL.currentCtx.err = 40962;
                        return
                }
            }
            Module["_alGetSourcef"] = _alGetSourcef;
            _alGetSourcef.sig = "viii";

            function _alGetSourcefv(sourceId, param, pValues) {
                var val = AL.getSourceParam("alGetSourcefv", sourceId, param);
                if (val === null) {
                    return
                }
                if (!pValues) {
                    AL.currentCtx.err = 40963;
                    return
                }
                switch (param) {
                    case 4097:
                    case 4098:
                    case 4099:
                    case 4106:
                    case 4109:
                    case 4110:
                    case 4128:
                    case 4129:
                    case 4130:
                    case 4131:
                    case 4132:
                    case 4133:
                    case 4134:
                    case 8203:
                        HEAPF32[pValues >> 2] = val[0];
                        break;
                    case 4100:
                    case 4101:
                    case 4102:
                        HEAPF32[pValues >> 2] = val[0];
                        HEAPF32[pValues + 4 >> 2] = val[1];
                        HEAPF32[pValues + 8 >> 2] = val[2];
                        break;
                    default:
                        AL.currentCtx.err = 40962;
                        return
                }
            }
            Module["_alGetSourcefv"] = _alGetSourcefv;
            _alGetSourcefv.sig = "viii";

            function _alGetSourcei(sourceId, param, pValue) {
                var val = AL.getSourceParam("alGetSourcei", sourceId, param);
                if (val === null) {
                    return
                }
                if (!pValue) {
                    AL.currentCtx.err = 40963;
                    return
                }
                switch (param) {
                    case 514:
                    case 4097:
                    case 4098:
                    case 4103:
                    case 4105:
                    case 4112:
                    case 4117:
                    case 4118:
                    case 4128:
                    case 4129:
                    case 4131:
                    case 4132:
                    case 4133:
                    case 4134:
                    case 4135:
                    case 4628:
                    case 8201:
                    case 8202:
                    case 53248:
                        HEAP32[pValue >> 2] = val;
                        break;
                    default:
                        AL.currentCtx.err = 40962;
                        return
                }
            }
            Module["_alGetSourcei"] = _alGetSourcei;
            _alGetSourcei.sig = "viii";

            function _alGetSourceiv(sourceId, param, pValues) {
                var val = AL.getSourceParam("alGetSourceiv", sourceId, param);
                if (val === null) {
                    return
                }
                if (!pValues) {
                    AL.currentCtx.err = 40963;
                    return
                }
                switch (param) {
                    case 514:
                    case 4097:
                    case 4098:
                    case 4103:
                    case 4105:
                    case 4112:
                    case 4117:
                    case 4118:
                    case 4128:
                    case 4129:
                    case 4131:
                    case 4132:
                    case 4133:
                    case 4134:
                    case 4135:
                    case 4628:
                    case 8201:
                    case 8202:
                    case 53248:
                        HEAP32[pValues >> 2] = val;
                        break;
                    case 4100:
                    case 4101:
                    case 4102:
                        HEAP32[pValues >> 2] = val[0];
                        HEAP32[pValues + 4 >> 2] = val[1];
                        HEAP32[pValues + 8 >> 2] = val[2];
                        break;
                    default:
                        AL.currentCtx.err = 40962;
                        return
                }
            }
            Module["_alGetSourceiv"] = _alGetSourceiv;
            _alGetSourceiv.sig = "viii";

            function _alGetString(param) {
                if (!AL.currentCtx) {
                    return 0
                }
                if (AL.stringCache[param]) {
                    return AL.stringCache[param]
                }
                var ret;
                switch (param) {
                    case 0:
                        ret = "No Error";
                        break;
                    case 40961:
                        ret = "Invalid Name";
                        break;
                    case 40962:
                        ret = "Invalid Enum";
                        break;
                    case 40963:
                        ret = "Invalid Value";
                        break;
                    case 40964:
                        ret = "Invalid Operation";
                        break;
                    case 40965:
                        ret = "Out of Memory";
                        break;
                    case 45057:
                        ret = "Emscripten";
                        break;
                    case 45058:
                        ret = "1.1";
                        break;
                    case 45059:
                        ret = "WebAudio";
                        break;
                    case 45060:
                        ret = "";
                        for (var ext in AL.AL_EXTENSIONS) {
                            ret = ret.concat(ext);
                            ret = ret.concat(" ")
                        }
                        ret = ret.trim();
                        break;
                    default:
                        AL.currentCtx.err = 40962;
                        return 0
                }
                ret = allocate(intArrayFromString(ret), ALLOC_NORMAL);
                AL.stringCache[param] = ret;
                return ret
            }
            Module["_alGetString"] = _alGetString;
            _alGetString.sig = "ii";

            function _alIsBuffer(bufferId) {
                if (!AL.currentCtx) {
                    return false
                }
                if (bufferId > AL.buffers.length) {
                    return false
                }
                if (!AL.buffers[bufferId]) {
                    return false
                } else {
                    return true
                }
            }
            Module["_alIsBuffer"] = _alIsBuffer;
            _alIsBuffer.sig = "ii";

            function _alIsEnabled(param) {
                if (!AL.currentCtx) {
                    return 0
                }
                switch (param) {
                    case "AL_SOURCE_DISTANCE_MODEL":
                        return AL.currentCtx.sourceDistanceModel ? 0 : 1;
                    default:
                        AL.currentCtx.err = 40962;
                        return 0
                }
            }
            Module["_alIsEnabled"] = _alIsEnabled;
            _alIsEnabled.sig = "ii";

            function _alIsExtensionPresent(pExtName) {
                var name = UTF8ToString(pExtName);
                return AL.AL_EXTENSIONS[name] ? 1 : 0
            }
            Module["_alIsExtensionPresent"] = _alIsExtensionPresent;
            _alIsExtensionPresent.sig = "ii";

            function _alIsSource(sourceId) {
                if (!AL.currentCtx) {
                    return false
                }
                if (!AL.currentCtx.sources[sourceId]) {
                    return false
                } else {
                    return true
                }
            }
            Module["_alIsSource"] = _alIsSource;
            _alIsSource.sig = "ii";

            function _alListener3f(param, value0, value1, value2) {
                switch (param) {
                    case 4100:
                    case 4102:
                        AL.paramArray[0] = value0;
                        AL.paramArray[1] = value1;
                        AL.paramArray[2] = value2;
                        AL.setListenerParam("alListener3f", param, AL.paramArray);
                        break;
                    default:
                        AL.setListenerParam("alListener3f", param, null);
                        break
                }
            }
            Module["_alListener3f"] = _alListener3f;
            _alListener3f.sig = "vifff";

            function _alListener3i(param, value0, value1, value2) {
                switch (param) {
                    case 4100:
                    case 4102:
                        AL.paramArray[0] = value0;
                        AL.paramArray[1] = value1;
                        AL.paramArray[2] = value2;
                        AL.setListenerParam("alListener3i", param, AL.paramArray);
                        break;
                    default:
                        AL.setListenerParam("alListener3i", param, null);
                        break
                }
            }
            Module["_alListener3i"] = _alListener3i;
            _alListener3i.sig = "viiii";

            function _alListenerf(param, value) {
                switch (param) {
                    case 4106:
                        AL.setListenerParam("alListenerf", param, value);
                        break;
                    default:
                        AL.setListenerParam("alListenerf", param, null);
                        break
                }
            }
            Module["_alListenerf"] = _alListenerf;
            _alListenerf.sig = "vif";

            function _alListenerfv(param, pValues) {
                if (!AL.currentCtx) {
                    return
                }
                if (!pValues) {
                    AL.currentCtx.err = 40963;
                    return
                }
                switch (param) {
                    case 4100:
                    case 4102:
                        AL.paramArray[0] = HEAPF32[pValues >> 2];
                        AL.paramArray[1] = HEAPF32[pValues + 4 >> 2];
                        AL.paramArray[2] = HEAPF32[pValues + 8 >> 2];
                        AL.setListenerParam("alListenerfv", param, AL.paramArray);
                        break;
                    case 4111:
                        AL.paramArray[0] = HEAPF32[pValues >> 2];
                        AL.paramArray[1] = HEAPF32[pValues + 4 >> 2];
                        AL.paramArray[2] = HEAPF32[pValues + 8 >> 2];
                        AL.paramArray[3] = HEAPF32[pValues + 12 >> 2];
                        AL.paramArray[4] = HEAPF32[pValues + 16 >> 2];
                        AL.paramArray[5] = HEAPF32[pValues + 20 >> 2];
                        AL.setListenerParam("alListenerfv", param, AL.paramArray);
                        break;
                    default:
                        AL.setListenerParam("alListenerfv", param, null);
                        break
                }
            }
            Module["_alListenerfv"] = _alListenerfv;
            _alListenerfv.sig = "vii";

            function _alListeneri(param, value) {
                AL.setListenerParam("alListeneri", param, null)
            }
            Module["_alListeneri"] = _alListeneri;
            _alListeneri.sig = "vii";

            function _alListeneriv(param, pValues) {
                if (!AL.currentCtx) {
                    return
                }
                if (!pValues) {
                    AL.currentCtx.err = 40963;
                    return
                }
                switch (param) {
                    case 4100:
                    case 4102:
                        AL.paramArray[0] = HEAP32[pValues >> 2];
                        AL.paramArray[1] = HEAP32[pValues + 4 >> 2];
                        AL.paramArray[2] = HEAP32[pValues + 8 >> 2];
                        AL.setListenerParam("alListeneriv", param, AL.paramArray);
                        break;
                    case 4111:
                        AL.paramArray[0] = HEAP32[pValues >> 2];
                        AL.paramArray[1] = HEAP32[pValues + 4 >> 2];
                        AL.paramArray[2] = HEAP32[pValues + 8 >> 2];
                        AL.paramArray[3] = HEAP32[pValues + 12 >> 2];
                        AL.paramArray[4] = HEAP32[pValues + 16 >> 2];
                        AL.paramArray[5] = HEAP32[pValues + 20 >> 2];
                        AL.setListenerParam("alListeneriv", param, AL.paramArray);
                        break;
                    default:
                        AL.setListenerParam("alListeneriv", param, null);
                        break
                }
            }
            Module["_alListeneriv"] = _alListeneriv;
            _alListeneriv.sig = "vii";

            function _alSource3f(sourceId, param, value0, value1, value2) {
                switch (param) {
                    case 4100:
                    case 4101:
                    case 4102:
                        AL.paramArray[0] = value0;
                        AL.paramArray[1] = value1;
                        AL.paramArray[2] = value2;
                        AL.setSourceParam("alSource3f", sourceId, param, AL.paramArray);
                        break;
                    default:
                        AL.setSourceParam("alSource3f", sourceId, param, null);
                        break
                }
            }
            Module["_alSource3f"] = _alSource3f;
            _alSource3f.sig = "viifff";

            function _alSource3i(sourceId, param, value0, value1, value2) {
                switch (param) {
                    case 4100:
                    case 4101:
                    case 4102:
                        AL.paramArray[0] = value0;
                        AL.paramArray[1] = value1;
                        AL.paramArray[2] = value2;
                        AL.setSourceParam("alSource3i", sourceId, param, AL.paramArray);
                        break;
                    default:
                        AL.setSourceParam("alSource3i", sourceId, param, null);
                        break
                }
            }
            Module["_alSource3i"] = _alSource3i;
            _alSource3i.sig = "viiiii";

            function _alSourcePause(sourceId) {
                if (!AL.currentCtx) {
                    return
                }
                var src = AL.currentCtx.sources[sourceId];
                if (!src) {
                    AL.currentCtx.err = 40961;
                    return
                }
                AL.setSourceState(src, 4115)
            }
            Module["_alSourcePause"] = _alSourcePause;
            _alSourcePause.sig = "vi";

            function _alSourcePausev(count, pSourceIds) {
                if (!AL.currentCtx) {
                    return
                }
                if (!pSourceIds) {
                    AL.currentCtx.err = 40963
                }
                for (var i = 0; i < count; ++i) {
                    if (!AL.currentCtx.sources[HEAP32[pSourceIds + i * 4 >> 2]]) {
                        AL.currentCtx.err = 40961;
                        return
                    }
                }
                for (var i = 0; i < count; ++i) {
                    AL.setSourceState(HEAP32[pSourceIds + i * 4 >> 2], 4115)
                }
            }
            Module["_alSourcePausev"] = _alSourcePausev;
            _alSourcePausev.sig = "vii";

            function _alSourcePlay(sourceId) {
                if (!AL.currentCtx) {
                    return
                }
                var src = AL.currentCtx.sources[sourceId];
                if (!src) {
                    AL.currentCtx.err = 40961;
                    return
                }
                AL.setSourceState(src, 4114)
            }
            Module["_alSourcePlay"] = _alSourcePlay;
            _alSourcePlay.sig = "vi";

            function _alSourcePlayv(count, pSourceIds) {
                if (!AL.currentCtx) {
                    return
                }
                if (!pSourceIds) {
                    AL.currentCtx.err = 40963
                }
                for (var i = 0; i < count; ++i) {
                    if (!AL.currentCtx.sources[HEAP32[pSourceIds + i * 4 >> 2]]) {
                        AL.currentCtx.err = 40961;
                        return
                    }
                }
                for (var i = 0; i < count; ++i) {
                    AL.setSourceState(HEAP32[pSourceIds + i * 4 >> 2], 4114)
                }
            }
            Module["_alSourcePlayv"] = _alSourcePlayv;
            _alSourcePlayv.sig = "vii";

            function _alSourceQueueBuffers(sourceId, count, pBufferIds) {
                if (!AL.currentCtx) {
                    return
                }
                var src = AL.currentCtx.sources[sourceId];
                if (!src) {
                    AL.currentCtx.err = 40961;
                    return
                }
                if (src.type === 4136) {
                    AL.currentCtx.err = 40964;
                    return
                }
                if (count === 0) {
                    return
                }
                var templateBuf = AL.buffers[0];
                for (var i = 0; i < src.bufQueue.length; i++) {
                    if (src.bufQueue[i].id !== 0) {
                        templateBuf = src.bufQueue[i];
                        break
                    }
                }
                for (var i = 0; i < count; ++i) {
                    var bufId = HEAP32[pBufferIds + i * 4 >> 2];
                    var buf = AL.buffers[bufId];
                    if (!buf) {
                        AL.currentCtx.err = 40961;
                        return
                    }
                    if (templateBuf.id !== 0 && (buf.frequency !== templateBuf.frequency || buf.bytesPerSample !== templateBuf.bytesPerSample || buf.channels !== templateBuf.channels)) {
                        AL.currentCtx.err = 40964
                    }
                }
                if (src.bufQueue.length === 1 && src.bufQueue[0].id === 0) {
                    src.bufQueue.length = 0
                }
                src.type = 4137;
                for (var i = 0; i < count; ++i) {
                    var bufId = HEAP32[pBufferIds + i * 4 >> 2];
                    var buf = AL.buffers[bufId];
                    buf.refCount++;
                    src.bufQueue.push(buf)
                }
                if (src.looping) {
                    AL.cancelPendingSourceAudio(src)
                }
                AL.initSourcePanner(src);
                AL.scheduleSourceAudio(src)
            }
            Module["_alSourceQueueBuffers"] = _alSourceQueueBuffers;
            _alSourceQueueBuffers.sig = "viii";

            function _alSourceRewind(sourceId) {
                if (!AL.currentCtx) {
                    return
                }
                var src = AL.currentCtx.sources[sourceId];
                if (!src) {
                    AL.currentCtx.err = 40961;
                    return
                }
                AL.setSourceState(src, 4116);
                AL.setSourceState(src, 4113)
            }
            Module["_alSourceRewind"] = _alSourceRewind;
            _alSourceRewind.sig = "vi";

            function _alSourceRewindv(count, pSourceIds) {
                if (!AL.currentCtx) {
                    return
                }
                if (!pSourceIds) {
                    AL.currentCtx.err = 40963
                }
                for (var i = 0; i < count; ++i) {
                    if (!AL.currentCtx.sources[HEAP32[pSourceIds + i * 4 >> 2]]) {
                        AL.currentCtx.err = 40961;
                        return
                    }
                }
                for (var i = 0; i < count; ++i) {
                    AL.setSourceState(HEAP32[pSourceIds + i * 4 >> 2], 4113)
                }
            }
            Module["_alSourceRewindv"] = _alSourceRewindv;
            _alSourceRewindv.sig = "vii";

            function _alSourceStop(sourceId) {
                if (!AL.currentCtx) {
                    return
                }
                var src = AL.currentCtx.sources[sourceId];
                if (!src) {
                    AL.currentCtx.err = 40961;
                    return
                }
                AL.setSourceState(src, 4116)
            }
            Module["_alSourceStop"] = _alSourceStop;
            _alSourceStop.sig = "vi";

            function _alSourceStopv(count, pSourceIds) {
                if (!AL.currentCtx) {
                    return
                }
                if (!pSourceIds) {
                    AL.currentCtx.err = 40963
                }
                for (var i = 0; i < count; ++i) {
                    if (!AL.currentCtx.sources[HEAP32[pSourceIds + i * 4 >> 2]]) {
                        AL.currentCtx.err = 40961;
                        return
                    }
                }
                for (var i = 0; i < count; ++i) {
                    AL.setSourceState(HEAP32[pSourceIds + i * 4 >> 2], 4116)
                }
            }
            Module["_alSourceStopv"] = _alSourceStopv;
            _alSourceStopv.sig = "vii";

            function _alSourceUnqueueBuffers(sourceId, count, pBufferIds) {
                if (!AL.currentCtx) {
                    return
                }
                var src = AL.currentCtx.sources[sourceId];
                if (!src) {
                    AL.currentCtx.err = 40961;
                    return
                }
                if (count > (src.bufQueue.length === 1 && src.bufQueue[0].id === 0 ? 0 : src.bufsProcessed)) {
                    AL.currentCtx.err = 40963;
                    return
                }
                if (count === 0) {
                    return
                }
                for (var i = 0; i < count; i++) {
                    var buf = src.bufQueue.shift();
                    buf.refCount--;
                    HEAP32[pBufferIds + i * 4 >> 2] = buf.id;
                    src.bufsProcessed--
                }
                if (src.bufQueue.length === 0) {
                    src.bufQueue.push(AL.buffers[0])
                }
                AL.initSourcePanner(src);
                AL.scheduleSourceAudio(src)
            }
            Module["_alSourceUnqueueBuffers"] = _alSourceUnqueueBuffers;
            _alSourceUnqueueBuffers.sig = "viii";

            function _alSourcef(sourceId, param, value) {
                switch (param) {
                    case 4097:
                    case 4098:
                    case 4099:
                    case 4106:
                    case 4109:
                    case 4110:
                    case 4128:
                    case 4129:
                    case 4130:
                    case 4131:
                    case 4132:
                    case 4133:
                    case 4134:
                    case 8203:
                        AL.setSourceParam("alSourcef", sourceId, param, value);
                        break;
                    default:
                        AL.setSourceParam("alSourcef", sourceId, param, null);
                        break
                }
            }
            Module["_alSourcef"] = _alSourcef;
            _alSourcef.sig = "viif";

            function _alSourcefv(sourceId, param, pValues) {
                if (!AL.currentCtx) {
                    return
                }
                if (!pValues) {
                    AL.currentCtx.err = 40963;
                    return
                }
                switch (param) {
                    case 4097:
                    case 4098:
                    case 4099:
                    case 4106:
                    case 4109:
                    case 4110:
                    case 4128:
                    case 4129:
                    case 4130:
                    case 4131:
                    case 4132:
                    case 4133:
                    case 4134:
                    case 8203:
                        var val = HEAPF32[pValues >> 2];
                        AL.setSourceParam("alSourcefv", sourceId, param, val);
                        break;
                    case 4100:
                    case 4101:
                    case 4102:
                        AL.paramArray[0] = HEAPF32[pValues >> 2];
                        AL.paramArray[1] = HEAPF32[pValues + 4 >> 2];
                        AL.paramArray[2] = HEAPF32[pValues + 8 >> 2];
                        AL.setSourceParam("alSourcefv", sourceId, param, AL.paramArray);
                        break;
                    default:
                        AL.setSourceParam("alSourcefv", sourceId, param, null);
                        break
                }
            }
            Module["_alSourcefv"] = _alSourcefv;
            _alSourcefv.sig = "viii";

            function _alSourceiv(sourceId, param, pValues) {
                if (!AL.currentCtx) {
                    return
                }
                if (!pValues) {
                    AL.currentCtx.err = 40963;
                    return
                }
                switch (param) {
                    case 514:
                    case 4097:
                    case 4098:
                    case 4103:
                    case 4105:
                    case 4128:
                    case 4129:
                    case 4131:
                    case 4132:
                    case 4133:
                    case 4134:
                    case 4628:
                    case 8201:
                    case 8202:
                    case 53248:
                        var val = HEAP32[pValues >> 2];
                        AL.setSourceParam("alSourceiv", sourceId, param, val);
                        break;
                    case 4100:
                    case 4101:
                    case 4102:
                        AL.paramArray[0] = HEAP32[pValues >> 2];
                        AL.paramArray[1] = HEAP32[pValues + 4 >> 2];
                        AL.paramArray[2] = HEAP32[pValues + 8 >> 2];
                        AL.setSourceParam("alSourceiv", sourceId, param, AL.paramArray);
                        break;
                    default:
                        AL.setSourceParam("alSourceiv", sourceId, param, null);
                        break
                }
            }
            Module["_alSourceiv"] = _alSourceiv;
            _alSourceiv.sig = "viii";

            function _alSpeedOfSound(value) {
                AL.setGlobalParam("alSpeedOfSound", 49155, value)
            }
            Module["_alSpeedOfSound"] = _alSpeedOfSound;
            _alSpeedOfSound.sig = "vi";

            function _alcCaptureCloseDevice(deviceId) {
                var c = AL.requireValidCaptureDevice(deviceId, "alcCaptureCloseDevice");
                if (!c) return false;
                delete AL.captures[deviceId];
                AL.freeIds.push(deviceId);
                if (c.mediaStreamSourceNode) c.mediaStreamSourceNode.disconnect();
                if (c.mergerNode) c.mergerNode.disconnect();
                if (c.splitterNode) c.splitterNode.disconnect();
                if (c.scriptProcessorNode) c.scriptProcessorNode.disconnect();
                if (c.mediaStream) {
                    c.mediaStream.getTracks().forEach(function(track) {
                        track.stop()
                    })
                }
                delete c.buffers;
                c.capturedFrameCount = 0;
                c.isCapturing = false;
                return true
            }
            Module["_alcCaptureCloseDevice"] = _alcCaptureCloseDevice;
            _alcCaptureCloseDevice.sig = "ii";

            function listenOnce(object, event, func) {
                object.addEventListener(event, func, {
                    "once": true
                })
            }
            Module["listenOnce"] = listenOnce;

            function autoResumeAudioContext(ctx, elements) {
                if (!elements) {
                    elements = [document, document.getElementById("canvas")]
                } ["keydown", "mousedown", "touchstart"].forEach(function(event) {
                    elements.forEach(function(element) {
                        if (element) {
                            listenOnce(element, event, function() {
                                if (ctx.state === "suspended") ctx.resume()
                            })
                        }
                    })
                })
            }
            Module["autoResumeAudioContext"] = autoResumeAudioContext;

            function _alcCaptureOpenDevice(pDeviceName, requestedSampleRate, format, bufferFrameCapacity) {
                var resolvedDeviceName = AL.CAPTURE_DEVICE_NAME;
                if (pDeviceName !== 0) {
                    resolvedDeviceName = UTF8ToString(pDeviceName);
                    if (resolvedDeviceName !== AL.CAPTURE_DEVICE_NAME) {
                        AL.alcErr = 40965;
                        return 0
                    }
                }
                if (bufferFrameCapacity < 0) {
                    AL.alcErr = 40964;
                    return 0
                }
                navigator.getUserMedia = navigator.getUserMedia || navigator.webkitGetUserMedia || navigator.mozGetUserMedia || navigator.msGetUserMedia;
                var has_getUserMedia = navigator.getUserMedia || navigator.mediaDevices && navigator.mediaDevices.getUserMedia;
                if (!has_getUserMedia) {
                    AL.alcErr = 40965;
                    return 0
                }
                var AudioContext = window.AudioContext || window.webkitAudioContext;
                if (!AL.sharedCaptureAudioCtx) {
                    try {
                        AL.sharedCaptureAudioCtx = new AudioContext
                    } catch (e) {
                        AL.alcErr = 40965;
                        return 0
                    }
                }
                autoResumeAudioContext(AL.sharedCaptureAudioCtx);
                var outputChannelCount;
                switch (format) {
                    case 65552:
                    case 4353:
                    case 4352:
                        outputChannelCount = 1;
                        break;
                    case 65553:
                    case 4355:
                    case 4354:
                        outputChannelCount = 2;
                        break;
                    default:
                        AL.alcErr = 40964;
                        return 0
                }

                function newF32Array(cap) {
                    return new Float32Array(cap)
                }

                function newI16Array(cap) {
                    return new Int16Array(cap)
                }

                function newU8Array(cap) {
                    return new Uint8Array(cap)
                }
                var requestedSampleType;
                var newSampleArray;
                switch (format) {
                    case 65552:
                    case 65553:
                        requestedSampleType = "f32";
                        newSampleArray = newF32Array;
                        break;
                    case 4353:
                    case 4355:
                        requestedSampleType = "i16";
                        newSampleArray = newI16Array;
                        break;
                    case 4352:
                    case 4354:
                        requestedSampleType = "u8";
                        newSampleArray = newU8Array;
                        break
                }
                var buffers = [];
                try {
                    for (var chan = 0; chan < outputChannelCount; ++chan) {
                        buffers[chan] = newSampleArray(bufferFrameCapacity)
                    }
                } catch (e) {
                    AL.alcErr = 40965;
                    return 0
                }
                var newCapture = {
                    audioCtx: AL.sharedCaptureAudioCtx,
                    deviceName: resolvedDeviceName,
                    requestedSampleRate: requestedSampleRate,
                    requestedSampleType: requestedSampleType,
                    outputChannelCount: outputChannelCount,
                    inputChannelCount: null,
                    mediaStreamError: null,
                    mediaStreamSourceNode: null,
                    mediaStream: null,
                    mergerNode: null,
                    splitterNode: null,
                    scriptProcessorNode: null,
                    isCapturing: false,
                    buffers: buffers,
                    get bufferFrameCapacity() {
                        return buffers[0].length
                    },
                    capturePlayhead: 0,
                    captureReadhead: 0,
                    capturedFrameCount: 0
                };
                var onError = function(mediaStreamError) {
                    newCapture.mediaStreamError = mediaStreamError
                };
                var onSuccess = function(mediaStream) {
                    newCapture.mediaStreamSourceNode = newCapture.audioCtx.createMediaStreamSource(mediaStream);
                    newCapture.mediaStream = mediaStream;
                    var inputChannelCount = 1;
                    switch (newCapture.mediaStreamSourceNode.channelCountMode) {
                        case "max":
                            inputChannelCount = outputChannelCount;
                            break;
                        case "clamped-max":
                            inputChannelCount = Math.min(outputChannelCount, newCapture.mediaStreamSourceNode.channelCount);
                            break;
                        case "explicit":
                            inputChannelCount = newCapture.mediaStreamSourceNode.channelCount;
                            break
                    }
                    newCapture.inputChannelCount = inputChannelCount;
                    var processorFrameCount = 512;
                    newCapture.scriptProcessorNode = newCapture.audioCtx.createScriptProcessor(processorFrameCount, inputChannelCount, outputChannelCount);
                    if (inputChannelCount > outputChannelCount) {
                        newCapture.mergerNode = newCapture.audioCtx.createChannelMerger(inputChannelCount);
                        newCapture.mediaStreamSourceNode.connect(newCapture.mergerNode);
                        newCapture.mergerNode.connect(newCapture.scriptProcessorNode)
                    } else if (inputChannelCount < outputChannelCount) {
                        newCapture.splitterNode = newCapture.audioCtx.createChannelSplitter(outputChannelCount);
                        newCapture.mediaStreamSourceNode.connect(newCapture.splitterNode);
                        newCapture.splitterNode.connect(newCapture.scriptProcessorNode)
                    } else {
                        newCapture.mediaStreamSourceNode.connect(newCapture.scriptProcessorNode)
                    }
                    newCapture.scriptProcessorNode.connect(newCapture.audioCtx.destination);
                    newCapture.scriptProcessorNode.onaudioprocess = function(audioProcessingEvent) {
                        if (!newCapture.isCapturing) {
                            return
                        }
                        var c = newCapture;
                        var srcBuf = audioProcessingEvent.inputBuffer;
                        switch (format) {
                            case 65552:
                                var channel0 = srcBuf.getChannelData(0);
                                for (var i = 0; i < srcBuf.length; ++i) {
                                    var wi = (c.capturePlayhead + i) % c.bufferFrameCapacity;
                                    c.buffers[0][wi] = channel0[i]
                                }
                                break;
                            case 65553:
                                var channel0 = srcBuf.getChannelData(0);
                                var channel1 = srcBuf.getChannelData(1);
                                for (var i = 0; i < srcBuf.length; ++i) {
                                    var wi = (c.capturePlayhead + i) % c.bufferFrameCapacity;
                                    c.buffers[0][wi] = channel0[i];
                                    c.buffers[1][wi] = channel1[i]
                                }
                                break;
                            case 4353:
                                var channel0 = srcBuf.getChannelData(0);
                                for (var i = 0; i < srcBuf.length; ++i) {
                                    var wi = (c.capturePlayhead + i) % c.bufferFrameCapacity;
                                    c.buffers[0][wi] = channel0[i] * 32767
                                }
                                break;
                            case 4355:
                                var channel0 = srcBuf.getChannelData(0);
                                var channel1 = srcBuf.getChannelData(1);
                                for (var i = 0; i < srcBuf.length; ++i) {
                                    var wi = (c.capturePlayhead + i) % c.bufferFrameCapacity;
                                    c.buffers[0][wi] = channel0[i] * 32767;
                                    c.buffers[1][wi] = channel1[i] * 32767
                                }
                                break;
                            case 4352:
                                var channel0 = srcBuf.getChannelData(0);
                                for (var i = 0; i < srcBuf.length; ++i) {
                                    var wi = (c.capturePlayhead + i) % c.bufferFrameCapacity;
                                    c.buffers[0][wi] = (channel0[i] + 1) * 127
                                }
                                break;
                            case 4354:
                                var channel0 = srcBuf.getChannelData(0);
                                var channel1 = srcBuf.getChannelData(1);
                                for (var i = 0; i < srcBuf.length; ++i) {
                                    var wi = (c.capturePlayhead + i) % c.bufferFrameCapacity;
                                    c.buffers[0][wi] = (channel0[i] + 1) * 127;
                                    c.buffers[1][wi] = (channel1[i] + 1) * 127
                                }
                                break
                        }
                        c.capturePlayhead += srcBuf.length;
                        c.capturePlayhead %= c.bufferFrameCapacity;
                        c.capturedFrameCount += srcBuf.length;
                        c.capturedFrameCount = Math.min(c.capturedFrameCount, c.bufferFrameCapacity)
                    }
                };
                if (navigator.mediaDevices && navigator.mediaDevices.getUserMedia) {
                    navigator.mediaDevices.getUserMedia({
                        audio: true
                    }).then(onSuccess).catch(onError)
                } else {
                    navigator.getUserMedia({
                        audio: true
                    }, onSuccess, onError)
                }
                var id = AL.newId();
                AL.captures[id] = newCapture;
                return id
            }
            Module["_alcCaptureOpenDevice"] = _alcCaptureOpenDevice;
            _alcCaptureOpenDevice.sig = "iiiii";

            function _alcCaptureSamples(deviceId, pFrames, requestedFrameCount) {
                var c = AL.requireValidCaptureDevice(deviceId, "alcCaptureSamples");
                if (!c) return;
                var dstfreq = c.requestedSampleRate;
                var srcfreq = c.audioCtx.sampleRate;
                var fratio = srcfreq / dstfreq;
                if (requestedFrameCount < 0 || requestedFrameCount > c.capturedFrameCount / fratio) {
                    console.error("alcCaptureSamples() with invalid bufferSize");
                    AL.alcErr = 40964;
                    return
                }

                function setF32Sample(i, sample) {
                    HEAPF32[pFrames + 4 * i >> 2] = sample
                }

                function setI16Sample(i, sample) {
                    HEAP16[pFrames + 2 * i >> 1] = sample
                }

                function setU8Sample(i, sample) {
                    HEAP8[pFrames + i >> 0] = sample
                }
                var setSample;
                switch (c.requestedSampleType) {
                    case "f32":
                        setSample = setF32Sample;
                        break;
                    case "i16":
                        setSample = setI16Sample;
                        break;
                    case "u8":
                        setSample = setU8Sample;
                        break;
                    default:
                        return
                }
                if (Math.floor(fratio) == fratio) {
                    for (var i = 0, frame_i = 0; frame_i < requestedFrameCount; ++frame_i) {
                        for (var chan = 0; chan < c.buffers.length; ++chan, ++i) {
                            setSample(i, c.buffers[chan][c.captureReadhead])
                        }
                        c.captureReadhead = (fratio + c.captureReadhead) % c.bufferFrameCapacity
                    }
                } else {
                    for (var i = 0, frame_i = 0; frame_i < requestedFrameCount; ++frame_i) {
                        var lefti = Math.floor(c.captureReadhead);
                        var righti = Math.ceil(c.captureReadhead);
                        var d = c.captureReadhead - lefti;
                        for (var chan = 0; chan < c.buffers.length; ++chan, ++i) {
                            var lefts = c.buffers[chan][lefti];
                            var rights = c.buffers[chan][righti];
                            setSample(i, (1 - d) * lefts + d * rights)
                        }
                        c.captureReadhead = (c.captureReadhead + fratio) % c.bufferFrameCapacity
                    }
                }
                c.capturedFrameCount = 0
            }
            Module["_alcCaptureSamples"] = _alcCaptureSamples;
            _alcCaptureSamples.sig = "viii";

            function _alcCaptureStart(deviceId) {
                var c = AL.requireValidCaptureDevice(deviceId, "alcCaptureStart");
                if (!c) return;
                if (c.isCapturing) {
                    return
                }
                c.isCapturing = true;
                c.capturedFrameCount = 0;
                c.capturePlayhead = 0
            }
            Module["_alcCaptureStart"] = _alcCaptureStart;
            _alcCaptureStart.sig = "vi";

            function _alcCaptureStop(deviceId) {
                var c = AL.requireValidCaptureDevice(deviceId, "alcCaptureStop");
                if (!c) return;
                c.isCapturing = false
            }
            Module["_alcCaptureStop"] = _alcCaptureStop;
            _alcCaptureStop.sig = "vi";

            function _alcCloseDevice(deviceId) {
                if (!(deviceId in AL.deviceRefCounts) || AL.deviceRefCounts[deviceId] > 0) {
                    return 0
                }
                delete AL.deviceRefCounts[deviceId];
                AL.freeIds.push(deviceId);
                return 1
            }
            Module["_alcCloseDevice"] = _alcCloseDevice;
            _alcCloseDevice.sig = "ii";

            function _alcCreateContext(deviceId, pAttrList) {
                if (!(deviceId in AL.deviceRefCounts)) {
                    AL.alcErr = 40961;
                    return 0
                }
                var options = null;
                var attrs = [];
                var hrtf = null;
                pAttrList >>= 2;
                if (pAttrList) {
                    var attr = 0;
                    var val = 0;
                    while (true) {
                        attr = HEAP32[pAttrList++];
                        attrs.push(attr);
                        if (attr === 0) {
                            break
                        }
                        val = HEAP32[pAttrList++];
                        attrs.push(val);
                        switch (attr) {
                            case 4103:
                                if (!options) {
                                    options = {}
                                }
                                options.sampleRate = val;
                                break;
                            case 4112:
                            case 4113:
                                break;
                            case 6546:
                                switch (val) {
                                    case 0:
                                        hrtf = false;
                                        break;
                                    case 1:
                                        hrtf = true;
                                        break;
                                    case 2:
                                        break;
                                    default:
                                        AL.alcErr = 40964;
                                        return 0
                                }
                                break;
                            case 6550:
                                if (val !== 0) {
                                    AL.alcErr = 40964;
                                    return 0
                                }
                                break;
                            default:
                                AL.alcErr = 40964;
                                return 0
                        }
                    }
                }
                var AudioContext = window.AudioContext || window.webkitAudioContext;
                var ac = null;
                try {
                    if (options) {
                        ac = new AudioContext(options)
                    } else {
                        ac = new AudioContext
                    }
                } catch (e) {
                    if (e.name === "NotSupportedError") {
                        AL.alcErr = 40964
                    } else {
                        AL.alcErr = 40961
                    }
                    return 0
                }
                autoResumeAudioContext(ac);
                if (typeof ac.createGain === "undefined") {
                    ac.createGain = ac.createGainNode
                }
                var gain = ac.createGain();
                gain.connect(ac.destination);
                var ctx = {
                    deviceId: deviceId,
                    id: AL.newId(),
                    attrs: attrs,
                    audioCtx: ac,
                    listener: {
                        position: [0, 0, 0],
                        velocity: [0, 0, 0],
                        direction: [0, 0, 0],
                        up: [0, 0, 0]
                    },
                    sources: [],
                    interval: setInterval(function() {
                        AL.scheduleContextAudio(ctx)
                    }, AL.QUEUE_INTERVAL),
                    gain: gain,
                    distanceModel: 53250,
                    speedOfSound: 343.3,
                    dopplerFactor: 1,
                    sourceDistanceModel: false,
                    hrtf: hrtf || false,
                    _err: 0,
                    get err() {
                        return this._err
                    },
                    set err(val) {
                        if (this._err === 0 || val === 0) {
                            this._err = val
                        }
                    }
                };
                AL.deviceRefCounts[deviceId]++;
                AL.contexts[ctx.id] = ctx;
                if (hrtf !== null) {
                    for (var ctxId in AL.contexts) {
                        var c = AL.contexts[ctxId];
                        if (c.deviceId === deviceId) {
                            c.hrtf = hrtf;
                            AL.updateContextGlobal(c)
                        }
                    }
                }
                return ctx.id
            }
            Module["_alcCreateContext"] = _alcCreateContext;
            _alcCreateContext.sig = "iii";

            function _alcDestroyContext(contextId) {
                var ctx = AL.contexts[contextId];
                if (AL.currentCtx === ctx) {
                    AL.alcErr = 40962;
                    return
                }
                if (AL.contexts[contextId].interval) {
                    clearInterval(AL.contexts[contextId].interval)
                }
                AL.deviceRefCounts[ctx.deviceId]--;
                delete AL.contexts[contextId];
                AL.freeIds.push(contextId)
            }
            Module["_alcDestroyContext"] = _alcDestroyContext;
            _alcDestroyContext.sig = "vi";

            function _alcGetContextsDevice(contextId) {
                if (contextId in AL.contexts) {
                    return AL.contexts[contextId].deviceId
                } else {
                    return 0
                }
            }
            Module["_alcGetContextsDevice"] = _alcGetContextsDevice;
            _alcGetContextsDevice.sig = "ii";

            function _alcGetCurrentContext() {
                if (AL.currentCtx !== null) {
                    return AL.currentCtx.id
                } else {
                    return 0
                }
            }
            Module["_alcGetCurrentContext"] = _alcGetCurrentContext;
            _alcGetCurrentContext.sig = "i";

            function _alcGetEnumValue(deviceId, pEnumName) {
                if (deviceId !== 0 && !(deviceId in AL.deviceRefCounts)) {
                    return 0
                } else if (!pEnumName) {
                    AL.alcErr = 40964;
                    return 0
                }
                var name = UTF8ToString(pEnumName);
                switch (name) {
                    case "ALC_NO_ERROR":
                        return 0;
                    case "ALC_INVALID_DEVICE":
                        return 40961;
                    case "ALC_INVALID_CONTEXT":
                        return 40962;
                    case "ALC_INVALID_ENUM":
                        return 40963;
                    case "ALC_INVALID_VALUE":
                        return 40964;
                    case "ALC_OUT_OF_MEMORY":
                        return 40965;
                    case "ALC_MAJOR_VERSION":
                        return 4096;
                    case "ALC_MINOR_VERSION":
                        return 4097;
                    case "ALC_ATTRIBUTES_SIZE":
                        return 4098;
                    case "ALC_ALL_ATTRIBUTES":
                        return 4099;
                    case "ALC_DEFAULT_DEVICE_SPECIFIER":
                        return 4100;
                    case "ALC_DEVICE_SPECIFIER":
                        return 4101;
                    case "ALC_EXTENSIONS":
                        return 4102;
                    case "ALC_FREQUENCY":
                        return 4103;
                    case "ALC_REFRESH":
                        return 4104;
                    case "ALC_SYNC":
                        return 4105;
                    case "ALC_MONO_SOURCES":
                        return 4112;
                    case "ALC_STEREO_SOURCES":
                        return 4113;
                    case "ALC_CAPTURE_DEVICE_SPECIFIER":
                        return 784;
                    case "ALC_CAPTURE_DEFAULT_DEVICE_SPECIFIER":
                        return 785;
                    case "ALC_CAPTURE_SAMPLES":
                        return 786;
                    case "ALC_HRTF_SOFT":
                        return 6546;
                    case "ALC_HRTF_ID_SOFT":
                        return 6550;
                    case "ALC_DONT_CARE_SOFT":
                        return 2;
                    case "ALC_HRTF_STATUS_SOFT":
                        return 6547;
                    case "ALC_NUM_HRTF_SPECIFIERS_SOFT":
                        return 6548;
                    case "ALC_HRTF_SPECIFIER_SOFT":
                        return 6549;
                    case "ALC_HRTF_DISABLED_SOFT":
                        return 0;
                    case "ALC_HRTF_ENABLED_SOFT":
                        return 1;
                    case "ALC_HRTF_DENIED_SOFT":
                        return 2;
                    case "ALC_HRTF_REQUIRED_SOFT":
                        return 3;
                    case "ALC_HRTF_HEADPHONES_DETECTED_SOFT":
                        return 4;
                    case "ALC_HRTF_UNSUPPORTED_FORMAT_SOFT":
                        return 5;
                    default:
                        AL.alcErr = 40964;
                        return 0
                }
            }
            Module["_alcGetEnumValue"] = _alcGetEnumValue;
            _alcGetEnumValue.sig = "iii";

            function _alcGetError(deviceId) {
                var err = AL.alcErr;
                AL.alcErr = 0;
                return err
            }
            Module["_alcGetError"] = _alcGetError;
            _alcGetError.sig = "ii";

            function _alcGetIntegerv(deviceId, param, size, pValues) {
                if (size === 0 || !pValues) {
                    return
                }
                switch (param) {
                    case 4096:
                        HEAP32[pValues >> 2] = 1;
                        break;
                    case 4097:
                        HEAP32[pValues >> 2] = 1;
                        break;
                    case 4098:
                        if (!(deviceId in AL.deviceRefCounts)) {
                            AL.alcErr = 40961;
                            return
                        }
                        if (!AL.currentCtx) {
                            AL.alcErr = 40962;
                            return
                        }
                        HEAP32[pValues >> 2] = AL.currentCtx.attrs.length;
                        break;
                    case 4099:
                        if (!(deviceId in AL.deviceRefCounts)) {
                            AL.alcErr = 40961;
                            return
                        }
                        if (!AL.currentCtx) {
                            AL.alcErr = 40962;
                            return
                        }
                        for (var i = 0; i < AL.currentCtx.attrs.length; i++) {
                            HEAP32[pValues + i * 4 >> 2] = AL.currentCtx.attrs[i]
                        }
                        break;
                    case 4103:
                        if (!(deviceId in AL.deviceRefCounts)) {
                            AL.alcErr = 40961;
                            return
                        }
                        if (!AL.currentCtx) {
                            AL.alcErr = 40962;
                            return
                        }
                        HEAP32[pValues >> 2] = AL.currentCtx.audioCtx.sampleRate;
                        break;
                    case 4112:
                    case 4113:
                        if (!(deviceId in AL.deviceRefCounts)) {
                            AL.alcErr = 40961;
                            return
                        }
                        if (!AL.currentCtx) {
                            AL.alcErr = 40962;
                            return
                        }
                        HEAP32[pValues >> 2] = 2147483647;
                        break;
                    case 6546:
                    case 6547:
                        if (!(deviceId in AL.deviceRefCounts)) {
                            AL.alcErr = 40961;
                            return
                        }
                        var hrtfStatus = 0;
                        for (var ctxId in AL.contexts) {
                            var ctx = AL.contexts[ctxId];
                            if (ctx.deviceId === deviceId) {
                                hrtfStatus = ctx.hrtf ? 1 : 0
                            }
                        }
                        HEAP32[pValues >> 2] = hrtfStatus;
                        break;
                    case 6548:
                        if (!(deviceId in AL.deviceRefCounts)) {
                            AL.alcErr = 40961;
                            return
                        }
                        HEAP32[pValues >> 2] = 1;
                        break;
                    case 131075:
                        if (!(deviceId in AL.deviceRefCounts)) {
                            AL.alcErr = 40961;
                            return
                        }
                        if (!AL.currentCtx) {
                            AL.alcErr = 40962;
                            return
                        }
                        HEAP32[pValues >> 2] = 1;
                    case 786:
                        var c = AL.requireValidCaptureDevice(deviceId, "alcGetIntegerv");
                        if (!c) {
                            return
                        }
                        var n = c.capturedFrameCount;
                        var dstfreq = c.requestedSampleRate;
                        var srcfreq = c.audioCtx.sampleRate;
                        var nsamples = Math.floor(n * (dstfreq / srcfreq));
                        HEAP32[pValues >> 2] = nsamples;
                        break;
                    default:
                        AL.alcErr = 40963;
                        return
                }
            }
            Module["_alcGetIntegerv"] = _alcGetIntegerv;
            _alcGetIntegerv.sig = "viiii";

            function _alcGetString(deviceId, param) {
                if (AL.alcStringCache[param]) {
                    return AL.alcStringCache[param]
                }
                var ret;
                switch (param) {
                    case 0:
                        ret = "No Error";
                        break;
                    case 40961:
                        ret = "Invalid Device";
                        break;
                    case 40962:
                        ret = "Invalid Context";
                        break;
                    case 40963:
                        ret = "Invalid Enum";
                        break;
                    case 40964:
                        ret = "Invalid Value";
                        break;
                    case 40965:
                        ret = "Out of Memory";
                        break;
                    case 4100:
                        if (typeof AudioContext !== "undefined" || typeof webkitAudioContext !== "undefined") {
                            ret = AL.DEVICE_NAME
                        } else {
                            return 0
                        }
                        break;
                    case 4101:
                        if (typeof AudioContext !== "undefined" || typeof webkitAudioContext !== "undefined") {
                            ret = AL.DEVICE_NAME.concat("\0")
                        } else {
                            ret = "\0"
                        }
                        break;
                    case 785:
                        ret = AL.CAPTURE_DEVICE_NAME;
                        break;
                    case 784:
                        if (deviceId === 0) ret = AL.CAPTURE_DEVICE_NAME.concat("\0");
                        else {
                            var c = AL.requireValidCaptureDevice(deviceId, "alcGetString");
                            if (!c) {
                                return 0
                            }
                            ret = c.deviceName
                        }
                        break;
                    case 4102:
                        if (!deviceId) {
                            AL.alcErr = 40961;
                            return 0
                        }
                        ret = "";
                        for (var ext in AL.ALC_EXTENSIONS) {
                            ret = ret.concat(ext);
                            ret = ret.concat(" ")
                        }
                        ret = ret.trim();
                        break;
                    default:
                        AL.alcErr = 40963;
                        return 0
                }
                ret = allocate(intArrayFromString(ret), ALLOC_NORMAL);
                AL.alcStringCache[param] = ret;
                return ret
            }
            Module["_alcGetString"] = _alcGetString;
            _alcGetString.sig = "iii";

            function _alcIsExtensionPresent(deviceId, pExtName) {
                var name = UTF8ToString(pExtName);
                return AL.ALC_EXTENSIONS[name] ? 1 : 0
            }
            Module["_alcIsExtensionPresent"] = _alcIsExtensionPresent;
            _alcIsExtensionPresent.sig = "iii";

            function _alcMakeContextCurrent(contextId) {
                if (contextId === 0) {
                    AL.currentCtx = null;
                    return 0
                } else {
                    AL.currentCtx = AL.contexts[contextId];
                    return 1
                }
            }
            Module["_alcMakeContextCurrent"] = _alcMakeContextCurrent;
            _alcMakeContextCurrent.sig = "ii";

            function _alcOpenDevice(pDeviceName) {
                if (pDeviceName) {
                    var name = UTF8ToString(pDeviceName);
                    if (name !== AL.DEVICE_NAME) {
                        return 0
                    }
                }
                if (typeof AudioContext !== "undefined" || typeof webkitAudioContext !== "undefined") {
                    var deviceId = AL.newId();
                    AL.deviceRefCounts[deviceId] = 0;
                    return deviceId
                } else {
                    return 0
                }
            }
            Module["_alcOpenDevice"] = _alcOpenDevice;
            _alcOpenDevice.sig = "ii";

            function _alcProcessContext(contextId) {}
            Module["_alcProcessContext"] = _alcProcessContext;
            _alcProcessContext.sig = "vi";

            function _alcSuspendContext(contextId) {}
            Module["_alcSuspendContext"] = _alcSuspendContext;
            _alcSuspendContext.sig = "vi";

            function _emscripten_alcDevicePauseSOFT(deviceId) {
                if (!(deviceId in AL.deviceRefCounts)) {
                    AL.alcErr = 40961;
                    return
                }
                if (AL.paused) {
                    return
                }
                AL.paused = true;
                for (var ctxId in AL.contexts) {
                    var ctx = AL.contexts[ctxId];
                    if (ctx.deviceId !== deviceId) {
                        continue
                    }
                    ctx.audioCtx.suspend();
                    clearInterval(ctx.interval);
                    ctx.interval = null
                }
            }
            Module["_emscripten_alcDevicePauseSOFT"] = _emscripten_alcDevicePauseSOFT;
            _emscripten_alcDevicePauseSOFT.sig = "vi";

            function _emscripten_alcDeviceResumeSOFT(deviceId) {
                if (!(deviceId in AL.deviceRefCounts)) {
                    AL.alcErr = 40961;
                    return
                }
                if (!AL.paused) {
                    return
                }
                AL.paused = false;
                for (var ctxId in AL.contexts) {
                    var ctx = AL.contexts[ctxId];
                    if (ctx.deviceId !== deviceId) {
                        continue
                    }
                    ctx.interval = setInterval(function() {
                        AL.scheduleContextAudio(ctx)
                    }, AL.QUEUE_INTERVAL);
                    ctx.audioCtx.resume()
                }
            }
            Module["_emscripten_alcDeviceResumeSOFT"] = _emscripten_alcDeviceResumeSOFT;
            _emscripten_alcDeviceResumeSOFT.sig = "vi";

            function _emscripten_alcGetStringiSOFT(deviceId, param, index) {
                if (!(deviceId in AL.deviceRefCounts)) {
                    AL.alcErr = 40961;
                    return 0
                }
                if (AL.alcStringCache[param]) {
                    return AL.alcStringCache[param]
                }
                var ret;
                switch (param) {
                    case 6549:
                        if (index === 0) {
                            ret = "Web Audio HRTF"
                        } else {
                            AL.alcErr = 40964;
                            return 0
                        }
                        break;
                    default:
                        if (index === 0) {
                            return _alcGetString(deviceId, param)
                        } else {
                            AL.alcErr = 40963;
                            return 0
                        }
                }
                ret = allocate(intArrayFromString(ret), ALLOC_NORMAL);
                AL.alcStringCache[param] = ret;
                return ret
            }
            Module["_emscripten_alcGetStringiSOFT"] = _emscripten_alcGetStringiSOFT;
            _emscripten_alcGetStringiSOFT.sig = "iiii";

            function _emscripten_alcResetDeviceSOFT(deviceId, pAttrList) {
                if (!(deviceId in AL.deviceRefCounts)) {
                    AL.alcErr = 40961;
                    return 0
                }
                var hrtf = null;
                pAttrList >>= 2;
                if (pAttrList) {
                    var attr = 0;
                    var val = 0;
                    while (true) {
                        attr = HEAP32[pAttrList++];
                        if (attr === 0) {
                            break
                        }
                        val = HEAP32[pAttrList++];
                        switch (attr) {
                            case 6546:
                                if (val === 1) {
                                    hrtf = true
                                } else if (val === 0) {
                                    hrtf = false
                                }
                                break
                        }
                    }
                }
                if (hrtf !== null) {
                    for (var ctxId in AL.contexts) {
                        var ctx = AL.contexts[ctxId];
                        if (ctx.deviceId === deviceId) {
                            ctx.hrtf = hrtf;
                            AL.updateContextGlobal(ctx)
                        }
                    }
                }
                return 1
            }
            Module["_emscripten_alcResetDeviceSOFT"] = _emscripten_alcResetDeviceSOFT;
            _emscripten_alcResetDeviceSOFT.sig = "iii";
            var readAsmConstArgsArray = [];
            Module["readAsmConstArgsArray"] = readAsmConstArgsArray;

            function readAsmConstArgs(sigPtr, buf) {
                readAsmConstArgsArray.length = 0;
                var ch;
                buf >>= 2;
                while (ch = HEAPU8[sigPtr++]) {
                    var double = ch < 105;
                    if (double && buf & 1) buf++;
                    readAsmConstArgsArray.push(double ? HEAPF64[buf++ >> 1] : HEAP32[buf]);
                    ++buf
                }
                return readAsmConstArgsArray
            }
            Module["readAsmConstArgs"] = readAsmConstArgs;

            function _emscripten_asm_const_int(code, sigPtr, argbuf) {
                code -= 1024;
                var args = readAsmConstArgs(sigPtr, argbuf);
                return ASM_CONSTS[code].apply(null, args)
            }
            Module["_emscripten_asm_const_int"] = _emscripten_asm_const_int;
            _emscripten_asm_const_int.sig = "iiii";

            function _emscripten_get_heap_max() {
                return HEAPU8.length
            }
            Module["_emscripten_get_heap_max"] = _emscripten_get_heap_max;

            function __webgl_enable_ANGLE_instanced_arrays(ctx) {
                var ext = ctx.getExtension("ANGLE_instanced_arrays");
                if (ext) {
                    ctx["vertexAttribDivisor"] = function(index, divisor) {
                        ext["vertexAttribDivisorANGLE"](index, divisor)
                    };
                    ctx["drawArraysInstanced"] = function(mode, first, count, primcount) {
                        ext["drawArraysInstancedANGLE"](mode, first, count, primcount)
                    };
                    ctx["drawElementsInstanced"] = function(mode, count, type, indices, primcount) {
                        ext["drawElementsInstancedANGLE"](mode, count, type, indices, primcount)
                    };
                    return 1
                }
            }
            Module["__webgl_enable_ANGLE_instanced_arrays"] = __webgl_enable_ANGLE_instanced_arrays;

            function __webgl_enable_OES_vertex_array_object(ctx) {
                var ext = ctx.getExtension("OES_vertex_array_object");
                if (ext) {
                    ctx["createVertexArray"] = function() {
                        return ext["createVertexArrayOES"]()
                    };
                    ctx["deleteVertexArray"] = function(vao) {
                        ext["deleteVertexArrayOES"](vao)
                    };
                    ctx["bindVertexArray"] = function(vao) {
                        ext["bindVertexArrayOES"](vao)
                    };
                    ctx["isVertexArray"] = function(vao) {
                        return ext["isVertexArrayOES"](vao)
                    };
                    return 1
                }
            }
            Module["__webgl_enable_OES_vertex_array_object"] = __webgl_enable_OES_vertex_array_object;

            function __webgl_enable_WEBGL_draw_buffers(ctx) {
                var ext = ctx.getExtension("WEBGL_draw_buffers");
                if (ext) {
                    ctx["drawBuffers"] = function(n, bufs) {
                        ext["drawBuffersWEBGL"](n, bufs)
                    };
                    return 1
                }
            }
            Module["__webgl_enable_WEBGL_draw_buffers"] = __webgl_enable_WEBGL_draw_buffers;

            function __webgl_enable_WEBGL_multi_draw(ctx) {
                return !!(ctx.multiDrawWebgl = ctx.getExtension("WEBGL_multi_draw"))
            }
            Module["__webgl_enable_WEBGL_multi_draw"] = __webgl_enable_WEBGL_multi_draw;
            var GL = {
                counter: 1,
                buffers: [],
                programs: [],
                framebuffers: [],
                renderbuffers: [],
                textures: [],
                shaders: [],
                vaos: [],
                contexts: [],
                offscreenCanvases: {},
                queries: [],
                stringCache: {},
                unpackAlignment: 4,
                recordError: function recordError(errorCode) {
                    if (!GL.lastError) {
                        GL.lastError = errorCode
                    }
                },
                getNewId: function(table) {
                    var ret = GL.counter++;
                    for (var i = table.length; i < ret; i++) {
                        table[i] = null
                    }
                    return ret
                },
                getSource: function(shader, count, string, length) {
                    var source = "";
                    for (var i = 0; i < count; ++i) {
                        var len = length ? HEAP32[length + i * 4 >> 2] : -1;
                        source += UTF8ToString(HEAP32[string + i * 4 >> 2], len < 0 ? undefined : len)
                    }
                    return source
                },
                createContext: function(canvas, webGLContextAttributes) {
                    if (!canvas.getContextSafariWebGL2Fixed) {
                        canvas.getContextSafariWebGL2Fixed = canvas.getContext;
                        canvas.getContext = function(ver, attrs) {
                            var gl = canvas.getContextSafariWebGL2Fixed(ver, attrs);
                            return ver == "webgl" == gl instanceof WebGLRenderingContext ? gl : null
                        }
                    }
                    var ctx = canvas.getContext("webgl", webGLContextAttributes);
                    if (!ctx) return 0;
                    var handle = GL.registerContext(ctx, webGLContextAttributes);
                    return handle
                },
                registerContext: function(ctx, webGLContextAttributes) {
                    var handle = GL.getNewId(GL.contexts);
                    var context = {
                        handle: handle,
                        attributes: webGLContextAttributes,
                        version: webGLContextAttributes.majorVersion,
                        GLctx: ctx
                    };
                    if (ctx.canvas) ctx.canvas.GLctxObject = context;
                    GL.contexts[handle] = context;
                    if (typeof webGLContextAttributes.enableExtensionsByDefault === "undefined" || webGLContextAttributes.enableExtensionsByDefault) {
                        GL.initExtensions(context)
                    }
                    return handle
                },
                makeContextCurrent: function(contextHandle) {
                    GL.currentContext = GL.contexts[contextHandle];
                    Module.ctx = GLctx = GL.currentContext && GL.currentContext.GLctx;
                    return !(contextHandle && !GLctx)
                },
                getContext: function(contextHandle) {
                    return GL.contexts[contextHandle]
                },
                deleteContext: function(contextHandle) {
                    if (GL.currentContext === GL.contexts[contextHandle]) GL.currentContext = null;
                    if (typeof JSEvents === "object") JSEvents.removeAllHandlersOnTarget(GL.contexts[contextHandle].GLctx.canvas);
                    if (GL.contexts[contextHandle] && GL.contexts[contextHandle].GLctx.canvas) GL.contexts[contextHandle].GLctx.canvas.GLctxObject = undefined;
                    GL.contexts[contextHandle] = null
                },
                initExtensions: function(context) {
                    if (!context) context = GL.currentContext;
                    if (context.initExtensionsDone) return;
                    context.initExtensionsDone = true;
                    var GLctx = context.GLctx;
                    __webgl_enable_ANGLE_instanced_arrays(GLctx);
                    __webgl_enable_OES_vertex_array_object(GLctx);
                    __webgl_enable_WEBGL_draw_buffers(GLctx); {
                        GLctx.disjointTimerQueryExt = GLctx.getExtension("EXT_disjoint_timer_query")
                    }
                    __webgl_enable_WEBGL_multi_draw(GLctx);
                    var exts = GLctx.getSupportedExtensions() || [];
                    exts.forEach(function(ext) {
                        if (!ext.includes("lose_context") && !ext.includes("debug")) {
                            GLctx.getExtension(ext)
                        }
                    })
                }
            };
            Module["GL"] = GL;

            function _emscripten_glActiveTexture(x0) {
                GLctx["activeTexture"](x0)
            }
            Module["_emscripten_glActiveTexture"] = _emscripten_glActiveTexture;
            _emscripten_glActiveTexture.sig = "vi";

            function _emscripten_glAttachShader(program, shader) {
                GLctx.attachShader(GL.programs[program], GL.shaders[shader])
            }
            Module["_emscripten_glAttachShader"] = _emscripten_glAttachShader;
            _emscripten_glAttachShader.sig = "vii";

            function _emscripten_glBeginQueryEXT(target, id) {
                GLctx.disjointTimerQueryExt["beginQueryEXT"](target, GL.queries[id])
            }
            Module["_emscripten_glBeginQueryEXT"] = _emscripten_glBeginQueryEXT;
            _emscripten_glBeginQueryEXT.sig = "vii";

            function _emscripten_glBindAttribLocation(program, index, name) {
                GLctx.bindAttribLocation(GL.programs[program], index, UTF8ToString(name))
            }
            Module["_emscripten_glBindAttribLocation"] = _emscripten_glBindAttribLocation;
            _emscripten_glBindAttribLocation.sig = "viii";

            function _emscripten_glBindBuffer(target, buffer) {
                GLctx.bindBuffer(target, GL.buffers[buffer])
            }
            Module["_emscripten_glBindBuffer"] = _emscripten_glBindBuffer;
            _emscripten_glBindBuffer.sig = "vii";

            function _emscripten_glBindFramebuffer(target, framebuffer) {
                GLctx.bindFramebuffer(target, GL.framebuffers[framebuffer])
            }
            Module["_emscripten_glBindFramebuffer"] = _emscripten_glBindFramebuffer;
            _emscripten_glBindFramebuffer.sig = "vii";

            function _emscripten_glBindRenderbuffer(target, renderbuffer) {
                GLctx.bindRenderbuffer(target, GL.renderbuffers[renderbuffer])
            }
            Module["_emscripten_glBindRenderbuffer"] = _emscripten_glBindRenderbuffer;
            _emscripten_glBindRenderbuffer.sig = "vii";

            function _emscripten_glBindTexture(target, texture) {
                GLctx.bindTexture(target, GL.textures[texture])
            }
            Module["_emscripten_glBindTexture"] = _emscripten_glBindTexture;
            _emscripten_glBindTexture.sig = "vii";

            function _emscripten_glBindVertexArrayOES(vao) {
                GLctx["bindVertexArray"](GL.vaos[vao])
            }
            Module["_emscripten_glBindVertexArrayOES"] = _emscripten_glBindVertexArrayOES;
            _emscripten_glBindVertexArrayOES.sig = "vi";

            function _emscripten_glBlendColor(x0, x1, x2, x3) {
                GLctx["blendColor"](x0, x1, x2, x3)
            }
            Module["_emscripten_glBlendColor"] = _emscripten_glBlendColor;
            _emscripten_glBlendColor.sig = "vffff";

            function _emscripten_glBlendEquation(x0) {
                GLctx["blendEquation"](x0)
            }
            Module["_emscripten_glBlendEquation"] = _emscripten_glBlendEquation;
            _emscripten_glBlendEquation.sig = "vi";

            function _emscripten_glBlendEquationSeparate(x0, x1) {
                GLctx["blendEquationSeparate"](x0, x1)
            }
            Module["_emscripten_glBlendEquationSeparate"] = _emscripten_glBlendEquationSeparate;
            _emscripten_glBlendEquationSeparate.sig = "vii";

            function _emscripten_glBlendFunc(x0, x1) {
                GLctx["blendFunc"](x0, x1)
            }
            Module["_emscripten_glBlendFunc"] = _emscripten_glBlendFunc;
            _emscripten_glBlendFunc.sig = "vii";

            function _emscripten_glBlendFuncSeparate(x0, x1, x2, x3) {
                GLctx["blendFuncSeparate"](x0, x1, x2, x3)
            }
            Module["_emscripten_glBlendFuncSeparate"] = _emscripten_glBlendFuncSeparate;
            _emscripten_glBlendFuncSeparate.sig = "viiii";

            function _emscripten_glBufferData(target, size, data, usage) {
                GLctx.bufferData(target, data ? HEAPU8.subarray(data, data + size) : size, usage)
            }
            Module["_emscripten_glBufferData"] = _emscripten_glBufferData;
            _emscripten_glBufferData.sig = "viiii";

            function _emscripten_glBufferSubData(target, offset, size, data) {
                GLctx.bufferSubData(target, offset, HEAPU8.subarray(data, data + size))
            }
            Module["_emscripten_glBufferSubData"] = _emscripten_glBufferSubData;
            _emscripten_glBufferSubData.sig = "viiii";

            function _emscripten_glCheckFramebufferStatus(x0) {
                return GLctx["checkFramebufferStatus"](x0)
            }
            Module["_emscripten_glCheckFramebufferStatus"] = _emscripten_glCheckFramebufferStatus;
            _emscripten_glCheckFramebufferStatus.sig = "ii";

            function _emscripten_glClear(x0) {
                GLctx["clear"](x0)
            }
            Module["_emscripten_glClear"] = _emscripten_glClear;
            _emscripten_glClear.sig = "vi";

            function _emscripten_glClearColor(x0, x1, x2, x3) {
                GLctx["clearColor"](x0, x1, x2, x3)
            }
            Module["_emscripten_glClearColor"] = _emscripten_glClearColor;
            _emscripten_glClearColor.sig = "viiii";

            function _emscripten_glClearDepthf(x0) {
                GLctx["clearDepth"](x0)
            }
            Module["_emscripten_glClearDepthf"] = _emscripten_glClearDepthf;
            _emscripten_glClearDepthf.sig = "vi";

            function _emscripten_glClearStencil(x0) {
                GLctx["clearStencil"](x0)
            }
            Module["_emscripten_glClearStencil"] = _emscripten_glClearStencil;
            _emscripten_glClearStencil.sig = "vi";

            function _emscripten_glColorMask(red, green, blue, alpha) {
                GLctx.colorMask(!!red, !!green, !!blue, !!alpha)
            }
            Module["_emscripten_glColorMask"] = _emscripten_glColorMask;
            _emscripten_glColorMask.sig = "viiii";

            function _emscripten_glCompileShader(shader) {
                GLctx.compileShader(GL.shaders[shader])
            }
            Module["_emscripten_glCompileShader"] = _emscripten_glCompileShader;
            _emscripten_glCompileShader.sig = "vi";

            function _emscripten_glCompressedTexImage2D(target, level, internalFormat, width, height, border, imageSize, data) {
                GLctx["compressedTexImage2D"](target, level, internalFormat, width, height, border, data ? HEAPU8.subarray(data, data + imageSize) : null)
            }
            Module["_emscripten_glCompressedTexImage2D"] = _emscripten_glCompressedTexImage2D;
            _emscripten_glCompressedTexImage2D.sig = "viiiiiiii";

            function _emscripten_glCompressedTexSubImage2D(target, level, xoffset, yoffset, width, height, format, imageSize, data) {
                GLctx["compressedTexSubImage2D"](target, level, xoffset, yoffset, width, height, format, data ? HEAPU8.subarray(data, data + imageSize) : null)
            }
            Module["_emscripten_glCompressedTexSubImage2D"] = _emscripten_glCompressedTexSubImage2D;
            _emscripten_glCompressedTexSubImage2D.sig = "viiiiiiiii";

            function _emscripten_glCopyTexImage2D(x0, x1, x2, x3, x4, x5, x6, x7) {
                GLctx["copyTexImage2D"](x0, x1, x2, x3, x4, x5, x6, x7)
            }
            Module["_emscripten_glCopyTexImage2D"] = _emscripten_glCopyTexImage2D;
            _emscripten_glCopyTexImage2D.sig = "viiiiiiii";

            function _emscripten_glCopyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7) {
                GLctx["copyTexSubImage2D"](x0, x1, x2, x3, x4, x5, x6, x7)
            }
            Module["_emscripten_glCopyTexSubImage2D"] = _emscripten_glCopyTexSubImage2D;
            _emscripten_glCopyTexSubImage2D.sig = "viiiiiiii";

            function _emscripten_glCreateProgram() {
                var id = GL.getNewId(GL.programs);
                var program = GLctx.createProgram();
                program.name = id;
                program.maxUniformLength = program.maxAttributeLength = program.maxUniformBlockNameLength = 0;
                program.uniformIdCounter = 1;
                GL.programs[id] = program;
                return id
            }
            Module["_emscripten_glCreateProgram"] = _emscripten_glCreateProgram;
            _emscripten_glCreateProgram.sig = "i";

            function _emscripten_glCreateShader(shaderType) {
                var id = GL.getNewId(GL.shaders);
                GL.shaders[id] = GLctx.createShader(shaderType);
                return id
            }
            Module["_emscripten_glCreateShader"] = _emscripten_glCreateShader;
            _emscripten_glCreateShader.sig = "ii";

            function _emscripten_glCullFace(x0) {
                GLctx["cullFace"](x0)
            }
            Module["_emscripten_glCullFace"] = _emscripten_glCullFace;
            _emscripten_glCullFace.sig = "vi";

            function _emscripten_glDeleteBuffers(n, buffers) {
                for (var i = 0; i < n; i++) {
                    var id = HEAP32[buffers + i * 4 >> 2];
                    var buffer = GL.buffers[id];
                    if (!buffer) continue;
                    GLctx.deleteBuffer(buffer);
                    buffer.name = 0;
                    GL.buffers[id] = null
                }
            }
            Module["_emscripten_glDeleteBuffers"] = _emscripten_glDeleteBuffers;
            _emscripten_glDeleteBuffers.sig = "vii";

            function _emscripten_glDeleteFramebuffers(n, framebuffers) {
                for (var i = 0; i < n; ++i) {
                    var id = HEAP32[framebuffers + i * 4 >> 2];
                    var framebuffer = GL.framebuffers[id];
                    if (!framebuffer) continue;
                    GLctx.deleteFramebuffer(framebuffer);
                    framebuffer.name = 0;
                    GL.framebuffers[id] = null
                }
            }
            Module["_emscripten_glDeleteFramebuffers"] = _emscripten_glDeleteFramebuffers;
            _emscripten_glDeleteFramebuffers.sig = "vii";

            function _emscripten_glDeleteProgram(id) {
                if (!id) return;
                var program = GL.programs[id];
                if (!program) {
                    GL.recordError(1281);
                    return
                }
                GLctx.deleteProgram(program);
                program.name = 0;
                GL.programs[id] = null
            }
            Module["_emscripten_glDeleteProgram"] = _emscripten_glDeleteProgram;
            _emscripten_glDeleteProgram.sig = "vi";

            function _emscripten_glDeleteQueriesEXT(n, ids) {
                for (var i = 0; i < n; i++) {
                    var id = HEAP32[ids + i * 4 >> 2];
                    var query = GL.queries[id];
                    if (!query) continue;
                    GLctx.disjointTimerQueryExt["deleteQueryEXT"](query);
                    GL.queries[id] = null
                }
            }
            Module["_emscripten_glDeleteQueriesEXT"] = _emscripten_glDeleteQueriesEXT;
            _emscripten_glDeleteQueriesEXT.sig = "vii";

            function _emscripten_glDeleteRenderbuffers(n, renderbuffers) {
                for (var i = 0; i < n; i++) {
                    var id = HEAP32[renderbuffers + i * 4 >> 2];
                    var renderbuffer = GL.renderbuffers[id];
                    if (!renderbuffer) continue;
                    GLctx.deleteRenderbuffer(renderbuffer);
                    renderbuffer.name = 0;
                    GL.renderbuffers[id] = null
                }
            }
            Module["_emscripten_glDeleteRenderbuffers"] = _emscripten_glDeleteRenderbuffers;
            _emscripten_glDeleteRenderbuffers.sig = "vii";

            function _emscripten_glDeleteShader(id) {
                if (!id) return;
                var shader = GL.shaders[id];
                if (!shader) {
                    GL.recordError(1281);
                    return
                }
                GLctx.deleteShader(shader);
                GL.shaders[id] = null
            }
            Module["_emscripten_glDeleteShader"] = _emscripten_glDeleteShader;
            _emscripten_glDeleteShader.sig = "vi";

            function _emscripten_glDeleteTextures(n, textures) {
                for (var i = 0; i < n; i++) {
                    var id = HEAP32[textures + i * 4 >> 2];
                    var texture = GL.textures[id];
                    if (!texture) continue;
                    GLctx.deleteTexture(texture);
                    texture.name = 0;
                    GL.textures[id] = null
                }
            }
            Module["_emscripten_glDeleteTextures"] = _emscripten_glDeleteTextures;
            _emscripten_glDeleteTextures.sig = "vii";

            function _emscripten_glDeleteVertexArraysOES(n, vaos) {
                for (var i = 0; i < n; i++) {
                    var id = HEAP32[vaos + i * 4 >> 2];
                    GLctx["deleteVertexArray"](GL.vaos[id]);
                    GL.vaos[id] = null
                }
            }
            Module["_emscripten_glDeleteVertexArraysOES"] = _emscripten_glDeleteVertexArraysOES;
            _emscripten_glDeleteVertexArraysOES.sig = "vii";

            function _emscripten_glDepthFunc(x0) {
                GLctx["depthFunc"](x0)
            }
            Module["_emscripten_glDepthFunc"] = _emscripten_glDepthFunc;
            _emscripten_glDepthFunc.sig = "vi";

            function _emscripten_glDepthMask(flag) {
                GLctx.depthMask(!!flag)
            }
            Module["_emscripten_glDepthMask"] = _emscripten_glDepthMask;
            _emscripten_glDepthMask.sig = "vi";

            function _emscripten_glDepthRangef(x0, x1) {
                GLctx["depthRange"](x0, x1)
            }
            Module["_emscripten_glDepthRangef"] = _emscripten_glDepthRangef;
            _emscripten_glDepthRangef.sig = "vii";

            function _emscripten_glDetachShader(program, shader) {
                GLctx.detachShader(GL.programs[program], GL.shaders[shader])
            }
            Module["_emscripten_glDetachShader"] = _emscripten_glDetachShader;
            _emscripten_glDetachShader.sig = "vii";

            function _emscripten_glDisable(x0) {
                GLctx["disable"](x0)
            }
            Module["_emscripten_glDisable"] = _emscripten_glDisable;
            _emscripten_glDisable.sig = "vi";

            function _emscripten_glDisableVertexAttribArray(index) {
                GLctx.disableVertexAttribArray(index)
            }
            Module["_emscripten_glDisableVertexAttribArray"] = _emscripten_glDisableVertexAttribArray;
            _emscripten_glDisableVertexAttribArray.sig = "vi";

            function _emscripten_glDrawArrays(mode, first, count) {
                GLctx.drawArrays(mode, first, count)
            }
            Module["_emscripten_glDrawArrays"] = _emscripten_glDrawArrays;
            _emscripten_glDrawArrays.sig = "viii";

            function _emscripten_glDrawArraysInstancedANGLE(mode, first, count, primcount) {
                GLctx["drawArraysInstanced"](mode, first, count, primcount)
            }
            Module["_emscripten_glDrawArraysInstancedANGLE"] = _emscripten_glDrawArraysInstancedANGLE;
            _emscripten_glDrawArraysInstancedANGLE.sig = "viiii";
            var tempFixedLengthArray = [];
            Module["tempFixedLengthArray"] = tempFixedLengthArray;

            function _emscripten_glDrawBuffersWEBGL(n, bufs) {
                var bufArray = tempFixedLengthArray[n];
                for (var i = 0; i < n; i++) {
                    bufArray[i] = HEAP32[bufs + i * 4 >> 2]
                }
                GLctx["drawBuffers"](bufArray)
            }
            Module["_emscripten_glDrawBuffersWEBGL"] = _emscripten_glDrawBuffersWEBGL;
            _emscripten_glDrawBuffersWEBGL.sig = "vii";

            function _emscripten_glDrawElements(mode, count, type, indices) {
                GLctx.drawElements(mode, count, type, indices)
            }
            Module["_emscripten_glDrawElements"] = _emscripten_glDrawElements;
            _emscripten_glDrawElements.sig = "viiii";

            function _emscripten_glDrawElementsInstancedANGLE(mode, count, type, indices, primcount) {
                GLctx["drawElementsInstanced"](mode, count, type, indices, primcount)
            }
            Module["_emscripten_glDrawElementsInstancedANGLE"] = _emscripten_glDrawElementsInstancedANGLE;
            _emscripten_glDrawElementsInstancedANGLE.sig = "viiiii";

            function _emscripten_glEnable(x0) {
                GLctx["enable"](x0)
            }
            Module["_emscripten_glEnable"] = _emscripten_glEnable;
            _emscripten_glEnable.sig = "vi";

            function _emscripten_glEnableVertexAttribArray(index) {
                GLctx.enableVertexAttribArray(index)
            }
            Module["_emscripten_glEnableVertexAttribArray"] = _emscripten_glEnableVertexAttribArray;
            _emscripten_glEnableVertexAttribArray.sig = "vi";

            function _emscripten_glEndQueryEXT(target) {
                GLctx.disjointTimerQueryExt["endQueryEXT"](target)
            }
            Module["_emscripten_glEndQueryEXT"] = _emscripten_glEndQueryEXT;
            _emscripten_glEndQueryEXT.sig = "vi";

            function _emscripten_glFinish() {
                GLctx["finish"]()
            }
            Module["_emscripten_glFinish"] = _emscripten_glFinish;
            _emscripten_glFinish.sig = "v";

            function _emscripten_glFlush() {
                GLctx["flush"]()
            }
            Module["_emscripten_glFlush"] = _emscripten_glFlush;
            _emscripten_glFlush.sig = "v";

            function _emscripten_glFramebufferRenderbuffer(target, attachment, renderbuffertarget, renderbuffer) {
                GLctx.framebufferRenderbuffer(target, attachment, renderbuffertarget, GL.renderbuffers[renderbuffer])
            }
            Module["_emscripten_glFramebufferRenderbuffer"] = _emscripten_glFramebufferRenderbuffer;
            _emscripten_glFramebufferRenderbuffer.sig = "viiii";

            function _emscripten_glFramebufferTexture2D(target, attachment, textarget, texture, level) {
                GLctx.framebufferTexture2D(target, attachment, textarget, GL.textures[texture], level)
            }
            Module["_emscripten_glFramebufferTexture2D"] = _emscripten_glFramebufferTexture2D;
            _emscripten_glFramebufferTexture2D.sig = "viiiii";

            function _emscripten_glFrontFace(x0) {
                GLctx["frontFace"](x0)
            }
            Module["_emscripten_glFrontFace"] = _emscripten_glFrontFace;
            _emscripten_glFrontFace.sig = "vi";

            function __glGenObject(n, buffers, createFunction, objectTable) {
                for (var i = 0; i < n; i++) {
                    var buffer = GLctx[createFunction]();
                    var id = buffer && GL.getNewId(objectTable);
                    if (buffer) {
                        buffer.name = id;
                        objectTable[id] = buffer
                    } else {
                        GL.recordError(1282)
                    }
                    HEAP32[buffers + i * 4 >> 2] = id
                }
            }
            Module["__glGenObject"] = __glGenObject;
            __glGenObject.sig = "vii";

            function _emscripten_glGenBuffers(n, buffers) {
                __glGenObject(n, buffers, "createBuffer", GL.buffers)
            }
            Module["_emscripten_glGenBuffers"] = _emscripten_glGenBuffers;
            _emscripten_glGenBuffers.sig = "vii";

            function _emscripten_glGenFramebuffers(n, ids) {
                __glGenObject(n, ids, "createFramebuffer", GL.framebuffers)
            }
            Module["_emscripten_glGenFramebuffers"] = _emscripten_glGenFramebuffers;
            _emscripten_glGenFramebuffers.sig = "vii";

            function _emscripten_glGenQueriesEXT(n, ids) {
                for (var i = 0; i < n; i++) {
                    var query = GLctx.disjointTimerQueryExt["createQueryEXT"]();
                    if (!query) {
                        GL.recordError(1282);
                        while (i < n) HEAP32[ids + i++ * 4 >> 2] = 0;
                        return
                    }
                    var id = GL.getNewId(GL.queries);
                    query.name = id;
                    GL.queries[id] = query;
                    HEAP32[ids + i * 4 >> 2] = id
                }
            }
            Module["_emscripten_glGenQueriesEXT"] = _emscripten_glGenQueriesEXT;
            _emscripten_glGenQueriesEXT.sig = "vii";

            function _emscripten_glGenRenderbuffers(n, renderbuffers) {
                __glGenObject(n, renderbuffers, "createRenderbuffer", GL.renderbuffers)
            }
            Module["_emscripten_glGenRenderbuffers"] = _emscripten_glGenRenderbuffers;
            _emscripten_glGenRenderbuffers.sig = "vii";

            function _emscripten_glGenTextures(n, textures) {
                __glGenObject(n, textures, "createTexture", GL.textures)
            }
            Module["_emscripten_glGenTextures"] = _emscripten_glGenTextures;
            _emscripten_glGenTextures.sig = "vii";

            function _emscripten_glGenVertexArraysOES(n, arrays) {
                __glGenObject(n, arrays, "createVertexArray", GL.vaos)
            }
            Module["_emscripten_glGenVertexArraysOES"] = _emscripten_glGenVertexArraysOES;
            _emscripten_glGenVertexArraysOES.sig = "vii";

            function _emscripten_glGenerateMipmap(x0) {
                GLctx["generateMipmap"](x0)
            }
            Module["_emscripten_glGenerateMipmap"] = _emscripten_glGenerateMipmap;
            _emscripten_glGenerateMipmap.sig = "vi";

            function __glGetActiveAttribOrUniform(funcName, program, index, bufSize, length, size, type, name) {
                program = GL.programs[program];
                var info = GLctx[funcName](program, index);
                if (info) {
                    var numBytesWrittenExclNull = name && stringToUTF8(info.name, name, bufSize);
                    if (length) HEAP32[length >> 2] = numBytesWrittenExclNull;
                    if (size) HEAP32[size >> 2] = info.size;
                    if (type) HEAP32[type >> 2] = info.type
                }
            }
            Module["__glGetActiveAttribOrUniform"] = __glGetActiveAttribOrUniform;

            function _emscripten_glGetActiveAttrib(program, index, bufSize, length, size, type, name) {
                __glGetActiveAttribOrUniform("getActiveAttrib", program, index, bufSize, length, size, type, name)
            }
            Module["_emscripten_glGetActiveAttrib"] = _emscripten_glGetActiveAttrib;
            _emscripten_glGetActiveAttrib.sig = "viiiiiii";

            function _emscripten_glGetActiveUniform(program, index, bufSize, length, size, type, name) {
                __glGetActiveAttribOrUniform("getActiveUniform", program, index, bufSize, length, size, type, name)
            }
            Module["_emscripten_glGetActiveUniform"] = _emscripten_glGetActiveUniform;
            _emscripten_glGetActiveUniform.sig = "viiiiiii";

            function _emscripten_glGetAttachedShaders(program, maxCount, count, shaders) {
                var result = GLctx.getAttachedShaders(GL.programs[program]);
                var len = result.length;
                if (len > maxCount) {
                    len = maxCount
                }
                HEAP32[count >> 2] = len;
                for (var i = 0; i < len; ++i) {
                    var id = GL.shaders.indexOf(result[i]);
                    HEAP32[shaders + i * 4 >> 2] = id
                }
            }
            Module["_emscripten_glGetAttachedShaders"] = _emscripten_glGetAttachedShaders;
            _emscripten_glGetAttachedShaders.sig = "viiii";

            function _emscripten_glGetAttribLocation(program, name) {
                return GLctx.getAttribLocation(GL.programs[program], UTF8ToString(name))
            }
            Module["_emscripten_glGetAttribLocation"] = _emscripten_glGetAttribLocation;
            _emscripten_glGetAttribLocation.sig = "iii";

            function writeI53ToI64(ptr, num) {
                HEAPU32[ptr >> 2] = num;
                HEAPU32[ptr + 4 >> 2] = (num - HEAPU32[ptr >> 2]) / 4294967296
            }
            Module["writeI53ToI64"] = writeI53ToI64;

            function emscriptenWebGLGet(name_, p, type) {
                if (!p) {
                    GL.recordError(1281);
                    return
                }
                var ret = undefined;
                switch (name_) {
                    case 36346:
                        ret = 1;
                        break;
                    case 36344:
                        if (type != 0 && type != 1) {
                            GL.recordError(1280)
                        }
                        return;
                    case 36345:
                        ret = 0;
                        break;
                    case 34466:
                        var formats = GLctx.getParameter(34467);
                        ret = formats ? formats.length : 0;
                        break
                }
                if (ret === undefined) {
                    var result = GLctx.getParameter(name_);
                    switch (typeof result) {
                        case "number":
                            ret = result;
                            break;
                        case "boolean":
                            ret = result ? 1 : 0;
                            break;
                        case "string":
                            GL.recordError(1280);
                            return;
                        case "object":
                            if (result === null) {
                                switch (name_) {
                                    case 34964:
                                    case 35725:
                                    case 34965:
                                    case 36006:
                                    case 36007:
                                    case 32873:
                                    case 34229:
                                    case 34068: {
                                        ret = 0;
                                        break
                                    }
                                    default: {
                                        GL.recordError(1280);
                                        return
                                    }
                                }
                            } else if (result instanceof Float32Array || result instanceof Uint32Array || result instanceof Int32Array || result instanceof Array) {
                                for (var i = 0; i < result.length; ++i) {
                                    switch (type) {
                                        case 0:
                                            HEAP32[p + i * 4 >> 2] = result[i];
                                            break;
                                        case 2:
                                            HEAPF32[p + i * 4 >> 2] = result[i];
                                            break;
                                        case 4:
                                            HEAP8[p + i >> 0] = result[i] ? 1 : 0;
                                            break
                                    }
                                }
                                return
                            } else {
                                try {
                                    ret = result.name | 0
                                } catch (e) {
                                    GL.recordError(1280);
                                    err("GL_INVALID_ENUM in glGet" + type + "v: Unknown object returned from WebGL getParameter(" + name_ + ")! (error: " + e + ")");
                                    return
                                }
                            }
                            break;
                        default:
                            GL.recordError(1280);
                            err("GL_INVALID_ENUM in glGet" + type + "v: Native code calling glGet" + type + "v(" + name_ + ") and it returns " + result + " of type " + typeof result + "!");
                            return
                    }
                }
                switch (type) {
                    case 1:
                        writeI53ToI64(p, ret);
                        break;
                    case 0:
                        HEAP32[p >> 2] = ret;
                        break;
                    case 2:
                        HEAPF32[p >> 2] = ret;
                        break;
                    case 4:
                        HEAP8[p >> 0] = ret ? 1 : 0;
                        break
                }
            }
            Module["emscriptenWebGLGet"] = emscriptenWebGLGet;

            function _emscripten_glGetBooleanv(name_, p) {
                emscriptenWebGLGet(name_, p, 4)
            }
            Module["_emscripten_glGetBooleanv"] = _emscripten_glGetBooleanv;
            _emscripten_glGetBooleanv.sig = "vii";

            function _emscripten_glGetBufferParameteriv(target, value, data) {
                if (!data) {
                    GL.recordError(1281);
                    return
                }
                HEAP32[data >> 2] = GLctx.getBufferParameter(target, value)
            }
            Module["_emscripten_glGetBufferParameteriv"] = _emscripten_glGetBufferParameteriv;
            _emscripten_glGetBufferParameteriv.sig = "viii";

            function _emscripten_glGetError() {
                var error = GLctx.getError() || GL.lastError;
                GL.lastError = 0;
                return error
            }
            Module["_emscripten_glGetError"] = _emscripten_glGetError;
            _emscripten_glGetError.sig = "i";

            function _emscripten_glGetFloatv(name_, p) {
                emscriptenWebGLGet(name_, p, 2)
            }
            Module["_emscripten_glGetFloatv"] = _emscripten_glGetFloatv;
            _emscripten_glGetFloatv.sig = "vii";

            function _emscripten_glGetFramebufferAttachmentParameteriv(target, attachment, pname, params) {
                var result = GLctx.getFramebufferAttachmentParameter(target, attachment, pname);
                if (result instanceof WebGLRenderbuffer || result instanceof WebGLTexture) {
                    result = result.name | 0
                }
                HEAP32[params >> 2] = result
            }
            Module["_emscripten_glGetFramebufferAttachmentParameteriv"] = _emscripten_glGetFramebufferAttachmentParameteriv;
            _emscripten_glGetFramebufferAttachmentParameteriv.sig = "viiii";

            function _emscripten_glGetIntegerv(name_, p) {
                emscriptenWebGLGet(name_, p, 0)
            }
            Module["_emscripten_glGetIntegerv"] = _emscripten_glGetIntegerv;
            _emscripten_glGetIntegerv.sig = "vii";

            function _emscripten_glGetProgramInfoLog(program, maxLength, length, infoLog) {
                var log = GLctx.getProgramInfoLog(GL.programs[program]);
                if (log === null) log = "(unknown error)";
                var numBytesWrittenExclNull = maxLength > 0 && infoLog ? stringToUTF8(log, infoLog, maxLength) : 0;
                if (length) HEAP32[length >> 2] = numBytesWrittenExclNull
            }
            Module["_emscripten_glGetProgramInfoLog"] = _emscripten_glGetProgramInfoLog;
            _emscripten_glGetProgramInfoLog.sig = "viiii";

            function _emscripten_glGetProgramiv(program, pname, p) {
                if (!p) {
                    GL.recordError(1281);
                    return
                }
                if (program >= GL.counter) {
                    GL.recordError(1281);
                    return
                }
                program = GL.programs[program];
                if (pname == 35716) {
                    var log = GLctx.getProgramInfoLog(program);
                    if (log === null) log = "(unknown error)";
                    HEAP32[p >> 2] = log.length + 1
                } else if (pname == 35719) {
                    if (!program.maxUniformLength) {
                        for (var i = 0; i < GLctx.getProgramParameter(program, 35718); ++i) {
                            program.maxUniformLength = Math.max(program.maxUniformLength, GLctx.getActiveUniform(program, i).name.length + 1)
                        }
                    }
                    HEAP32[p >> 2] = program.maxUniformLength
                } else if (pname == 35722) {
                    if (!program.maxAttributeLength) {
                        for (var i = 0; i < GLctx.getProgramParameter(program, 35721); ++i) {
                            program.maxAttributeLength = Math.max(program.maxAttributeLength, GLctx.getActiveAttrib(program, i).name.length + 1)
                        }
                    }
                    HEAP32[p >> 2] = program.maxAttributeLength
                } else if (pname == 35381) {
                    if (!program.maxUniformBlockNameLength) {
                        for (var i = 0; i < GLctx.getProgramParameter(program, 35382); ++i) {
                            program.maxUniformBlockNameLength = Math.max(program.maxUniformBlockNameLength, GLctx.getActiveUniformBlockName(program, i).length + 1)
                        }
                    }
                    HEAP32[p >> 2] = program.maxUniformBlockNameLength
                } else {
                    HEAP32[p >> 2] = GLctx.getProgramParameter(program, pname)
                }
            }
            Module["_emscripten_glGetProgramiv"] = _emscripten_glGetProgramiv;
            _emscripten_glGetProgramiv.sig = "viii";

            function _emscripten_glGetQueryObjecti64vEXT(id, pname, params) {
                if (!params) {
                    GL.recordError(1281);
                    return
                }
                var query = GL.queries[id];
                var param; {
                    param = GLctx.disjointTimerQueryExt["getQueryObjectEXT"](query, pname)
                }
                var ret;
                if (typeof param == "boolean") {
                    ret = param ? 1 : 0
                } else {
                    ret = param
                }
                writeI53ToI64(params, ret)
            }
            Module["_emscripten_glGetQueryObjecti64vEXT"] = _emscripten_glGetQueryObjecti64vEXT;
            _emscripten_glGetQueryObjecti64vEXT.sig = "viii";

            function _emscripten_glGetQueryObjectivEXT(id, pname, params) {
                if (!params) {
                    GL.recordError(1281);
                    return
                }
                var query = GL.queries[id];
                var param = GLctx.disjointTimerQueryExt["getQueryObjectEXT"](query, pname);
                var ret;
                if (typeof param == "boolean") {
                    ret = param ? 1 : 0
                } else {
                    ret = param
                }
                HEAP32[params >> 2] = ret
            }
            Module["_emscripten_glGetQueryObjectivEXT"] = _emscripten_glGetQueryObjectivEXT;
            _emscripten_glGetQueryObjectivEXT.sig = "viii";

            function _emscripten_glGetQueryObjectui64vEXT(id, pname, params) {
                if (!params) {
                    GL.recordError(1281);
                    return
                }
                var query = GL.queries[id];
                var param; {
                    param = GLctx.disjointTimerQueryExt["getQueryObjectEXT"](query, pname)
                }
                var ret;
                if (typeof param == "boolean") {
                    ret = param ? 1 : 0
                } else {
                    ret = param
                }
                writeI53ToI64(params, ret)
            }
            Module["_emscripten_glGetQueryObjectui64vEXT"] = _emscripten_glGetQueryObjectui64vEXT;
            _emscripten_glGetQueryObjectui64vEXT.sig = "viii";

            function _emscripten_glGetQueryObjectuivEXT(id, pname, params) {
                if (!params) {
                    GL.recordError(1281);
                    return
                }
                var query = GL.queries[id];
                var param = GLctx.disjointTimerQueryExt["getQueryObjectEXT"](query, pname);
                var ret;
                if (typeof param == "boolean") {
                    ret = param ? 1 : 0
                } else {
                    ret = param
                }
                HEAP32[params >> 2] = ret
            }
            Module["_emscripten_glGetQueryObjectuivEXT"] = _emscripten_glGetQueryObjectuivEXT;
            _emscripten_glGetQueryObjectuivEXT.sig = "viii";

            function _emscripten_glGetQueryivEXT(target, pname, params) {
                if (!params) {
                    GL.recordError(1281);
                    return
                }
                HEAP32[params >> 2] = GLctx.disjointTimerQueryExt["getQueryEXT"](target, pname)
            }
            Module["_emscripten_glGetQueryivEXT"] = _emscripten_glGetQueryivEXT;
            _emscripten_glGetQueryivEXT.sig = "viii";

            function _emscripten_glGetRenderbufferParameteriv(target, pname, params) {
                if (!params) {
                    GL.recordError(1281);
                    return
                }
                HEAP32[params >> 2] = GLctx.getRenderbufferParameter(target, pname)
            }
            Module["_emscripten_glGetRenderbufferParameteriv"] = _emscripten_glGetRenderbufferParameteriv;
            _emscripten_glGetRenderbufferParameteriv.sig = "viii";

            function _emscripten_glGetShaderInfoLog(shader, maxLength, length, infoLog) {
                var log = GLctx.getShaderInfoLog(GL.shaders[shader]);
                if (log === null) log = "(unknown error)";
                var numBytesWrittenExclNull = maxLength > 0 && infoLog ? stringToUTF8(log, infoLog, maxLength) : 0;
                if (length) HEAP32[length >> 2] = numBytesWrittenExclNull
            }
            Module["_emscripten_glGetShaderInfoLog"] = _emscripten_glGetShaderInfoLog;
            _emscripten_glGetShaderInfoLog.sig = "viiii";

            function _emscripten_glGetShaderPrecisionFormat(shaderType, precisionType, range, precision) {
                var result = GLctx.getShaderPrecisionFormat(shaderType, precisionType);
                HEAP32[range >> 2] = result.rangeMin;
                HEAP32[range + 4 >> 2] = result.rangeMax;
                HEAP32[precision >> 2] = result.precision
            }
            Module["_emscripten_glGetShaderPrecisionFormat"] = _emscripten_glGetShaderPrecisionFormat;
            _emscripten_glGetShaderPrecisionFormat.sig = "viiii";

            function _emscripten_glGetShaderSource(shader, bufSize, length, source) {
                var result = GLctx.getShaderSource(GL.shaders[shader]);
                if (!result) return;
                var numBytesWrittenExclNull = bufSize > 0 && source ? stringToUTF8(result, source, bufSize) : 0;
                if (length) HEAP32[length >> 2] = numBytesWrittenExclNull
            }
            Module["_emscripten_glGetShaderSource"] = _emscripten_glGetShaderSource;
            _emscripten_glGetShaderSource.sig = "viiii";

            function _emscripten_glGetShaderiv(shader, pname, p) {
                if (!p) {
                    GL.recordError(1281);
                    return
                }
                if (pname == 35716) {
                    var log = GLctx.getShaderInfoLog(GL.shaders[shader]);
                    if (log === null) log = "(unknown error)";
                    var logLength = log ? log.length + 1 : 0;
                    HEAP32[p >> 2] = logLength
                } else if (pname == 35720) {
                    var source = GLctx.getShaderSource(GL.shaders[shader]);
                    var sourceLength = source ? source.length + 1 : 0;
                    HEAP32[p >> 2] = sourceLength
                } else {
                    HEAP32[p >> 2] = GLctx.getShaderParameter(GL.shaders[shader], pname)
                }
            }
            Module["_emscripten_glGetShaderiv"] = _emscripten_glGetShaderiv;
            _emscripten_glGetShaderiv.sig = "viii";

            function stringToNewUTF8(jsString) {
                var length = lengthBytesUTF8(jsString) + 1;
                var cString = _malloc(length);
                stringToUTF8(jsString, cString, length);
                return cString
            }
            Module["stringToNewUTF8"] = stringToNewUTF8;

            function _emscripten_glGetString(name_) {
                var ret = GL.stringCache[name_];
                if (!ret) {
                    switch (name_) {
                        case 7939:
                            var exts = GLctx.getSupportedExtensions() || [];
                            exts = exts.concat(exts.map(function(e) {
                                return "GL_" + e
                            }));
                            ret = stringToNewUTF8(exts.join(" "));
                            break;
                        case 7936:
                        case 7937:
                        case 37445:
                        case 37446:
                            var s = GLctx.getParameter(name_);
                            if (!s) {
                                GL.recordError(1280)
                            }
                            ret = s && stringToNewUTF8(s);
                            break;
                        case 7938:
                            var glVersion = GLctx.getParameter(7938); {
                                glVersion = "OpenGL ES 2.0 (" + glVersion + ")"
                            }
                            ret = stringToNewUTF8(glVersion);
                            break;
                        case 35724:
                            var glslVersion = GLctx.getParameter(35724);
                            var ver_re = /^WebGL GLSL ES ([0-9]\.[0-9][0-9]?)(?:$| .*)/;
                            var ver_num = glslVersion.match(ver_re);
                            if (ver_num !== null) {
                                if (ver_num[1].length == 3) ver_num[1] = ver_num[1] + "0";
                                glslVersion = "OpenGL ES GLSL ES " + ver_num[1] + " (" + glslVersion + ")"
                            }
                            ret = stringToNewUTF8(glslVersion);
                            break;
                        default:
                            GL.recordError(1280)
                    }
                    GL.stringCache[name_] = ret
                }
                return ret
            }
            Module["_emscripten_glGetString"] = _emscripten_glGetString;
            _emscripten_glGetString.sig = "ii";

            function _emscripten_glGetTexParameterfv(target, pname, params) {
                if (!params) {
                    GL.recordError(1281);
                    return
                }
                HEAPF32[params >> 2] = GLctx.getTexParameter(target, pname)
            }
            Module["_emscripten_glGetTexParameterfv"] = _emscripten_glGetTexParameterfv;
            _emscripten_glGetTexParameterfv.sig = "viii";

            function _emscripten_glGetTexParameteriv(target, pname, params) {
                if (!params) {
                    GL.recordError(1281);
                    return
                }
                HEAP32[params >> 2] = GLctx.getTexParameter(target, pname)
            }
            Module["_emscripten_glGetTexParameteriv"] = _emscripten_glGetTexParameteriv;
            _emscripten_glGetTexParameteriv.sig = "viii";

            function _emscripten_glGetUniformLocation(program, name) {
                function getLeftBracePos(name) {
                    return name.slice(-1) == "]" && name.lastIndexOf("[")
                }
                name = UTF8ToString(name);
                if (program = GL.programs[program]) {
                    var uniformLocsById = program.uniformLocsById;
                    var uniformSizeAndIdsByName = program.uniformSizeAndIdsByName;
                    var i, j;
                    var arrayIndex = 0;
                    var uniformBaseName = name;
                    var leftBrace = getLeftBracePos(name);
                    if (!uniformLocsById) {
                        program.uniformLocsById = uniformLocsById = {};
                        program.uniformArrayNamesById = {};
                        for (i = 0; i < GLctx.getProgramParameter(program, 35718); ++i) {
                            var u = GLctx.getActiveUniform(program, i);
                            var nm = u.name;
                            var sz = u.size;
                            var lb = getLeftBracePos(nm);
                            var arrayName = lb > 0 ? nm.slice(0, lb) : nm;
                            var id = program.uniformIdCounter;
                            program.uniformIdCounter += sz;
                            uniformSizeAndIdsByName[arrayName] = [sz, id];
                            for (j = 0; j < sz; ++j) {
                                uniformLocsById[id] = j;
                                program.uniformArrayNamesById[id++] = arrayName
                            }
                        }
                    }
                    if (leftBrace > 0) {
                        arrayIndex = jstoi_q(name.slice(leftBrace + 1)) >>> 0;
                        uniformBaseName = name.slice(0, leftBrace)
                    }
                    var sizeAndId = uniformSizeAndIdsByName[uniformBaseName];
                    if (sizeAndId && arrayIndex < sizeAndId[0]) {
                        arrayIndex += sizeAndId[1];
                        if (uniformLocsById[arrayIndex] = uniformLocsById[arrayIndex] || GLctx.getUniformLocation(program, name)) {
                            return arrayIndex
                        }
                    }
                } else {
                    GL.recordError(1281)
                }
                return -1
            }
            Module["_emscripten_glGetUniformLocation"] = _emscripten_glGetUniformLocation;
            _emscripten_glGetUniformLocation.sig = "iii";

            function emscriptenWebGLGetUniform(program, location, params, type) {
                if (!params) {
                    GL.recordError(1281);
                    return
                }
                program = GL.programs[program];
                var data = GLctx.getUniform(program, program.uniformLocsById[location]);
                if (typeof data == "number" || typeof data == "boolean") {
                    switch (type) {
                        case 0:
                            HEAP32[params >> 2] = data;
                            break;
                        case 2:
                            HEAPF32[params >> 2] = data;
                            break
                    }
                } else {
                    for (var i = 0; i < data.length; i++) {
                        switch (type) {
                            case 0:
                                HEAP32[params + i * 4 >> 2] = data[i];
                                break;
                            case 2:
                                HEAPF32[params + i * 4 >> 2] = data[i];
                                break
                        }
                    }
                }
            }
            Module["emscriptenWebGLGetUniform"] = emscriptenWebGLGetUniform;

            function _emscripten_glGetUniformfv(program, location, params) {
                emscriptenWebGLGetUniform(program, location, params, 2)
            }
            Module["_emscripten_glGetUniformfv"] = _emscripten_glGetUniformfv;
            _emscripten_glGetUniformfv.sig = "viii";

            function _emscripten_glGetUniformiv(program, location, params) {
                emscriptenWebGLGetUniform(program, location, params, 0)
            }
            Module["_emscripten_glGetUniformiv"] = _emscripten_glGetUniformiv;
            _emscripten_glGetUniformiv.sig = "viii";

            function _emscripten_glGetVertexAttribPointerv(index, pname, pointer) {
                if (!pointer) {
                    GL.recordError(1281);
                    return
                }
                HEAP32[pointer >> 2] = GLctx.getVertexAttribOffset(index, pname)
            }
            Module["_emscripten_glGetVertexAttribPointerv"] = _emscripten_glGetVertexAttribPointerv;
            _emscripten_glGetVertexAttribPointerv.sig = "viii";

            function emscriptenWebGLGetVertexAttrib(index, pname, params, type) {
                if (!params) {
                    GL.recordError(1281);
                    return
                }
                var data = GLctx.getVertexAttrib(index, pname);
                if (pname == 34975) {
                    HEAP32[params >> 2] = data && data["name"]
                } else if (typeof data == "number" || typeof data == "boolean") {
                    switch (type) {
                        case 0:
                            HEAP32[params >> 2] = data;
                            break;
                        case 2:
                            HEAPF32[params >> 2] = data;
                            break;
                        case 5:
                            HEAP32[params >> 2] = Math.fround(data);
                            break
                    }
                } else {
                    for (var i = 0; i < data.length; i++) {
                        switch (type) {
                            case 0:
                                HEAP32[params + i * 4 >> 2] = data[i];
                                break;
                            case 2:
                                HEAPF32[params + i * 4 >> 2] = data[i];
                                break;
                            case 5:
                                HEAP32[params + i * 4 >> 2] = Math.fround(data[i]);
                                break
                        }
                    }
                }
            }
            Module["emscriptenWebGLGetVertexAttrib"] = emscriptenWebGLGetVertexAttrib;

            function _emscripten_glGetVertexAttribfv(index, pname, params) {
                emscriptenWebGLGetVertexAttrib(index, pname, params, 2)
            }
            Module["_emscripten_glGetVertexAttribfv"] = _emscripten_glGetVertexAttribfv;
            _emscripten_glGetVertexAttribfv.sig = "viii";

            function _emscripten_glGetVertexAttribiv(index, pname, params) {
                emscriptenWebGLGetVertexAttrib(index, pname, params, 5)
            }
            Module["_emscripten_glGetVertexAttribiv"] = _emscripten_glGetVertexAttribiv;
            _emscripten_glGetVertexAttribiv.sig = "viii";

            function _emscripten_glHint(x0, x1) {
                GLctx["hint"](x0, x1)
            }
            Module["_emscripten_glHint"] = _emscripten_glHint;
            _emscripten_glHint.sig = "vii";

            function _emscripten_glIsBuffer(buffer) {
                var b = GL.buffers[buffer];
                if (!b) return 0;
                return GLctx.isBuffer(b)
            }
            Module["_emscripten_glIsBuffer"] = _emscripten_glIsBuffer;
            _emscripten_glIsBuffer.sig = "ii";

            function _emscripten_glIsEnabled(x0) {
                return GLctx["isEnabled"](x0)
            }
            Module["_emscripten_glIsEnabled"] = _emscripten_glIsEnabled;
            _emscripten_glIsEnabled.sig = "ii";

            function _emscripten_glIsFramebuffer(framebuffer) {
                var fb = GL.framebuffers[framebuffer];
                if (!fb) return 0;
                return GLctx.isFramebuffer(fb)
            }
            Module["_emscripten_glIsFramebuffer"] = _emscripten_glIsFramebuffer;
            _emscripten_glIsFramebuffer.sig = "ii";

            function _emscripten_glIsProgram(program) {
                program = GL.programs[program];
                if (!program) return 0;
                return GLctx.isProgram(program)
            }
            Module["_emscripten_glIsProgram"] = _emscripten_glIsProgram;
            _emscripten_glIsProgram.sig = "ii";

            function _emscripten_glIsQueryEXT(id) {
                var query = GL.queries[id];
                if (!query) return 0;
                return GLctx.disjointTimerQueryExt["isQueryEXT"](query)
            }
            Module["_emscripten_glIsQueryEXT"] = _emscripten_glIsQueryEXT;
            _emscripten_glIsQueryEXT.sig = "ii";

            function _emscripten_glIsRenderbuffer(renderbuffer) {
                var rb = GL.renderbuffers[renderbuffer];
                if (!rb) return 0;
                return GLctx.isRenderbuffer(rb)
            }
            Module["_emscripten_glIsRenderbuffer"] = _emscripten_glIsRenderbuffer;
            _emscripten_glIsRenderbuffer.sig = "ii";

            function _emscripten_glIsShader(shader) {
                var s = GL.shaders[shader];
                if (!s) return 0;
                return GLctx.isShader(s)
            }
            Module["_emscripten_glIsShader"] = _emscripten_glIsShader;
            _emscripten_glIsShader.sig = "ii";

            function _emscripten_glIsTexture(id) {
                var texture = GL.textures[id];
                if (!texture) return 0;
                return GLctx.isTexture(texture)
            }
            Module["_emscripten_glIsTexture"] = _emscripten_glIsTexture;
            _emscripten_glIsTexture.sig = "ii";

            function _emscripten_glIsVertexArrayOES(array) {
                var vao = GL.vaos[array];
                if (!vao) return 0;
                return GLctx["isVertexArray"](vao)
            }
            Module["_emscripten_glIsVertexArrayOES"] = _emscripten_glIsVertexArrayOES;
            _emscripten_glIsVertexArrayOES.sig = "ii";

            function _emscripten_glLineWidth(x0) {
                GLctx["lineWidth"](x0)
            }
            Module["_emscripten_glLineWidth"] = _emscripten_glLineWidth;
            _emscripten_glLineWidth.sig = "vi";

            function _emscripten_glLinkProgram(program) {
                program = GL.programs[program];
                GLctx.linkProgram(program);
                program.uniformLocsById = 0;
                program.uniformSizeAndIdsByName = {}
            }
            Module["_emscripten_glLinkProgram"] = _emscripten_glLinkProgram;
            _emscripten_glLinkProgram.sig = "vi";

            function _emscripten_glPixelStorei(pname, param) {
                if (pname == 3317) {
                    GL.unpackAlignment = param
                }
                GLctx.pixelStorei(pname, param)
            }
            Module["_emscripten_glPixelStorei"] = _emscripten_glPixelStorei;
            _emscripten_glPixelStorei.sig = "vii";

            function _emscripten_glPolygonOffset(x0, x1) {
                GLctx["polygonOffset"](x0, x1)
            }
            Module["_emscripten_glPolygonOffset"] = _emscripten_glPolygonOffset;
            _emscripten_glPolygonOffset.sig = "vii";

            function _emscripten_glQueryCounterEXT(id, target) {
                GLctx.disjointTimerQueryExt["queryCounterEXT"](GL.queries[id], target)
            }
            Module["_emscripten_glQueryCounterEXT"] = _emscripten_glQueryCounterEXT;
            _emscripten_glQueryCounterEXT.sig = "vii";

            function computeUnpackAlignedImageSize(width, height, sizePerPixel, alignment) {
                function roundedToNextMultipleOf(x, y) {
                    return x + y - 1 & -y
                }
                var plainRowSize = width * sizePerPixel;
                var alignedRowSize = roundedToNextMultipleOf(plainRowSize, alignment);
                return height * alignedRowSize
            }
            Module["computeUnpackAlignedImageSize"] = computeUnpackAlignedImageSize;

            function __colorChannelsInGlTextureFormat(format) {
                var colorChannels = {
                    5: 3,
                    6: 4,
                    8: 2,
                    29502: 3,
                    29504: 4
                };
                return colorChannels[format - 6402] || 1
            }
            Module["__colorChannelsInGlTextureFormat"] = __colorChannelsInGlTextureFormat;

            function heapObjectForWebGLType(type) {
                type -= 5120;
                if (type == 1) return HEAPU8;
                if (type == 4) return HEAP32;
                if (type == 6) return HEAPF32;
                if (type == 5 || type == 28922) return HEAPU32;
                return HEAPU16
            }
            Module["heapObjectForWebGLType"] = heapObjectForWebGLType;

            function heapAccessShiftForWebGLHeap(heap) {
                return 31 - Math.clz32(heap.BYTES_PER_ELEMENT)
            }
            Module["heapAccessShiftForWebGLHeap"] = heapAccessShiftForWebGLHeap;

            function emscriptenWebGLGetTexPixelData(type, format, width, height, pixels, internalFormat) {
                var heap = heapObjectForWebGLType(type);
                var shift = heapAccessShiftForWebGLHeap(heap);
                var byteSize = 1 << shift;
                var sizePerPixel = __colorChannelsInGlTextureFormat(format) * byteSize;
                var bytes = computeUnpackAlignedImageSize(width, height, sizePerPixel, GL.unpackAlignment);
                return heap.subarray(pixels >> shift, pixels + bytes >> shift)
            }
            Module["emscriptenWebGLGetTexPixelData"] = emscriptenWebGLGetTexPixelData;

            function _emscripten_glReadPixels(x, y, width, height, format, type, pixels) {
                var pixelData = emscriptenWebGLGetTexPixelData(type, format, width, height, pixels, format);
                if (!pixelData) {
                    GL.recordError(1280);
                    return
                }
                GLctx.readPixels(x, y, width, height, format, type, pixelData)
            }
            Module["_emscripten_glReadPixels"] = _emscripten_glReadPixels;
            _emscripten_glReadPixels.sig = "viiiiiii";

            function _emscripten_glReleaseShaderCompiler() {}
            Module["_emscripten_glReleaseShaderCompiler"] = _emscripten_glReleaseShaderCompiler;
            _emscripten_glReleaseShaderCompiler.sig = "v";

            function _emscripten_glRenderbufferStorage(x0, x1, x2, x3) {
                GLctx["renderbufferStorage"](x0, x1, x2, x3)
            }
            Module["_emscripten_glRenderbufferStorage"] = _emscripten_glRenderbufferStorage;
            _emscripten_glRenderbufferStorage.sig = "viiii";

            function _emscripten_glSampleCoverage(value, invert) {
                GLctx.sampleCoverage(value, !!invert)
            }
            Module["_emscripten_glSampleCoverage"] = _emscripten_glSampleCoverage;
            _emscripten_glSampleCoverage.sig = "vii";

            function _emscripten_glScissor(x0, x1, x2, x3) {
                GLctx["scissor"](x0, x1, x2, x3)
            }
            Module["_emscripten_glScissor"] = _emscripten_glScissor;
            _emscripten_glScissor.sig = "viiii";

            function _emscripten_glShaderBinary() {
                GL.recordError(1280)
            }
            Module["_emscripten_glShaderBinary"] = _emscripten_glShaderBinary;
            _emscripten_glShaderBinary.sig = "v";

            function _emscripten_glShaderSource(shader, count, string, length) {
                var source = GL.getSource(shader, count, string, length);
                GLctx.shaderSource(GL.shaders[shader], source)
            }
            Module["_emscripten_glShaderSource"] = _emscripten_glShaderSource;
            _emscripten_glShaderSource.sig = "viiii";

            function _emscripten_glStencilFunc(x0, x1, x2) {
                GLctx["stencilFunc"](x0, x1, x2)
            }
            Module["_emscripten_glStencilFunc"] = _emscripten_glStencilFunc;
            _emscripten_glStencilFunc.sig = "viii";

            function _emscripten_glStencilFuncSeparate(x0, x1, x2, x3) {
                GLctx["stencilFuncSeparate"](x0, x1, x2, x3)
            }
            Module["_emscripten_glStencilFuncSeparate"] = _emscripten_glStencilFuncSeparate;
            _emscripten_glStencilFuncSeparate.sig = "viiii";

            function _emscripten_glStencilMask(x0) {
                GLctx["stencilMask"](x0)
            }
            Module["_emscripten_glStencilMask"] = _emscripten_glStencilMask;
            _emscripten_glStencilMask.sig = "vi";

            function _emscripten_glStencilMaskSeparate(x0, x1) {
                GLctx["stencilMaskSeparate"](x0, x1)
            }
            Module["_emscripten_glStencilMaskSeparate"] = _emscripten_glStencilMaskSeparate;
            _emscripten_glStencilMaskSeparate.sig = "vii";

            function _emscripten_glStencilOp(x0, x1, x2) {
                GLctx["stencilOp"](x0, x1, x2)
            }
            Module["_emscripten_glStencilOp"] = _emscripten_glStencilOp;
            _emscripten_glStencilOp.sig = "viii";

            function _emscripten_glStencilOpSeparate(x0, x1, x2, x3) {
                GLctx["stencilOpSeparate"](x0, x1, x2, x3)
            }
            Module["_emscripten_glStencilOpSeparate"] = _emscripten_glStencilOpSeparate;
            _emscripten_glStencilOpSeparate.sig = "viiii";

            function _emscripten_glTexImage2D(target, level, internalFormat, width, height, border, format, type, pixels) {
                GLctx.texImage2D(target, level, internalFormat, width, height, border, format, type, pixels ? emscriptenWebGLGetTexPixelData(type, format, width, height, pixels, internalFormat) : null)
            }
            Module["_emscripten_glTexImage2D"] = _emscripten_glTexImage2D;
            _emscripten_glTexImage2D.sig = "viiiiiiiii";

            function _emscripten_glTexParameterf(x0, x1, x2) {
                GLctx["texParameterf"](x0, x1, x2)
            }
            Module["_emscripten_glTexParameterf"] = _emscripten_glTexParameterf;
            _emscripten_glTexParameterf.sig = "viii";

            function _emscripten_glTexParameterfv(target, pname, params) {
                var param = HEAPF32[params >> 2];
                GLctx.texParameterf(target, pname, param)
            }
            Module["_emscripten_glTexParameterfv"] = _emscripten_glTexParameterfv;
            _emscripten_glTexParameterfv.sig = "viii";

            function _emscripten_glTexParameteri(x0, x1, x2) {
                GLctx["texParameteri"](x0, x1, x2)
            }
            Module["_emscripten_glTexParameteri"] = _emscripten_glTexParameteri;
            _emscripten_glTexParameteri.sig = "viii";

            function _emscripten_glTexParameteriv(target, pname, params) {
                var param = HEAP32[params >> 2];
                GLctx.texParameteri(target, pname, param)
            }
            Module["_emscripten_glTexParameteriv"] = _emscripten_glTexParameteriv;
            _emscripten_glTexParameteriv.sig = "viii";

            function _emscripten_glTexSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels) {
                var pixelData = null;
                if (pixels) pixelData = emscriptenWebGLGetTexPixelData(type, format, width, height, pixels, 0);
                GLctx.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixelData)
            }
            Module["_emscripten_glTexSubImage2D"] = _emscripten_glTexSubImage2D;
            _emscripten_glTexSubImage2D.sig = "viiiiiiiii";

            function webglGetUniformLocation(location) {
                var p = GLctx.currentProgram;
                if (p) {
                    var webglLoc = p.uniformLocsById[location];
                    if (webglLoc >= 0) {
                        p.uniformLocsById[location] = webglLoc = GLctx.getUniformLocation(p, p.uniformArrayNamesById[location] + (webglLoc > 0 ? "[" + webglLoc + "]" : ""))
                    }
                    return webglLoc
                } else {
                    GL.recordError(1282)
                }
            }
            Module["webglGetUniformLocation"] = webglGetUniformLocation;

            function _emscripten_glUniform1f(location, v0) {
                GLctx.uniform1f(webglGetUniformLocation(location), v0)
            }
            Module["_emscripten_glUniform1f"] = _emscripten_glUniform1f;
            _emscripten_glUniform1f.sig = "vif";
            var miniTempWebGLFloatBuffers = [];
            Module["miniTempWebGLFloatBuffers"] = miniTempWebGLFloatBuffers;

            function _emscripten_glUniform1fv(location, count, value) {
                if (count <= 288) {
                    var view = miniTempWebGLFloatBuffers[count - 1];
                    for (var i = 0; i < count; ++i) {
                        view[i] = HEAPF32[value + 4 * i >> 2]
                    }
                } else {
                    var view = HEAPF32.subarray(value >> 2, value + count * 4 >> 2)
                }
                GLctx.uniform1fv(webglGetUniformLocation(location), view)
            }
            Module["_emscripten_glUniform1fv"] = _emscripten_glUniform1fv;
            _emscripten_glUniform1fv.sig = "viii";

            function _emscripten_glUniform1i(location, v0) {
                GLctx.uniform1i(webglGetUniformLocation(location), v0)
            }
            Module["_emscripten_glUniform1i"] = _emscripten_glUniform1i;
            _emscripten_glUniform1i.sig = "vii";
            var __miniTempWebGLIntBuffers = [];
            Module["__miniTempWebGLIntBuffers"] = __miniTempWebGLIntBuffers;

            function _emscripten_glUniform1iv(location, count, value) {
                if (count <= 288) {
                    var view = __miniTempWebGLIntBuffers[count - 1];
                    for (var i = 0; i < count; ++i) {
                        view[i] = HEAP32[value + 4 * i >> 2]
                    }
                } else {
                    var view = HEAP32.subarray(value >> 2, value + count * 4 >> 2)
                }
                GLctx.uniform1iv(webglGetUniformLocation(location), view)
            }
            Module["_emscripten_glUniform1iv"] = _emscripten_glUniform1iv;
            _emscripten_glUniform1iv.sig = "viii";

            function _emscripten_glUniform2f(location, v0, v1) {
                GLctx.uniform2f(webglGetUniformLocation(location), v0, v1)
            }
            Module["_emscripten_glUniform2f"] = _emscripten_glUniform2f;
            _emscripten_glUniform2f.sig = "viff";

            function _emscripten_glUniform2fv(location, count, value) {
                if (count <= 144) {
                    var view = miniTempWebGLFloatBuffers[2 * count - 1];
                    for (var i = 0; i < 2 * count; i += 2) {
                        view[i] = HEAPF32[value + 4 * i >> 2];
                        view[i + 1] = HEAPF32[value + (4 * i + 4) >> 2]
                    }
                } else {
                    var view = HEAPF32.subarray(value >> 2, value + count * 8 >> 2)
                }
                GLctx.uniform2fv(webglGetUniformLocation(location), view)
            }
            Module["_emscripten_glUniform2fv"] = _emscripten_glUniform2fv;
            _emscripten_glUniform2fv.sig = "viii";

            function _emscripten_glUniform2i(location, v0, v1) {
                GLctx.uniform2i(webglGetUniformLocation(location), v0, v1)
            }
            Module["_emscripten_glUniform2i"] = _emscripten_glUniform2i;
            _emscripten_glUniform2i.sig = "viii";

            function _emscripten_glUniform2iv(location, count, value) {
                if (count <= 144) {
                    var view = __miniTempWebGLIntBuffers[2 * count - 1];
                    for (var i = 0; i < 2 * count; i += 2) {
                        view[i] = HEAP32[value + 4 * i >> 2];
                        view[i + 1] = HEAP32[value + (4 * i + 4) >> 2]
                    }
                } else {
                    var view = HEAP32.subarray(value >> 2, value + count * 8 >> 2)
                }
                GLctx.uniform2iv(webglGetUniformLocation(location), view)
            }
            Module["_emscripten_glUniform2iv"] = _emscripten_glUniform2iv;
            _emscripten_glUniform2iv.sig = "viii";

            function _emscripten_glUniform3f(location, v0, v1, v2) {
                GLctx.uniform3f(webglGetUniformLocation(location), v0, v1, v2)
            }
            Module["_emscripten_glUniform3f"] = _emscripten_glUniform3f;
            _emscripten_glUniform3f.sig = "vifff";

            function _emscripten_glUniform3fv(location, count, value) {
                if (count <= 96) {
                    var view = miniTempWebGLFloatBuffers[3 * count - 1];
                    for (var i = 0; i < 3 * count; i += 3) {
                        view[i] = HEAPF32[value + 4 * i >> 2];
                        view[i + 1] = HEAPF32[value + (4 * i + 4) >> 2];
                        view[i + 2] = HEAPF32[value + (4 * i + 8) >> 2]
                    }
                } else {
                    var view = HEAPF32.subarray(value >> 2, value + count * 12 >> 2)
                }
                GLctx.uniform3fv(webglGetUniformLocation(location), view)
            }
            Module["_emscripten_glUniform3fv"] = _emscripten_glUniform3fv;
            _emscripten_glUniform3fv.sig = "viii";

            function _emscripten_glUniform3i(location, v0, v1, v2) {
                GLctx.uniform3i(webglGetUniformLocation(location), v0, v1, v2)
            }
            Module["_emscripten_glUniform3i"] = _emscripten_glUniform3i;
            _emscripten_glUniform3i.sig = "viiii";

            function _emscripten_glUniform3iv(location, count, value) {
                if (count <= 96) {
                    var view = __miniTempWebGLIntBuffers[3 * count - 1];
                    for (var i = 0; i < 3 * count; i += 3) {
                        view[i] = HEAP32[value + 4 * i >> 2];
                        view[i + 1] = HEAP32[value + (4 * i + 4) >> 2];
                        view[i + 2] = HEAP32[value + (4 * i + 8) >> 2]
                    }
                } else {
                    var view = HEAP32.subarray(value >> 2, value + count * 12 >> 2)
                }
                GLctx.uniform3iv(webglGetUniformLocation(location), view)
            }
            Module["_emscripten_glUniform3iv"] = _emscripten_glUniform3iv;
            _emscripten_glUniform3iv.sig = "viii";

            function _emscripten_glUniform4f(location, v0, v1, v2, v3) {
                GLctx.uniform4f(webglGetUniformLocation(location), v0, v1, v2, v3)
            }
            Module["_emscripten_glUniform4f"] = _emscripten_glUniform4f;
            _emscripten_glUniform4f.sig = "viffff";

            function _emscripten_glUniform4fv(location, count, value) {
                if (count <= 72) {
                    var view = miniTempWebGLFloatBuffers[4 * count - 1];
                    var heap = HEAPF32;
                    value >>= 2;
                    for (var i = 0; i < 4 * count; i += 4) {
                        var dst = value + i;
                        view[i] = heap[dst];
                        view[i + 1] = heap[dst + 1];
                        view[i + 2] = heap[dst + 2];
                        view[i + 3] = heap[dst + 3]
                    }
                } else {
                    var view = HEAPF32.subarray(value >> 2, value + count * 16 >> 2)
                }
                GLctx.uniform4fv(webglGetUniformLocation(location), view)
            }
            Module["_emscripten_glUniform4fv"] = _emscripten_glUniform4fv;
            _emscripten_glUniform4fv.sig = "viii";

            function _emscripten_glUniform4i(location, v0, v1, v2, v3) {
                GLctx.uniform4i(webglGetUniformLocation(location), v0, v1, v2, v3)
            }
            Module["_emscripten_glUniform4i"] = _emscripten_glUniform4i;
            _emscripten_glUniform4i.sig = "viiiii";

            function _emscripten_glUniform4iv(location, count, value) {
                if (count <= 72) {
                    var view = __miniTempWebGLIntBuffers[4 * count - 1];
                    for (var i = 0; i < 4 * count; i += 4) {
                        view[i] = HEAP32[value + 4 * i >> 2];
                        view[i + 1] = HEAP32[value + (4 * i + 4) >> 2];
                        view[i + 2] = HEAP32[value + (4 * i + 8) >> 2];
                        view[i + 3] = HEAP32[value + (4 * i + 12) >> 2]
                    }
                } else {
                    var view = HEAP32.subarray(value >> 2, value + count * 16 >> 2)
                }
                GLctx.uniform4iv(webglGetUniformLocation(location), view)
            }
            Module["_emscripten_glUniform4iv"] = _emscripten_glUniform4iv;
            _emscripten_glUniform4iv.sig = "viii";

            function _emscripten_glUniformMatrix2fv(location, count, transpose, value) {
                if (count <= 72) {
                    var view = miniTempWebGLFloatBuffers[4 * count - 1];
                    for (var i = 0; i < 4 * count; i += 4) {
                        view[i] = HEAPF32[value + 4 * i >> 2];
                        view[i + 1] = HEAPF32[value + (4 * i + 4) >> 2];
                        view[i + 2] = HEAPF32[value + (4 * i + 8) >> 2];
                        view[i + 3] = HEAPF32[value + (4 * i + 12) >> 2]
                    }
                } else {
                    var view = HEAPF32.subarray(value >> 2, value + count * 16 >> 2)
                }
                GLctx.uniformMatrix2fv(webglGetUniformLocation(location), !!transpose, view)
            }
            Module["_emscripten_glUniformMatrix2fv"] = _emscripten_glUniformMatrix2fv;
            _emscripten_glUniformMatrix2fv.sig = "viiii";

            function _emscripten_glUniformMatrix3fv(location, count, transpose, value) {
                if (count <= 32) {
                    var view = miniTempWebGLFloatBuffers[9 * count - 1];
                    for (var i = 0; i < 9 * count; i += 9) {
                        view[i] = HEAPF32[value + 4 * i >> 2];
                        view[i + 1] = HEAPF32[value + (4 * i + 4) >> 2];
                        view[i + 2] = HEAPF32[value + (4 * i + 8) >> 2];
                        view[i + 3] = HEAPF32[value + (4 * i + 12) >> 2];
                        view[i + 4] = HEAPF32[value + (4 * i + 16) >> 2];
                        view[i + 5] = HEAPF32[value + (4 * i + 20) >> 2];
                        view[i + 6] = HEAPF32[value + (4 * i + 24) >> 2];
                        view[i + 7] = HEAPF32[value + (4 * i + 28) >> 2];
                        view[i + 8] = HEAPF32[value + (4 * i + 32) >> 2]
                    }
                } else {
                    var view = HEAPF32.subarray(value >> 2, value + count * 36 >> 2)
                }
                GLctx.uniformMatrix3fv(webglGetUniformLocation(location), !!transpose, view)
            }
            Module["_emscripten_glUniformMatrix3fv"] = _emscripten_glUniformMatrix3fv;
            _emscripten_glUniformMatrix3fv.sig = "viiii";

            function _emscripten_glUniformMatrix4fv(location, count, transpose, value) {
                if (count <= 18) {
                    var view = miniTempWebGLFloatBuffers[16 * count - 1];
                    var heap = HEAPF32;
                    value >>= 2;
                    for (var i = 0; i < 16 * count; i += 16) {
                        var dst = value + i;
                        view[i] = heap[dst];
                        view[i + 1] = heap[dst + 1];
                        view[i + 2] = heap[dst + 2];
                        view[i + 3] = heap[dst + 3];
                        view[i + 4] = heap[dst + 4];
                        view[i + 5] = heap[dst + 5];
                        view[i + 6] = heap[dst + 6];
                        view[i + 7] = heap[dst + 7];
                        view[i + 8] = heap[dst + 8];
                        view[i + 9] = heap[dst + 9];
                        view[i + 10] = heap[dst + 10];
                        view[i + 11] = heap[dst + 11];
                        view[i + 12] = heap[dst + 12];
                        view[i + 13] = heap[dst + 13];
                        view[i + 14] = heap[dst + 14];
                        view[i + 15] = heap[dst + 15]
                    }
                } else {
                    var view = HEAPF32.subarray(value >> 2, value + count * 64 >> 2)
                }
                GLctx.uniformMatrix4fv(webglGetUniformLocation(location), !!transpose, view)
            }
            Module["_emscripten_glUniformMatrix4fv"] = _emscripten_glUniformMatrix4fv;
            _emscripten_glUniformMatrix4fv.sig = "viiii";

            function _emscripten_glUseProgram(program) {
                program = GL.programs[program];
                GLctx.useProgram(program);
                GLctx.currentProgram = program
            }
            Module["_emscripten_glUseProgram"] = _emscripten_glUseProgram;
            _emscripten_glUseProgram.sig = "vi";

            function _emscripten_glValidateProgram(program) {
                GLctx.validateProgram(GL.programs[program])
            }
            Module["_emscripten_glValidateProgram"] = _emscripten_glValidateProgram;
            _emscripten_glValidateProgram.sig = "vi";

            function _emscripten_glVertexAttrib1f(x0, x1) {
                GLctx["vertexAttrib1f"](x0, x1)
            }
            Module["_emscripten_glVertexAttrib1f"] = _emscripten_glVertexAttrib1f;
            _emscripten_glVertexAttrib1f.sig = "vii";

            function _emscripten_glVertexAttrib1fv(index, v) {
                GLctx.vertexAttrib1f(index, HEAPF32[v >> 2])
            }
            Module["_emscripten_glVertexAttrib1fv"] = _emscripten_glVertexAttrib1fv;
            _emscripten_glVertexAttrib1fv.sig = "vii";

            function _emscripten_glVertexAttrib2f(x0, x1, x2) {
                GLctx["vertexAttrib2f"](x0, x1, x2)
            }
            Module["_emscripten_glVertexAttrib2f"] = _emscripten_glVertexAttrib2f;
            _emscripten_glVertexAttrib2f.sig = "viii";

            function _emscripten_glVertexAttrib2fv(index, v) {
                GLctx.vertexAttrib2f(index, HEAPF32[v >> 2], HEAPF32[v + 4 >> 2])
            }
            Module["_emscripten_glVertexAttrib2fv"] = _emscripten_glVertexAttrib2fv;
            _emscripten_glVertexAttrib2fv.sig = "vii";

            function _emscripten_glVertexAttrib3f(x0, x1, x2, x3) {
                GLctx["vertexAttrib3f"](x0, x1, x2, x3)
            }
            Module["_emscripten_glVertexAttrib3f"] = _emscripten_glVertexAttrib3f;
            _emscripten_glVertexAttrib3f.sig = "viiii";

            function _emscripten_glVertexAttrib3fv(index, v) {
                GLctx.vertexAttrib3f(index, HEAPF32[v >> 2], HEAPF32[v + 4 >> 2], HEAPF32[v + 8 >> 2])
            }
            Module["_emscripten_glVertexAttrib3fv"] = _emscripten_glVertexAttrib3fv;
            _emscripten_glVertexAttrib3fv.sig = "vii";

            function _emscripten_glVertexAttrib4f(x0, x1, x2, x3, x4) {
                GLctx["vertexAttrib4f"](x0, x1, x2, x3, x4)
            }
            Module["_emscripten_glVertexAttrib4f"] = _emscripten_glVertexAttrib4f;
            _emscripten_glVertexAttrib4f.sig = "viiiii";

            function _emscripten_glVertexAttrib4fv(index, v) {
                GLctx.vertexAttrib4f(index, HEAPF32[v >> 2], HEAPF32[v + 4 >> 2], HEAPF32[v + 8 >> 2], HEAPF32[v + 12 >> 2])
            }
            Module["_emscripten_glVertexAttrib4fv"] = _emscripten_glVertexAttrib4fv;
            _emscripten_glVertexAttrib4fv.sig = "vii";

            function _emscripten_glVertexAttribDivisorANGLE(index, divisor) {
                GLctx["vertexAttribDivisor"](index, divisor)
            }
            Module["_emscripten_glVertexAttribDivisorANGLE"] = _emscripten_glVertexAttribDivisorANGLE;
            _emscripten_glVertexAttribDivisorANGLE.sig = "vii";

            function _emscripten_glVertexAttribPointer(index, size, type, normalized, stride, ptr) {
                GLctx.vertexAttribPointer(index, size, type, !!normalized, stride, ptr)
            }
            Module["_emscripten_glVertexAttribPointer"] = _emscripten_glVertexAttribPointer;
            _emscripten_glVertexAttribPointer.sig = "viiiiii";

            function _emscripten_glViewport(x0, x1, x2, x3) {
                GLctx["viewport"](x0, x1, x2, x3)
            }
            Module["_emscripten_glViewport"] = _emscripten_glViewport;
            _emscripten_glViewport.sig = "viiii";

            function _emscripten_memcpy_big(dest, src, num) {
                HEAPU8.copyWithin(dest, src, src + num)
            }
            Module["_emscripten_memcpy_big"] = _emscripten_memcpy_big;

            function abortOnCannotGrowMemory(requestedSize) {
                abort("OOM")
            }
            Module["abortOnCannotGrowMemory"] = abortOnCannotGrowMemory;

            function _emscripten_resize_heap(requestedSize) {
                var oldSize = HEAPU8.length;
                requestedSize = requestedSize >>> 0;
                abortOnCannotGrowMemory(requestedSize)
            }
            Module["_emscripten_resize_heap"] = _emscripten_resize_heap;

            function _emscripten_thread_sleep(msecs) {
                var start = _emscripten_get_now();
                while (_emscripten_get_now() - start < msecs) {}
            }
            Module["_emscripten_thread_sleep"] = _emscripten_thread_sleep;
            var ENV = {};
            Module["ENV"] = ENV;

            function getExecutableName() {
                return thisProgram || "./this.program"
            }
            Module["getExecutableName"] = getExecutableName;

            function getEnvStrings() {
                if (!getEnvStrings.strings) {
                    var lang = (typeof navigator === "object" && navigator.languages && navigator.languages[0] || "C").replace("-", "_") + ".UTF-8";
                    var env = {
                        "USER": "web_user",
                        "LOGNAME": "web_user",
                        "PATH": "/",
                        "PWD": "/",
                        "HOME": "/home/web_user",
                        "LANG": lang,
                        "_": getExecutableName()
                    };
                    for (var x in ENV) {
                        env[x] = ENV[x]
                    }
                    var strings = [];
                    for (var x in env) {
                        strings.push(x + "=" + env[x])
                    }
                    getEnvStrings.strings = strings
                }
                return getEnvStrings.strings
            }
            Module["getEnvStrings"] = getEnvStrings;

            function _environ_get(__environ, environ_buf) {
                try {
                    var bufSize = 0;
                    getEnvStrings().forEach(function(string, i) {
                        var ptr = environ_buf + bufSize;
                        HEAP32[__environ + i * 4 >> 2] = ptr;
                        writeAsciiToMemory(string, ptr);
                        bufSize += string.length + 1
                    });
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return e.errno
                }
            }
            Module["_environ_get"] = _environ_get;
            _environ_get.sig = "iii";

            function _environ_sizes_get(penviron_count, penviron_buf_size) {
                try {
                    var strings = getEnvStrings();
                    HEAP32[penviron_count >> 2] = strings.length;
                    var bufSize = 0;
                    strings.forEach(function(string) {
                        bufSize += string.length + 1
                    });
                    HEAP32[penviron_buf_size >> 2] = bufSize;
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return e.errno
                }
            }
            Module["_environ_sizes_get"] = _environ_sizes_get;
            _environ_sizes_get.sig = "iii";

            function _execve(path, argv, envp) {
                setErrNo(45);
                return -1
            }
            Module["_execve"] = _execve;
            _execve.sig = "iiii";

            function _fd_close(fd) {
                try {
                    var stream = SYSCALLS.getStreamFromFD(fd);
                    FS.close(stream);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return e.errno
                }
            }
            Module["_fd_close"] = _fd_close;
            _fd_close.sig = "ii";

            function _fd_fdstat_get(fd, pbuf) {
                try {
                    var stream = SYSCALLS.getStreamFromFD(fd);
                    var type = stream.tty ? 2 : FS.isDir(stream.mode) ? 3 : FS.isLink(stream.mode) ? 7 : 4;
                    HEAP8[pbuf >> 0] = type;
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return e.errno
                }
            }
            Module["_fd_fdstat_get"] = _fd_fdstat_get;
            _fd_fdstat_get.sig = "iii";

            function _fd_pread(fd, iov, iovcnt, offset_low, offset_high, pnum) {
                try {
                    var stream = SYSCALLS.getStreamFromFD(fd);
                    var num = SYSCALLS.doReadv(stream, iov, iovcnt, offset_low);
                    HEAP32[pnum >> 2] = num;
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return e.errno
                }
            }
            Module["_fd_pread"] = _fd_pread;

            function _fd_pwrite(fd, iov, iovcnt, offset_low, offset_high, pnum) {
                try {
                    var stream = SYSCALLS.getStreamFromFD(fd);
                    var num = SYSCALLS.doWritev(stream, iov, iovcnt, offset_low);
                    HEAP32[pnum >> 2] = num;
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return e.errno
                }
            }
            Module["_fd_pwrite"] = _fd_pwrite;

            function _fd_read(fd, iov, iovcnt, pnum) {
                try {
                    var stream = SYSCALLS.getStreamFromFD(fd);
                    var num = SYSCALLS.doReadv(stream, iov, iovcnt);
                    HEAP32[pnum >> 2] = num;
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return e.errno
                }
            }
            Module["_fd_read"] = _fd_read;
            _fd_read.sig = "iiiii";

            function _fd_seek(fd, offset_low, offset_high, whence, newOffset) {
                try {
                    var stream = SYSCALLS.getStreamFromFD(fd);
                    var HIGH_OFFSET = 4294967296;
                    var offset = offset_high * HIGH_OFFSET + (offset_low >>> 0);
                    var DOUBLE_LIMIT = 9007199254740992;
                    if (offset <= -DOUBLE_LIMIT || offset >= DOUBLE_LIMIT) {
                        return -61
                    }
                    FS.llseek(stream, offset, whence);
                    tempI64 = [stream.position >>> 0, (tempDouble = stream.position, +Math.abs(tempDouble) >= 1 ? tempDouble > 0 ? (Math.min(+Math.floor(tempDouble / 4294967296), 4294967295) | 0) >>> 0 : ~~+Math.ceil((tempDouble - +(~~tempDouble >>> 0)) / 4294967296) >>> 0 : 0)], HEAP32[newOffset >> 2] = tempI64[0], HEAP32[newOffset + 4 >> 2] = tempI64[1];
                    if (stream.getdents && offset === 0 && whence === 0) stream.getdents = null;
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return e.errno
                }
            }
            Module["_fd_seek"] = _fd_seek;

            function _fd_sync(fd) {
                try {
                    var stream = SYSCALLS.getStreamFromFD(fd);
                    if (stream.stream_ops && stream.stream_ops.fsync) {
                        return -stream.stream_ops.fsync(stream)
                    }
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return e.errno
                }
            }
            Module["_fd_sync"] = _fd_sync;
            _fd_sync.sig = "ii";

            function _fd_write(fd, iov, iovcnt, pnum) {
                try {
                    var stream = SYSCALLS.getStreamFromFD(fd);
                    var num = SYSCALLS.doWritev(stream, iov, iovcnt);
                    HEAP32[pnum >> 2] = num;
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return e.errno
                }
            }
            Module["_fd_write"] = _fd_write;
            _fd_write.sig = "iiiii";

            function _fork() {
                setErrNo(52);
                return -1
            }
            Module["_fork"] = _fork;
            _fork.sig = "i";

            function _getentropy(buffer, size) {
                if (!_getentropy.randomDevice) {
                    _getentropy.randomDevice = getRandomDevice()
                }
                for (var i = 0; i < size; i++) {
                    HEAP8[buffer + i >> 0] = _getentropy.randomDevice()
                }
                return 0
            }
            Module["_getentropy"] = _getentropy;

            function _getnameinfo(sa, salen, node, nodelen, serv, servlen, flags) {
                var info = readSockaddr(sa, salen);
                if (info.errno) {
                    return -6
                }
                var port = info.port;
                var addr = info.addr;
                var overflowed = false;
                if (node && nodelen) {
                    var lookup;
                    if (flags & 1 || !(lookup = DNS.lookup_addr(addr))) {
                        if (flags & 8) {
                            return -2
                        }
                    } else {
                        addr = lookup
                    }
                    var numBytesWrittenExclNull = stringToUTF8(addr, node, nodelen);
                    if (numBytesWrittenExclNull + 1 >= nodelen) {
                        overflowed = true
                    }
                }
                if (serv && servlen) {
                    port = "" + port;
                    var numBytesWrittenExclNull = stringToUTF8(port, serv, servlen);
                    if (numBytesWrittenExclNull + 1 >= servlen) {
                        overflowed = true
                    }
                }
                if (overflowed) {
                    return -12
                }
                return 0
            }
            Module["_getnameinfo"] = _getnameinfo;

            function _pthread_cleanup_push(routine, arg) {
                __ATEXIT__.push({
                    func: routine,
                    arg: arg
                });
                _pthread_cleanup_push.level = __ATEXIT__.length
            }
            Module["_pthread_cleanup_push"] = _pthread_cleanup_push;
            _pthread_cleanup_push.sig = "vii";

            function _pthread_cleanup_pop(execute) {
                assert(_pthread_cleanup_push.level == __ATEXIT__.length, "cannot pop if something else added meanwhile!");
                var callback = __ATEXIT__.pop();
                if (execute) {
                    wasmTable.get(callback.func)(callback.arg)
                }
                _pthread_cleanup_push.level = __ATEXIT__.length
            }
            Module["_pthread_cleanup_pop"] = _pthread_cleanup_pop;
            _pthread_cleanup_pop.sig = "vi";

            function _pthread_create() {
                return 6
            }
            Module["_pthread_create"] = _pthread_create;

            function _pthread_join() {
                return 28
            }
            Module["_pthread_join"] = _pthread_join;

            function _pthread_sigmask(how, set, oldset) {
                err("pthread_sigmask() is not supported: this is a no-op.");
                return 0
            }
            Module["_pthread_sigmask"] = _pthread_sigmask;

            function _setTempRet0(val) {
                setTempRet0(val)
            }
            Module["_setTempRet0"] = _setTempRet0;
            _setTempRet0.sig = "vi";

            function _setitimer() {
                throw "setitimer() is not implemented yet"
            }
            Module["_setitimer"] = _setitimer;

            function _sigfillset(set) {
                HEAP32[set >> 2] = -1 >>> 0;
                return 0
            }
            Module["_sigfillset"] = _sigfillset;

            function __isLeapYear(year) {
                return year % 4 === 0 && (year % 100 !== 0 || year % 400 === 0)
            }
            Module["__isLeapYear"] = __isLeapYear;

            function __arraySum(array, index) {
                var sum = 0;
                for (var i = 0; i <= index; sum += array[i++]) {}
                return sum
            }
            Module["__arraySum"] = __arraySum;
            var __MONTH_DAYS_LEAP = [31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
            Module["__MONTH_DAYS_LEAP"] = __MONTH_DAYS_LEAP;
            var __MONTH_DAYS_REGULAR = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
            Module["__MONTH_DAYS_REGULAR"] = __MONTH_DAYS_REGULAR;

            function __addDays(date, days) {
                var newDate = new Date(date.getTime());
                while (days > 0) {
                    var leap = __isLeapYear(newDate.getFullYear());
                    var currentMonth = newDate.getMonth();
                    var daysInCurrentMonth = (leap ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR)[currentMonth];
                    if (days > daysInCurrentMonth - newDate.getDate()) {
                        days -= daysInCurrentMonth - newDate.getDate() + 1;
                        newDate.setDate(1);
                        if (currentMonth < 11) {
                            newDate.setMonth(currentMonth + 1)
                        } else {
                            newDate.setMonth(0);
                            newDate.setFullYear(newDate.getFullYear() + 1)
                        }
                    } else {
                        newDate.setDate(newDate.getDate() + days);
                        return newDate
                    }
                }
                return newDate
            }
            Module["__addDays"] = __addDays;

            function _strftime(s, maxsize, format, tm) {
                var tm_zone = HEAP32[tm + 40 >> 2];
                var date = {
                    tm_sec: HEAP32[tm >> 2],
                    tm_min: HEAP32[tm + 4 >> 2],
                    tm_hour: HEAP32[tm + 8 >> 2],
                    tm_mday: HEAP32[tm + 12 >> 2],
                    tm_mon: HEAP32[tm + 16 >> 2],
                    tm_year: HEAP32[tm + 20 >> 2],
                    tm_wday: HEAP32[tm + 24 >> 2],
                    tm_yday: HEAP32[tm + 28 >> 2],
                    tm_isdst: HEAP32[tm + 32 >> 2],
                    tm_gmtoff: HEAP32[tm + 36 >> 2],
                    tm_zone: tm_zone ? UTF8ToString(tm_zone) : ""
                };
                var pattern = UTF8ToString(format);
                var EXPANSION_RULES_1 = {
                    "%c": "%a %b %d %H:%M:%S %Y",
                    "%D": "%m/%d/%y",
                    "%F": "%Y-%m-%d",
                    "%h": "%b",
                    "%r": "%I:%M:%S %p",
                    "%R": "%H:%M",
                    "%T": "%H:%M:%S",
                    "%x": "%m/%d/%y",
                    "%X": "%H:%M:%S",
                    "%Ec": "%c",
                    "%EC": "%C",
                    "%Ex": "%m/%d/%y",
                    "%EX": "%H:%M:%S",
                    "%Ey": "%y",
                    "%EY": "%Y",
                    "%Od": "%d",
                    "%Oe": "%e",
                    "%OH": "%H",
                    "%OI": "%I",
                    "%Om": "%m",
                    "%OM": "%M",
                    "%OS": "%S",
                    "%Ou": "%u",
                    "%OU": "%U",
                    "%OV": "%V",
                    "%Ow": "%w",
                    "%OW": "%W",
                    "%Oy": "%y"
                };
                for (var rule in EXPANSION_RULES_1) {
                    pattern = pattern.replace(new RegExp(rule, "g"), EXPANSION_RULES_1[rule])
                }
                var WEEKDAYS = ["Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"];
                var MONTHS = ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"];

                function leadingSomething(value, digits, character) {
                    var str = typeof value === "number" ? value.toString() : value || "";
                    while (str.length < digits) {
                        str = character[0] + str
                    }
                    return str
                }

                function leadingNulls(value, digits) {
                    return leadingSomething(value, digits, "0")
                }

                function compareByDay(date1, date2) {
                    function sgn(value) {
                        return value < 0 ? -1 : value > 0 ? 1 : 0
                    }
                    var compare;
                    if ((compare = sgn(date1.getFullYear() - date2.getFullYear())) === 0) {
                        if ((compare = sgn(date1.getMonth() - date2.getMonth())) === 0) {
                            compare = sgn(date1.getDate() - date2.getDate())
                        }
                    }
                    return compare
                }

                function getFirstWeekStartDate(janFourth) {
                    switch (janFourth.getDay()) {
                        case 0:
                            return new Date(janFourth.getFullYear() - 1, 11, 29);
                        case 1:
                            return janFourth;
                        case 2:
                            return new Date(janFourth.getFullYear(), 0, 3);
                        case 3:
                            return new Date(janFourth.getFullYear(), 0, 2);
                        case 4:
                            return new Date(janFourth.getFullYear(), 0, 1);
                        case 5:
                            return new Date(janFourth.getFullYear() - 1, 11, 31);
                        case 6:
                            return new Date(janFourth.getFullYear() - 1, 11, 30)
                    }
                }

                function getWeekBasedYear(date) {
                    var thisDate = __addDays(new Date(date.tm_year + 1900, 0, 1), date.tm_yday);
                    var janFourthThisYear = new Date(thisDate.getFullYear(), 0, 4);
                    var janFourthNextYear = new Date(thisDate.getFullYear() + 1, 0, 4);
                    var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
                    var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
                    if (compareByDay(firstWeekStartThisYear, thisDate) <= 0) {
                        if (compareByDay(firstWeekStartNextYear, thisDate) <= 0) {
                            return thisDate.getFullYear() + 1
                        } else {
                            return thisDate.getFullYear()
                        }
                    } else {
                        return thisDate.getFullYear() - 1
                    }
                }
                var EXPANSION_RULES_2 = {
                    "%a": function(date) {
                        return WEEKDAYS[date.tm_wday].substring(0, 3)
                    },
                    "%A": function(date) {
                        return WEEKDAYS[date.tm_wday]
                    },
                    "%b": function(date) {
                        return MONTHS[date.tm_mon].substring(0, 3)
                    },
                    "%B": function(date) {
                        return MONTHS[date.tm_mon]
                    },
                    "%C": function(date) {
                        var year = date.tm_year + 1900;
                        return leadingNulls(year / 100 | 0, 2)
                    },
                    "%d": function(date) {
                        return leadingNulls(date.tm_mday, 2)
                    },
                    "%e": function(date) {
                        return leadingSomething(date.tm_mday, 2, " ")
                    },
                    "%g": function(date) {
                        return getWeekBasedYear(date).toString().substring(2)
                    },
                    "%G": function(date) {
                        return getWeekBasedYear(date)
                    },
                    "%H": function(date) {
                        return leadingNulls(date.tm_hour, 2)
                    },
                    "%I": function(date) {
                        var twelveHour = date.tm_hour;
                        if (twelveHour == 0) twelveHour = 12;
                        else if (twelveHour > 12) twelveHour -= 12;
                        return leadingNulls(twelveHour, 2)
                    },
                    "%j": function(date) {
                        return leadingNulls(date.tm_mday + __arraySum(__isLeapYear(date.tm_year + 1900) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, date.tm_mon - 1), 3)
                    },
                    "%m": function(date) {
                        return leadingNulls(date.tm_mon + 1, 2)
                    },
                    "%M": function(date) {
                        return leadingNulls(date.tm_min, 2)
                    },
                    "%n": function() {
                        return "\n"
                    },
                    "%p": function(date) {
                        if (date.tm_hour >= 0 && date.tm_hour < 12) {
                            return "AM"
                        } else {
                            return "PM"
                        }
                    },
                    "%S": function(date) {
                        return leadingNulls(date.tm_sec, 2)
                    },
                    "%t": function() {
                        return "\t"
                    },
                    "%u": function(date) {
                        return date.tm_wday || 7
                    },
                    "%U": function(date) {
                        var janFirst = new Date(date.tm_year + 1900, 0, 1);
                        var firstSunday = janFirst.getDay() === 0 ? janFirst : __addDays(janFirst, 7 - janFirst.getDay());
                        var endDate = new Date(date.tm_year + 1900, date.tm_mon, date.tm_mday);
                        if (compareByDay(firstSunday, endDate) < 0) {
                            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth() - 1) - 31;
                            var firstSundayUntilEndJanuary = 31 - firstSunday.getDate();
                            var days = firstSundayUntilEndJanuary + februaryFirstUntilEndMonth + endDate.getDate();
                            return leadingNulls(Math.ceil(days / 7), 2)
                        }
                        return compareByDay(firstSunday, janFirst) === 0 ? "01" : "00"
                    },
                    "%V": function(date) {
                        var janFourthThisYear = new Date(date.tm_year + 1900, 0, 4);
                        var janFourthNextYear = new Date(date.tm_year + 1901, 0, 4);
                        var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
                        var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
                        var endDate = __addDays(new Date(date.tm_year + 1900, 0, 1), date.tm_yday);
                        if (compareByDay(endDate, firstWeekStartThisYear) < 0) {
                            return "53"
                        }
                        if (compareByDay(firstWeekStartNextYear, endDate) <= 0) {
                            return "01"
                        }
                        var daysDifference;
                        if (firstWeekStartThisYear.getFullYear() < date.tm_year + 1900) {
                            daysDifference = date.tm_yday + 32 - firstWeekStartThisYear.getDate()
                        } else {
                            daysDifference = date.tm_yday + 1 - firstWeekStartThisYear.getDate()
                        }
                        return leadingNulls(Math.ceil(daysDifference / 7), 2)
                    },
                    "%w": function(date) {
                        return date.tm_wday
                    },
                    "%W": function(date) {
                        var janFirst = new Date(date.tm_year, 0, 1);
                        var firstMonday = janFirst.getDay() === 1 ? janFirst : __addDays(janFirst, janFirst.getDay() === 0 ? 1 : 7 - janFirst.getDay() + 1);
                        var endDate = new Date(date.tm_year + 1900, date.tm_mon, date.tm_mday);
                        if (compareByDay(firstMonday, endDate) < 0) {
                            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth() - 1) - 31;
                            var firstMondayUntilEndJanuary = 31 - firstMonday.getDate();
                            var days = firstMondayUntilEndJanuary + februaryFirstUntilEndMonth + endDate.getDate();
                            return leadingNulls(Math.ceil(days / 7), 2)
                        }
                        return compareByDay(firstMonday, janFirst) === 0 ? "01" : "00"
                    },
                    "%y": function(date) {
                        return (date.tm_year + 1900).toString().substring(2)
                    },
                    "%Y": function(date) {
                        return date.tm_year + 1900
                    },
                    "%z": function(date) {
                        var off = date.tm_gmtoff;
                        var ahead = off >= 0;
                        off = Math.abs(off) / 60;
                        off = off / 60 * 100 + off % 60;
                        return (ahead ? "+" : "-") + String("0000" + off).slice(-4)
                    },
                    "%Z": function(date) {
                        return date.tm_zone
                    },
                    "%%": function() {
                        return "%"
                    }
                };
                for (var rule in EXPANSION_RULES_2) {
                    if (pattern.includes(rule)) {
                        pattern = pattern.replace(new RegExp(rule, "g"), EXPANSION_RULES_2[rule](date))
                    }
                }
                var bytes = intArrayFromString(pattern, false);
                if (bytes.length > maxsize) {
                    return 0
                }
                writeArrayToMemory(bytes, s);
                return bytes.length - 1
            }
            Module["_strftime"] = _strftime;
            _strftime.sig = "iiiii";

            function _strftime_l(s, maxsize, format, tm) {
                return _strftime(s, maxsize, format, tm)
            }
            Module["_strftime_l"] = _strftime_l;

            function _time(ptr) {
                var ret = Date.now() / 1e3 | 0;
                if (ptr) {
                    HEAP32[ptr >> 2] = ret
                }
                return ret
            }
            Module["_time"] = _time;
            _time.sig = "ii";
            var ___memory_base = 1024;
            Module["___memory_base"] = ___memory_base;
            var ___table_base = 1;
            Module["___table_base"] = ___table_base;

            function _getTempRet0() {
                return getTempRet0()
            }
            Module["_getTempRet0"] = _getTempRet0;
            _getTempRet0.sig = "i";

            function setFileTime(path, time) {
                path = UTF8ToString(path);
                try {
                    FS.utime(path, time, time);
                    return 0
                } catch (e) {
                    if (!(e instanceof FS.ErrnoError)) throw e + " : " + stackTrace();
                    setErrNo(e.errno);
                    return -1
                }
            }
            Module["setFileTime"] = setFileTime;

            function _utime(path, times) {
                var time;
                if (times) {
                    time = HEAP32[times + 4 >> 2] * 1e3
                } else {
                    time = Date.now()
                }
                return setFileTime(path, time)
            }
            Module["_utime"] = _utime;
            _utime.sig = "iii";

            function _utimes(path, times) {
                var time;
                if (times) {
                    var mtime = times + 8;
                    time = HEAP32[mtime >> 2] * 1e3;
                    time += HEAP32[mtime + 4 >> 2] / 1e3
                } else {
                    time = Date.now()
                }
                return setFileTime(path, time)
            }
            Module["_utimes"] = _utimes;
            _utimes.sig = "iii";

            function _flock(fd, operation) {
                return 0
            }
            Module["_flock"] = _flock;

            function _chroot(path) {
                setErrNo(2);
                return -1
            }
            Module["_chroot"] = _chroot;
            _chroot.sig = "ii";

            function __Exit(a0) {
                return _exit(a0)
            }
            Module["__Exit"] = __Exit;
            __Exit.sig = "vi";

            function _vfork() {
                return _fork()
            }
            Module["_vfork"] = _vfork;
            _vfork.sig = "i";

            function _posix_spawn() {
                return _fork()
            }
            Module["_posix_spawn"] = _posix_spawn;
            _posix_spawn.sig = "i";

            function _setgroups(ngroups, gidset) {
                if (ngroups < 1 || ngroups > _sysconf(3)) {
                    setErrNo(28);
                    return -1
                } else {
                    setErrNo(63);
                    return -1
                }
            }
            Module["_setgroups"] = _setgroups;

            function emscripten_realloc_buffer(size) {
                try {
                    wasmMemory.grow(size - buffer.byteLength + 65535 >>> 16);
                    updateGlobalBufferAndViews(wasmMemory.buffer);
                    return 1
                } catch (e) {}
            }
            Module["emscripten_realloc_buffer"] = emscripten_realloc_buffer;

            function _emscripten_notify_memory_growth(memoryIndex) {
                updateGlobalBufferAndViews(wasmMemory.buffer)
            }
            Module["_emscripten_notify_memory_growth"] = _emscripten_notify_memory_growth;

            function _system(command) {
                if (ENVIRONMENT_IS_NODE) {
                    if (!command) return 1;
                    var cmdstr = UTF8ToString(command);
                    if (!cmdstr.length) return 0;
                    var cp = require("child_process");
                    var ret = cp.spawnSync(cmdstr, [], {
                        shell: true,
                        stdio: "inherit"
                    });
                    var _W_EXITCODE = function(ret, sig) {
                        return ret << 8 | sig
                    };
                    if (ret.status === null) {
                        var signalToNumber = function(sig) {
                            switch (sig) {
                                case "SIGHUP":
                                    return 1;
                                case "SIGINT":
                                    return 2;
                                case "SIGQUIT":
                                    return 3;
                                case "SIGFPE":
                                    return 8;
                                case "SIGKILL":
                                    return 9;
                                case "SIGALRM":
                                    return 14;
                                case "SIGTERM":
                                    return 15
                            }
                            return 2
                        };
                        return _W_EXITCODE(0, signalToNumber(ret.signal))
                    }
                    return _W_EXITCODE(ret.status, 0)
                }
                if (!command) return 0;
                setErrNo(52);
                return -1
            }
            Module["_system"] = _system;

            function ___cxa_thread_atexit(a0, a1) {
                return _atexit(a0, a1)
            }
            Module["___cxa_thread_atexit"] = ___cxa_thread_atexit;
            ___cxa_thread_atexit.sig = "iii";

            function ___cxa_thread_atexit_impl(a0, a1) {
                return _atexit(a0, a1)
            }
            Module["___cxa_thread_atexit_impl"] = ___cxa_thread_atexit_impl;
            ___cxa_thread_atexit_impl.sig = "iii";

            function _getloadavg(loadavg, nelem) {
                var limit = Math.min(nelem, 3);
                var doubleSize = 8;
                for (var i = 0; i < limit; i++) {
                    HEAPF64[loadavg + i * doubleSize >> 3] = .1
                }
                return limit
            }
            Module["_getloadavg"] = _getloadavg;

            function ___assert_fail(condition, filename, line, func) {
                abort("Assertion failed: " + UTF8ToString(condition) + ", at: " + [filename ? UTF8ToString(filename) : "unknown filename", line, func ? UTF8ToString(func) : "unknown function"])
            }
            Module["___assert_fail"] = ___assert_fail;
            ___assert_fail.sig = "viiii";

            function _getpwuid() {
                throw "getpwuid: TODO"
            }
            Module["_getpwuid"] = _getpwuid;

            function _clock() {
                if (_clock.start === undefined) _clock.start = Date.now();
                return (Date.now() - _clock.start) * (1e6 / 1e3) | 0
            }
            Module["_clock"] = _clock;
            _clock.sig = "i";

            function _difftime(time1, time0) {
                return time1 - time0
            }
            Module["_difftime"] = _difftime;
            _difftime.sig = "dii";

            function _timelocal(a0) {
                return _mktime(a0)
            }
            Module["_timelocal"] = _timelocal;
            _timelocal.sig = "ii";

            function _timegm(tmPtr) {
                _tzset();
                var time = Date.UTC(HEAP32[tmPtr + 20 >> 2] + 1900, HEAP32[tmPtr + 16 >> 2], HEAP32[tmPtr + 12 >> 2], HEAP32[tmPtr + 8 >> 2], HEAP32[tmPtr + 4 >> 2], HEAP32[tmPtr >> 2], 0);
                var date = new Date(time);
                HEAP32[tmPtr + 24 >> 2] = date.getUTCDay();
                var start = Date.UTC(date.getUTCFullYear(), 0, 1, 0, 0, 0, 0);
                var yday = (date.getTime() - start) / (1e3 * 60 * 60 * 24) | 0;
                HEAP32[tmPtr + 28 >> 2] = yday;
                return date.getTime() / 1e3 | 0
            }
            Module["_timegm"] = _timegm;
            _timegm.sig = "ii";

            function _ctime_r(time, buf) {
                var stack = stackSave();
                var rv = ___asctime(_localtime_r(time, stackAlloc(44)), buf);
                stackRestore(stack);
                return rv
            }
            Module["_ctime_r"] = _ctime_r;
            _ctime_r.sig = "iii";

            function ___ctime_r(a0, a1) {
                return _ctime_r(a0, a1)
            }
            Module["___ctime_r"] = ___ctime_r;
            ___ctime_r.sig = "iii";

            function _dysize(year) {
                var leap = year % 4 == 0 && (year % 100 != 0 || year % 400 == 0);
                return leap ? 366 : 365
            }
            Module["_dysize"] = _dysize;

            function _stime(when) {
                setErrNo(63);
                return -1
            }
            Module["_stime"] = _stime;

            function _strptime(buf, format, tm) {
                var pattern = UTF8ToString(format);
                var SPECIAL_CHARS = "\\!@#$^&*()+=-[]/{}|:<>?,.";
                for (var i = 0, ii = SPECIAL_CHARS.length; i < ii; ++i) {
                    pattern = pattern.replace(new RegExp("\\" + SPECIAL_CHARS[i], "g"), "\\" + SPECIAL_CHARS[i])
                }
                var EQUIVALENT_MATCHERS = {
                    "%A": "%a",
                    "%B": "%b",
                    "%c": "%a %b %d %H:%M:%S %Y",
                    "%D": "%m\\/%d\\/%y",
                    "%e": "%d",
                    "%F": "%Y-%m-%d",
                    "%h": "%b",
                    "%R": "%H\\:%M",
                    "%r": "%I\\:%M\\:%S\\s%p",
                    "%T": "%H\\:%M\\:%S",
                    "%x": "%m\\/%d\\/(?:%y|%Y)",
                    "%X": "%H\\:%M\\:%S"
                };
                for (var matcher in EQUIVALENT_MATCHERS) {
                    pattern = pattern.replace(matcher, EQUIVALENT_MATCHERS[matcher])
                }
                var DATE_PATTERNS = {
                    "%a": "(?:Sun(?:day)?)|(?:Mon(?:day)?)|(?:Tue(?:sday)?)|(?:Wed(?:nesday)?)|(?:Thu(?:rsday)?)|(?:Fri(?:day)?)|(?:Sat(?:urday)?)",
                    "%b": "(?:Jan(?:uary)?)|(?:Feb(?:ruary)?)|(?:Mar(?:ch)?)|(?:Apr(?:il)?)|May|(?:Jun(?:e)?)|(?:Jul(?:y)?)|(?:Aug(?:ust)?)|(?:Sep(?:tember)?)|(?:Oct(?:ober)?)|(?:Nov(?:ember)?)|(?:Dec(?:ember)?)",
                    "%C": "\\d\\d",
                    "%d": "0[1-9]|[1-9](?!\\d)|1\\d|2\\d|30|31",
                    "%H": "\\d(?!\\d)|[0,1]\\d|20|21|22|23",
                    "%I": "\\d(?!\\d)|0\\d|10|11|12",
                    "%j": "00[1-9]|0?[1-9](?!\\d)|0?[1-9]\\d(?!\\d)|[1,2]\\d\\d|3[0-6]\\d",
                    "%m": "0[1-9]|[1-9](?!\\d)|10|11|12",
                    "%M": "0\\d|\\d(?!\\d)|[1-5]\\d",
                    "%n": "\\s",
                    "%p": "AM|am|PM|pm|A\\.M\\.|a\\.m\\.|P\\.M\\.|p\\.m\\.",
                    "%S": "0\\d|\\d(?!\\d)|[1-5]\\d|60",
                    "%U": "0\\d|\\d(?!\\d)|[1-4]\\d|50|51|52|53",
                    "%W": "0\\d|\\d(?!\\d)|[1-4]\\d|50|51|52|53",
                    "%w": "[0-6]",
                    "%y": "\\d\\d",
                    "%Y": "\\d\\d\\d\\d",
                    "%%": "%",
                    "%t": "\\s"
                };
                var MONTH_NUMBERS = {
                    JAN: 0,
                    FEB: 1,
                    MAR: 2,
                    APR: 3,
                    MAY: 4,
                    JUN: 5,
                    JUL: 6,
                    AUG: 7,
                    SEP: 8,
                    OCT: 9,
                    NOV: 10,
                    DEC: 11
                };
                var DAY_NUMBERS_SUN_FIRST = {
                    SUN: 0,
                    MON: 1,
                    TUE: 2,
                    WED: 3,
                    THU: 4,
                    FRI: 5,
                    SAT: 6
                };
                var DAY_NUMBERS_MON_FIRST = {
                    MON: 0,
                    TUE: 1,
                    WED: 2,
                    THU: 3,
                    FRI: 4,
                    SAT: 5,
                    SUN: 6
                };
                for (var datePattern in DATE_PATTERNS) {
                    pattern = pattern.replace(datePattern, "(" + datePattern + DATE_PATTERNS[datePattern] + ")")
                }
                var capture = [];
                for (var i = pattern.indexOf("%"); i >= 0; i = pattern.indexOf("%")) {
                    capture.push(pattern[i + 1]);
                    pattern = pattern.replace(new RegExp("\\%" + pattern[i + 1], "g"), "")
                }
                var matches = new RegExp("^" + pattern, "i").exec(UTF8ToString(buf));

                function initDate() {
                    function fixup(value, min, max) {
                        return typeof value !== "number" || isNaN(value) ? min : value >= min ? value <= max ? value : max : min
                    }
                    return {
                        year: fixup(HEAP32[tm + 20 >> 2] + 1900, 1970, 9999),
                        month: fixup(HEAP32[tm + 16 >> 2], 0, 11),
                        day: fixup(HEAP32[tm + 12 >> 2], 1, 31),
                        hour: fixup(HEAP32[tm + 8 >> 2], 0, 23),
                        min: fixup(HEAP32[tm + 4 >> 2], 0, 59),
                        sec: fixup(HEAP32[tm >> 2], 0, 59)
                    }
                }
                if (matches) {
                    var date = initDate();
                    var value;
                    var getMatch = function(symbol) {
                        var pos = capture.indexOf(symbol);
                        if (pos >= 0) {
                            return matches[pos + 1]
                        }
                        return
                    };
                    if (value = getMatch("S")) {
                        date.sec = jstoi_q(value)
                    }
                    if (value = getMatch("M")) {
                        date.min = jstoi_q(value)
                    }
                    if (value = getMatch("H")) {
                        date.hour = jstoi_q(value)
                    } else if (value = getMatch("I")) {
                        var hour = jstoi_q(value);
                        if (value = getMatch("p")) {
                            hour += value.toUpperCase()[0] === "P" ? 12 : 0
                        }
                        date.hour = hour
                    }
                    if (value = getMatch("Y")) {
                        date.year = jstoi_q(value)
                    } else if (value = getMatch("y")) {
                        var year = jstoi_q(value);
                        if (value = getMatch("C")) {
                            year += jstoi_q(value) * 100
                        } else {
                            year += year < 69 ? 2e3 : 1900
                        }
                        date.year = year
                    }
                    if (value = getMatch("m")) {
                        date.month = jstoi_q(value) - 1
                    } else if (value = getMatch("b")) {
                        date.month = MONTH_NUMBERS[value.substring(0, 3).toUpperCase()] || 0
                    }
                    if (value = getMatch("d")) {
                        date.day = jstoi_q(value)
                    } else if (value = getMatch("j")) {
                        var day = jstoi_q(value);
                        var leapYear = __isLeapYear(date.year);
                        for (var month = 0; month < 12; ++month) {
                            var daysUntilMonth = __arraySum(leapYear ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, month - 1);
                            if (day <= daysUntilMonth + (leapYear ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR)[month]) {
                                date.day = day - daysUntilMonth
                            }
                        }
                    } else if (value = getMatch("a")) {
                        var weekDay = value.substring(0, 3).toUpperCase();
                        if (value = getMatch("U")) {
                            var weekDayNumber = DAY_NUMBERS_SUN_FIRST[weekDay];
                            var weekNumber = jstoi_q(value);
                            var janFirst = new Date(date.year, 0, 1);
                            var endDate;
                            if (janFirst.getDay() === 0) {
                                endDate = __addDays(janFirst, weekDayNumber + 7 * (weekNumber - 1))
                            } else {
                                endDate = __addDays(janFirst, 7 - janFirst.getDay() + weekDayNumber + 7 * (weekNumber - 1))
                            }
                            date.day = endDate.getDate();
                            date.month = endDate.getMonth()
                        } else if (value = getMatch("W")) {
                            var weekDayNumber = DAY_NUMBERS_MON_FIRST[weekDay];
                            var weekNumber = jstoi_q(value);
                            var janFirst = new Date(date.year, 0, 1);
                            var endDate;
                            if (janFirst.getDay() === 1) {
                                endDate = __addDays(janFirst, weekDayNumber + 7 * (weekNumber - 1))
                            } else {
                                endDate = __addDays(janFirst, 7 - janFirst.getDay() + 1 + weekDayNumber + 7 * (weekNumber - 1))
                            }
                            date.day = endDate.getDate();
                            date.month = endDate.getMonth()
                        }
                    }
                    var fullDate = new Date(date.year, date.month, date.day, date.hour, date.min, date.sec, 0);
                    HEAP32[tm >> 2] = fullDate.getSeconds();
                    HEAP32[tm + 4 >> 2] = fullDate.getMinutes();
                    HEAP32[tm + 8 >> 2] = fullDate.getHours();
                    HEAP32[tm + 12 >> 2] = fullDate.getDate();
                    HEAP32[tm + 16 >> 2] = fullDate.getMonth();
                    HEAP32[tm + 20 >> 2] = fullDate.getFullYear() - 1900;
                    HEAP32[tm + 24 >> 2] = fullDate.getDay();
                    HEAP32[tm + 28 >> 2] = __arraySum(__isLeapYear(fullDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, fullDate.getMonth() - 1) + fullDate.getDate() - 1;
                    HEAP32[tm + 32 >> 2] = 0;
                    return buf + intArrayFromString(matches[0]).length - 1
                }
                return 0
            }
            Module["_strptime"] = _strptime;

            function _strptime_l(buf, format, tm) {
                return _strptime(buf, format, tm)
            }
            Module["_strptime_l"] = _strptime_l;

            function _getdate(string) {
                return 0
            }
            Module["_getdate"] = _getdate;

            function _timespec_get(ts, base) {
                if (base !== 1) {
                    setErrNo(28);
                    return 0
                }
                var ret = _clock_gettime(0, ts);
                return ret < 0 ? 0 : base
            }
            Module["_timespec_get"] = _timespec_get;

            function _emscripten_get_now_res() {
                if (ENVIRONMENT_IS_NODE) {
                    return 1
                } else if (typeof dateNow !== "undefined") {
                    return 1e3
                } else return 1e3
            }
            Module["_emscripten_get_now_res"] = _emscripten_get_now_res;

            function _clock_getres(clk_id, res) {
                var nsec;
                if (clk_id === 0) {
                    nsec = 1e3 * 1e3
                } else if (clk_id === 1 && _emscripten_get_now_is_monotonic) {
                    nsec = _emscripten_get_now_res()
                } else {
                    setErrNo(28);
                    return -1
                }
                HEAP32[res >> 2] = nsec / 1e9 | 0;
                HEAP32[res + 4 >> 2] = nsec;
                return 0
            }
            Module["_clock_getres"] = _clock_getres;

            function _clock_getcpuclockid(pid, clk_id) {
                if (pid < 0) return 71;
                if (pid !== 0 && pid !== 42) return 52;
                if (clk_id) HEAP32[clk_id >> 2] = 2;
                return 0
            }
            Module["_clock_getcpuclockid"] = _clock_getcpuclockid;

            function _gettimeofday(ptr) {
                var now = Date.now();
                HEAP32[ptr >> 2] = now / 1e3 | 0;
                HEAP32[ptr + 4 >> 2] = now % 1e3 * 1e3 | 0;
                return 0
            }
            Module["_gettimeofday"] = _gettimeofday;

            function _ftime(p) {
                var millis = Date.now();
                HEAP32[p >> 2] = millis / 1e3 | 0;
                HEAP16[p + 4 >> 1] = millis % 1e3;
                HEAP16[p + 6 >> 1] = 0;
                HEAP16[p + 8 >> 1] = 0;
                return 0
            }
            Module["_ftime"] = _ftime;

            function _times(buffer) {
                if (buffer !== 0) {
                    _memset(buffer, 0, 16)
                }
                return 0
            }
            Module["_times"] = _times;

            function _makedev(maj, min) {
                return maj << 8 | min
            }
            Module["_makedev"] = _makedev;
            _makedev.sig = "iii";

            function _gnu_dev_makedev(a0, a1) {
                return _makedev(a0, a1)
            }
            Module["_gnu_dev_makedev"] = _gnu_dev_makedev;
            _gnu_dev_makedev.sig = "iii";

            function _major(dev) {
                return dev >> 8
            }
            Module["_major"] = _major;
            _major.sig = "ii";

            function _gnu_dev_major(a0) {
                return _major(a0)
            }
            Module["_gnu_dev_major"] = _gnu_dev_major;
            _gnu_dev_major.sig = "ii";

            function _minor(dev) {
                return dev & 255
            }
            Module["_minor"] = _minor;
            _minor.sig = "ii";

            function _gnu_dev_minor(a0) {
                return _minor(a0)
            }
            Module["_gnu_dev_minor"] = _gnu_dev_minor;
            _gnu_dev_minor.sig = "ii";

            function _longjmp(env, value) {
                _setThrew(env, value || 1);
                throw "longjmp"
            }
            Module["_longjmp"] = _longjmp;
            _longjmp.sig = "vii";

            function _emscripten_longjmp(a0, a1) {
                return _longjmp(a0, a1)
            }
            Module["_emscripten_longjmp"] = _emscripten_longjmp;
            _emscripten_longjmp.sig = "vii";

            function _waitid(a0) {
                return _wait(a0)
            }
            Module["_waitid"] = _waitid;
            _waitid.sig = "ii";

            function _wait3(a0) {
                return _wait(a0)
            }
            Module["_wait3"] = _wait3;
            _wait3.sig = "ii";

            function _wait4(a0) {
                return _wait(a0)
            }
            Module["_wait4"] = _wait4;
            _wait4.sig = "ii";
            var ERRNO_MESSAGES = {
                0: "Success",
                1: "Arg list too long",
                2: "Permission denied",
                3: "Address already in use",
                4: "Address not available",
                5: "Address family not supported by protocol family",
                6: "No more processes",
                7: "Socket already connected",
                8: "Bad file number",
                9: "Trying to read unreadable message",
                10: "Mount device busy",
                11: "Operation canceled",
                12: "No children",
                13: "Connection aborted",
                14: "Connection refused",
                15: "Connection reset by peer",
                16: "File locking deadlock error",
                17: "Destination address required",
                18: "Math arg out of domain of func",
                19: "Quota exceeded",
                20: "File exists",
                21: "Bad address",
                22: "File too large",
                23: "Host is unreachable",
                24: "Identifier removed",
                25: "Illegal byte sequence",
                26: "Connection already in progress",
                27: "Interrupted system call",
                28: "Invalid argument",
                29: "I/O error",
                30: "Socket is already connected",
                31: "Is a directory",
                32: "Too many symbolic links",
                33: "Too many open files",
                34: "Too many links",
                35: "Message too long",
                36: "Multihop attempted",
                37: "File or path name too long",
                38: "Network interface is not configured",
                39: "Connection reset by network",
                40: "Network is unreachable",
                41: "Too many open files in system",
                42: "No buffer space available",
                43: "No such device",
                44: "No such file or directory",
                45: "Exec format error",
                46: "No record locks available",
                47: "The link has been severed",
                48: "Not enough core",
                49: "No message of desired type",
                50: "Protocol not available",
                51: "No space left on device",
                52: "Function not implemented",
                53: "Socket is not connected",
                54: "Not a directory",
                55: "Directory not empty",
                56: "State not recoverable",
                57: "Socket operation on non-socket",
                59: "Not a typewriter",
                60: "No such device or address",
                61: "Value too large for defined data type",
                62: "Previous owner died",
                63: "Not super-user",
                64: "Broken pipe",
                65: "Protocol error",
                66: "Unknown protocol",
                67: "Protocol wrong type for socket",
                68: "Math result not representable",
                69: "Read only file system",
                70: "Illegal seek",
                71: "No such process",
                72: "Stale file handle",
                73: "Connection timed out",
                74: "Text file busy",
                75: "Cross-device link",
                100: "Device not a stream",
                101: "Bad font file fmt",
                102: "Invalid slot",
                103: "Invalid request code",
                104: "No anode",
                105: "Block device required",
                106: "Channel number out of range",
                107: "Level 3 halted",
                108: "Level 3 reset",
                109: "Link number out of range",
                110: "Protocol driver not attached",
                111: "No CSI structure available",
                112: "Level 2 halted",
                113: "Invalid exchange",
                114: "Invalid request descriptor",
                115: "Exchange full",
                116: "No data (for no delay io)",
                117: "Timer expired",
                118: "Out of streams resources",
                119: "Machine is not on the network",
                120: "Package not installed",
                121: "The object is remote",
                122: "Advertise error",
                123: "Srmount error",
                124: "Communication error on send",
                125: "Cross mount point (not really error)",
                126: "Given log. name not unique",
                127: "f.d. invalid for this operation",
                128: "Remote address changed",
                129: "Can   access a needed shared lib",
                130: "Accessing a corrupted shared lib",
                131: ".lib section in a.out corrupted",
                132: "Attempting to link in too many libs",
                133: "Attempting to exec a shared library",
                135: "Streams pipe error",
                136: "Too many users",
                137: "Socket type not supported",
                138: "Not supported",
                139: "Protocol family not supported",
                140: "Can't send after socket shutdown",
                141: "Too many references",
                142: "Host is down",
                148: "No medium (in tape drive)",
                156: "Level 2 not synchronized"
            };
            Module["ERRNO_MESSAGES"] = ERRNO_MESSAGES;

            function getHostByName(name) {
                var ret = _malloc(20);
                var nameBuf = _malloc(name.length + 1);
                stringToUTF8(name, nameBuf, name.length + 1);
                HEAP32[ret >> 2] = nameBuf;
                var aliasesBuf = _malloc(4);
                HEAP32[aliasesBuf >> 2] = 0;
                HEAP32[ret + 4 >> 2] = aliasesBuf;
                var afinet = 2;
                HEAP32[ret + 8 >> 2] = afinet;
                HEAP32[ret + 12 >> 2] = 4;
                var addrListBuf = _malloc(12);
                HEAP32[addrListBuf >> 2] = addrListBuf + 8;
                HEAP32[addrListBuf + 4 >> 2] = 0;
                HEAP32[addrListBuf + 8 >> 2] = inetPton4(DNS.lookup_name(name));
                HEAP32[ret + 16 >> 2] = addrListBuf;
                return ret
            }
            Module["getHostByName"] = getHostByName;

            function _gethostbyaddr(addr, addrlen, type) {
                if (type !== 2) {
                    setErrNo(5);
                    return null
                }
                addr = HEAP32[addr >> 2];
                var host = inetNtop4(addr);
                var lookup = DNS.lookup_addr(host);
                if (lookup) {
                    host = lookup
                }
                return getHostByName(host)
            }
            Module["_gethostbyaddr"] = _gethostbyaddr;
            _gethostbyaddr.sig = "iiii";

            function _gethostbyname(name) {
                return getHostByName(UTF8ToString(name))
            }
            Module["_gethostbyname"] = _gethostbyname;
            _gethostbyname.sig = "ii";

            function _gethostbyname_r(name, ret, buf, buflen, out, err) {
                var data = _gethostbyname(name);
                _memcpy(ret, data, 20);
                _free(data);
                HEAP32[err >> 2] = 0;
                HEAP32[out >> 2] = ret;
                return 0
            }
            Module["_gethostbyname_r"] = _gethostbyname_r;
            _gethostbyname_r.sig = "iiiiiii";

            function _getaddrinfo(node, service, hint, out) {
                var addrs = [];
                var canon = null;
                var addr = 0;
                var port = 0;
                var flags = 0;
                var family = 0;
                var type = 0;
                var proto = 0;
                var ai, last;

                function allocaddrinfo(family, type, proto, canon, addr, port) {
                    var sa, salen, ai;
                    var errno;
                    salen = family === 10 ? 28 : 16;
                    addr = family === 10 ? inetNtop6(addr) : inetNtop4(addr);
                    sa = _malloc(salen);
                    errno = writeSockaddr(sa, family, addr, port);
                    assert(!errno);
                    ai = _malloc(32);
                    HEAP32[ai + 4 >> 2] = family;
                    HEAP32[ai + 8 >> 2] = type;
                    HEAP32[ai + 12 >> 2] = proto;
                    HEAP32[ai + 24 >> 2] = canon;
                    HEAP32[ai + 20 >> 2] = sa;
                    if (family === 10) {
                        HEAP32[ai + 16 >> 2] = 28
                    } else {
                        HEAP32[ai + 16 >> 2] = 16
                    }
                    HEAP32[ai + 28 >> 2] = 0;
                    return ai
                }
                if (hint) {
                    flags = HEAP32[hint >> 2];
                    family = HEAP32[hint + 4 >> 2];
                    type = HEAP32[hint + 8 >> 2];
                    proto = HEAP32[hint + 12 >> 2]
                }
                if (type && !proto) {
                    proto = type === 2 ? 17 : 6
                }
                if (!type && proto) {
                    type = proto === 17 ? 2 : 1
                }
                if (proto === 0) {
                    proto = 6
                }
                if (type === 0) {
                    type = 1
                }
                if (!node && !service) {
                    return -2
                }
                if (flags & ~(1 | 2 | 4 | 1024 | 8 | 16 | 32)) {
                    return -1
                }
                if (hint !== 0 && HEAP32[hint >> 2] & 2 && !node) {
                    return -1
                }
                if (flags & 32) {
                    return -2
                }
                if (type !== 0 && type !== 1 && type !== 2) {
                    return -7
                }
                if (family !== 0 && family !== 2 && family !== 10) {
                    return -6
                }
                if (service) {
                    service = UTF8ToString(service);
                    port = parseInt(service, 10);
                    if (isNaN(port)) {
                        if (flags & 1024) {
                            return -2
                        }
                        return -8
                    }
                }
                if (!node) {
                    if (family === 0) {
                        family = 2
                    }
                    if ((flags & 1) === 0) {
                        if (family === 2) {
                            addr = _htonl(2130706433)
                        } else {
                            addr = [0, 0, 0, 1]
                        }
                    }
                    ai = allocaddrinfo(family, type, proto, null, addr, port);
                    HEAP32[out >> 2] = ai;
                    return 0
                }
                node = UTF8ToString(node);
                addr = inetPton4(node);
                if (addr !== null) {
                    if (family === 0 || family === 2) {
                        family = 2
                    } else if (family === 10 && flags & 8) {
                        addr = [0, 0, _htonl(65535), addr];
                        family = 10
                    } else {
                        return -2
                    }
                } else {
                    addr = inetPton6(node);
                    if (addr !== null) {
                        if (family === 0 || family === 10) {
                            family = 10
                        } else {
                            return -2
                        }
                    }
                }
                if (addr != null) {
                    ai = allocaddrinfo(family, type, proto, node, addr, port);
                    HEAP32[out >> 2] = ai;
                    return 0
                }
                if (flags & 4) {
                    return -2
                }
                node = DNS.lookup_name(node);
                addr = inetPton4(node);
                if (family === 0) {
                    family = 2
                } else if (family === 10) {
                    addr = [0, 0, _htonl(65535), addr]
                }
                ai = allocaddrinfo(family, type, proto, null, addr, port);
                HEAP32[out >> 2] = ai;
                return 0
            }
            Module["_getaddrinfo"] = _getaddrinfo;
            _getaddrinfo.sig = "iiiii";
            var GAI_ERRNO_MESSAGES = {};
            Module["GAI_ERRNO_MESSAGES"] = GAI_ERRNO_MESSAGES;

            function _gai_strerror(val) {
                var buflen = 256;
                if (!_gai_strerror.buffer) {
                    _gai_strerror.buffer = _malloc(buflen);
                    GAI_ERRNO_MESSAGES["0"] = "Success";
                    GAI_ERRNO_MESSAGES["" + -1] = "Invalid value for 'ai_flags' field";
                    GAI_ERRNO_MESSAGES["" + -2] = "NAME or SERVICE is unknown";
                    GAI_ERRNO_MESSAGES["" + -3] = "Temporary failure in name resolution";
                    GAI_ERRNO_MESSAGES["" + -4] = "Non-recoverable failure in name res";
                    GAI_ERRNO_MESSAGES["" + -6] = "'ai_family' not supported";
                    GAI_ERRNO_MESSAGES["" + -7] = "'ai_socktype' not supported";
                    GAI_ERRNO_MESSAGES["" + -8] = "SERVICE not supported for 'ai_socktype'";
                    GAI_ERRNO_MESSAGES["" + -10] = "Memory allocation failure";
                    GAI_ERRNO_MESSAGES["" + -11] = "System error returned in 'errno'";
                    GAI_ERRNO_MESSAGES["" + -12] = "Argument buffer overflow"
                }
                var msg = "Unknown error";
                if (val in GAI_ERRNO_MESSAGES) {
                    if (GAI_ERRNO_MESSAGES[val].length > buflen - 1) {
                        msg = "Message too long"
                    } else {
                        msg = GAI_ERRNO_MESSAGES[val]
                    }
                }
                writeAsciiToMemory(msg, _gai_strerror.buffer);
                return _gai_strerror.buffer
            }
            Module["_gai_strerror"] = _gai_strerror;
            var Protocols = {
                list: [],
                map: {}
            };
            Module["Protocols"] = Protocols;

            function _setprotoent(stayopen) {
                function allocprotoent(name, proto, aliases) {
                    var nameBuf = _malloc(name.length + 1);
                    writeAsciiToMemory(name, nameBuf);
                    var j = 0;
                    var length = aliases.length;
                    var aliasListBuf = _malloc((length + 1) * 4);
                    for (var i = 0; i < length; i++, j += 4) {
                        var alias = aliases[i];
                        var aliasBuf = _malloc(alias.length + 1);
                        writeAsciiToMemory(alias, aliasBuf);
                        HEAP32[aliasListBuf + j >> 2] = aliasBuf
                    }
                    HEAP32[aliasListBuf + j >> 2] = 0;
                    var pe = _malloc(12);
                    HEAP32[pe >> 2] = nameBuf;
                    HEAP32[pe + 4 >> 2] = aliasListBuf;
                    HEAP32[pe + 8 >> 2] = proto;
                    return pe
                }
                var list = Protocols.list;
                var map = Protocols.map;
                if (list.length === 0) {
                    var entry = allocprotoent("tcp", 6, ["TCP"]);
                    list.push(entry);
                    map["tcp"] = map["6"] = entry;
                    entry = allocprotoent("udp", 17, ["UDP"]);
                    list.push(entry);
                    map["udp"] = map["17"] = entry
                }
                _setprotoent.index = 0
            }
            Module["_setprotoent"] = _setprotoent;

            function _endprotoent() {}
            Module["_endprotoent"] = _endprotoent;

            function _getprotoent(number) {
                if (_setprotoent.index === Protocols.list.length) {
                    return 0
                } else {
                    var result = Protocols.list[_setprotoent.index++];
                    return result
                }
            }
            Module["_getprotoent"] = _getprotoent;

            function _getprotobyname(name) {
                name = UTF8ToString(name);
                _setprotoent(true);
                var result = Protocols.map[name];
                return result
            }
            Module["_getprotobyname"] = _getprotobyname;

            function _getprotobynumber(number) {
                _setprotoent(true);
                var result = Protocols.map[number];
                return result
            }
            Module["_getprotobynumber"] = _getprotobynumber;

            function _getpwnam() {
                throw "getpwnam: TODO"
            }
            Module["_getpwnam"] = _getpwnam;

            function _getpwnam_r() {
                throw "getpwnam_r: TODO"
            }
            Module["_getpwnam_r"] = _getpwnam_r;

            function _getpwuid_r() {
                throw "getpwuid_r: TODO"
            }
            Module["_getpwuid_r"] = _getpwuid_r;

            function _setpwent() {
                throw "setpwent: TODO"
            }
            Module["_setpwent"] = _setpwent;

            function _getpwent() {
                throw "getpwent: TODO"
            }
            Module["_getpwent"] = _getpwent;

            function _endpwent() {
                throw "endpwent: TODO"
            }
            Module["_endpwent"] = _endpwent;

            function _getgrgid() {
                throw "getgrgid: TODO"
            }
            Module["_getgrgid"] = _getgrgid;

            function _getgrgid_r() {
                throw "getgrgid_r: TODO"
            }
            Module["_getgrgid_r"] = _getgrgid_r;

            function _getgrnam() {
                throw "getgrnam: TODO"
            }
            Module["_getgrnam"] = _getgrnam;

            function _getgrnam_r() {
                throw "getgrnam_r: TODO"
            }
            Module["_getgrnam_r"] = _getgrnam_r;

            function _getgrent() {
                throw "getgrent: TODO"
            }
            Module["_getgrent"] = _getgrent;

            function _endgrent() {
                throw "endgrent: TODO"
            }
            Module["_endgrent"] = _endgrent;

            function _setgrent() {
                throw "setgrent: TODO"
            }
            Module["_setgrent"] = _setgrent;

            function _emscripten_run_script(ptr) {
                eval(UTF8ToString(ptr))
            }
            Module["_emscripten_run_script"] = _emscripten_run_script;
            _emscripten_run_script.sig = "vi";

            function _emscripten_run_script_int(ptr) {
                return eval(UTF8ToString(ptr)) | 0
            }
            Module["_emscripten_run_script_int"] = _emscripten_run_script_int;
            _emscripten_run_script_int.sig = "ii";

            function _emscripten_run_script_string(ptr) {
                var s = eval(UTF8ToString(ptr));
                if (s == null) {
                    return 0
                }
                s += "";
                var me = _emscripten_run_script_string;
                var len = lengthBytesUTF8(s);
                if (!me.bufferSize || me.bufferSize < len + 1) {
                    if (me.bufferSize) _free(me.buffer);
                    me.bufferSize = len + 1;
                    me.buffer = _malloc(me.bufferSize)
                }
                stringToUTF8(s, me.buffer, me.bufferSize);
                return me.buffer
            }
            Module["_emscripten_run_script_string"] = _emscripten_run_script_string;
            _emscripten_run_script_string.sig = "ii";

            function _emscripten_random() {
                return Math.random()
            }
            Module["_emscripten_random"] = _emscripten_random;

            function traverseStack(args) {
                if (!args || !args.callee || !args.callee.name) {
                    return [null, "", ""]
                }
                var funstr = args.callee.toString();
                var funcname = args.callee.name;
                var str = "(";
                var first = true;
                for (var i in args) {
                    var a = args[i];
                    if (!first) {
                        str += ", "
                    }
                    first = false;
                    if (typeof a === "number" || typeof a === "string") {
                        str += a
                    } else {
                        str += "(" + typeof a + ")"
                    }
                }
                str += ")";
                var caller = args.callee.caller;
                args = caller ? caller.arguments : [];
                if (first) str = "";
                return [args, funcname, str]
            }
            Module["traverseStack"] = traverseStack;

            function _emscripten_get_callstack_js(flags) {
                var callstack = jsStackTrace();
                var iThisFunc = callstack.lastIndexOf("_emscripten_log");
                var iThisFunc2 = callstack.lastIndexOf("_emscripten_get_callstack");
                var iNextLine = callstack.indexOf("\n", Math.max(iThisFunc, iThisFunc2)) + 1;
                callstack = callstack.slice(iNextLine);
                if (flags & 32) {
                    warnOnce("EM_LOG_DEMANGLE is deprecated; ignoring")
                }
                if (flags & 8 && typeof emscripten_source_map === "undefined") {
                    warnOnce('Source map information is not available, emscripten_log with EM_LOG_C_STACK will be ignored. Build with "--pre-js $EMSCRIPTEN/src/emscripten-source-map.min.js" linker flag to add source map loading to code.');
                    flags ^= 8;
                    flags |= 16
                }
                var stack_args = null;
                if (flags & 128) {
                    stack_args = traverseStack(arguments);
                    while (stack_args[1].includes("_emscripten_")) stack_args = traverseStack(stack_args[0])
                }
                var lines = callstack.split("\n");
                callstack = "";
                var newFirefoxRe = new RegExp("\\s*(.*?)@(.*?):([0-9]+):([0-9]+)");
                var firefoxRe = new RegExp("\\s*(.*?)@(.*):(.*)(:(.*))?");
                var chromeRe = new RegExp("\\s*at (.*?) \\((.*):(.*):(.*)\\)");
                for (var l in lines) {
                    var line = lines[l];
                    var symbolName = "";
                    var file = "";
                    var lineno = 0;
                    var column = 0;
                    var parts = chromeRe.exec(line);
                    if (parts && parts.length == 5) {
                        symbolName = parts[1];
                        file = parts[2];
                        lineno = parts[3];
                        column = parts[4]
                    } else {
                        parts = newFirefoxRe.exec(line);
                        if (!parts) parts = firefoxRe.exec(line);
                        if (parts && parts.length >= 4) {
                            symbolName = parts[1];
                            file = parts[2];
                            lineno = parts[3];
                            column = parts[4] | 0
                        } else {
                            callstack += line + "\n";
                            continue
                        }
                    }
                    var haveSourceMap = false;
                    if (flags & 8) {
                        var orig = emscripten_source_map.originalPositionFor({
                            line: lineno,
                            column: column
                        });
                        haveSourceMap = orig && orig.source;
                        if (haveSourceMap) {
                            if (flags & 64) {
                                orig.source = orig.source.substring(orig.source.replace(/\\/g, "/").lastIndexOf("/") + 1)
                            }
                            callstack += "    at " + symbolName + " (" + orig.source + ":" + orig.line + ":" + orig.column + ")\n"
                        }
                    }
                    if (flags & 16 || !haveSourceMap) {
                        if (flags & 64) {
                            file = file.substring(file.replace(/\\/g, "/").lastIndexOf("/") + 1)
                        }
                        callstack += (haveSourceMap ? "     = " + symbolName : "    at " + symbolName) + " (" + file + ":" + lineno + ":" + column + ")\n"
                    }
                    if (flags & 128 && stack_args[0]) {
                        if (stack_args[1] == symbolName && stack_args[2].length > 0) {
                            callstack = callstack.replace(/\s+$/, "");
                            callstack += " with values: " + stack_args[1] + stack_args[2] + "\n"
                        }
                        stack_args = traverseStack(stack_args[0])
                    }
                }
                callstack = callstack.replace(/\s+$/, "");
                return callstack
            }
            Module["_emscripten_get_callstack_js"] = _emscripten_get_callstack_js;

            function _emscripten_get_callstack(flags, str, maxbytes) {
                var callstack = _emscripten_get_callstack_js(flags);
                if (!str || maxbytes <= 0) {
                    return lengthBytesUTF8(callstack) + 1
                }
                var bytesWrittenExcludingNull = stringToUTF8(callstack, str, maxbytes);
                return bytesWrittenExcludingNull + 1
            }
            Module["_emscripten_get_callstack"] = _emscripten_get_callstack;

            function _emscripten_log_js(flags, str) {
                if (flags & 24) {
                    str = str.replace(/\s+$/, "");
                    str += (str.length > 0 ? "\n" : "") + _emscripten_get_callstack_js(flags)
                }
                if (flags & 1) {
                    if (flags & 4) {
                        console.error(str)
                    } else if (flags & 2) {
                        console.warn(str)
                    } else if (flags & 512) {
                        console.info(str)
                    } else if (flags & 256) {
                        console.debug(str)
                    } else {
                        console.log(str)
                    }
                } else if (flags & 6) {
                    err(str)
                } else {
                    out(str)
                }
            }
            Module["_emscripten_log_js"] = _emscripten_log_js;

            function reallyNegative(x) {
                return x < 0 || x === 0 && 1 / x === -Infinity
            }
            Module["reallyNegative"] = reallyNegative;

            function convertI32PairToI53(lo, hi) {
                return (lo >>> 0) + hi * 4294967296
            }
            Module["convertI32PairToI53"] = convertI32PairToI53;

            function convertU32PairToI53(lo, hi) {
                return (lo >>> 0) + (hi >>> 0) * 4294967296
            }
            Module["convertU32PairToI53"] = convertU32PairToI53;

            function reSign(value, bits) {
                if (value <= 0) {
                    return value
                }
                var half = bits <= 32 ? Math.abs(1 << bits - 1) : Math.pow(2, bits - 1);
                if (value >= half && (bits <= 32 || value > half)) {
                    value = -2 * half + value
                }
                return value
            }
            Module["reSign"] = reSign;

            function unSign(value, bits) {
                if (value >= 0) {
                    return value
                }
                return bits <= 32 ? 2 * Math.abs(1 << bits - 1) + value : Math.pow(2, bits) + value
            }
            Module["unSign"] = unSign;

            function formatString(format, varargs) {
                var textIndex = format;
                var argIndex = varargs;

                function prepVararg(ptr, type) {
                    if (type === "double" || type === "i64") {
                        if (ptr & 7) {
                            ptr += 4
                        }
                    } else {}
                    return ptr
                }

                function getNextArg(type) {
                    var ret;
                    argIndex = prepVararg(argIndex, type);
                    if (type === "double") {
                        ret = HEAPF64[argIndex >> 3];
                        argIndex += 8
                    } else if (type == "i64") {
                        ret = [HEAP32[argIndex >> 2], HEAP32[argIndex + 4 >> 2]];
                        argIndex += 8
                    } else {
                        type = "i32";
                        ret = HEAP32[argIndex >> 2];
                        argIndex += 4
                    }
                    return ret
                }
                var ret = [];
                var curr, next, currArg;
                while (1) {
                    var startTextIndex = textIndex;
                    curr = HEAP8[textIndex >> 0];
                    if (curr === 0) break;
                    next = HEAP8[textIndex + 1 >> 0];
                    if (curr == 37) {
                        var flagAlwaysSigned = false;
                        var flagLeftAlign = false;
                        var flagAlternative = false;
                        var flagZeroPad = false;
                        var flagPadSign = false;
                        flagsLoop: while (1) {
                            switch (next) {
                                case 43:
                                    flagAlwaysSigned = true;
                                    break;
                                case 45:
                                    flagLeftAlign = true;
                                    break;
                                case 35:
                                    flagAlternative = true;
                                    break;
                                case 48:
                                    if (flagZeroPad) {
                                        break flagsLoop
                                    } else {
                                        flagZeroPad = true;
                                        break
                                    }
                                    case 32:
                                        flagPadSign = true;
                                        break;
                                    default:
                                        break flagsLoop
                            }
                            textIndex++;
                            next = HEAP8[textIndex + 1 >> 0]
                        }
                        var width = 0;
                        if (next == 42) {
                            width = getNextArg("i32");
                            textIndex++;
                            next = HEAP8[textIndex + 1 >> 0]
                        } else {
                            while (next >= 48 && next <= 57) {
                                width = width * 10 + (next - 48);
                                textIndex++;
                                next = HEAP8[textIndex + 1 >> 0]
                            }
                        }
                        var precisionSet = false,
                            precision = -1;
                        if (next == 46) {
                            precision = 0;
                            precisionSet = true;
                            textIndex++;
                            next = HEAP8[textIndex + 1 >> 0];
                            if (next == 42) {
                                precision = getNextArg("i32");
                                textIndex++
                            } else {
                                while (1) {
                                    var precisionChr = HEAP8[textIndex + 1 >> 0];
                                    if (precisionChr < 48 || precisionChr > 57) break;
                                    precision = precision * 10 + (precisionChr - 48);
                                    textIndex++
                                }
                            }
                            next = HEAP8[textIndex + 1 >> 0]
                        }
                        if (precision < 0) {
                            precision = 6;
                            precisionSet = false
                        }
                        var argSize;
                        switch (String.fromCharCode(next)) {
                            case "h":
                                var nextNext = HEAP8[textIndex + 2 >> 0];
                                if (nextNext == 104) {
                                    textIndex++;
                                    argSize = 1
                                } else {
                                    argSize = 2
                                }
                                break;
                            case "l":
                                var nextNext = HEAP8[textIndex + 2 >> 0];
                                if (nextNext == 108) {
                                    textIndex++;
                                    argSize = 8
                                } else {
                                    argSize = 4
                                }
                                break;
                            case "L":
                            case "q":
                            case "j":
                                argSize = 8;
                                break;
                            case "z":
                            case "t":
                            case "I":
                                argSize = 4;
                                break;
                            default:
                                argSize = null
                        }
                        if (argSize) textIndex++;
                        next = HEAP8[textIndex + 1 >> 0];
                        switch (String.fromCharCode(next)) {
                            case "d":
                            case "i":
                            case "u":
                            case "o":
                            case "x":
                            case "X":
                            case "p": {
                                var signed = next == 100 || next == 105;
                                argSize = argSize || 4;
                                currArg = getNextArg("i" + argSize * 8);
                                var argText;
                                if (argSize == 8) {
                                    currArg = next == 117 ? convertU32PairToI53(currArg[0], currArg[1]) : convertI32PairToI53(currArg[0], currArg[1])
                                }
                                if (argSize <= 4) {
                                    var limit = Math.pow(256, argSize) - 1;
                                    currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8)
                                }
                                var currAbsArg = Math.abs(currArg);
                                var prefix = "";
                                if (next == 100 || next == 105) {
                                    argText = reSign(currArg, 8 * argSize, 1).toString(10)
                                } else if (next == 117) {
                                    argText = unSign(currArg, 8 * argSize, 1).toString(10);
                                    currArg = Math.abs(currArg)
                                } else if (next == 111) {
                                    argText = (flagAlternative ? "0" : "") + currAbsArg.toString(8)
                                } else if (next == 120 || next == 88) {
                                    prefix = flagAlternative && currArg != 0 ? "0x" : "";
                                    if (currArg < 0) {
                                        currArg = -currArg;
                                        argText = (currAbsArg - 1).toString(16);
                                        var buffer = [];
                                        for (var i = 0; i < argText.length; i++) {
                                            buffer.push((15 - parseInt(argText[i], 16)).toString(16))
                                        }
                                        argText = buffer.join("");
                                        while (argText.length < argSize * 2) argText = "f" + argText
                                    } else {
                                        argText = currAbsArg.toString(16)
                                    }
                                    if (next == 88) {
                                        prefix = prefix.toUpperCase();
                                        argText = argText.toUpperCase()
                                    }
                                } else if (next == 112) {
                                    if (currAbsArg === 0) {
                                        argText = "(nil)"
                                    } else {
                                        prefix = "0x";
                                        argText = currAbsArg.toString(16)
                                    }
                                }
                                if (precisionSet) {
                                    while (argText.length < precision) {
                                        argText = "0" + argText
                                    }
                                }
                                if (currArg >= 0) {
                                    if (flagAlwaysSigned) {
                                        prefix = "+" + prefix
                                    } else if (flagPadSign) {
                                        prefix = " " + prefix
                                    }
                                }
                                if (argText.charAt(0) == "-") {
                                    prefix = "-" + prefix;
                                    argText = argText.substr(1)
                                }
                                while (prefix.length + argText.length < width) {
                                    if (flagLeftAlign) {
                                        argText += " "
                                    } else {
                                        if (flagZeroPad) {
                                            argText = "0" + argText
                                        } else {
                                            prefix = " " + prefix
                                        }
                                    }
                                }
                                argText = prefix + argText;
                                argText.split("").forEach(function(chr) {
                                    ret.push(chr.charCodeAt(0))
                                });
                                break
                            }
                            case "f":
                            case "F":
                            case "e":
                            case "E":
                            case "g":
                            case "G": {
                                currArg = getNextArg("double");
                                var argText;
                                if (isNaN(currArg)) {
                                    argText = "nan";
                                    flagZeroPad = false
                                } else if (!isFinite(currArg)) {
                                    argText = (currArg < 0 ? "-" : "") + "inf";
                                    flagZeroPad = false
                                } else {
                                    var isGeneral = false;
                                    var effectivePrecision = Math.min(precision, 20);
                                    if (next == 103 || next == 71) {
                                        isGeneral = true;
                                        precision = precision || 1;
                                        var exponent = parseInt(currArg.toExponential(effectivePrecision).split("e")[1], 10);
                                        if (precision > exponent && exponent >= -4) {
                                            next = (next == 103 ? "f" : "F").charCodeAt(0);
                                            precision -= exponent + 1
                                        } else {
                                            next = (next == 103 ? "e" : "E").charCodeAt(0);
                                            precision--
                                        }
                                        effectivePrecision = Math.min(precision, 20)
                                    }
                                    if (next == 101 || next == 69) {
                                        argText = currArg.toExponential(effectivePrecision);
                                        if (/[eE][-+]\d$/.test(argText)) {
                                            argText = argText.slice(0, -1) + "0" + argText.slice(-1)
                                        }
                                    } else if (next == 102 || next == 70) {
                                        argText = currArg.toFixed(effectivePrecision);
                                        if (currArg === 0 && reallyNegative(currArg)) {
                                            argText = "-" + argText
                                        }
                                    }
                                    var parts = argText.split("e");
                                    if (isGeneral && !flagAlternative) {
                                        while (parts[0].length > 1 && parts[0].includes(".") && (parts[0].slice(-1) == "0" || parts[0].slice(-1) == ".")) {
                                            parts[0] = parts[0].slice(0, -1)
                                        }
                                    } else {
                                        if (flagAlternative && argText.indexOf(".") == -1) parts[0] += ".";
                                        while (precision > effectivePrecision++) parts[0] += "0"
                                    }
                                    argText = parts[0] + (parts.length > 1 ? "e" + parts[1] : "");
                                    if (next == 69) argText = argText.toUpperCase();
                                    if (currArg >= 0) {
                                        if (flagAlwaysSigned) {
                                            argText = "+" + argText
                                        } else if (flagPadSign) {
                                            argText = " " + argText
                                        }
                                    }
                                }
                                while (argText.length < width) {
                                    if (flagLeftAlign) {
                                        argText += " "
                                    } else {
                                        if (flagZeroPad && (argText[0] == "-" || argText[0] == "+")) {
                                            argText = argText[0] + "0" + argText.slice(1)
                                        } else {
                                            argText = (flagZeroPad ? "0" : " ") + argText
                                        }
                                    }
                                }
                                if (next < 97) argText = argText.toUpperCase();
                                argText.split("").forEach(function(chr) {
                                    ret.push(chr.charCodeAt(0))
                                });
                                break
                            }
                            case "s": {
                                var arg = getNextArg("i8*");
                                var argLength = arg ? _strlen(arg) : "(null)".length;
                                if (precisionSet) argLength = Math.min(argLength, precision);
                                if (!flagLeftAlign) {
                                    while (argLength < width--) {
                                        ret.push(32)
                                    }
                                }
                                if (arg) {
                                    for (var i = 0; i < argLength; i++) {
                                        ret.push(HEAPU8[arg++ >> 0])
                                    }
                                } else {
                                    ret = ret.concat(intArrayFromString("(null)".substr(0, argLength), true))
                                }
                                if (flagLeftAlign) {
                                    while (argLength < width--) {
                                        ret.push(32)
                                    }
                                }
                                break
                            }
                            case "c": {
                                if (flagLeftAlign) ret.push(getNextArg("i8"));
                                while (--width > 0) {
                                    ret.push(32)
                                }
                                if (!flagLeftAlign) ret.push(getNextArg("i8"));
                                break
                            }
                            case "n": {
                                var ptr = getNextArg("i32*");
                                HEAP32[ptr >> 2] = ret.length;
                                break
                            }
                            case "%": {
                                ret.push(curr);
                                break
                            }
                            default: {
                                for (var i = startTextIndex; i < textIndex + 2; i++) {
                                    ret.push(HEAP8[i >> 0])
                                }
                            }
                        }
                        textIndex += 2
                    } else {
                        ret.push(curr);
                        textIndex += 1
                    }
                }
                return ret
            }
            Module["formatString"] = formatString;

            function _emscripten_log(flags, format, varargs) {
                var result = formatString(format, varargs);
                var str = UTF8ArrayToString(result, 0);
                _emscripten_log_js(flags, str)
            }
            Module["_emscripten_log"] = _emscripten_log;

            function _emscripten_get_compiler_setting(name) {
                throw "You must build with -s RETAIN_COMPILER_SETTINGS=1 for getCompilerSetting or emscripten_get_compiler_setting to work"
            }
            Module["_emscripten_get_compiler_setting"] = _emscripten_get_compiler_setting;

            function _emscripten_has_asyncify() {
                return 0
            }
            Module["_emscripten_has_asyncify"] = _emscripten_has_asyncify;

            function _emscripten_debugger() {
                debugger
            }
            Module["_emscripten_debugger"] = _emscripten_debugger;

            function _emscripten_print_double(x, to, max) {
                var str = x + "";
                if (to) return stringToUTF8(str, to, max);
                else return lengthBytesUTF8(str)
            }
            Module["_emscripten_print_double"] = _emscripten_print_double;

            function _emscripten_generate_pc(frame) {
                abort("Cannot use emscripten_generate_pc (needed by __builtin_return_address) without -s USE_OFFSET_CONVERTER")
            }
            Module["_emscripten_generate_pc"] = _emscripten_generate_pc;

            function _emscripten_return_address(level) {
                var callstack = (new Error).stack.split("\n");
                if (callstack[0] == "Error") {
                    callstack.shift()
                }
                return _emscripten_generate_pc(callstack[level + 2])
            }
            Module["_emscripten_return_address"] = _emscripten_return_address;
            var UNWIND_CACHE = {};
            Module["UNWIND_CACHE"] = UNWIND_CACHE;

            function __emscripten_save_in_unwind_cache(callstack) {
                callstack.forEach(function(frame) {
                    var pc = _emscripten_generate_pc(frame);
                    if (pc) {
                        UNWIND_CACHE[pc] = frame
                    }
                })
            }
            Module["__emscripten_save_in_unwind_cache"] = __emscripten_save_in_unwind_cache;

            function _emscripten_stack_snapshot() {
                var callstack = (new Error).stack.split("\n");
                if (callstack[0] == "Error") {
                    callstack.shift()
                }
                __emscripten_save_in_unwind_cache(callstack);
                UNWIND_CACHE.last_addr = _emscripten_generate_pc(callstack[2]);
                UNWIND_CACHE.last_stack = callstack;
                return UNWIND_CACHE.last_addr
            }
            Module["_emscripten_stack_snapshot"] = _emscripten_stack_snapshot;

            function _emscripten_stack_unwind_buffer(addr, buffer, count) {
                var stack;
                if (UNWIND_CACHE.last_addr == addr) {
                    stack = UNWIND_CACHE.last_stack
                } else {
                    stack = (new Error).stack.split("\n");
                    if (stack[0] == "Error") {
                        stack.shift()
                    }
                    __emscripten_save_in_unwind_cache(stack)
                }
                var offset = 2;
                while (stack[offset] && _emscripten_generate_pc(stack[offset]) != addr) {
                    ++offset
                }
                for (var i = 0; i < count && stack[i + offset]; ++i) {
                    HEAP32[buffer + i * 4 >> 2] = _emscripten_generate_pc(stack[i + offset])
                }
                return i
            }
            Module["_emscripten_stack_unwind_buffer"] = _emscripten_stack_unwind_buffer;

            function _emscripten_pc_get_function(pc) {
                abort("Cannot use emscripten_pc_get_function without -s USE_OFFSET_CONVERTER")
            }
            Module["_emscripten_pc_get_function"] = _emscripten_pc_get_function;

            function _emscripten_pc_get_source_js(pc) {
                if (UNWIND_CACHE.last_get_source_pc == pc) return UNWIND_CACHE.last_source;
                var match;
                var source;
                if (!source) {
                    var frame = UNWIND_CACHE[pc];
                    if (!frame) return null;
                    if (match = /\((.*):(\d+):(\d+)\)$/.exec(frame)) {
                        source = {
                            file: match[1],
                            line: match[2],
                            column: match[3]
                        }
                    } else if (match = /@(.*):(\d+):(\d+)/.exec(frame)) {
                        source = {
                            file: match[1],
                            line: match[2],
                            column: match[3]
                        }
                    }
                }
                UNWIND_CACHE.last_get_source_pc = pc;
                UNWIND_CACHE.last_source = source;
                return source
            }
            Module["_emscripten_pc_get_source_js"] = _emscripten_pc_get_source_js;

            function withBuiltinMalloc(func) {
                var prev_malloc = typeof _malloc !== "undefined" ? _malloc : undefined;
                var prev_memalign = typeof _memalign !== "undefined" ? _memalign : undefined;
                var prev_free = typeof _free !== "undefined" ? _free : undefined;
                _malloc = _emscripten_builtin_malloc;
                _memalign = _emscripten_builtin_memalign;
                _free = _emscripten_builtin_free;
                try {
                    return func()
                } finally {
                    _malloc = prev_malloc;
                    _memalign = prev_memalign;
                    _free = prev_free
                }
            }
            Module["withBuiltinMalloc"] = withBuiltinMalloc;

            function _emscripten_pc_get_file(pc) {
                var result = _emscripten_pc_get_source_js(pc);
                if (!result) return 0;
                withBuiltinMalloc(function() {
                    if (_emscripten_pc_get_file.ret) _free(_emscripten_pc_get_file.ret);
                    _emscripten_pc_get_file.ret = allocateUTF8(result.file)
                });
                return _emscripten_pc_get_file.ret
            }
            Module["_emscripten_pc_get_file"] = _emscripten_pc_get_file;

            function _emscripten_pc_get_line(pc) {
                var result = _emscripten_pc_get_source_js(pc);
                return result ? result.line : 0
            }
            Module["_emscripten_pc_get_line"] = _emscripten_pc_get_line;

            function _emscripten_pc_get_column(pc) {
                var result = _emscripten_pc_get_source_js(pc);
                return result ? result.column || 0 : 0
            }
            Module["_emscripten_pc_get_column"] = _emscripten_pc_get_column;

            function _emscripten_get_module_name(buf, length) {
                return stringToUTF8(wasmBinaryFile, buf, length)
            }
            Module["_emscripten_get_module_name"] = _emscripten_get_module_name;

            function _emscripten_builtin_mmap2(addr, len, prot, flags, fd, off) {
                return withBuiltinMalloc(function() {
                    return syscallMmap2(addr, len, prot, flags, fd, off)
                })
            }
            Module["_emscripten_builtin_mmap2"] = _emscripten_builtin_mmap2;

            function _emscripten_builtin_munmap(addr, len) {
                return withBuiltinMalloc(function() {
                    return syscallMunmap(addr, len)
                })
            }
            Module["_emscripten_builtin_munmap"] = _emscripten_builtin_munmap;

            function _emscripten_asm_const_double(a0, a1, a2) {
                return _emscripten_asm_const_int(a0, a1, a2)
            }
            Module["_emscripten_asm_const_double"] = _emscripten_asm_const_double;
            _emscripten_asm_const_double.sig = "iiii";

            function mainThreadEM_ASM(code, sigPtr, argbuf, sync) {
                code -= 1024;
                var args = readAsmConstArgs(sigPtr, argbuf);
                return ASM_CONSTS[code].apply(null, args)
            }
            Module["mainThreadEM_ASM"] = mainThreadEM_ASM;

            function _emscripten_asm_const_int_sync_on_main_thread(code, sigPtr, argbuf) {
                return mainThreadEM_ASM(code, sigPtr, argbuf, 1)
            }
            Module["_emscripten_asm_const_int_sync_on_main_thread"] = _emscripten_asm_const_int_sync_on_main_thread;
            _emscripten_asm_const_int_sync_on_main_thread.sig = "iiii";

            function _emscripten_asm_const_double_sync_on_main_thread(a0, a1, a2) {
                return _emscripten_asm_const_int_sync_on_main_thread(a0, a1, a2)
            }
            Module["_emscripten_asm_const_double_sync_on_main_thread"] = _emscripten_asm_const_double_sync_on_main_thread;
            _emscripten_asm_const_double_sync_on_main_thread.sig = "iiii";

            function _emscripten_asm_const_async_on_main_thread(code, sigPtr, argbuf) {
                return mainThreadEM_ASM(code, sigPtr, argbuf, 0)
            }
            Module["_emscripten_asm_const_async_on_main_thread"] = _emscripten_asm_const_async_on_main_thread;

            function jstoi_s(str) {
                return Number(str)
            }
            Module["jstoi_s"] = jstoi_s;

            function __Unwind_Backtrace(func, arg) {
                var trace = _emscripten_get_callstack_js();
                var parts = trace.split("\n");
                for (var i = 0; i < parts.length; i++) {
                    var ret = wasmTable.get(func)(0, arg);
                    if (ret !== 0) return
                }
            }
            Module["__Unwind_Backtrace"] = __Unwind_Backtrace;

            function __Unwind_GetIPInfo() {
                abort("Unwind_GetIPInfo")
            }
            Module["__Unwind_GetIPInfo"] = __Unwind_GetIPInfo;

            function __Unwind_FindEnclosingFunction() {
                return 0
            }
            Module["__Unwind_FindEnclosingFunction"] = __Unwind_FindEnclosingFunction;
            var ExceptionInfoAttrs = {
                DESTRUCTOR_OFFSET: 0,
                REFCOUNT_OFFSET: 4,
                TYPE_OFFSET: 8,
                CAUGHT_OFFSET: 12,
                RETHROWN_OFFSET: 13,
                SIZE: 16
            };
            Module["ExceptionInfoAttrs"] = ExceptionInfoAttrs;

            function ExceptionInfo(excPtr) {
                this.excPtr = excPtr;
                this.ptr = excPtr - ExceptionInfoAttrs.SIZE;
                this.set_type = function(type) {
                    HEAP32[this.ptr + ExceptionInfoAttrs.TYPE_OFFSET >> 2] = type
                };
                this.get_type = function() {
                    return HEAP32[this.ptr + ExceptionInfoAttrs.TYPE_OFFSET >> 2]
                };
                this.set_destructor = function(destructor) {
                    HEAP32[this.ptr + ExceptionInfoAttrs.DESTRUCTOR_OFFSET >> 2] = destructor
                };
                this.get_destructor = function() {
                    return HEAP32[this.ptr + ExceptionInfoAttrs.DESTRUCTOR_OFFSET >> 2]
                };
                this.set_refcount = function(refcount) {
                    HEAP32[this.ptr + ExceptionInfoAttrs.REFCOUNT_OFFSET >> 2] = refcount
                };
                this.set_caught = function(caught) {
                    caught = caught ? 1 : 0;
                    HEAP8[this.ptr + ExceptionInfoAttrs.CAUGHT_OFFSET >> 0] = caught
                };
                this.get_caught = function() {
                    return HEAP8[this.ptr + ExceptionInfoAttrs.CAUGHT_OFFSET >> 0] != 0
                };
                this.set_rethrown = function(rethrown) {
                    rethrown = rethrown ? 1 : 0;
                    HEAP8[this.ptr + ExceptionInfoAttrs.RETHROWN_OFFSET >> 0] = rethrown
                };
                this.get_rethrown = function() {
                    return HEAP8[this.ptr + ExceptionInfoAttrs.RETHROWN_OFFSET >> 0] != 0
                };
                this.init = function(type, destructor) {
                    this.set_type(type);
                    this.set_destructor(destructor);
                    this.set_refcount(0);
                    this.set_caught(false);
                    this.set_rethrown(false)
                };
                this.add_ref = function() {
                    var value = HEAP32[this.ptr + ExceptionInfoAttrs.REFCOUNT_OFFSET >> 2];
                    HEAP32[this.ptr + ExceptionInfoAttrs.REFCOUNT_OFFSET >> 2] = value + 1
                };
                this.release_ref = function() {
                    var prev = HEAP32[this.ptr + ExceptionInfoAttrs.REFCOUNT_OFFSET >> 2];
                    HEAP32[this.ptr + ExceptionInfoAttrs.REFCOUNT_OFFSET >> 2] = prev - 1;
                    return prev === 1
                }
            }
            Module["ExceptionInfo"] = ExceptionInfo;
            var exceptionLast = 0;
            Module["exceptionLast"] = exceptionLast;
            var uncaughtExceptionCount = 0;
            Module["uncaughtExceptionCount"] = uncaughtExceptionCount;

            function ___cxa_throw(ptr, type, destructor) {
                var info = new ExceptionInfo(ptr);
                info.init(type, destructor);
                exceptionLast = ptr;
                uncaughtExceptionCount++;
                throw ptr
            }
            Module["___cxa_throw"] = ___cxa_throw;
            ___cxa_throw.sig = "viii";

            function __Unwind_RaiseException(ex) {
                err("Warning: _Unwind_RaiseException is not correctly implemented");
                return ___cxa_throw(ex, 0, 0)
            }
            Module["__Unwind_RaiseException"] = __Unwind_RaiseException;

            function __Unwind_DeleteException(ex) {
                err("TODO: Unwind_DeleteException")
            }
            Module["__Unwind_DeleteException"] = __Unwind_DeleteException;

            function _emscripten_autodebug_i64(line, valuel, valueh) {
                out("AD:" + [line, valuel, valueh])
            }
            Module["_emscripten_autodebug_i64"] = _emscripten_autodebug_i64;

            function _emscripten_autodebug_i32(line, value) {
                out("AD:" + [line, value])
            }
            Module["_emscripten_autodebug_i32"] = _emscripten_autodebug_i32;

            function _emscripten_autodebug_i16(line, value) {
                out("AD:" + [line, value])
            }
            Module["_emscripten_autodebug_i16"] = _emscripten_autodebug_i16;

            function _emscripten_autodebug_i8(line, value) {
                out("AD:" + [line, value])
            }
            Module["_emscripten_autodebug_i8"] = _emscripten_autodebug_i8;

            function _emscripten_autodebug_float(line, value) {
                out("AD:" + [line, value])
            }
            Module["_emscripten_autodebug_float"] = _emscripten_autodebug_float;

            function _emscripten_autodebug_double(line, value) {
                out("AD:" + [line, value])
            }
            Module["_emscripten_autodebug_double"] = _emscripten_autodebug_double;

            function ___handle_stack_overflow() {
                abort("stack overflow")
            }
            Module["___handle_stack_overflow"] = ___handle_stack_overflow;

            function getDynCaller(sig, ptr) {
                var argCache = [];
                return function() {
                    argCache.length = arguments.length;
                    for (var i = 0; i < arguments.length; i++) {
                        argCache[i] = arguments[i]
                    }
                    return dynCall(sig, ptr, argCache)
                }
            }
            Module["getDynCaller"] = getDynCaller;

            function _emscripten_exit_with_live_runtime() {
                throw "unwind"
            }
            Module["_emscripten_exit_with_live_runtime"] = _emscripten_exit_with_live_runtime;
            _emscripten_exit_with_live_runtime.sig = "v";

            function _emscripten_force_exit(status) {
                noExitRuntime = false;
                runtimeKeepaliveCounter = 0;
                exit(status)
            }
            Module["_emscripten_force_exit"] = _emscripten_force_exit;
            _emscripten_force_exit.sig = "vi";

            function _emscripten_math_cbrt(x) {
                return Math.cbrt(x)
            }
            Module["_emscripten_math_cbrt"] = _emscripten_math_cbrt;

            function _emscripten_math_pow(x, y) {
                return Math.pow(x, y)
            }
            Module["_emscripten_math_pow"] = _emscripten_math_pow;

            function _emscripten_math_random(x) {
                return Math.random(x)
            }
            Module["_emscripten_math_random"] = _emscripten_math_random;

            function _emscripten_math_sign(x) {
                return Math.sign(x)
            }
            Module["_emscripten_math_sign"] = _emscripten_math_sign;

            function _emscripten_math_sqrt(x) {
                return Math.sqrt(x)
            }
            Module["_emscripten_math_sqrt"] = _emscripten_math_sqrt;

            function _emscripten_math_exp(x) {
                return Math.exp(x)
            }
            Module["_emscripten_math_exp"] = _emscripten_math_exp;

            function _emscripten_math_expm1(x) {
                return Math.expm1(x)
            }
            Module["_emscripten_math_expm1"] = _emscripten_math_expm1;

            function _emscripten_math_fmod(x, y) {
                return x % y
            }
            Module["_emscripten_math_fmod"] = _emscripten_math_fmod;

            function _emscripten_math_log(x) {
                return Math.log(x)
            }
            Module["_emscripten_math_log"] = _emscripten_math_log;

            function _emscripten_math_log1p(x) {
                return Math.log1p(x)
            }
            Module["_emscripten_math_log1p"] = _emscripten_math_log1p;

            function _emscripten_math_log10(x) {
                return Math.log10(x)
            }
            Module["_emscripten_math_log10"] = _emscripten_math_log10;

            function _emscripten_math_log2(x) {
                return Math.log2(x)
            }
            Module["_emscripten_math_log2"] = _emscripten_math_log2;

            function _emscripten_math_round(x) {
                return Math.round(x)
            }
            Module["_emscripten_math_round"] = _emscripten_math_round;

            function _emscripten_math_acos(x) {
                return Math.acos(x)
            }
            Module["_emscripten_math_acos"] = _emscripten_math_acos;

            function _emscripten_math_acosh(x) {
                return Math.acosh(x)
            }
            Module["_emscripten_math_acosh"] = _emscripten_math_acosh;

            function _emscripten_math_asin(x) {
                return Math.asin(x)
            }
            Module["_emscripten_math_asin"] = _emscripten_math_asin;

            function _emscripten_math_asinh(x) {
                return Math.asinh(x)
            }
            Module["_emscripten_math_asinh"] = _emscripten_math_asinh;

            function _emscripten_math_atan(x) {
                return Math.atan(x)
            }
            Module["_emscripten_math_atan"] = _emscripten_math_atan;

            function _emscripten_math_atanh(x) {
                return Math.atanh(x)
            }
            Module["_emscripten_math_atanh"] = _emscripten_math_atanh;

            function _emscripten_math_atan2(y, x) {
                return Math.atan2(y, x)
            }
            Module["_emscripten_math_atan2"] = _emscripten_math_atan2;

            function _emscripten_math_cos(x) {
                return Math.cos(x)
            }
            Module["_emscripten_math_cos"] = _emscripten_math_cos;

            function _emscripten_math_cosh(x) {
                return Math.cosh(x)
            }
            Module["_emscripten_math_cosh"] = _emscripten_math_cosh;

            function _emscripten_math_hypot(count, varargs) {
                var args = [];
                for (var i = 0; i < count; ++i) args.push(HEAPF64[(varargs >> 3) + i]);
                return Math.hypot.apply(null, args)
            }
            Module["_emscripten_math_hypot"] = _emscripten_math_hypot;

            function _emscripten_math_sin(x) {
                return Math.sin(x)
            }
            Module["_emscripten_math_sin"] = _emscripten_math_sin;

            function _emscripten_math_sinh(x) {
                return Math.sinh(x)
            }
            Module["_emscripten_math_sinh"] = _emscripten_math_sinh;

            function _emscripten_math_tan(x) {
                return Math.tan(x)
            }
            Module["_emscripten_math_tan"] = _emscripten_math_tan;

            function _emscripten_math_tanh(x) {
                return Math.tanh(x)
            }
            Module["_emscripten_math_tanh"] = _emscripten_math_tanh;
            var __sigalrm_handler = 0;
            Module["__sigalrm_handler"] = __sigalrm_handler;

            function _signal(sig, func) {
                if (sig == 14) {
                    __sigalrm_handler = func
                } else {}
                return 0
            }
            Module["_signal"] = _signal;
            _signal.sig = "iii";

            function _bsd_signal(a0, a1) {
                return _signal(a0, a1)
            }
            Module["_bsd_signal"] = _bsd_signal;
            _bsd_signal.sig = "iii";

            function _sigemptyset(set) {
                HEAP32[set >> 2] = 0;
                return 0
            }
            Module["_sigemptyset"] = _sigemptyset;

            function _sigaddset(set, signum) {
                HEAP32[set >> 2] = HEAP32[set >> 2] | 1 << signum - 1;
                return 0
            }
            Module["_sigaddset"] = _sigaddset;

            function _sigdelset(set, signum) {
                HEAP32[set >> 2] = HEAP32[set >> 2] & ~(1 << signum - 1);
                return 0
            }
            Module["_sigdelset"] = _sigdelset;

            function _sigismember(set, signum) {
                return HEAP32[set >> 2] & 1 << signum - 1
            }
            Module["_sigismember"] = _sigismember;

            function _sigaction(signum, act, oldact) {
                return 0
            }
            Module["_sigaction"] = _sigaction;

            function _sigprocmask() {
                return 0
            }
            Module["_sigprocmask"] = _sigprocmask;

            function ___libc_current_sigrtmin() {
                return 0
            }
            Module["___libc_current_sigrtmin"] = ___libc_current_sigrtmin;

            function ___libc_current_sigrtmax() {
                return 0
            }
            Module["___libc_current_sigrtmax"] = ___libc_current_sigrtmax;

            function _kill(pid, sig) {
                setErrNo(ERRNO_CODES.EPERM);
                return -1
            }
            Module["_kill"] = _kill;

            function _killpg() {
                setErrNo(ERRNO_CODES.EPERM);
                return -1
            }
            Module["_killpg"] = _killpg;

            function _siginterrupt() {
                return 0
            }
            Module["_siginterrupt"] = _siginterrupt;

            function _raise(sig) {
                setErrNo(ERRNO_CODES.ENOSYS);
                return -1
            }
            Module["_raise"] = _raise;

            function _alarm(seconds) {
                setTimeout(function() {
                    if (__sigalrm_handler) wasmTable.get(__sigalrm_handler)(0)
                }, seconds * 1e3)
            }
            Module["_alarm"] = _alarm;

            function _getitimer() {
                throw "getitimer() is not implemented yet"
            }
            Module["_getitimer"] = _getitimer;

            function _siglongjmp(a0, a1) {
                return _longjmp(a0, a1)
            }
            Module["_siglongjmp"] = _siglongjmp;
            _siglongjmp.sig = "vii";

            function _sigpending(set) {
                HEAP32[set >> 2] = 0;
                return 0
            }
            Module["_sigpending"] = _sigpending;

            function ___sys_exit(status) {
                try {
                    exit(status)
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_exit"] = ___sys_exit;

            function ___sys_getpgrp() {
                return 42
            }
            Module["___sys_getpgrp"] = ___sys_getpgrp;

            function ___sys_setitimer(which, new_value, old_value) {
                return -52
            }
            Module["___sys_setitimer"] = ___sys_setitimer;

            function ___sys_rt_sigqueueinfo(tgid, pid, uinfo) {
                return 0
            }
            Module["___sys_rt_sigqueueinfo"] = ___sys_rt_sigqueueinfo;

            function ___sys_setregid32(ruid, euid) {
                if (ruid !== 0) return -63;
                return 0
            }
            Module["___sys_setregid32"] = ___sys_setregid32;
            ___sys_setregid32.sig = "iii";

            function ___sys_setreuid32(a0, a1) {
                return ___sys_setregid32(a0, a1)
            }
            Module["___sys_setreuid32"] = ___sys_setreuid32;
            ___sys_setreuid32.sig = "iii";

            function ___sys_setgid32(uid) {
                if (uid !== 0) return -63;
                return 0
            }
            Module["___sys_setgid32"] = ___sys_setgid32;
            ___sys_setgid32.sig = "ii";

            function ___sys_setuid32(a0) {
                return ___sys_setgid32(a0)
            }
            Module["___sys_setuid32"] = ___sys_setuid32;
            ___sys_setuid32.sig = "ii";

            function ___sys_setresgid32(ruid, euid, suid) {
                if (euid !== 0) return -63;
                return 0
            }
            Module["___sys_setresgid32"] = ___sys_setresgid32;
            ___sys_setresgid32.sig = "iiii";

            function ___sys_setresuid32(a0, a1, a2) {
                return ___sys_setresgid32(a0, a1, a2)
            }
            Module["___sys_setresuid32"] = ___sys_setresuid32;
            ___sys_setresuid32.sig = "iiii";

            function ___sys_exit_group(status) {
                try {
                    exit(status);
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_exit_group"] = ___sys_exit_group;

            function ___sys_faccessat(dirfd, path, amode, flags) {
                try {
                    path = SYSCALLS.getStr(path);
                    path = SYSCALLS.calculateAt(dirfd, path);
                    return SYSCALLS.doAccess(path, amode)
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return -e.errno
                }
            }
            Module["___sys_faccessat"] = ___sys_faccessat;
            var JSEvents = {
                inEventHandler: 0,
                removeAllEventListeners: function() {
                    for (var i = JSEvents.eventHandlers.length - 1; i >= 0; --i) {
                        JSEvents._removeHandler(i)
                    }
                    JSEvents.eventHandlers = [];
                    JSEvents.deferredCalls = []
                },
                registerRemoveEventListeners: function() {
                    if (!JSEvents.removeEventListenersRegistered) {
                        __ATEXIT__.push(JSEvents.removeAllEventListeners);
                        JSEvents.removeEventListenersRegistered = true
                    }
                },
                deferredCalls: [],
                deferCall: function(targetFunction, precedence, argsList) {
                    function arraysHaveEqualContent(arrA, arrB) {
                        if (arrA.length != arrB.length) return false;
                        for (var i in arrA) {
                            if (arrA[i] != arrB[i]) return false
                        }
                        return true
                    }
                    for (var i in JSEvents.deferredCalls) {
                        var call = JSEvents.deferredCalls[i];
                        if (call.targetFunction == targetFunction && arraysHaveEqualContent(call.argsList, argsList)) {
                            return
                        }
                    }
                    JSEvents.deferredCalls.push({
                        targetFunction: targetFunction,
                        precedence: precedence,
                        argsList: argsList
                    });
                    JSEvents.deferredCalls.sort(function(x, y) {
                        return x.precedence < y.precedence
                    })
                },
                removeDeferredCalls: function(targetFunction) {
                    for (var i = 0; i < JSEvents.deferredCalls.length; ++i) {
                        if (JSEvents.deferredCalls[i].targetFunction == targetFunction) {
                            JSEvents.deferredCalls.splice(i, 1);
                            --i
                        }
                    }
                },
                canPerformEventHandlerRequests: function() {
                    return JSEvents.inEventHandler && JSEvents.currentEventHandler.allowsDeferredCalls
                },
                runDeferredCalls: function() {
                    if (!JSEvents.canPerformEventHandlerRequests()) {
                        return
                    }
                    for (var i = 0; i < JSEvents.deferredCalls.length; ++i) {
                        var call = JSEvents.deferredCalls[i];
                        JSEvents.deferredCalls.splice(i, 1);
                        --i;
                        call.targetFunction.apply(null, call.argsList)
                    }
                },
                eventHandlers: [],
                removeAllHandlersOnTarget: function(target, eventTypeString) {
                    for (var i = 0; i < JSEvents.eventHandlers.length; ++i) {
                        if (JSEvents.eventHandlers[i].target == target && (!eventTypeString || eventTypeString == JSEvents.eventHandlers[i].eventTypeString)) {
                            JSEvents._removeHandler(i--)
                        }
                    }
                },
                _removeHandler: function(i) {
                    var h = JSEvents.eventHandlers[i];
                    h.target.removeEventListener(h.eventTypeString, h.eventListenerFunc, h.useCapture);
                    JSEvents.eventHandlers.splice(i, 1)
                },
                registerOrRemoveHandler: function(eventHandler) {
                    var jsEventHandler = function jsEventHandler(event) {
                        ++JSEvents.inEventHandler;
                        JSEvents.currentEventHandler = eventHandler;
                        JSEvents.runDeferredCalls();
                        eventHandler.handlerFunc(event);
                        JSEvents.runDeferredCalls();
                        --JSEvents.inEventHandler
                    };
                    if (eventHandler.callbackfunc) {
                        eventHandler.eventListenerFunc = jsEventHandler;
                        eventHandler.target.addEventListener(eventHandler.eventTypeString, jsEventHandler, eventHandler.useCapture);
                        JSEvents.eventHandlers.push(eventHandler);
                        JSEvents.registerRemoveEventListeners()
                    } else {
                        for (var i = 0; i < JSEvents.eventHandlers.length; ++i) {
                            if (JSEvents.eventHandlers[i].target == eventHandler.target && JSEvents.eventHandlers[i].eventTypeString == eventHandler.eventTypeString) {
                                JSEvents._removeHandler(i--)
                            }
                        }
                    }
                },
                getNodeNameForTarget: function(target) {
                    if (!target) return "";
                    if (target == window) return "#window";
                    if (target == screen) return "#screen";
                    return target && target.nodeName ? target.nodeName : ""
                },
                fullscreenEnabled: function() {
                    return document.fullscreenEnabled || document.webkitFullscreenEnabled
                }
            };
            Module["JSEvents"] = JSEvents;

            function maybeCStringToJsString(cString) {
                return cString > 2 ? UTF8ToString(cString) : cString
            }
            Module["maybeCStringToJsString"] = maybeCStringToJsString;
            var specialHTMLTargets = [0, typeof document !== "undefined" ? document : 0, typeof window !== "undefined" ? window : 0];
            Module["specialHTMLTargets"] = specialHTMLTargets;

            function findEventTarget(target) {
                target = maybeCStringToJsString(target);
                var domElement = specialHTMLTargets[target] || (typeof document !== "undefined" ? document.querySelector(target) : undefined);
                return domElement
            }
            Module["findEventTarget"] = findEventTarget;

            function registerKeyEventCallback(target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
                if (!JSEvents.keyEvent) JSEvents.keyEvent = _malloc(164);
                var keyEventHandlerFunc = function(e) {
                    var keyEventData = JSEvents.keyEvent;
                    var idx = keyEventData >> 2;
                    HEAP32[idx + 0] = e.location;
                    HEAP32[idx + 1] = e.ctrlKey;
                    HEAP32[idx + 2] = e.shiftKey;
                    HEAP32[idx + 3] = e.altKey;
                    HEAP32[idx + 4] = e.metaKey;
                    HEAP32[idx + 5] = e.repeat;
                    HEAP32[idx + 6] = e.charCode;
                    HEAP32[idx + 7] = e.keyCode;
                    HEAP32[idx + 8] = e.which;
                    stringToUTF8(e.key || "", keyEventData + 36, 32);
                    stringToUTF8(e.code || "", keyEventData + 68, 32);
                    stringToUTF8(e.char || "", keyEventData + 100, 32);
                    stringToUTF8(e.locale || "", keyEventData + 132, 32);
                    if (wasmTable.get(callbackfunc)(eventTypeId, keyEventData, userData)) e.preventDefault()
                };
                var eventHandler = {
                    target: findEventTarget(target),
                    allowsDeferredCalls: true,
                    eventTypeString: eventTypeString,
                    callbackfunc: callbackfunc,
                    handlerFunc: keyEventHandlerFunc,
                    useCapture: useCapture
                };
                JSEvents.registerOrRemoveHandler(eventHandler)
            }
            Module["registerKeyEventCallback"] = registerKeyEventCallback;

            function findCanvasEventTarget(target) {
                return findEventTarget(target)
            }
            Module["findCanvasEventTarget"] = findCanvasEventTarget;

            function _emscripten_set_keypress_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                registerKeyEventCallback(target, userData, useCapture, callbackfunc, 1, "keypress", targetThread);
                return 0
            }
            Module["_emscripten_set_keypress_callback_on_thread"] = _emscripten_set_keypress_callback_on_thread;
            _emscripten_set_keypress_callback_on_thread.sig = "iiiiii";

            function _emscripten_set_keydown_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                registerKeyEventCallback(target, userData, useCapture, callbackfunc, 2, "keydown", targetThread);
                return 0
            }
            Module["_emscripten_set_keydown_callback_on_thread"] = _emscripten_set_keydown_callback_on_thread;
            _emscripten_set_keydown_callback_on_thread.sig = "iiiiii";

            function _emscripten_set_keyup_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                registerKeyEventCallback(target, userData, useCapture, callbackfunc, 3, "keyup", targetThread);
                return 0
            }
            Module["_emscripten_set_keyup_callback_on_thread"] = _emscripten_set_keyup_callback_on_thread;
            _emscripten_set_keyup_callback_on_thread.sig = "iiiiii";

            function getBoundingClientRect(e) {
                return specialHTMLTargets.indexOf(e) < 0 ? e.getBoundingClientRect() : {
                    "left": 0,
                    "top": 0
                }
            }
            Module["getBoundingClientRect"] = getBoundingClientRect;

            function fillMouseEventData(eventStruct, e, target) {
                var idx = eventStruct >> 2;
                HEAP32[idx + 0] = e.screenX;
                HEAP32[idx + 1] = e.screenY;
                HEAP32[idx + 2] = e.clientX;
                HEAP32[idx + 3] = e.clientY;
                HEAP32[idx + 4] = e.ctrlKey;
                HEAP32[idx + 5] = e.shiftKey;
                HEAP32[idx + 6] = e.altKey;
                HEAP32[idx + 7] = e.metaKey;
                HEAP16[idx * 2 + 16] = e.button;
                HEAP16[idx * 2 + 17] = e.buttons;
                HEAP32[idx + 9] = e["movementX"];
                HEAP32[idx + 10] = e["movementY"];
                var rect = getBoundingClientRect(target);
                HEAP32[idx + 11] = e.clientX - rect.left;
                HEAP32[idx + 12] = e.clientY - rect.top
            }
            Module["fillMouseEventData"] = fillMouseEventData;

            function registerMouseEventCallback(target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
                if (!JSEvents.mouseEvent) JSEvents.mouseEvent = _malloc(64);
                target = findEventTarget(target);
                var mouseEventHandlerFunc = function(ev) {
                    var e = ev || event;
                    fillMouseEventData(JSEvents.mouseEvent, e, target);
                    if (wasmTable.get(callbackfunc)(eventTypeId, JSEvents.mouseEvent, userData)) e.preventDefault()
                };
                var eventHandler = {
                    target: target,
                    allowsDeferredCalls: eventTypeString != "mousemove" && eventTypeString != "mouseenter" && eventTypeString != "mouseleave",
                    eventTypeString: eventTypeString,
                    callbackfunc: callbackfunc,
                    handlerFunc: mouseEventHandlerFunc,
                    useCapture: useCapture
                };
                JSEvents.registerOrRemoveHandler(eventHandler)
            }
            Module["registerMouseEventCallback"] = registerMouseEventCallback;

            function _emscripten_set_click_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                registerMouseEventCallback(target, userData, useCapture, callbackfunc, 4, "click", targetThread);
                return 0
            }
            Module["_emscripten_set_click_callback_on_thread"] = _emscripten_set_click_callback_on_thread;
            _emscripten_set_click_callback_on_thread.sig = "iiiiii";

            function _emscripten_set_mousedown_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                registerMouseEventCallback(target, userData, useCapture, callbackfunc, 5, "mousedown", targetThread);
                return 0
            }
            Module["_emscripten_set_mousedown_callback_on_thread"] = _emscripten_set_mousedown_callback_on_thread;
            _emscripten_set_mousedown_callback_on_thread.sig = "iiiiii";

            function _emscripten_set_mouseup_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                registerMouseEventCallback(target, userData, useCapture, callbackfunc, 6, "mouseup", targetThread);
                return 0
            }
            Module["_emscripten_set_mouseup_callback_on_thread"] = _emscripten_set_mouseup_callback_on_thread;
            _emscripten_set_mouseup_callback_on_thread.sig = "iiiiii";

            function _emscripten_set_dblclick_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                registerMouseEventCallback(target, userData, useCapture, callbackfunc, 7, "dblclick", targetThread);
                return 0
            }
            Module["_emscripten_set_dblclick_callback_on_thread"] = _emscripten_set_dblclick_callback_on_thread;
            _emscripten_set_dblclick_callback_on_thread.sig = "iiiiii";

            function _emscripten_set_mousemove_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                registerMouseEventCallback(target, userData, useCapture, callbackfunc, 8, "mousemove", targetThread);
                return 0
            }
            Module["_emscripten_set_mousemove_callback_on_thread"] = _emscripten_set_mousemove_callback_on_thread;
            _emscripten_set_mousemove_callback_on_thread.sig = "iiiiii";

            function _emscripten_set_mouseenter_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                registerMouseEventCallback(target, userData, useCapture, callbackfunc, 33, "mouseenter", targetThread);
                return 0
            }
            Module["_emscripten_set_mouseenter_callback_on_thread"] = _emscripten_set_mouseenter_callback_on_thread;
            _emscripten_set_mouseenter_callback_on_thread.sig = "iiiiii";

            function _emscripten_set_mouseleave_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                registerMouseEventCallback(target, userData, useCapture, callbackfunc, 34, "mouseleave", targetThread);
                return 0
            }
            Module["_emscripten_set_mouseleave_callback_on_thread"] = _emscripten_set_mouseleave_callback_on_thread;
            _emscripten_set_mouseleave_callback_on_thread.sig = "iiiiii";

            function _emscripten_set_mouseover_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                registerMouseEventCallback(target, userData, useCapture, callbackfunc, 35, "mouseover", targetThread);
                return 0
            }
            Module["_emscripten_set_mouseover_callback_on_thread"] = _emscripten_set_mouseover_callback_on_thread;
            _emscripten_set_mouseover_callback_on_thread.sig = "iiiiii";

            function _emscripten_set_mouseout_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                registerMouseEventCallback(target, userData, useCapture, callbackfunc, 36, "mouseout", targetThread);
                return 0
            }
            Module["_emscripten_set_mouseout_callback_on_thread"] = _emscripten_set_mouseout_callback_on_thread;
            _emscripten_set_mouseout_callback_on_thread.sig = "iiiiii";

            function _emscripten_get_mouse_status(mouseState) {
                if (!JSEvents.mouseEvent) return -7;
                HEAP8.set(HEAP8.subarray(JSEvents.mouseEvent, JSEvents.mouseEvent + 64), mouseState);
                return 0
            }
            Module["_emscripten_get_mouse_status"] = _emscripten_get_mouse_status;
            _emscripten_get_mouse_status.sig = "ii";

            function registerWheelEventCallback(target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
                if (!JSEvents.wheelEvent) JSEvents.wheelEvent = _malloc(96);
                var wheelHandlerFunc = function(ev) {
                    var e = ev || event;
                    var wheelEvent = JSEvents.wheelEvent;
                    fillMouseEventData(wheelEvent, e, target);
                    HEAPF64[wheelEvent + 64 >> 3] = e["deltaX"];
                    HEAPF64[wheelEvent + 72 >> 3] = e["deltaY"];
                    HEAPF64[wheelEvent + 80 >> 3] = e["deltaZ"];
                    HEAP32[wheelEvent + 88 >> 2] = e["deltaMode"];
                    if (wasmTable.get(callbackfunc)(eventTypeId, wheelEvent, userData)) e.preventDefault()
                };
                var eventHandler = {
                    target: target,
                    allowsDeferredCalls: true,
                    eventTypeString: eventTypeString,
                    callbackfunc: callbackfunc,
                    handlerFunc: wheelHandlerFunc,
                    useCapture: useCapture
                };
                JSEvents.registerOrRemoveHandler(eventHandler)
            }
            Module["registerWheelEventCallback"] = registerWheelEventCallback;

            function _emscripten_set_wheel_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                target = findEventTarget(target);
                if (typeof target.onwheel !== "undefined") {
                    registerWheelEventCallback(target, userData, useCapture, callbackfunc, 9, "wheel", targetThread);
                    return 0
                } else {
                    return -1
                }
            }
            Module["_emscripten_set_wheel_callback_on_thread"] = _emscripten_set_wheel_callback_on_thread;
            _emscripten_set_wheel_callback_on_thread.sig = "iiiiii";

            function registerUiEventCallback(target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
                if (!JSEvents.uiEvent) JSEvents.uiEvent = _malloc(36);
                target = findEventTarget(target);
                var uiEventHandlerFunc = function(ev) {
                    var e = ev || event;
                    if (e.target != target) {
                        return
                    }
                    var b = document.body;
                    if (!b) {
                        return
                    }
                    var uiEvent = JSEvents.uiEvent;
                    HEAP32[uiEvent >> 2] = e.detail;
                    HEAP32[uiEvent + 4 >> 2] = b.clientWidth;
                    HEAP32[uiEvent + 8 >> 2] = b.clientHeight;
                    HEAP32[uiEvent + 12 >> 2] = innerWidth;
                    HEAP32[uiEvent + 16 >> 2] = innerHeight;
                    HEAP32[uiEvent + 20 >> 2] = outerWidth;
                    HEAP32[uiEvent + 24 >> 2] = outerHeight;
                    HEAP32[uiEvent + 28 >> 2] = pageXOffset;
                    HEAP32[uiEvent + 32 >> 2] = pageYOffset;
                    if (wasmTable.get(callbackfunc)(eventTypeId, uiEvent, userData)) e.preventDefault()
                };
                var eventHandler = {
                    target: target,
                    eventTypeString: eventTypeString,
                    callbackfunc: callbackfunc,
                    handlerFunc: uiEventHandlerFunc,
                    useCapture: useCapture
                };
                JSEvents.registerOrRemoveHandler(eventHandler)
            }
            Module["registerUiEventCallback"] = registerUiEventCallback;

            function _emscripten_set_resize_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                registerUiEventCallback(target, userData, useCapture, callbackfunc, 10, "resize", targetThread);
                return 0
            }
            Module["_emscripten_set_resize_callback_on_thread"] = _emscripten_set_resize_callback_on_thread;
            _emscripten_set_resize_callback_on_thread.sig = "iiiiii";

            function _emscripten_set_scroll_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                registerUiEventCallback(target, userData, useCapture, callbackfunc, 11, "scroll", targetThread);
                return 0
            }
            Module["_emscripten_set_scroll_callback_on_thread"] = _emscripten_set_scroll_callback_on_thread;
            _emscripten_set_scroll_callback_on_thread.sig = "iiiiii";

            function registerFocusEventCallback(target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
                if (!JSEvents.focusEvent) JSEvents.focusEvent = _malloc(256);
                var focusEventHandlerFunc = function(ev) {
                    var e = ev || event;
                    var nodeName = JSEvents.getNodeNameForTarget(e.target);
                    var id = e.target.id ? e.target.id : "";
                    var focusEvent = JSEvents.focusEvent;
                    stringToUTF8(nodeName, focusEvent + 0, 128);
                    stringToUTF8(id, focusEvent + 128, 128);
                    if (wasmTable.get(callbackfunc)(eventTypeId, focusEvent, userData)) e.preventDefault()
                };
                var eventHandler = {
                    target: findEventTarget(target),
                    eventTypeString: eventTypeString,
                    callbackfunc: callbackfunc,
                    handlerFunc: focusEventHandlerFunc,
                    useCapture: useCapture
                };
                JSEvents.registerOrRemoveHandler(eventHandler)
            }
            Module["registerFocusEventCallback"] = registerFocusEventCallback;

            function _emscripten_set_blur_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                registerFocusEventCallback(target, userData, useCapture, callbackfunc, 12, "blur", targetThread);
                return 0
            }
            Module["_emscripten_set_blur_callback_on_thread"] = _emscripten_set_blur_callback_on_thread;
            _emscripten_set_blur_callback_on_thread.sig = "iiiiii";

            function _emscripten_set_focus_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                registerFocusEventCallback(target, userData, useCapture, callbackfunc, 13, "focus", targetThread);
                return 0
            }
            Module["_emscripten_set_focus_callback_on_thread"] = _emscripten_set_focus_callback_on_thread;
            _emscripten_set_focus_callback_on_thread.sig = "iiiiii";

            function _emscripten_set_focusin_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                registerFocusEventCallback(target, userData, useCapture, callbackfunc, 14, "focusin", targetThread);
                return 0
            }
            Module["_emscripten_set_focusin_callback_on_thread"] = _emscripten_set_focusin_callback_on_thread;
            _emscripten_set_focusin_callback_on_thread.sig = "iiiiii";

            function _emscripten_set_focusout_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                registerFocusEventCallback(target, userData, useCapture, callbackfunc, 15, "focusout", targetThread);
                return 0
            }
            Module["_emscripten_set_focusout_callback_on_thread"] = _emscripten_set_focusout_callback_on_thread;
            _emscripten_set_focusout_callback_on_thread.sig = "iiiiii";

            function fillDeviceOrientationEventData(eventStruct, e, target) {
                HEAPF64[eventStruct >> 3] = e.alpha;
                HEAPF64[eventStruct + 8 >> 3] = e.beta;
                HEAPF64[eventStruct + 16 >> 3] = e.gamma;
                HEAP32[eventStruct + 24 >> 2] = e.absolute
            }
            Module["fillDeviceOrientationEventData"] = fillDeviceOrientationEventData;

            function registerDeviceOrientationEventCallback(target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
                if (!JSEvents.deviceOrientationEvent) JSEvents.deviceOrientationEvent = _malloc(32);
                var deviceOrientationEventHandlerFunc = function(ev) {
                    var e = ev || event;
                    fillDeviceOrientationEventData(JSEvents.deviceOrientationEvent, e, target);
                    if (wasmTable.get(callbackfunc)(eventTypeId, JSEvents.deviceOrientationEvent, userData)) e.preventDefault()
                };
                var eventHandler = {
                    target: findEventTarget(target),
                    eventTypeString: eventTypeString,
                    callbackfunc: callbackfunc,
                    handlerFunc: deviceOrientationEventHandlerFunc,
                    useCapture: useCapture
                };
                JSEvents.registerOrRemoveHandler(eventHandler)
            }
            Module["registerDeviceOrientationEventCallback"] = registerDeviceOrientationEventCallback;

            function _emscripten_set_deviceorientation_callback_on_thread(userData, useCapture, callbackfunc, targetThread) {
                registerDeviceOrientationEventCallback(2, userData, useCapture, callbackfunc, 16, "deviceorientation", targetThread);
                return 0
            }
            Module["_emscripten_set_deviceorientation_callback_on_thread"] = _emscripten_set_deviceorientation_callback_on_thread;
            _emscripten_set_deviceorientation_callback_on_thread.sig = "iiiii";

            function _emscripten_get_deviceorientation_status(orientationState) {
                if (!JSEvents.deviceOrientationEvent) return -7;
                HEAP32.set(HEAP32.subarray(JSEvents.deviceOrientationEvent, 32), orientationState);
                return 0
            }
            Module["_emscripten_get_deviceorientation_status"] = _emscripten_get_deviceorientation_status;
            _emscripten_get_deviceorientation_status.sig = "ii";

            function fillDeviceMotionEventData(eventStruct, e, target) {
                var supportedFields = 0;
                var a = e["acceleration"];
                supportedFields |= a && 1;
                var ag = e["accelerationIncludingGravity"];
                supportedFields |= ag && 2;
                var rr = e["rotationRate"];
                supportedFields |= rr && 4;
                a = a || {};
                ag = ag || {};
                rr = rr || {};
                HEAPF64[eventStruct >> 3] = a["x"];
                HEAPF64[eventStruct + 8 >> 3] = a["y"];
                HEAPF64[eventStruct + 16 >> 3] = a["z"];
                HEAPF64[eventStruct + 24 >> 3] = ag["x"];
                HEAPF64[eventStruct + 32 >> 3] = ag["y"];
                HEAPF64[eventStruct + 40 >> 3] = ag["z"];
                HEAPF64[eventStruct + 48 >> 3] = rr["alpha"];
                HEAPF64[eventStruct + 56 >> 3] = rr["beta"];
                HEAPF64[eventStruct + 64 >> 3] = rr["gamma"]
            }
            Module["fillDeviceMotionEventData"] = fillDeviceMotionEventData;

            function registerDeviceMotionEventCallback(target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
                if (!JSEvents.deviceMotionEvent) JSEvents.deviceMotionEvent = _malloc(80);
                var deviceMotionEventHandlerFunc = function(ev) {
                    var e = ev || event;
                    fillDeviceMotionEventData(JSEvents.deviceMotionEvent, e, target);
                    if (wasmTable.get(callbackfunc)(eventTypeId, JSEvents.deviceMotionEvent, userData)) e.preventDefault()
                };
                var eventHandler = {
                    target: findEventTarget(target),
                    eventTypeString: eventTypeString,
                    callbackfunc: callbackfunc,
                    handlerFunc: deviceMotionEventHandlerFunc,
                    useCapture: useCapture
                };
                JSEvents.registerOrRemoveHandler(eventHandler)
            }
            Module["registerDeviceMotionEventCallback"] = registerDeviceMotionEventCallback;

            function _emscripten_set_devicemotion_callback_on_thread(userData, useCapture, callbackfunc, targetThread) {
                registerDeviceMotionEventCallback(2, userData, useCapture, callbackfunc, 17, "devicemotion", targetThread);
                return 0
            }
            Module["_emscripten_set_devicemotion_callback_on_thread"] = _emscripten_set_devicemotion_callback_on_thread;
            _emscripten_set_devicemotion_callback_on_thread.sig = "iiiii";

            function _emscripten_get_devicemotion_status(motionState) {
                if (!JSEvents.deviceMotionEvent) return -7;
                HEAP32.set(HEAP32.subarray(JSEvents.deviceMotionEvent, 80), motionState);
                return 0
            }
            Module["_emscripten_get_devicemotion_status"] = _emscripten_get_devicemotion_status;
            _emscripten_get_devicemotion_status.sig = "ii";

            function screenOrientation() {
                if (!screen) return undefined;
                return screen.orientation || screen.mozOrientation || screen.webkitOrientation || screen.msOrientation
            }
            Module["screenOrientation"] = screenOrientation;

            function fillOrientationChangeEventData(eventStruct) {
                var orientations = ["portrait-primary", "portrait-secondary", "landscape-primary", "landscape-secondary"];
                var orientations2 = ["portrait", "portrait", "landscape", "landscape"];
                var orientationString = screenOrientation();
                var orientation = orientations.indexOf(orientationString);
                if (orientation == -1) {
                    orientation = orientations2.indexOf(orientationString)
                }
                HEAP32[eventStruct >> 2] = 1 << orientation;
                HEAP32[eventStruct + 4 >> 2] = orientation
            }
            Module["fillOrientationChangeEventData"] = fillOrientationChangeEventData;

            function registerOrientationChangeEventCallback(target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
                if (!JSEvents.orientationChangeEvent) JSEvents.orientationChangeEvent = _malloc(8);
                var orientationChangeEventHandlerFunc = function(ev) {
                    var e = ev || event;
                    var orientationChangeEvent = JSEvents.orientationChangeEvent;
                    fillOrientationChangeEventData(orientationChangeEvent);
                    if (wasmTable.get(callbackfunc)(eventTypeId, orientationChangeEvent, userData)) e.preventDefault()
                };
                if (eventTypeString == "orientationchange" && screen.mozOrientation !== undefined) {
                    eventTypeString = "mozorientationchange"
                }
                var eventHandler = {
                    target: target,
                    eventTypeString: eventTypeString,
                    callbackfunc: callbackfunc,
                    handlerFunc: orientationChangeEventHandlerFunc,
                    useCapture: useCapture
                };
                JSEvents.registerOrRemoveHandler(eventHandler)
            }
            Module["registerOrientationChangeEventCallback"] = registerOrientationChangeEventCallback;

            function _emscripten_set_orientationchange_callback_on_thread(userData, useCapture, callbackfunc, targetThread) {
                if (!screen || !screen["addEventListener"]) return -1;
                registerOrientationChangeEventCallback(screen, userData, useCapture, callbackfunc, 18, "orientationchange", targetThread);
                return 0
            }
            Module["_emscripten_set_orientationchange_callback_on_thread"] = _emscripten_set_orientationchange_callback_on_thread;
            _emscripten_set_orientationchange_callback_on_thread.sig = "iiiii";

            function _emscripten_get_orientation_status(orientationChangeEvent) {
                if (!screenOrientation() && typeof orientation === "undefined") return -1;
                fillOrientationChangeEventData(orientationChangeEvent);
                return 0
            }
            Module["_emscripten_get_orientation_status"] = _emscripten_get_orientation_status;
            _emscripten_get_orientation_status.sig = "ii";

            function _emscripten_lock_orientation(allowedOrientations) {
                var orientations = [];
                if (allowedOrientations & 1) orientations.push("portrait-primary");
                if (allowedOrientations & 2) orientations.push("portrait-secondary");
                if (allowedOrientations & 4) orientations.push("landscape-primary");
                if (allowedOrientations & 8) orientations.push("landscape-secondary");
                var succeeded;
                if (screen.lockOrientation) {
                    succeeded = screen.lockOrientation(orientations)
                } else if (screen.mozLockOrientation) {
                    succeeded = screen.mozLockOrientation(orientations)
                } else if (screen.webkitLockOrientation) {
                    succeeded = screen.webkitLockOrientation(orientations)
                } else if (screen.msLockOrientation) {
                    succeeded = screen.msLockOrientation(orientations)
                } else {
                    return -1
                }
                if (succeeded) {
                    return 0
                } else {
                    return -6
                }
            }
            Module["_emscripten_lock_orientation"] = _emscripten_lock_orientation;
            _emscripten_lock_orientation.sig = "ii";

            function _emscripten_unlock_orientation() {
                if (screen.unlockOrientation) {
                    screen.unlockOrientation()
                } else if (screen.mozUnlockOrientation) {
                    screen.mozUnlockOrientation()
                } else if (screen.webkitUnlockOrientation) {
                    screen.webkitUnlockOrientation()
                } else if (screen.msUnlockOrientation) {
                    screen.msUnlockOrientation()
                } else {
                    return -1
                }
                return 0
            }
            Module["_emscripten_unlock_orientation"] = _emscripten_unlock_orientation;
            _emscripten_unlock_orientation.sig = "i";

            function fillFullscreenChangeEventData(eventStruct) {
                var fullscreenElement = document.fullscreenElement || document.mozFullScreenElement || document.webkitFullscreenElement || document.msFullscreenElement;
                var isFullscreen = !!fullscreenElement;
                HEAP32[eventStruct >> 2] = isFullscreen;
                HEAP32[eventStruct + 4 >> 2] = JSEvents.fullscreenEnabled();
                var reportedElement = isFullscreen ? fullscreenElement : JSEvents.previousFullscreenElement;
                var nodeName = JSEvents.getNodeNameForTarget(reportedElement);
                var id = reportedElement && reportedElement.id ? reportedElement.id : "";
                stringToUTF8(nodeName, eventStruct + 8, 128);
                stringToUTF8(id, eventStruct + 136, 128);
                HEAP32[eventStruct + 264 >> 2] = reportedElement ? reportedElement.clientWidth : 0;
                HEAP32[eventStruct + 268 >> 2] = reportedElement ? reportedElement.clientHeight : 0;
                HEAP32[eventStruct + 272 >> 2] = screen.width;
                HEAP32[eventStruct + 276 >> 2] = screen.height;
                if (isFullscreen) {
                    JSEvents.previousFullscreenElement = fullscreenElement
                }
            }
            Module["fillFullscreenChangeEventData"] = fillFullscreenChangeEventData;

            function registerFullscreenChangeEventCallback(target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
                if (!JSEvents.fullscreenChangeEvent) JSEvents.fullscreenChangeEvent = _malloc(280);
                var fullscreenChangeEventhandlerFunc = function(ev) {
                    var e = ev || event;
                    var fullscreenChangeEvent = JSEvents.fullscreenChangeEvent;
                    fillFullscreenChangeEventData(fullscreenChangeEvent);
                    if (wasmTable.get(callbackfunc)(eventTypeId, fullscreenChangeEvent, userData)) e.preventDefault()
                };
                var eventHandler = {
                    target: target,
                    eventTypeString: eventTypeString,
                    callbackfunc: callbackfunc,
                    handlerFunc: fullscreenChangeEventhandlerFunc,
                    useCapture: useCapture
                };
                JSEvents.registerOrRemoveHandler(eventHandler)
            }
            Module["registerFullscreenChangeEventCallback"] = registerFullscreenChangeEventCallback;

            function _emscripten_set_fullscreenchange_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                if (!JSEvents.fullscreenEnabled()) return -1;
                target = findEventTarget(target);
                if (!target) return -4;
                registerFullscreenChangeEventCallback(target, userData, useCapture, callbackfunc, 19, "fullscreenchange", targetThread);
                registerFullscreenChangeEventCallback(target, userData, useCapture, callbackfunc, 19, "webkitfullscreenchange", targetThread);
                return 0
            }
            Module["_emscripten_set_fullscreenchange_callback_on_thread"] = _emscripten_set_fullscreenchange_callback_on_thread;
            _emscripten_set_fullscreenchange_callback_on_thread.sig = "iiiiii";

            function _emscripten_get_fullscreen_status(fullscreenStatus) {
                if (!JSEvents.fullscreenEnabled()) return -1;
                fillFullscreenChangeEventData(fullscreenStatus);
                return 0
            }
            Module["_emscripten_get_fullscreen_status"] = _emscripten_get_fullscreen_status;
            _emscripten_get_fullscreen_status.sig = "ii";

            function _emscripten_get_canvas_element_size(target, width, height) {
                var canvas = findCanvasEventTarget(target);
                if (!canvas) return -4;
                HEAP32[width >> 2] = canvas.width;
                HEAP32[height >> 2] = canvas.height
            }
            Module["_emscripten_get_canvas_element_size"] = _emscripten_get_canvas_element_size;

            function getCanvasElementSize(target) {
                var stackTop = stackSave();
                var w = stackAlloc(8);
                var h = w + 4;
                var targetInt = stackAlloc(target.id.length + 1);
                stringToUTF8(target.id, targetInt, target.id.length + 1);
                var ret = _emscripten_get_canvas_element_size(targetInt, w, h);
                var size = [HEAP32[w >> 2], HEAP32[h >> 2]];
                stackRestore(stackTop);
                return size
            }
            Module["getCanvasElementSize"] = getCanvasElementSize;

            function _emscripten_set_canvas_element_size(target, width, height) {
                var canvas = findCanvasEventTarget(target);
                if (!canvas) return -4;
                canvas.width = width;
                canvas.height = height;
                return 0
            }
            Module["_emscripten_set_canvas_element_size"] = _emscripten_set_canvas_element_size;
            _emscripten_set_canvas_element_size.sig = "iiii";

            function setCanvasElementSize(target, width, height) {
                if (!target.controlTransferredOffscreen) {
                    target.width = width;
                    target.height = height
                } else {
                    var stackTop = stackSave();
                    var targetInt = stackAlloc(target.id.length + 1);
                    stringToUTF8(target.id, targetInt, target.id.length + 1);
                    _emscripten_set_canvas_element_size(targetInt, width, height);
                    stackRestore(stackTop)
                }
            }
            Module["setCanvasElementSize"] = setCanvasElementSize;

            function registerRestoreOldStyle(canvas) {
                var canvasSize = getCanvasElementSize(canvas);
                var oldWidth = canvasSize[0];
                var oldHeight = canvasSize[1];
                var oldCssWidth = canvas.style.width;
                var oldCssHeight = canvas.style.height;
                var oldBackgroundColor = canvas.style.backgroundColor;
                var oldDocumentBackgroundColor = document.body.style.backgroundColor;
                var oldPaddingLeft = canvas.style.paddingLeft;
                var oldPaddingRight = canvas.style.paddingRight;
                var oldPaddingTop = canvas.style.paddingTop;
                var oldPaddingBottom = canvas.style.paddingBottom;
                var oldMarginLeft = canvas.style.marginLeft;
                var oldMarginRight = canvas.style.marginRight;
                var oldMarginTop = canvas.style.marginTop;
                var oldMarginBottom = canvas.style.marginBottom;
                var oldDocumentBodyMargin = document.body.style.margin;
                var oldDocumentOverflow = document.documentElement.style.overflow;
                var oldDocumentScroll = document.body.scroll;
                var oldImageRendering = canvas.style.imageRendering;

                function restoreOldStyle() {
                    var fullscreenElement = document.fullscreenElement || document.webkitFullscreenElement || document.msFullscreenElement;
                    if (!fullscreenElement) {
                        document.removeEventListener("fullscreenchange", restoreOldStyle);
                        document.removeEventListener("webkitfullscreenchange", restoreOldStyle);
                        setCanvasElementSize(canvas, oldWidth, oldHeight);
                        canvas.style.width = oldCssWidth;
                        canvas.style.height = oldCssHeight;
                        canvas.style.backgroundColor = oldBackgroundColor;
                        if (!oldDocumentBackgroundColor) document.body.style.backgroundColor = "white";
                        document.body.style.backgroundColor = oldDocumentBackgroundColor;
                        canvas.style.paddingLeft = oldPaddingLeft;
                        canvas.style.paddingRight = oldPaddingRight;
                        canvas.style.paddingTop = oldPaddingTop;
                        canvas.style.paddingBottom = oldPaddingBottom;
                        canvas.style.marginLeft = oldMarginLeft;
                        canvas.style.marginRight = oldMarginRight;
                        canvas.style.marginTop = oldMarginTop;
                        canvas.style.marginBottom = oldMarginBottom;
                        document.body.style.margin = oldDocumentBodyMargin;
                        document.documentElement.style.overflow = oldDocumentOverflow;
                        document.body.scroll = oldDocumentScroll;
                        canvas.style.imageRendering = oldImageRendering;
                        if (canvas.GLctxObject) canvas.GLctxObject.GLctx.viewport(0, 0, oldWidth, oldHeight);
                        if (currentFullscreenStrategy.canvasResizedCallback) {
                            wasmTable.get(currentFullscreenStrategy.canvasResizedCallback)(37, 0, currentFullscreenStrategy.canvasResizedCallbackUserData)
                        }
                    }
                }
                document.addEventListener("fullscreenchange", restoreOldStyle);
                document.addEventListener("webkitfullscreenchange", restoreOldStyle);
                return restoreOldStyle
            }
            Module["registerRestoreOldStyle"] = registerRestoreOldStyle;

            function setLetterbox(element, topBottom, leftRight) {
                element.style.paddingLeft = element.style.paddingRight = leftRight + "px";
                element.style.paddingTop = element.style.paddingBottom = topBottom + "px"
            }
            Module["setLetterbox"] = setLetterbox;

            function _JSEvents_resizeCanvasForFullscreen(target, strategy) {
                var restoreOldStyle = registerRestoreOldStyle(target);
                var cssWidth = strategy.softFullscreen ? innerWidth : screen.width;
                var cssHeight = strategy.softFullscreen ? innerHeight : screen.height;
                var rect = getBoundingClientRect(target);
                var windowedCssWidth = rect.width;
                var windowedCssHeight = rect.height;
                var canvasSize = getCanvasElementSize(target);
                var windowedRttWidth = canvasSize[0];
                var windowedRttHeight = canvasSize[1];
                if (strategy.scaleMode == 3) {
                    setLetterbox(target, (cssHeight - windowedCssHeight) / 2, (cssWidth - windowedCssWidth) / 2);
                    cssWidth = windowedCssWidth;
                    cssHeight = windowedCssHeight
                } else if (strategy.scaleMode == 2) {
                    if (cssWidth * windowedRttHeight < windowedRttWidth * cssHeight) {
                        var desiredCssHeight = windowedRttHeight * cssWidth / windowedRttWidth;
                        setLetterbox(target, (cssHeight - desiredCssHeight) / 2, 0);
                        cssHeight = desiredCssHeight
                    } else {
                        var desiredCssWidth = windowedRttWidth * cssHeight / windowedRttHeight;
                        setLetterbox(target, 0, (cssWidth - desiredCssWidth) / 2);
                        cssWidth = desiredCssWidth
                    }
                }
                if (!target.style.backgroundColor) target.style.backgroundColor = "black";
                if (!document.body.style.backgroundColor) document.body.style.backgroundColor = "black";
                target.style.width = cssWidth + "px";
                target.style.height = cssHeight + "px";
                if (strategy.filteringMode == 1) {
                    target.style.imageRendering = "optimizeSpeed";
                    target.style.imageRendering = "-moz-crisp-edges";
                    target.style.imageRendering = "-o-crisp-edges";
                    target.style.imageRendering = "-webkit-optimize-contrast";
                    target.style.imageRendering = "optimize-contrast";
                    target.style.imageRendering = "crisp-edges";
                    target.style.imageRendering = "pixelated"
                }
                var dpiScale = strategy.canvasResolutionScaleMode == 2 ? devicePixelRatio : 1;
                if (strategy.canvasResolutionScaleMode != 0) {
                    var newWidth = cssWidth * dpiScale | 0;
                    var newHeight = cssHeight * dpiScale | 0;
                    setCanvasElementSize(target, newWidth, newHeight);
                    if (target.GLctxObject) target.GLctxObject.GLctx.viewport(0, 0, newWidth, newHeight)
                }
                return restoreOldStyle
            }
            Module["_JSEvents_resizeCanvasForFullscreen"] = _JSEvents_resizeCanvasForFullscreen;

            function _JSEvents_requestFullscreen(target, strategy) {
                if (strategy.scaleMode != 0 || strategy.canvasResolutionScaleMode != 0) {
                    _JSEvents_resizeCanvasForFullscreen(target, strategy)
                }
                if (target.requestFullscreen) {
                    target.requestFullscreen()
                } else if (target.webkitRequestFullscreen) {
                    target.webkitRequestFullscreen(Element.ALLOW_KEYBOARD_INPUT)
                } else {
                    return JSEvents.fullscreenEnabled() ? -3 : -1
                }
                currentFullscreenStrategy = strategy;
                if (strategy.canvasResizedCallback) {
                    wasmTable.get(strategy.canvasResizedCallback)(37, 0, strategy.canvasResizedCallbackUserData)
                }
                return 0
            }
            Module["_JSEvents_requestFullscreen"] = _JSEvents_requestFullscreen;

            function hideEverythingExceptGivenElement(onlyVisibleElement) {
                var child = onlyVisibleElement;
                var parent = child.parentNode;
                var hiddenElements = [];
                while (child != document.body) {
                    var children = parent.children;
                    for (var i = 0; i < children.length; ++i) {
                        if (children[i] != child) {
                            hiddenElements.push({
                                node: children[i],
                                displayState: children[i].style.display
                            });
                            children[i].style.display = "none"
                        }
                    }
                    child = parent;
                    parent = parent.parentNode
                }
                return hiddenElements
            }
            Module["hideEverythingExceptGivenElement"] = hideEverythingExceptGivenElement;

            function restoreHiddenElements(hiddenElements) {
                for (var i = 0; i < hiddenElements.length; ++i) {
                    hiddenElements[i].node.style.display = hiddenElements[i].displayState
                }
            }
            Module["restoreHiddenElements"] = restoreHiddenElements;
            var currentFullscreenStrategy = {};
            Module["currentFullscreenStrategy"] = currentFullscreenStrategy;
            var restoreOldWindowedStyle = null;
            Module["restoreOldWindowedStyle"] = restoreOldWindowedStyle;

            function softFullscreenResizeWebGLRenderTarget() {
                var dpr = devicePixelRatio;
                var inHiDPIFullscreenMode = currentFullscreenStrategy.canvasResolutionScaleMode == 2;
                var inAspectRatioFixedFullscreenMode = currentFullscreenStrategy.scaleMode == 2;
                var inPixelPerfectFullscreenMode = currentFullscreenStrategy.canvasResolutionScaleMode != 0;
                var inCenteredWithoutScalingFullscreenMode = currentFullscreenStrategy.scaleMode == 3;
                var screenWidth = inHiDPIFullscreenMode ? Math.round(innerWidth * dpr) : innerWidth;
                var screenHeight = inHiDPIFullscreenMode ? Math.round(innerHeight * dpr) : innerHeight;
                var w = screenWidth;
                var h = screenHeight;
                var canvas = currentFullscreenStrategy.target;
                var canvasSize = getCanvasElementSize(canvas);
                var x = canvasSize[0];
                var y = canvasSize[1];
                var topMargin;
                if (inAspectRatioFixedFullscreenMode) {
                    if (w * y < x * h) h = w * y / x | 0;
                    else if (w * y > x * h) w = h * x / y | 0;
                    topMargin = (screenHeight - h) / 2 | 0
                }
                if (inPixelPerfectFullscreenMode) {
                    setCanvasElementSize(canvas, w, h);
                    if (canvas.GLctxObject) canvas.GLctxObject.GLctx.viewport(0, 0, w, h)
                }
                if (inHiDPIFullscreenMode) {
                    topMargin /= dpr;
                    w /= dpr;
                    h /= dpr;
                    w = Math.round(w * 1e4) / 1e4;
                    h = Math.round(h * 1e4) / 1e4;
                    topMargin = Math.round(topMargin * 1e4) / 1e4
                }
                if (inCenteredWithoutScalingFullscreenMode) {
                    var t = (innerHeight - jstoi_q(canvas.style.height)) / 2;
                    var b = (innerWidth - jstoi_q(canvas.style.width)) / 2;
                    setLetterbox(canvas, t, b)
                } else {
                    canvas.style.width = w + "px";
                    canvas.style.height = h + "px";
                    var b = (innerWidth - w) / 2;
                    setLetterbox(canvas, topMargin, b)
                }
                if (!inCenteredWithoutScalingFullscreenMode && currentFullscreenStrategy.canvasResizedCallback) {
                    wasmTable.get(currentFullscreenStrategy.canvasResizedCallback)(37, 0, currentFullscreenStrategy.canvasResizedCallbackUserData)
                }
            }
            Module["softFullscreenResizeWebGLRenderTarget"] = softFullscreenResizeWebGLRenderTarget;

            function doRequestFullscreen(target, strategy) {
                if (!JSEvents.fullscreenEnabled()) return -1;
                target = findEventTarget(target);
                if (!target) return -4;
                if (!target.requestFullscreen && !target.webkitRequestFullscreen) {
                    return -3
                }
                var canPerformRequests = JSEvents.canPerformEventHandlerRequests();
                if (!canPerformRequests) {
                    if (strategy.deferUntilInEventHandler) {
                        JSEvents.deferCall(_JSEvents_requestFullscreen, 1, [target, strategy]);
                        return 1
                    } else {
                        return -2
                    }
                }
                return _JSEvents_requestFullscreen(target, strategy)
            }
            Module["doRequestFullscreen"] = doRequestFullscreen;

            function _emscripten_request_fullscreen(target, deferUntilInEventHandler) {
                var strategy = {
                    scaleMode: 0,
                    canvasResolutionScaleMode: 0,
                    filteringMode: 0,
                    deferUntilInEventHandler: deferUntilInEventHandler,
                    canvasResizedCallbackTargetThread: 2
                };
                return doRequestFullscreen(target, strategy)
            }
            Module["_emscripten_request_fullscreen"] = _emscripten_request_fullscreen;
            _emscripten_request_fullscreen.sig = "iii";

            function _emscripten_request_fullscreen_strategy(target, deferUntilInEventHandler, fullscreenStrategy) {
                var strategy = {
                    scaleMode: HEAP32[fullscreenStrategy >> 2],
                    canvasResolutionScaleMode: HEAP32[fullscreenStrategy + 4 >> 2],
                    filteringMode: HEAP32[fullscreenStrategy + 8 >> 2],
                    deferUntilInEventHandler: deferUntilInEventHandler,
                    canvasResizedCallback: HEAP32[fullscreenStrategy + 12 >> 2],
                    canvasResizedCallbackUserData: HEAP32[fullscreenStrategy + 16 >> 2]
                };
                return doRequestFullscreen(target, strategy)
            }
            Module["_emscripten_request_fullscreen_strategy"] = _emscripten_request_fullscreen_strategy;
            _emscripten_request_fullscreen_strategy.sig = "iiii";

            function _emscripten_enter_soft_fullscreen(target, fullscreenStrategy) {
                target = findEventTarget(target);
                if (!target) return -4;
                var strategy = {
                    scaleMode: HEAP32[fullscreenStrategy >> 2],
                    canvasResolutionScaleMode: HEAP32[fullscreenStrategy + 4 >> 2],
                    filteringMode: HEAP32[fullscreenStrategy + 8 >> 2],
                    canvasResizedCallback: HEAP32[fullscreenStrategy + 12 >> 2],
                    canvasResizedCallbackUserData: HEAP32[fullscreenStrategy + 16 >> 2],
                    target: target,
                    softFullscreen: true
                };
                var restoreOldStyle = _JSEvents_resizeCanvasForFullscreen(target, strategy);
                document.documentElement.style.overflow = "hidden";
                document.body.scroll = "no";
                document.body.style.margin = "0px";
                var hiddenElements = hideEverythingExceptGivenElement(target);

                function restoreWindowedState() {
                    restoreOldStyle();
                    restoreHiddenElements(hiddenElements);
                    removeEventListener("resize", softFullscreenResizeWebGLRenderTarget);
                    if (strategy.canvasResizedCallback) {
                        wasmTable.get(strategy.canvasResizedCallback)(37, 0, strategy.canvasResizedCallbackUserData)
                    }
                    currentFullscreenStrategy = 0
                }
                restoreOldWindowedStyle = restoreWindowedState;
                currentFullscreenStrategy = strategy;
                addEventListener("resize", softFullscreenResizeWebGLRenderTarget);
                if (strategy.canvasResizedCallback) {
                    wasmTable.get(strategy.canvasResizedCallback)(37, 0, strategy.canvasResizedCallbackUserData)
                }
                return 0
            }
            Module["_emscripten_enter_soft_fullscreen"] = _emscripten_enter_soft_fullscreen;
            _emscripten_enter_soft_fullscreen.sig = "iii";

            function _emscripten_exit_soft_fullscreen() {
                if (restoreOldWindowedStyle) restoreOldWindowedStyle();
                restoreOldWindowedStyle = null;
                return 0
            }
            Module["_emscripten_exit_soft_fullscreen"] = _emscripten_exit_soft_fullscreen;
            _emscripten_exit_soft_fullscreen.sig = "i";

            function _emscripten_exit_fullscreen() {
                if (!JSEvents.fullscreenEnabled()) return -1;
                JSEvents.removeDeferredCalls(_JSEvents_requestFullscreen);
                var d = specialHTMLTargets[1];
                if (d.exitFullscreen) {
                    d.fullscreenElement && d.exitFullscreen()
                } else if (d.webkitExitFullscreen) {
                    d.webkitFullscreenElement && d.webkitExitFullscreen()
                } else {
                    return -1
                }
                return 0
            }
            Module["_emscripten_exit_fullscreen"] = _emscripten_exit_fullscreen;
            _emscripten_exit_fullscreen.sig = "i";

            function fillPointerlockChangeEventData(eventStruct) {
                var pointerLockElement = document.pointerLockElement || document.mozPointerLockElement || document.webkitPointerLockElement || document.msPointerLockElement;
                var isPointerlocked = !!pointerLockElement;
                HEAP32[eventStruct >> 2] = isPointerlocked;
                var nodeName = JSEvents.getNodeNameForTarget(pointerLockElement);
                var id = pointerLockElement && pointerLockElement.id ? pointerLockElement.id : "";
                stringToUTF8(nodeName, eventStruct + 4, 128);
                stringToUTF8(id, eventStruct + 132, 128)
            }
            Module["fillPointerlockChangeEventData"] = fillPointerlockChangeEventData;

            function registerPointerlockChangeEventCallback(target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
                if (!JSEvents.pointerlockChangeEvent) JSEvents.pointerlockChangeEvent = _malloc(260);
                var pointerlockChangeEventHandlerFunc = function(ev) {
                    var e = ev || event;
                    var pointerlockChangeEvent = JSEvents.pointerlockChangeEvent;
                    fillPointerlockChangeEventData(pointerlockChangeEvent);
                    if (wasmTable.get(callbackfunc)(eventTypeId, pointerlockChangeEvent, userData)) e.preventDefault()
                };
                var eventHandler = {
                    target: target,
                    eventTypeString: eventTypeString,
                    callbackfunc: callbackfunc,
                    handlerFunc: pointerlockChangeEventHandlerFunc,
                    useCapture: useCapture
                };
                JSEvents.registerOrRemoveHandler(eventHandler)
            }
            Module["registerPointerlockChangeEventCallback"] = registerPointerlockChangeEventCallback;

            function _emscripten_set_pointerlockchange_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                if (!document || !document.body || !document.body.requestPointerLock && !document.body.mozRequestPointerLock && !document.body.webkitRequestPointerLock && !document.body.msRequestPointerLock) {
                    return -1
                }
                target = findEventTarget(target);
                if (!target) return -4;
                registerPointerlockChangeEventCallback(target, userData, useCapture, callbackfunc, 20, "pointerlockchange", targetThread);
                registerPointerlockChangeEventCallback(target, userData, useCapture, callbackfunc, 20, "mozpointerlockchange", targetThread);
                registerPointerlockChangeEventCallback(target, userData, useCapture, callbackfunc, 20, "webkitpointerlockchange", targetThread);
                registerPointerlockChangeEventCallback(target, userData, useCapture, callbackfunc, 20, "mspointerlockchange", targetThread);
                return 0
            }
            Module["_emscripten_set_pointerlockchange_callback_on_thread"] = _emscripten_set_pointerlockchange_callback_on_thread;
            _emscripten_set_pointerlockchange_callback_on_thread.sig = "iiiiii";

            function registerPointerlockErrorEventCallback(target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
                var pointerlockErrorEventHandlerFunc = function(ev) {
                    var e = ev || event;
                    if (wasmTable.get(callbackfunc)(eventTypeId, 0, userData)) e.preventDefault()
                };
                var eventHandler = {
                    target: target,
                    eventTypeString: eventTypeString,
                    callbackfunc: callbackfunc,
                    handlerFunc: pointerlockErrorEventHandlerFunc,
                    useCapture: useCapture
                };
                JSEvents.registerOrRemoveHandler(eventHandler)
            }
            Module["registerPointerlockErrorEventCallback"] = registerPointerlockErrorEventCallback;

            function _emscripten_set_pointerlockerror_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                if (!document || !document.body.requestPointerLock && !document.body.mozRequestPointerLock && !document.body.webkitRequestPointerLock && !document.body.msRequestPointerLock) {
                    return -1
                }
                target = findEventTarget(target);
                if (!target) return -4;
                registerPointerlockErrorEventCallback(target, userData, useCapture, callbackfunc, 38, "pointerlockerror", targetThread);
                registerPointerlockErrorEventCallback(target, userData, useCapture, callbackfunc, 38, "mozpointerlockerror", targetThread);
                registerPointerlockErrorEventCallback(target, userData, useCapture, callbackfunc, 38, "webkitpointerlockerror", targetThread);
                registerPointerlockErrorEventCallback(target, userData, useCapture, callbackfunc, 38, "mspointerlockerror", targetThread);
                return 0
            }
            Module["_emscripten_set_pointerlockerror_callback_on_thread"] = _emscripten_set_pointerlockerror_callback_on_thread;
            _emscripten_set_pointerlockerror_callback_on_thread.sig = "iiiiii";

            function _emscripten_get_pointerlock_status(pointerlockStatus) {
                if (pointerlockStatus) fillPointerlockChangeEventData(pointerlockStatus);
                if (!document.body || !document.body.requestPointerLock && !document.body.mozRequestPointerLock && !document.body.webkitRequestPointerLock && !document.body.msRequestPointerLock) {
                    return -1
                }
                return 0
            }
            Module["_emscripten_get_pointerlock_status"] = _emscripten_get_pointerlock_status;
            _emscripten_get_pointerlock_status.sig = "ii";

            function requestPointerLock(target) {
                if (target.requestPointerLock) {
                    target.requestPointerLock()
                } else if (target.msRequestPointerLock) {
                    target.msRequestPointerLock()
                } else {
                    if (document.body.requestPointerLock || document.body.msRequestPointerLock) {
                        return -3
                    } else {
                        return -1
                    }
                }
                return 0
            }
            Module["requestPointerLock"] = requestPointerLock;

            function _emscripten_request_pointerlock(target, deferUntilInEventHandler) {
                target = findEventTarget(target);
                if (!target) return -4;
                if (!target.requestPointerLock && !target.msRequestPointerLock) {
                    return -1
                }
                var canPerformRequests = JSEvents.canPerformEventHandlerRequests();
                if (!canPerformRequests) {
                    if (deferUntilInEventHandler) {
                        JSEvents.deferCall(requestPointerLock, 2, [target]);
                        return 1
                    } else {
                        return -2
                    }
                }
                return requestPointerLock(target)
            }
            Module["_emscripten_request_pointerlock"] = _emscripten_request_pointerlock;
            _emscripten_request_pointerlock.sig = "iii";

            function _emscripten_exit_pointerlock() {
                JSEvents.removeDeferredCalls(requestPointerLock);
                if (document.exitPointerLock) {
                    document.exitPointerLock()
                } else if (document.msExitPointerLock) {
                    document.msExitPointerLock()
                } else {
                    return -1
                }
                return 0
            }
            Module["_emscripten_exit_pointerlock"] = _emscripten_exit_pointerlock;
            _emscripten_exit_pointerlock.sig = "i";

            function _emscripten_vibrate(msecs) {
                if (!navigator.vibrate) return -1;
                navigator.vibrate(msecs);
                return 0
            }
            Module["_emscripten_vibrate"] = _emscripten_vibrate;
            _emscripten_vibrate.sig = "ii";

            function _emscripten_vibrate_pattern(msecsArray, numEntries) {
                if (!navigator.vibrate) return -1;
                var vibrateList = [];
                for (var i = 0; i < numEntries; ++i) {
                    var msecs = HEAP32[msecsArray + i * 4 >> 2];
                    vibrateList.push(msecs)
                }
                navigator.vibrate(vibrateList);
                return 0
            }
            Module["_emscripten_vibrate_pattern"] = _emscripten_vibrate_pattern;
            _emscripten_vibrate_pattern.sig = "iii";

            function fillVisibilityChangeEventData(eventStruct) {
                var visibilityStates = ["hidden", "visible", "prerender", "unloaded"];
                var visibilityState = visibilityStates.indexOf(document.visibilityState);
                HEAP32[eventStruct >> 2] = document.hidden;
                HEAP32[eventStruct + 4 >> 2] = visibilityState
            }
            Module["fillVisibilityChangeEventData"] = fillVisibilityChangeEventData;

            function registerVisibilityChangeEventCallback(target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
                if (!JSEvents.visibilityChangeEvent) JSEvents.visibilityChangeEvent = _malloc(8);
                var visibilityChangeEventHandlerFunc = function(ev) {
                    var e = ev || event;
                    var visibilityChangeEvent = JSEvents.visibilityChangeEvent;
                    fillVisibilityChangeEventData(visibilityChangeEvent);
                    if (wasmTable.get(callbackfunc)(eventTypeId, visibilityChangeEvent, userData)) e.preventDefault()
                };
                var eventHandler = {
                    target: target,
                    eventTypeString: eventTypeString,
                    callbackfunc: callbackfunc,
                    handlerFunc: visibilityChangeEventHandlerFunc,
                    useCapture: useCapture
                };
                JSEvents.registerOrRemoveHandler(eventHandler)
            }
            Module["registerVisibilityChangeEventCallback"] = registerVisibilityChangeEventCallback;

            function _emscripten_set_visibilitychange_callback_on_thread(userData, useCapture, callbackfunc, targetThread) {
                if (!specialHTMLTargets[1]) {
                    return -4
                }
                registerVisibilityChangeEventCallback(specialHTMLTargets[1], userData, useCapture, callbackfunc, 21, "visibilitychange", targetThread);
                return 0
            }
            Module["_emscripten_set_visibilitychange_callback_on_thread"] = _emscripten_set_visibilitychange_callback_on_thread;
            _emscripten_set_visibilitychange_callback_on_thread.sig = "iiiii";

            function _emscripten_get_visibility_status(visibilityStatus) {
                if (typeof document.visibilityState === "undefined" && typeof document.hidden === "undefined") {
                    return -1
                }
                fillVisibilityChangeEventData(visibilityStatus);
                return 0
            }
            Module["_emscripten_get_visibility_status"] = _emscripten_get_visibility_status;
            _emscripten_get_visibility_status.sig = "ii";

            function registerTouchEventCallback(target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
                if (!JSEvents.touchEvent) JSEvents.touchEvent = _malloc(1684);
                target = findEventTarget(target);
                var touchEventHandlerFunc = function(e) {
                    var touches = {};
                    var et = e.touches;
                    for (var i = 0; i < et.length; ++i) {
                        var touch = et[i];
                        touches[touch.identifier] = touch
                    }
                    et = e.changedTouches;
                    for (var i = 0; i < et.length; ++i) {
                        var touch = et[i];
                        touch.isChanged = 1;
                        touches[touch.identifier] = touch
                    }
                    et = e.targetTouches;
                    for (var i = 0; i < et.length; ++i) {
                        touches[et[i].identifier].onTarget = 1
                    }
                    var touchEvent = JSEvents.touchEvent;
                    var idx = touchEvent >> 2;
                    HEAP32[idx + 1] = e.ctrlKey;
                    HEAP32[idx + 2] = e.shiftKey;
                    HEAP32[idx + 3] = e.altKey;
                    HEAP32[idx + 4] = e.metaKey;
                    idx += 5;
                    var targetRect = getBoundingClientRect(target);
                    var numTouches = 0;
                    for (var i in touches) {
                        var t = touches[i];
                        HEAP32[idx + 0] = t.identifier;
                        HEAP32[idx + 1] = t.screenX;
                        HEAP32[idx + 2] = t.screenY;
                        HEAP32[idx + 3] = t.clientX;
                        HEAP32[idx + 4] = t.clientY;
                        HEAP32[idx + 5] = t.pageX;
                        HEAP32[idx + 6] = t.pageY;
                        HEAP32[idx + 7] = t.isChanged;
                        HEAP32[idx + 8] = t.onTarget;
                        HEAP32[idx + 9] = t.clientX - targetRect.left;
                        HEAP32[idx + 10] = t.clientY - targetRect.top;
                        idx += 13;
                        if (++numTouches > 31) {
                            break
                        }
                    }
                    HEAP32[touchEvent >> 2] = numTouches;
                    if (wasmTable.get(callbackfunc)(eventTypeId, touchEvent, userData)) e.preventDefault()
                };
                var eventHandler = {
                    target: target,
                    allowsDeferredCalls: eventTypeString == "touchstart" || eventTypeString == "touchend",
                    eventTypeString: eventTypeString,
                    callbackfunc: callbackfunc,
                    handlerFunc: touchEventHandlerFunc,
                    useCapture: useCapture
                };
                JSEvents.registerOrRemoveHandler(eventHandler)
            }
            Module["registerTouchEventCallback"] = registerTouchEventCallback;

            function _emscripten_set_touchstart_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                registerTouchEventCallback(target, userData, useCapture, callbackfunc, 22, "touchstart", targetThread);
                return 0
            }
            Module["_emscripten_set_touchstart_callback_on_thread"] = _emscripten_set_touchstart_callback_on_thread;
            _emscripten_set_touchstart_callback_on_thread.sig = "iiiiii";

            function _emscripten_set_touchend_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                registerTouchEventCallback(target, userData, useCapture, callbackfunc, 23, "touchend", targetThread);
                return 0
            }
            Module["_emscripten_set_touchend_callback_on_thread"] = _emscripten_set_touchend_callback_on_thread;
            _emscripten_set_touchend_callback_on_thread.sig = "iiiiii";

            function _emscripten_set_touchmove_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                registerTouchEventCallback(target, userData, useCapture, callbackfunc, 24, "touchmove", targetThread);
                return 0
            }
            Module["_emscripten_set_touchmove_callback_on_thread"] = _emscripten_set_touchmove_callback_on_thread;
            _emscripten_set_touchmove_callback_on_thread.sig = "iiiiii";

            function _emscripten_set_touchcancel_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                registerTouchEventCallback(target, userData, useCapture, callbackfunc, 25, "touchcancel", targetThread);
                return 0
            }
            Module["_emscripten_set_touchcancel_callback_on_thread"] = _emscripten_set_touchcancel_callback_on_thread;
            _emscripten_set_touchcancel_callback_on_thread.sig = "iiiiii";

            function fillGamepadEventData(eventStruct, e) {
                HEAPF64[eventStruct >> 3] = e.timestamp;
                for (var i = 0; i < e.axes.length; ++i) {
                    HEAPF64[eventStruct + i * 8 + 16 >> 3] = e.axes[i]
                }
                for (var i = 0; i < e.buttons.length; ++i) {
                    if (typeof e.buttons[i] === "object") {
                        HEAPF64[eventStruct + i * 8 + 528 >> 3] = e.buttons[i].value
                    } else {
                        HEAPF64[eventStruct + i * 8 + 528 >> 3] = e.buttons[i]
                    }
                }
                for (var i = 0; i < e.buttons.length; ++i) {
                    if (typeof e.buttons[i] === "object") {
                        HEAP32[eventStruct + i * 4 + 1040 >> 2] = e.buttons[i].pressed
                    } else {
                        HEAP32[eventStruct + i * 4 + 1040 >> 2] = e.buttons[i] == 1
                    }
                }
                HEAP32[eventStruct + 1296 >> 2] = e.connected;
                HEAP32[eventStruct + 1300 >> 2] = e.index;
                HEAP32[eventStruct + 8 >> 2] = e.axes.length;
                HEAP32[eventStruct + 12 >> 2] = e.buttons.length;
                stringToUTF8(e.id, eventStruct + 1304, 64);
                stringToUTF8(e.mapping, eventStruct + 1368, 64)
            }
            Module["fillGamepadEventData"] = fillGamepadEventData;

            function registerGamepadEventCallback(target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
                if (!JSEvents.gamepadEvent) JSEvents.gamepadEvent = _malloc(1432);
                var gamepadEventHandlerFunc = function(ev) {
                    var e = ev || event;
                    var gamepadEvent = JSEvents.gamepadEvent;
                    fillGamepadEventData(gamepadEvent, e["gamepad"]);
                    if (wasmTable.get(callbackfunc)(eventTypeId, gamepadEvent, userData)) e.preventDefault()
                };
                var eventHandler = {
                    target: findEventTarget(target),
                    allowsDeferredCalls: true,
                    eventTypeString: eventTypeString,
                    callbackfunc: callbackfunc,
                    handlerFunc: gamepadEventHandlerFunc,
                    useCapture: useCapture
                };
                JSEvents.registerOrRemoveHandler(eventHandler)
            }
            Module["registerGamepadEventCallback"] = registerGamepadEventCallback;

            function _emscripten_set_gamepadconnected_callback_on_thread(userData, useCapture, callbackfunc, targetThread) {
                if (!navigator.getGamepads && !navigator.webkitGetGamepads) return -1;
                registerGamepadEventCallback(2, userData, useCapture, callbackfunc, 26, "gamepadconnected", targetThread);
                return 0
            }
            Module["_emscripten_set_gamepadconnected_callback_on_thread"] = _emscripten_set_gamepadconnected_callback_on_thread;
            _emscripten_set_gamepadconnected_callback_on_thread.sig = "iiiii";

            function _emscripten_set_gamepaddisconnected_callback_on_thread(userData, useCapture, callbackfunc, targetThread) {
                if (!navigator.getGamepads && !navigator.webkitGetGamepads) return -1;
                registerGamepadEventCallback(2, userData, useCapture, callbackfunc, 27, "gamepaddisconnected", targetThread);
                return 0
            }
            Module["_emscripten_set_gamepaddisconnected_callback_on_thread"] = _emscripten_set_gamepaddisconnected_callback_on_thread;
            _emscripten_set_gamepaddisconnected_callback_on_thread.sig = "iiiii";

            function _emscripten_sample_gamepad_data() {
                return (JSEvents.lastGamepadState = navigator.getGamepads ? navigator.getGamepads() : navigator.webkitGetGamepads ? navigator.webkitGetGamepads() : null) ? 0 : -1
            }
            Module["_emscripten_sample_gamepad_data"] = _emscripten_sample_gamepad_data;
            _emscripten_sample_gamepad_data.sig = "i";

            function _emscripten_get_num_gamepads() {
                return JSEvents.lastGamepadState.length
            }
            Module["_emscripten_get_num_gamepads"] = _emscripten_get_num_gamepads;
            _emscripten_get_num_gamepads.sig = "i";

            function _emscripten_get_gamepad_status(index, gamepadState) {
                if (index < 0 || index >= JSEvents.lastGamepadState.length) return -5;
                if (!JSEvents.lastGamepadState[index]) return -7;
                fillGamepadEventData(gamepadState, JSEvents.lastGamepadState[index]);
                return 0
            }
            Module["_emscripten_get_gamepad_status"] = _emscripten_get_gamepad_status;
            _emscripten_get_gamepad_status.sig = "iii";

            function registerBeforeUnloadEventCallback(target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString) {
                var beforeUnloadEventHandlerFunc = function(ev) {
                    var e = ev || event;
                    var confirmationMessage = wasmTable.get(callbackfunc)(eventTypeId, 0, userData);
                    if (confirmationMessage) {
                        confirmationMessage = UTF8ToString(confirmationMessage)
                    }
                    if (confirmationMessage) {
                        e.preventDefault();
                        e.returnValue = confirmationMessage;
                        return confirmationMessage
                    }
                };
                var eventHandler = {
                    target: findEventTarget(target),
                    eventTypeString: eventTypeString,
                    callbackfunc: callbackfunc,
                    handlerFunc: beforeUnloadEventHandlerFunc,
                    useCapture: useCapture
                };
                JSEvents.registerOrRemoveHandler(eventHandler)
            }
            Module["registerBeforeUnloadEventCallback"] = registerBeforeUnloadEventCallback;

            function _emscripten_set_beforeunload_callback_on_thread(userData, callbackfunc, targetThread) {
                if (typeof onbeforeunload === "undefined") return -1;
                if (targetThread !== 1) return -5;
                registerBeforeUnloadEventCallback(2, userData, true, callbackfunc, 28, "beforeunload");
                return 0
            }
            Module["_emscripten_set_beforeunload_callback_on_thread"] = _emscripten_set_beforeunload_callback_on_thread;
            _emscripten_set_beforeunload_callback_on_thread.sig = "iii";

            function fillBatteryEventData(eventStruct, e) {
                HEAPF64[eventStruct >> 3] = e.chargingTime;
                HEAPF64[eventStruct + 8 >> 3] = e.dischargingTime;
                HEAPF64[eventStruct + 16 >> 3] = e.level;
                HEAP32[eventStruct + 24 >> 2] = e.charging
            }
            Module["fillBatteryEventData"] = fillBatteryEventData;

            function battery() {
                return navigator.battery || navigator.mozBattery || navigator.webkitBattery
            }
            Module["battery"] = battery;

            function registerBatteryEventCallback(target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
                if (!JSEvents.batteryEvent) JSEvents.batteryEvent = _malloc(32);
                var batteryEventHandlerFunc = function(ev) {
                    var e = ev || event;
                    var batteryEvent = JSEvents.batteryEvent;
                    fillBatteryEventData(batteryEvent, battery());
                    if (wasmTable.get(callbackfunc)(eventTypeId, batteryEvent, userData)) e.preventDefault()
                };
                var eventHandler = {
                    target: findEventTarget(target),
                    eventTypeString: eventTypeString,
                    callbackfunc: callbackfunc,
                    handlerFunc: batteryEventHandlerFunc,
                    useCapture: useCapture
                };
                JSEvents.registerOrRemoveHandler(eventHandler)
            }
            Module["registerBatteryEventCallback"] = registerBatteryEventCallback;

            function _emscripten_set_batterychargingchange_callback_on_thread(userData, callbackfunc, targetThread) {
                if (!battery()) return -1;
                registerBatteryEventCallback(battery(), userData, true, callbackfunc, 29, "chargingchange", targetThread);
                return 0
            }
            Module["_emscripten_set_batterychargingchange_callback_on_thread"] = _emscripten_set_batterychargingchange_callback_on_thread;
            _emscripten_set_batterychargingchange_callback_on_thread.sig = "iii";

            function _emscripten_set_batterylevelchange_callback_on_thread(userData, callbackfunc, targetThread) {
                if (!battery()) return -1;
                registerBatteryEventCallback(battery(), userData, true, callbackfunc, 30, "levelchange", targetThread);
                return 0
            }
            Module["_emscripten_set_batterylevelchange_callback_on_thread"] = _emscripten_set_batterylevelchange_callback_on_thread;
            _emscripten_set_batterylevelchange_callback_on_thread.sig = "iii";

            function _emscripten_get_battery_status(batteryState) {
                if (!battery()) return -1;
                fillBatteryEventData(batteryState, battery());
                return 0
            }
            Module["_emscripten_get_battery_status"] = _emscripten_get_battery_status;
            _emscripten_get_battery_status.sig = "ii";

            function _emscripten_set_element_css_size(target, width, height) {
                target = findEventTarget(target);
                if (!target) return -4;
                target.style.width = width + "px";
                target.style.height = height + "px";
                return 0
            }
            Module["_emscripten_set_element_css_size"] = _emscripten_set_element_css_size;
            _emscripten_set_element_css_size.sig = "iiii";

            function _emscripten_get_element_css_size(target, width, height) {
                target = findEventTarget(target);
                if (!target) return -4;
                var rect = getBoundingClientRect(target);
                HEAPF64[width >> 3] = rect.width;
                HEAPF64[height >> 3] = rect.height;
                return 0
            }
            Module["_emscripten_get_element_css_size"] = _emscripten_get_element_css_size;
            _emscripten_get_element_css_size.sig = "iiii";

            function _emscripten_html5_remove_all_event_listeners() {
                JSEvents.removeAllEventListeners()
            }
            Module["_emscripten_html5_remove_all_event_listeners"] = _emscripten_html5_remove_all_event_listeners;
            _emscripten_html5_remove_all_event_listeners.sig = "v";

            function _emscripten_request_animation_frame(cb, userData) {
                return requestAnimationFrame(function(timeStamp) {
                    wasmTable.get(cb)(timeStamp, userData)
                })
            }
            Module["_emscripten_request_animation_frame"] = _emscripten_request_animation_frame;

            function _emscripten_cancel_animation_frame(id) {
                cancelAnimationFrame(id)
            }
            Module["_emscripten_cancel_animation_frame"] = _emscripten_cancel_animation_frame;

            function _emscripten_request_animation_frame_loop(cb, userData) {
                function tick(timeStamp) {
                    if (wasmTable.get(cb)(timeStamp, userData)) {
                        requestAnimationFrame(tick)
                    }
                }
                return requestAnimationFrame(tick)
            }
            Module["_emscripten_request_animation_frame_loop"] = _emscripten_request_animation_frame_loop;

            function polyfillSetImmediate() {}
            Module["polyfillSetImmediate"] = polyfillSetImmediate;

            function _emscripten_set_immediate(cb, userData) {
                polyfillSetImmediate();
                return emSetImmediate(function() {
                    wasmTable.get(cb)(userData)
                })
            }
            Module["_emscripten_set_immediate"] = _emscripten_set_immediate;

            function _emscripten_clear_immediate(id) {
                emClearImmediate(id)
            }
            Module["_emscripten_clear_immediate"] = _emscripten_clear_immediate;

            function _emscripten_set_immediate_loop(cb, userData) {
                polyfillSetImmediate();

                function tick() {
                    if (wasmTable.get(cb)(userData)) {
                        emSetImmediate(tick)
                    }
                }
                return emSetImmediate(tick)
            }
            Module["_emscripten_set_immediate_loop"] = _emscripten_set_immediate_loop;

            function _emscripten_set_timeout(cb, msecs, userData) {
                return setTimeout(function() {
                    wasmTable.get(cb)(userData)
                }, msecs)
            }
            Module["_emscripten_set_timeout"] = _emscripten_set_timeout;

            function _emscripten_clear_timeout(id) {
                clearTimeout(id)
            }
            Module["_emscripten_clear_timeout"] = _emscripten_clear_timeout;

            function _emscripten_set_timeout_loop(cb, msecs, userData) {
                function tick() {
                    var t = performance.now();
                    var n = t + msecs;
                    if (wasmTable.get(cb)(t, userData)) {
                        setTimeout(tick, n - performance.now())
                    }
                }
                return setTimeout(tick, 0)
            }
            Module["_emscripten_set_timeout_loop"] = _emscripten_set_timeout_loop;

            function _emscripten_set_interval(cb, msecs, userData) {
                return setInterval(function() {
                    wasmTable.get(cb)(userData)
                }, msecs)
            }
            Module["_emscripten_set_interval"] = _emscripten_set_interval;

            function _emscripten_clear_interval(id) {
                clearInterval(id)
            }
            Module["_emscripten_clear_interval"] = _emscripten_clear_interval;

            function _emscripten_date_now() {
                return Date.now()
            }
            Module["_emscripten_date_now"] = _emscripten_date_now;

            function _emscripten_performance_now() {
                return performance.now()
            }
            Module["_emscripten_performance_now"] = _emscripten_performance_now;

            function _emscripten_console_log(str) {
                console.log(UTF8ToString(str))
            }
            Module["_emscripten_console_log"] = _emscripten_console_log;

            function _emscripten_console_warn(str) {
                console.warn(UTF8ToString(str))
            }
            Module["_emscripten_console_warn"] = _emscripten_console_warn;

            function _emscripten_console_error(str) {
                console.error(UTF8ToString(str))
            }
            Module["_emscripten_console_error"] = _emscripten_console_error;

            function _emscripten_throw_number(number) {
                throw number
            }
            Module["_emscripten_throw_number"] = _emscripten_throw_number;

            function _emscripten_throw_string(str) {
                throw UTF8ToString(str)
            }
            Module["_emscripten_throw_string"] = _emscripten_throw_string;

            function _emscripten_unwind_to_js_event_loop() {
                throw "unwind"
            }
            Module["_emscripten_unwind_to_js_event_loop"] = _emscripten_unwind_to_js_event_loop;

            function _emscripten_get_device_pixel_ratio() {
                return typeof devicePixelRatio === "number" && devicePixelRatio || 1
            }
            Module["_emscripten_get_device_pixel_ratio"] = _emscripten_get_device_pixel_ratio;
            _emscripten_get_device_pixel_ratio.sig = "d";

            function _proc_exit(code) {
                try {
                    _exit(code)
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return e.errno
                }
            }
            Module["_proc_exit"] = _proc_exit;
            _proc_exit.sig = "vi";

            function checkWasiClock(clock_id) {
                return clock_id == 0 || clock_id == 1 || clock_id == 2 || clock_id == 3
            }
            Module["checkWasiClock"] = checkWasiClock;

            function _clock_time_get(clk_id, precision_low, precision_high, ptime) {
                try {
                    if (!checkWasiClock(clk_id)) {
                        return 28
                    }
                    var now;
                    if (clk_id === 0) {
                        now = Date.now()
                    } else if (_emscripten_get_now_is_monotonic) {
                        now = _emscripten_get_now()
                    } else {
                        return 52
                    }
                    var nsec = Math.round(now * 1e3 * 1e3);
                    HEAP32[ptime >> 2] = nsec >>> 0;
                    HEAP32[ptime + 4 >> 2] = nsec / Math.pow(2, 32) >>> 0;
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return e.errno
                }
            }
            Module["_clock_time_get"] = _clock_time_get;
            _clock_time_get.sig = "iiiii";

            function _clock_res_get(clk_id, pres) {
                try {
                    if (!checkWasiClock(clk_id)) {
                        return 28
                    }
                    var nsec;
                    if (clk_id === 0) {
                        nsec = 1e3 * 1e3
                    } else if (_emscripten_get_now_is_monotonic) {
                        nsec = _emscripten_get_now_res()
                    } else {
                        return 52
                    }
                    HEAP32[pres >> 2] = nsec >>> 0;
                    HEAP32[pres + 4 >> 2] = nsec / Math.pow(2, 32) >>> 0;
                    return 0
                } catch (e) {
                    if (typeof FS === "undefined" || !(e instanceof FS.ErrnoError)) abort(e);
                    return e.errno
                }
            }
            Module["_clock_res_get"] = _clock_res_get;
            _clock_res_get.sig = "iii";

            function writeI53ToI64Clamped(ptr, num) {
                if (num > 0x8000000000000000) {
                    HEAPU32[ptr >> 2] = 4294967295;
                    HEAPU32[ptr + 4 >> 2] = 2147483647
                } else if (num < -0x8000000000000000) {
                    HEAPU32[ptr >> 2] = 0;
                    HEAPU32[ptr + 4 >> 2] = 2147483648
                } else {
                    HEAPU32[ptr >> 2] = num;
                    HEAPU32[ptr + 4 >> 2] = (num - HEAPU32[ptr >> 2]) / 4294967296
                }
            }
            Module["writeI53ToI64Clamped"] = writeI53ToI64Clamped;

            function writeI53ToI64Signaling(ptr, num) {
                if (num > 0x8000000000000000 || num < -0x8000000000000000) {
                    throw "RangeError:" + num
                }
                HEAPU32[ptr >> 2] = num;
                HEAPU32[ptr + 4 >> 2] = (num - HEAPU32[ptr >> 2]) / 4294967296
            }
            Module["writeI53ToI64Signaling"] = writeI53ToI64Signaling;

            function writeI53ToU64Clamped(ptr, num) {
                if (num > 0x10000000000000000) HEAPU32[ptr >> 2] = HEAPU32[ptr + 4 >> 2] = 4294967295;
                else if (num < 0) HEAPU32[ptr >> 2] = HEAPU32[ptr + 4 >> 2] = 0;
                else {
                    HEAPU32[ptr >> 2] = num;
                    HEAPU32[ptr + 4 >> 2] = (num - HEAPU32[ptr >> 2]) / 4294967296
                }
            }
            Module["writeI53ToU64Clamped"] = writeI53ToU64Clamped;

            function writeI53ToU64Signaling(ptr, num) {
                if (num < 0 || num > 0x10000000000000000) {
                    throw "RangeError:" + num
                }
                HEAPU32[ptr >> 2] = num;
                HEAPU32[ptr + 4 >> 2] = (num - HEAPU32[ptr >> 2]) / 4294967296
            }
            Module["writeI53ToU64Signaling"] = writeI53ToU64Signaling;

            function readI53FromI64(ptr) {
                return HEAPU32[ptr >> 2] + HEAP32[ptr + 4 >> 2] * 4294967296
            }
            Module["readI53FromI64"] = readI53FromI64;

            function readI53FromU64(ptr) {
                return HEAPU32[ptr >> 2] + HEAPU32[ptr + 4 >> 2] * 4294967296
            }
            Module["readI53FromU64"] = readI53FromU64;
            var DLFCN = {
                error: null,
                errorMsg: null
            };
            Module["DLFCN"] = DLFCN;

            function _dlopen(filenameAddr, flags) {
                var searchpaths = [];
                var filename;
                if (filenameAddr === 0) {
                    filename = "__main__"
                } else {
                    filename = UTF8ToString(filenameAddr);
                    var isValidFile = function(filename) {
                        var target = FS.findObject(filename);
                        return target && !target.isFolder && !target.isDevice
                    };
                    if (!isValidFile(filename)) {
                        if (ENV["LD_LIBRARY_PATH"]) {
                            searchpaths = ENV["LD_LIBRARY_PATH"].split(":")
                        }
                        for (var ident in searchpaths) {
                            var searchfile = PATH.join2(searchpaths[ident], filename);
                            if (isValidFile(searchfile)) {
                                filename = searchfile;
                                break
                            }
                        }
                    }
                }
                if (!(flags & (1 | 2))) {
                    DLFCN.errorMsg = "invalid mode for dlopen(): Either RTLD_LAZY or RTLD_NOW is required";
                    return 0
                }
                var jsflags = {
                    global: Boolean(flags & 256),
                    nodelete: Boolean(flags & 4096),
                    fs: FS
                };
                try {
                    return loadDynamicLibrary(filename, jsflags)
                } catch (e) {
                    DLFCN.errorMsg = "Could not load dynamic lib: " + filename + "\n" + e;
                    return 0
                }
            }
            Module["_dlopen"] = _dlopen;
            _dlopen.sig = "iii";

            function _dlclose(handle) {
                var lib = LDSO.loadedLibs[handle];
                if (!lib) {
                    DLFCN.errorMsg = "Tried to dlclose() unopened handle: " + handle;
                    return 1
                }
                if (--lib.refcount == 0) {
                    delete LDSO.loadedLibNames[lib.name];
                    delete LDSO.loadedLibs[handle]
                }
                return 0
            }
            Module["_dlclose"] = _dlclose;
            _dlclose.sig = "ii";

            function _dlsym(handle, symbol) {
                symbol = UTF8ToString(symbol);
                var result;
                if (handle == 0) {
                    result = resolveGlobalSymbol(symbol, true);
                    if (!result) {
                        DLFCN.errorMsg = 'Tried to lookup unknown symbol "' + symbol + '" in dynamic lib: RTLD_DEFAULT';
                        return 0
                    }
                } else {
                    var lib = LDSO.loadedLibs[handle];
                    if (!lib) {
                        DLFCN.errorMsg = "Tried to dlsym() from an unopened handle: " + handle;
                        return 0
                    }
                    if (!lib.module.hasOwnProperty(symbol)) {
                        DLFCN.errorMsg = 'Tried to lookup unknown symbol "' + symbol + '" in dynamic lib: ' + lib.name;
                        return 0
                    }
                    result = lib.module["orig$" + symbol];
                    if (!result) result = lib.module[symbol]
                }
                if (typeof result === "function") {
                    return addFunctionWasm(result, result.sig)
                } else {
                    return result
                }
            }
            Module["_dlsym"] = _dlsym;
            _dlsym.sig = "iii";

            function _dlerror() {
                if (DLFCN.errorMsg === null) {
                    return 0
                }
                if (DLFCN.error) _free(DLFCN.error);
                DLFCN.error = stringToNewUTF8(DLFCN.errorMsg);
                DLFCN.errorMsg = null;
                return DLFCN.error
            }
            Module["_dlerror"] = _dlerror;
            _dlerror.sig = "i";

            function _dladdr(addr, info) {
                var fname = stringToNewUTF8(getExecutableName());
                HEAP32[info >> 2] = fname;
                HEAP32[info + 4 >> 2] = 0;
                HEAP32[info + 8 >> 2] = 0;
                HEAP32[info + 12 >> 2] = 0;
                return 1
            }
            Module["_dladdr"] = _dladdr;
            _dladdr.sig = "iii";
            var exceptionCaught = [];
            Module["exceptionCaught"] = exceptionCaught;

            function CatchInfo(ptr) {
                this.free = function() {
                    _free(this.ptr);
                    this.ptr = 0
                };
                this.set_base_ptr = function(basePtr) {
                    HEAP32[this.ptr >> 2] = basePtr
                };
                this.get_base_ptr = function() {
                    return HEAP32[this.ptr >> 2]
                };
                this.set_adjusted_ptr = function(adjustedPtr) {
                    var ptrSize = 4;
                    HEAP32[this.ptr + ptrSize >> 2] = adjustedPtr
                };
                this.get_adjusted_ptr = function() {
                    var ptrSize = 4;
                    return HEAP32[this.ptr + ptrSize >> 2]
                };
                this.get_exception_ptr = function() {
                    var isPointer = Module["___cxa_is_pointer_type"](this.get_exception_info().get_type());
                    if (isPointer) {
                        return HEAP32[this.get_base_ptr() >> 2]
                    }
                    var adjusted = this.get_adjusted_ptr();
                    if (adjusted !== 0) return adjusted;
                    return this.get_base_ptr()
                };
                this.get_exception_info = function() {
                    return new ExceptionInfo(this.get_base_ptr())
                };
                if (ptr === undefined) {
                    this.ptr = _malloc(8);
                    this.set_adjusted_ptr(0)
                } else {
                    this.ptr = ptr
                }
            }
            Module["CatchInfo"] = CatchInfo;

            function exception_addRef(info) {
                info.add_ref()
            }
            Module["exception_addRef"] = exception_addRef;

            function ___cxa_free_exception(ptr) {
                try {
                    return _free(new ExceptionInfo(ptr).ptr)
                } catch (e) {}
            }
            Module["___cxa_free_exception"] = ___cxa_free_exception;
            ___cxa_free_exception.sig = "vi";

            function exception_decRef(info) {
                if (info.release_ref() && !info.get_rethrown()) {
                    var destructor = info.get_destructor();
                    if (destructor) {
                        wasmTable.get(destructor)(info.excPtr)
                    }
                    ___cxa_free_exception(info.excPtr)
                }
            }
            Module["exception_decRef"] = exception_decRef;

            function ___cxa_allocate_exception(size) {
                return _malloc(size + ExceptionInfoAttrs.SIZE) + ExceptionInfoAttrs.SIZE
            }
            Module["___cxa_allocate_exception"] = ___cxa_allocate_exception;
            ___cxa_allocate_exception.sig = "vi";

            function ___cxa_rethrow() {
                var catchInfo = exceptionCaught.pop();
                if (!catchInfo) {
                    abort("no exception to throw")
                }
                var info = catchInfo.get_exception_info();
                var ptr = catchInfo.get_base_ptr();
                if (!info.get_rethrown()) {
                    exceptionCaught.push(catchInfo);
                    info.set_rethrown(true);
                    info.set_caught(false);
                    uncaughtExceptionCount++
                } else {
                    catchInfo.free()
                }
                exceptionLast = ptr;
                throw ptr
            }
            Module["___cxa_rethrow"] = ___cxa_rethrow;
            ___cxa_rethrow.sig = "v";

            function _llvm_eh_typeid_for(type) {
                return type
            }
            Module["_llvm_eh_typeid_for"] = _llvm_eh_typeid_for;

            function ___cxa_begin_catch(ptr) {
                var catchInfo = new CatchInfo(ptr);
                var info = catchInfo.get_exception_info();
                if (!info.get_caught()) {
                    info.set_caught(true);
                    uncaughtExceptionCount--
                }
                info.set_rethrown(false);
                exceptionCaught.push(catchInfo);
                exception_addRef(info);
                return catchInfo.get_exception_ptr()
            }
            Module["___cxa_begin_catch"] = ___cxa_begin_catch;

            function ___cxa_end_catch() {
                _setThrew(0);
                var catchInfo = exceptionCaught.pop();
                exception_decRef(catchInfo.get_exception_info());
                catchInfo.free();
                exceptionLast = 0
            }
            Module["___cxa_end_catch"] = ___cxa_end_catch;
            ___cxa_end_catch.sig = "v";

            function ___cxa_get_exception_ptr(ptr) {
                return new CatchInfo(ptr).get_exception_ptr()
            }
            Module["___cxa_get_exception_ptr"] = ___cxa_get_exception_ptr;

            function ___cxa_call_unexpected(exception) {
                err("Unexpected exception thrown, this is not properly supported - aborting");
                ABORT = true;
                throw exception
            }
            Module["___cxa_call_unexpected"] = ___cxa_call_unexpected;

            function ___resumeException(catchInfoPtr) {
                var catchInfo = new CatchInfo(catchInfoPtr);
                var ptr = catchInfo.get_base_ptr();
                if (!exceptionLast) {
                    exceptionLast = ptr
                }
                catchInfo.free();
                throw ptr
            }
            Module["___resumeException"] = ___resumeException;

            function ___cxa_find_matching_catch() {
                var thrown = exceptionLast;
                if (!thrown) {
                    setTempRet0(0);
                    return 0 | 0
                }
                var info = new ExceptionInfo(thrown);
                var thrownType = info.get_type();
                var catchInfo = new CatchInfo;
                catchInfo.set_base_ptr(thrown);
                if (!thrownType) {
                    setTempRet0(0);
                    return catchInfo.ptr | 0
                }
                var typeArray = Array.prototype.slice.call(arguments);
                var stackTop = stackSave();
                var exceptionThrowBuf = stackAlloc(4);
                HEAP32[exceptionThrowBuf >> 2] = thrown;
                for (var i = 0; i < typeArray.length; i++) {
                    var caughtType = typeArray[i];
                    if (caughtType === 0 || caughtType === thrownType) {
                        break
                    }
                    if (Module["___cxa_can_catch"](caughtType, thrownType, exceptionThrowBuf)) {
                        var adjusted = HEAP32[exceptionThrowBuf >> 2];
                        if (thrown !== adjusted) {
                            catchInfo.set_adjusted_ptr(adjusted)
                        }
                        setTempRet0(caughtType);
                        return catchInfo.ptr | 0
                    }
                }
                stackRestore(stackTop);
                setTempRet0(thrownType);
                return catchInfo.ptr | 0
            }
            Module["___cxa_find_matching_catch"] = ___cxa_find_matching_catch;

            function _emscripten_async_wget(url, file, onload, onerror) {
                var _url = UTF8ToString(url);
                var _file = UTF8ToString(file);
                _file = PATH_FS.resolve(_file);

                function doCallback(callback) {
                    if (callback) {
                        var stack = stackSave();
                        wasmTable.get(callback)(allocate(intArrayFromString(_file), ALLOC_STACK));
                        stackRestore(stack)
                    }
                }
                var destinationDirectory = PATH.dirname(_file);
                FS.createPreloadedFile(destinationDirectory, PATH.basename(_file), _url, true, true, function() {
                    doCallback(onload)
                }, function() {
                    doCallback(onerror)
                }, false, false, function() {
                    try {
                        FS.unlink(_file)
                    } catch (e) {}
                    FS.mkdirTree(destinationDirectory)
                })
            }
            Module["_emscripten_async_wget"] = _emscripten_async_wget;
            _emscripten_async_wget.sig = "viiii";
            var funcWrappers = {};
            Module["funcWrappers"] = funcWrappers;

            function getFuncWrapper(func, sig) {
                if (!func) return;
                assert(sig);
                if (!funcWrappers[sig]) {
                    funcWrappers[sig] = {}
                }
                var sigCache = funcWrappers[sig];
                if (!sigCache[func]) {
                    if (sig.length === 1) {
                        sigCache[func] = function dynCall_wrapper() {
                            return dynCall(sig, func)
                        }
                    } else if (sig.length === 2) {
                        sigCache[func] = function dynCall_wrapper(arg) {
                            return dynCall(sig, func, [arg])
                        }
                    } else {
                        sigCache[func] = function dynCall_wrapper() {
                            return dynCall(sig, func, Array.prototype.slice.call(arguments))
                        }
                    }
                }
                return sigCache[func]
            }
            Module["getFuncWrapper"] = getFuncWrapper;

            function _emscripten_async_wget_data(url, arg, onload, onerror) {
                Browser.asyncLoad(UTF8ToString(url), function(byteArray) {
                    var buffer = _malloc(byteArray.length);
                    HEAPU8.set(byteArray, buffer);
                    wasmTable.get(onload)(arg, buffer, byteArray.length);
                    _free(buffer)
                }, function() {
                    if (onerror) wasmTable.get(onerror)(arg)
                }, true)
            }
            Module["_emscripten_async_wget_data"] = _emscripten_async_wget_data;
            _emscripten_async_wget_data.sig = "viiii";

            function _emscripten_async_wget2(url, file, request, param, arg, onload, onerror, onprogress) {
                var _url = UTF8ToString(url);
                var _file = UTF8ToString(file);
                _file = PATH_FS.resolve(_file);
                var _request = UTF8ToString(request);
                var _param = UTF8ToString(param);
                var index = _file.lastIndexOf("/");
                var http = new XMLHttpRequest;
                http.open(_request, _url, true);
                http.responseType = "arraybuffer";
                var handle = Browser.getNextWgetRequestHandle();
                var destinationDirectory = PATH.dirname(_file);
                http.onload = function http_onload(e) {
                    if (http.status >= 200 && http.status < 300) {
                        try {
                            FS.unlink(_file)
                        } catch (e) {}
                        FS.mkdirTree(destinationDirectory);
                        FS.createDataFile(_file.substr(0, index), _file.substr(index + 1), new Uint8Array(http.response), true, true, false);
                        if (onload) {
                            var stack = stackSave();
                            wasmTable.get(onload)(handle, arg, allocate(intArrayFromString(_file), ALLOC_STACK));
                            stackRestore(stack)
                        }
                    } else {
                        if (onerror) wasmTable.get(onerror)(handle, arg, http.status)
                    }
                    delete Browser.wgetRequests[handle]
                };
                http.onerror = function http_onerror(e) {
                    if (onerror) wasmTable.get(onerror)(handle, arg, http.status);
                    delete Browser.wgetRequests[handle]
                };
                http.onprogress = function http_onprogress(e) {
                    if (e.lengthComputable || e.lengthComputable === undefined && e.total != 0) {
                        var percentComplete = e.loaded / e.total * 100;
                        if (onprogress) wasmTable.get(onprogress)(handle, arg, percentComplete)
                    }
                };
                http.onabort = function http_onabort(e) {
                    delete Browser.wgetRequests[handle]
                };
                if (_request == "POST") {
                    http.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
                    http.send(_param)
                } else {
                    http.send(null)
                }
                Browser.wgetRequests[handle] = http;
                return handle
            }
            Module["_emscripten_async_wget2"] = _emscripten_async_wget2;
            _emscripten_async_wget2.sig = "iiiiiiiii";

            function _emscripten_async_wget2_data(url, request, param, arg, free, onload, onerror, onprogress) {
                var _url = UTF8ToString(url);
                var _request = UTF8ToString(request);
                var _param = UTF8ToString(param);
                var http = new XMLHttpRequest;
                http.open(_request, _url, true);
                http.responseType = "arraybuffer";
                var handle = Browser.getNextWgetRequestHandle();
                http.onload = function http_onload(e) {
                    if (http.status >= 200 && http.status < 300 || http.status === 0 && _url.substr(0, 4).toLowerCase() != "http") {
                        var byteArray = new Uint8Array(http.response);
                        var buffer = _malloc(byteArray.length);
                        HEAPU8.set(byteArray, buffer);
                        if (onload) wasmTable.get(onload)(handle, arg, buffer, byteArray.length);
                        if (free) _free(buffer)
                    } else {
                        if (onerror) wasmTable.get(onerror)(handle, arg, http.status, http.statusText)
                    }
                    delete Browser.wgetRequests[handle]
                };
                http.onerror = function http_onerror(e) {
                    if (onerror) {
                        wasmTable.get(onerror)(handle, arg, http.status, http.statusText)
                    }
                    delete Browser.wgetRequests[handle]
                };
                http.onprogress = function http_onprogress(e) {
                    if (onprogress) wasmTable.get(onprogress)(handle, arg, e.loaded, e.lengthComputable || e.lengthComputable === undefined ? e.total : 0)
                };
                http.onabort = function http_onabort(e) {
                    delete Browser.wgetRequests[handle]
                };
                if (_request == "POST") {
                    http.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
                    http.send(_param)
                } else {
                    http.send(null)
                }
                Browser.wgetRequests[handle] = http;
                return handle
            }
            Module["_emscripten_async_wget2_data"] = _emscripten_async_wget2_data;
            _emscripten_async_wget2_data.sig = "iiiiiiiii";

            function _emscripten_async_wget2_abort(handle) {
                var http = Browser.wgetRequests[handle];
                if (http) {
                    http.abort()
                }
            }
            Module["_emscripten_async_wget2_abort"] = _emscripten_async_wget2_abort;
            _emscripten_async_wget2_abort.sig = "vi";

            function _emscripten_run_preload_plugins(file, onload, onerror) {
                var _file = UTF8ToString(file);
                var data = FS.analyzePath(_file);
                if (!data.exists) return -1;
                FS.createPreloadedFile(PATH.dirname(_file), PATH.basename(_file), new Uint8Array(data.object.contents), true, true, function() {
                    if (onload) wasmTable.get(onload)(file)
                }, function() {
                    if (onerror) wasmTable.get(onerror)(file)
                }, true);
                return 0
            }
            Module["_emscripten_run_preload_plugins"] = _emscripten_run_preload_plugins;
            _emscripten_run_preload_plugins.sig = "iiii";

            function _emscripten_run_preload_plugins_data(data, size, suffix, arg, onload, onerror) {
                var _suffix = UTF8ToString(suffix);
                if (!Browser.asyncPrepareDataCounter) Browser.asyncPrepareDataCounter = 0;
                var name = "prepare_data_" + Browser.asyncPrepareDataCounter++ + "." + _suffix;
                var lengthAsUTF8 = lengthBytesUTF8(name);
                var cname = _malloc(lengthAsUTF8 + 1);
                stringToUTF8(name, cname, lengthAsUTF8 + 1);
                FS.createPreloadedFile("/", name, HEAPU8.subarray(data, data + size), true, true, function() {
                    if (onload) wasmTable.get(onload)(arg, cname)
                }, function() {
                    if (onerror) wasmTable.get(onerror)(arg)
                }, true)
            }
            Module["_emscripten_run_preload_plugins_data"] = _emscripten_run_preload_plugins_data;
            _emscripten_run_preload_plugins_data.sig = "viiiiii";

            function _emscripten_async_run_script(script, millis) {
                Browser.safeSetTimeout(function() {
                    _emscripten_run_script(script)
                }, millis)
            }
            Module["_emscripten_async_run_script"] = _emscripten_async_run_script;

            function _emscripten_async_load_script(url, onload, onerror) {
                onload = wasmTable.get(onload);
                onerror = wasmTable.get(onerror);
                assert(runDependencies === 0, "async_load_script must be run when no other dependencies are active");
                var script = document.createElement("script");
                script.onload = function script_onload() {
                    if (onload) {
                        if (runDependencies > 0) {
                            dependenciesFulfilled = onload
                        } else {
                            onload()
                        }
                    }
                };
                script.onerror = function() {
                    if (onerror) onerror()
                };
                script.src = UTF8ToString(url);
                document.body.appendChild(script)
            }
            Module["_emscripten_async_load_script"] = _emscripten_async_load_script;

            function _emscripten_get_main_loop_timing(mode, value) {
                if (mode) HEAP32[mode >> 2] = Browser.mainLoop.timingMode;
                if (value) HEAP32[value >> 2] = Browser.mainLoop.timingValue
            }
            Module["_emscripten_get_main_loop_timing"] = _emscripten_get_main_loop_timing;
            _emscripten_get_main_loop_timing.sig = "vii";

            function _emscripten_set_main_loop(func, fps, simulateInfiniteLoop) {
                var browserIterationFunc = wasmTable.get(func);
                setMainLoop(browserIterationFunc, fps, simulateInfiniteLoop)
            }
            Module["_emscripten_set_main_loop"] = _emscripten_set_main_loop;

            function _emscripten_set_main_loop_arg(func, arg, fps, simulateInfiniteLoop) {
                var browserIterationFunc = function() {
                    wasmTable.get(func)(arg)
                };
                setMainLoop(browserIterationFunc, fps, simulateInfiniteLoop, arg)
            }
            Module["_emscripten_set_main_loop_arg"] = _emscripten_set_main_loop_arg;
            _emscripten_set_main_loop_arg.sig = "viiii";

            function _emscripten_cancel_main_loop() {
                Browser.mainLoop.pause();
                Browser.mainLoop.func = null
            }
            Module["_emscripten_cancel_main_loop"] = _emscripten_cancel_main_loop;
            _emscripten_cancel_main_loop.sig = "v";

            function _emscripten_pause_main_loop() {
                Browser.mainLoop.pause()
            }
            Module["_emscripten_pause_main_loop"] = _emscripten_pause_main_loop;
            _emscripten_pause_main_loop.sig = "v";

            function _emscripten_resume_main_loop() {
                Browser.mainLoop.resume()
            }
            Module["_emscripten_resume_main_loop"] = _emscripten_resume_main_loop;
            _emscripten_resume_main_loop.sig = "v";

            function __emscripten_push_main_loop_blocker(func, arg, name) {
                Browser.mainLoop.queue.push({
                    func: function() {
                        wasmTable.get(func)(arg)
                    },
                    name: UTF8ToString(name),
                    counted: true
                });
                Browser.mainLoop.updateStatus()
            }
            Module["__emscripten_push_main_loop_blocker"] = __emscripten_push_main_loop_blocker;

            function __emscripten_push_uncounted_main_loop_blocker(func, arg, name) {
                Browser.mainLoop.queue.push({
                    func: function() {
                        wasmTable.get(func)(arg)
                    },
                    name: UTF8ToString(name),
                    counted: false
                });
                Browser.mainLoop.updateStatus()
            }
            Module["__emscripten_push_uncounted_main_loop_blocker"] = __emscripten_push_uncounted_main_loop_blocker;

            function _emscripten_set_main_loop_expected_blockers(num) {
                Browser.mainLoop.expectedBlockers = num;
                Browser.mainLoop.remainingBlockers = num;
                Browser.mainLoop.updateStatus()
            }
            Module["_emscripten_set_main_loop_expected_blockers"] = _emscripten_set_main_loop_expected_blockers;
            _emscripten_set_main_loop_expected_blockers.sig = "vi";

            function _emscripten_async_call(func, arg, millis) {
                function wrapper() {
                    wasmTable.get(func)(arg)
                }
                if (millis >= 0) {
                    Browser.safeSetTimeout(wrapper, millis)
                } else {
                    Browser.safeRequestAnimationFrame(wrapper)
                }
            }
            Module["_emscripten_async_call"] = _emscripten_async_call;
            _emscripten_async_call.sig = "viii";

            function _emscripten_get_window_title() {
                var buflen = 256;
                if (!_emscripten_get_window_title.buffer) {
                    _emscripten_get_window_title.buffer = _malloc(buflen)
                }
                writeAsciiToMemory(document.title.slice(0, buflen - 1), _emscripten_get_window_title.buffer);
                return _emscripten_get_window_title.buffer
            }
            Module["_emscripten_get_window_title"] = _emscripten_get_window_title;
            _emscripten_get_window_title.sig = "iv";

            function _emscripten_set_window_title(title) {
                setWindowTitle(AsciiToString(title))
            }
            Module["_emscripten_set_window_title"] = _emscripten_set_window_title;
            _emscripten_set_window_title.sig = "vi";

            function _emscripten_get_screen_size(width, height) {
                HEAP32[width >> 2] = screen.width;
                HEAP32[height >> 2] = screen.height
            }
            Module["_emscripten_get_screen_size"] = _emscripten_get_screen_size;
            _emscripten_get_screen_size.sig = "vii";

            function _emscripten_hide_mouse() {
                var styleSheet = document.styleSheets[0];
                var rules = styleSheet.cssRules;
                for (var i = 0; i < rules.length; i++) {
                    if (rules[i].cssText.substr(0, 6) == "canvas") {
                        styleSheet.deleteRule(i);
                        i--
                    }
                }
                styleSheet.insertRule("canvas.emscripten { border: 1px solid black; cursor: none; }", 0)
            }
            Module["_emscripten_hide_mouse"] = _emscripten_hide_mouse;
            _emscripten_hide_mouse.sig = "v";

            function _emscripten_set_canvas_size(width, height) {
                Browser.setCanvasSize(width, height)
            }
            Module["_emscripten_set_canvas_size"] = _emscripten_set_canvas_size;
            _emscripten_set_canvas_size.sig = "vii";

            function _emscripten_get_canvas_size(width, height, isFullscreen) {
                var canvas = Module["canvas"];
                HEAP32[width >> 2] = canvas.width;
                HEAP32[height >> 2] = canvas.height;
                HEAP32[isFullscreen >> 2] = Browser.isFullscreen ? 1 : 0
            }
            Module["_emscripten_get_canvas_size"] = _emscripten_get_canvas_size;
            _emscripten_get_canvas_size.sig = "viii";

            function _emscripten_create_worker(url) {
                url = UTF8ToString(url);
                var id = Browser.workers.length;
                var info = {
                    worker: new Worker(url),
                    callbacks: [],
                    awaited: 0,
                    buffer: 0,
                    bufferSize: 0
                };
                info.worker.onmessage = function info_worker_onmessage(msg) {
                    if (ABORT) return;
                    var info = Browser.workers[id];
                    if (!info) return;
                    var callbackId = msg.data["callbackId"];
                    var callbackInfo = info.callbacks[callbackId];
                    if (!callbackInfo) return;
                    if (msg.data["finalResponse"]) {
                        info.awaited--;
                        info.callbacks[callbackId] = null
                    }
                    var data = msg.data["data"];
                    if (data) {
                        if (!data.byteLength) data = new Uint8Array(data);
                        if (!info.buffer || info.bufferSize < data.length) {
                            if (info.buffer) _free(info.buffer);
                            info.bufferSize = data.length;
                            info.buffer = _malloc(data.length)
                        }
                        HEAPU8.set(data, info.buffer);
                        callbackInfo.func(info.buffer, data.length, callbackInfo.arg)
                    } else {
                        callbackInfo.func(0, 0, callbackInfo.arg)
                    }
                };
                Browser.workers.push(info);
                return id
            }
            Module["_emscripten_create_worker"] = _emscripten_create_worker;
            _emscripten_create_worker.sig = "ii";

            function _emscripten_destroy_worker(id) {
                var info = Browser.workers[id];
                info.worker.terminate();
                if (info.buffer) _free(info.buffer);
                Browser.workers[id] = null
            }
            Module["_emscripten_destroy_worker"] = _emscripten_destroy_worker;
            _emscripten_destroy_worker.sig = "vi";

            function _emscripten_call_worker(id, funcName, data, size, callback, arg) {
                funcName = UTF8ToString(funcName);
                var info = Browser.workers[id];
                var callbackId = -1;
                if (callback) {
                    callbackId = info.callbacks.length;
                    info.callbacks.push({
                        func: wasmTable.get(callback),
                        arg: arg
                    });
                    info.awaited++
                }
                var transferObject = {
                    "funcName": funcName,
                    "callbackId": callbackId,
                    "data": data ? new Uint8Array(HEAPU8.subarray(data, data + size)) : 0
                };
                if (data) {
                    info.worker.postMessage(transferObject, [transferObject.data.buffer])
                } else {
                    info.worker.postMessage(transferObject)
                }
            }
            Module["_emscripten_call_worker"] = _emscripten_call_worker;
            _emscripten_call_worker.sig = "viiiiii";

            function _emscripten_get_worker_queue_size(id) {
                var info = Browser.workers[id];
                if (!info) return -1;
                return info.awaited
            }
            Module["_emscripten_get_worker_queue_size"] = _emscripten_get_worker_queue_size;
            _emscripten_get_worker_queue_size.sig = "i";

            function _emscripten_get_preloaded_image_data(path, w, h) {
                if ((path | 0) === path) path = UTF8ToString(path);
                path = PATH_FS.resolve(path);
                var canvas = Module["preloadedImages"][path];
                if (canvas) {
                    var ctx = canvas.getContext("2d");
                    var image = ctx.getImageData(0, 0, canvas.width, canvas.height);
                    var buf = _malloc(canvas.width * canvas.height * 4);
                    HEAPU8.set(image.data, buf);
                    HEAP32[w >> 2] = canvas.width;
                    HEAP32[h >> 2] = canvas.height;
                    return buf
                }
                return 0
            }
            Module["_emscripten_get_preloaded_image_data"] = _emscripten_get_preloaded_image_data;
            _emscripten_get_preloaded_image_data.sig = "iiii";

            function _emscripten_get_preloaded_image_data_from_FILE(file, w, h) {
                var fd = Module["_fileno"](file);
                var stream = FS.getStream(fd);
                if (stream) {
                    return _emscripten_get_preloaded_image_data(stream.path, w, h)
                }
                return 0
            }
            Module["_emscripten_get_preloaded_image_data_from_FILE"] = _emscripten_get_preloaded_image_data_from_FILE;
            _emscripten_get_preloaded_image_data_from_FILE.sig = "iiii";

            function _setNetworkCallback(event, userData, callback) {
                function _callback(data) {
                    try {
                        if (event === "error") {
                            var sp = stackSave();
                            var msg = allocate(intArrayFromString(data[2]), ALLOC_STACK);
                            wasmTable.get(callback)(data[0], data[1], msg, userData);
                            stackRestore(sp)
                        } else {
                            wasmTable.get(callback)(data, userData)
                        }
                    } catch (e) {
                        if (e instanceof ExitStatus) {
                            return
                        } else {
                            if (e && typeof e === "object" && e.stack) err("exception thrown: " + [e, e.stack]);
                            throw e
                        }
                    }
                }
                Module["websocket"]["on"](event, callback ? _callback : null)
            }
            Module["_setNetworkCallback"] = _setNetworkCallback;

            function _emscripten_set_socket_error_callback(userData, callback) {
                _setNetworkCallback("error", userData, callback)
            }
            Module["_emscripten_set_socket_error_callback"] = _emscripten_set_socket_error_callback;

            function _emscripten_set_socket_open_callback(userData, callback) {
                _setNetworkCallback("open", userData, callback)
            }
            Module["_emscripten_set_socket_open_callback"] = _emscripten_set_socket_open_callback;

            function _emscripten_set_socket_listen_callback(userData, callback) {
                _setNetworkCallback("listen", userData, callback)
            }
            Module["_emscripten_set_socket_listen_callback"] = _emscripten_set_socket_listen_callback;

            function _emscripten_set_socket_connection_callback(userData, callback) {
                _setNetworkCallback("connection", userData, callback)
            }
            Module["_emscripten_set_socket_connection_callback"] = _emscripten_set_socket_connection_callback;

            function _emscripten_set_socket_message_callback(userData, callback) {
                _setNetworkCallback("message", userData, callback)
            }
            Module["_emscripten_set_socket_message_callback"] = _emscripten_set_socket_message_callback;

            function _emscripten_set_socket_close_callback(userData, callback) {
                _setNetworkCallback("close", userData, callback)
            }
            Module["_emscripten_set_socket_close_callback"] = _emscripten_set_socket_close_callback;

            function _emscripten_webgl_enable_ANGLE_instanced_arrays(ctx) {
                return __webgl_enable_ANGLE_instanced_arrays(GL.contexts[ctx].GLctx)
            }
            Module["_emscripten_webgl_enable_ANGLE_instanced_arrays"] = _emscripten_webgl_enable_ANGLE_instanced_arrays;

            function _emscripten_webgl_enable_OES_vertex_array_object(ctx) {
                return __webgl_enable_OES_vertex_array_object(GL.contexts[ctx].GLctx)
            }
            Module["_emscripten_webgl_enable_OES_vertex_array_object"] = _emscripten_webgl_enable_OES_vertex_array_object;

            function _emscripten_webgl_enable_WEBGL_draw_buffers(ctx) {
                return __webgl_enable_WEBGL_draw_buffers(GL.contexts[ctx].GLctx)
            }
            Module["_emscripten_webgl_enable_WEBGL_draw_buffers"] = _emscripten_webgl_enable_WEBGL_draw_buffers;

            function _emscripten_webgl_enable_WEBGL_multi_draw(ctx) {
                return __webgl_enable_WEBGL_multi_draw(GL.contexts[ctx].GLctx)
            }
            Module["_emscripten_webgl_enable_WEBGL_multi_draw"] = _emscripten_webgl_enable_WEBGL_multi_draw;

            function _glPixelStorei(pname, param) {
                if (pname == 3317) {
                    GL.unpackAlignment = param
                }
                GLctx.pixelStorei(pname, param)
            }
            Module["_glPixelStorei"] = _glPixelStorei;
            _glPixelStorei.sig = "vii";

            function _glGetString(name_) {
                var ret = GL.stringCache[name_];
                if (!ret) {
                    switch (name_) {
                        case 7939:
                            var exts = GLctx.getSupportedExtensions() || [];
                            exts = exts.concat(exts.map(function(e) {
                                return "GL_" + e
                            }));
                            ret = stringToNewUTF8(exts.join(" "));
                            break;
                        case 7936:
                        case 7937:
                        case 37445:
                        case 37446:
                            var s = GLctx.getParameter(name_);
                            if (!s) {
                                GL.recordError(1280)
                            }
                            ret = s && stringToNewUTF8(s);
                            break;
                        case 7938:
                            var glVersion = GLctx.getParameter(7938); {
                                glVersion = "OpenGL ES 2.0 (" + glVersion + ")"
                            }
                            ret = stringToNewUTF8(glVersion);
                            break;
                        case 35724:
                            var glslVersion = GLctx.getParameter(35724);
                            var ver_re = /^WebGL GLSL ES ([0-9]\.[0-9][0-9]?)(?:$| .*)/;
                            var ver_num = glslVersion.match(ver_re);
                            if (ver_num !== null) {
                                if (ver_num[1].length == 3) ver_num[1] = ver_num[1] + "0";
                                glslVersion = "OpenGL ES GLSL ES " + ver_num[1] + " (" + glslVersion + ")"
                            }
                            ret = stringToNewUTF8(glslVersion);
                            break;
                        default:
                            GL.recordError(1280)
                    }
                    GL.stringCache[name_] = ret
                }
                return ret
            }
            Module["_glGetString"] = _glGetString;
            _glGetString.sig = "ii";

            function _glGetIntegerv(name_, p) {
                emscriptenWebGLGet(name_, p, 0)
            }
            Module["_glGetIntegerv"] = _glGetIntegerv;
            _glGetIntegerv.sig = "vii";

            function _glGetFloatv(name_, p) {
                emscriptenWebGLGet(name_, p, 2)
            }
            Module["_glGetFloatv"] = _glGetFloatv;
            _glGetFloatv.sig = "vii";

            function _glGetBooleanv(name_, p) {
                emscriptenWebGLGet(name_, p, 4)
            }
            Module["_glGetBooleanv"] = _glGetBooleanv;
            _glGetBooleanv.sig = "vii";

            function _glDeleteTextures(n, textures) {
                for (var i = 0; i < n; i++) {
                    var id = HEAP32[textures + i * 4 >> 2];
                    var texture = GL.textures[id];
                    if (!texture) continue;
                    GLctx.deleteTexture(texture);
                    texture.name = 0;
                    GL.textures[id] = null
                }
            }
            Module["_glDeleteTextures"] = _glDeleteTextures;
            _glDeleteTextures.sig = "vii";

            function _glCompressedTexImage2D(target, level, internalFormat, width, height, border, imageSize, data) {
                GLctx["compressedTexImage2D"](target, level, internalFormat, width, height, border, data ? HEAPU8.subarray(data, data + imageSize) : null)
            }
            Module["_glCompressedTexImage2D"] = _glCompressedTexImage2D;
            _glCompressedTexImage2D.sig = "viiiiiiii";

            function _glCompressedTexSubImage2D(target, level, xoffset, yoffset, width, height, format, imageSize, data) {
                GLctx["compressedTexSubImage2D"](target, level, xoffset, yoffset, width, height, format, data ? HEAPU8.subarray(data, data + imageSize) : null)
            }
            Module["_glCompressedTexSubImage2D"] = _glCompressedTexSubImage2D;
            _glCompressedTexSubImage2D.sig = "viiiiiiiii";

            function _glTexImage2D(target, level, internalFormat, width, height, border, format, type, pixels) {
                GLctx.texImage2D(target, level, internalFormat, width, height, border, format, type, pixels ? emscriptenWebGLGetTexPixelData(type, format, width, height, pixels, internalFormat) : null)
            }
            Module["_glTexImage2D"] = _glTexImage2D;
            _glTexImage2D.sig = "viiiiiiiii";

            function _glTexSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels) {
                var pixelData = null;
                if (pixels) pixelData = emscriptenWebGLGetTexPixelData(type, format, width, height, pixels, 0);
                GLctx.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixelData)
            }
            Module["_glTexSubImage2D"] = _glTexSubImage2D;
            _glTexSubImage2D.sig = "viiiiiiiii";

            function _glReadPixels(x, y, width, height, format, type, pixels) {
                var pixelData = emscriptenWebGLGetTexPixelData(type, format, width, height, pixels, format);
                if (!pixelData) {
                    GL.recordError(1280);
                    return
                }
                GLctx.readPixels(x, y, width, height, format, type, pixelData)
            }
            Module["_glReadPixels"] = _glReadPixels;
            _glReadPixels.sig = "viiiiiii";

            function _glBindTexture(target, texture) {
                GLctx.bindTexture(target, GL.textures[texture])
            }
            Module["_glBindTexture"] = _glBindTexture;
            _glBindTexture.sig = "vii";

            function _glGetTexParameterfv(target, pname, params) {
                if (!params) {
                    GL.recordError(1281);
                    return
                }
                HEAPF32[params >> 2] = GLctx.getTexParameter(target, pname)
            }
            Module["_glGetTexParameterfv"] = _glGetTexParameterfv;
            _glGetTexParameterfv.sig = "viii";

            function _glGetTexParameteriv(target, pname, params) {
                if (!params) {
                    GL.recordError(1281);
                    return
                }
                HEAP32[params >> 2] = GLctx.getTexParameter(target, pname)
            }
            Module["_glGetTexParameteriv"] = _glGetTexParameteriv;
            _glGetTexParameteriv.sig = "viii";

            function _glTexParameterfv(target, pname, params) {
                var param = HEAPF32[params >> 2];
                GLctx.texParameterf(target, pname, param)
            }
            Module["_glTexParameterfv"] = _glTexParameterfv;
            _glTexParameterfv.sig = "viii";

            function _glTexParameteriv(target, pname, params) {
                var param = HEAP32[params >> 2];
                GLctx.texParameteri(target, pname, param)
            }
            Module["_glTexParameteriv"] = _glTexParameteriv;
            _glTexParameteriv.sig = "viii";

            function _glIsTexture(id) {
                var texture = GL.textures[id];
                if (!texture) return 0;
                return GLctx.isTexture(texture)
            }
            Module["_glIsTexture"] = _glIsTexture;
            _glIsTexture.sig = "ii";

            function _glGenBuffers(n, buffers) {
                __glGenObject(n, buffers, "createBuffer", GL.buffers)
            }
            Module["_glGenBuffers"] = _glGenBuffers;
            _glGenBuffers.sig = "vii";

            function _glGenTextures(n, textures) {
                __glGenObject(n, textures, "createTexture", GL.textures)
            }
            Module["_glGenTextures"] = _glGenTextures;
            _glGenTextures.sig = "vii";

            function _glDeleteBuffers(n, buffers) {
                for (var i = 0; i < n; i++) {
                    var id = HEAP32[buffers + i * 4 >> 2];
                    var buffer = GL.buffers[id];
                    if (!buffer) continue;
                    GLctx.deleteBuffer(buffer);
                    buffer.name = 0;
                    GL.buffers[id] = null
                }
            }
            Module["_glDeleteBuffers"] = _glDeleteBuffers;
            _glDeleteBuffers.sig = "vii";

            function _glGetBufferParameteriv(target, value, data) {
                if (!data) {
                    GL.recordError(1281);
                    return
                }
                HEAP32[data >> 2] = GLctx.getBufferParameter(target, value)
            }
            Module["_glGetBufferParameteriv"] = _glGetBufferParameteriv;
            _glGetBufferParameteriv.sig = "viii";

            function _glBufferData(target, size, data, usage) {
                GLctx.bufferData(target, data ? HEAPU8.subarray(data, data + size) : size, usage)
            }
            Module["_glBufferData"] = _glBufferData;
            _glBufferData.sig = "viiii";

            function _glBufferSubData(target, offset, size, data) {
                GLctx.bufferSubData(target, offset, HEAPU8.subarray(data, data + size))
            }
            Module["_glBufferSubData"] = _glBufferSubData;
            _glBufferSubData.sig = "viiii";

            function _glGenQueriesEXT(n, ids) {
                for (var i = 0; i < n; i++) {
                    var query = GLctx.disjointTimerQueryExt["createQueryEXT"]();
                    if (!query) {
                        GL.recordError(1282);
                        while (i < n) HEAP32[ids + i++ * 4 >> 2] = 0;
                        return
                    }
                    var id = GL.getNewId(GL.queries);
                    query.name = id;
                    GL.queries[id] = query;
                    HEAP32[ids + i * 4 >> 2] = id
                }
            }
            Module["_glGenQueriesEXT"] = _glGenQueriesEXT;
            _glGenQueriesEXT.sig = "vii";

            function _glDeleteQueriesEXT(n, ids) {
                for (var i = 0; i < n; i++) {
                    var id = HEAP32[ids + i * 4 >> 2];
                    var query = GL.queries[id];
                    if (!query) continue;
                    GLctx.disjointTimerQueryExt["deleteQueryEXT"](query);
                    GL.queries[id] = null
                }
            }
            Module["_glDeleteQueriesEXT"] = _glDeleteQueriesEXT;
            _glDeleteQueriesEXT.sig = "vii";

            function _glIsQueryEXT(id) {
                var query = GL.queries[id];
                if (!query) return 0;
                return GLctx.disjointTimerQueryExt["isQueryEXT"](query)
            }
            Module["_glIsQueryEXT"] = _glIsQueryEXT;
            _glIsQueryEXT.sig = "ii";

            function _glBeginQueryEXT(target, id) {
                GLctx.disjointTimerQueryExt["beginQueryEXT"](target, GL.queries[id])
            }
            Module["_glBeginQueryEXT"] = _glBeginQueryEXT;
            _glBeginQueryEXT.sig = "vii";

            function _glEndQueryEXT(target) {
                GLctx.disjointTimerQueryExt["endQueryEXT"](target)
            }
            Module["_glEndQueryEXT"] = _glEndQueryEXT;
            _glEndQueryEXT.sig = "vi";

            function _glQueryCounterEXT(id, target) {
                GLctx.disjointTimerQueryExt["queryCounterEXT"](GL.queries[id], target)
            }
            Module["_glQueryCounterEXT"] = _glQueryCounterEXT;
            _glQueryCounterEXT.sig = "vii";

            function _glGetQueryivEXT(target, pname, params) {
                if (!params) {
                    GL.recordError(1281);
                    return
                }
                HEAP32[params >> 2] = GLctx.disjointTimerQueryExt["getQueryEXT"](target, pname)
            }
            Module["_glGetQueryivEXT"] = _glGetQueryivEXT;
            _glGetQueryivEXT.sig = "viii";

            function _glGetQueryObjectivEXT(id, pname, params) {
                if (!params) {
                    GL.recordError(1281);
                    return
                }
                var query = GL.queries[id];
                var param = GLctx.disjointTimerQueryExt["getQueryObjectEXT"](query, pname);
                var ret;
                if (typeof param == "boolean") {
                    ret = param ? 1 : 0
                } else {
                    ret = param
                }
                HEAP32[params >> 2] = ret
            }
            Module["_glGetQueryObjectivEXT"] = _glGetQueryObjectivEXT;
            _glGetQueryObjectivEXT.sig = "viii";

            function _glGetQueryObjectuivEXT(id, pname, params) {
                if (!params) {
                    GL.recordError(1281);
                    return
                }
                var query = GL.queries[id];
                var param = GLctx.disjointTimerQueryExt["getQueryObjectEXT"](query, pname);
                var ret;
                if (typeof param == "boolean") {
                    ret = param ? 1 : 0
                } else {
                    ret = param
                }
                HEAP32[params >> 2] = ret
            }
            Module["_glGetQueryObjectuivEXT"] = _glGetQueryObjectuivEXT;
            _glGetQueryObjectuivEXT.sig = "viii";

            function _glGetQueryObjecti64vEXT(id, pname, params) {
                if (!params) {
                    GL.recordError(1281);
                    return
                }
                var query = GL.queries[id];
                var param; {
                    param = GLctx.disjointTimerQueryExt["getQueryObjectEXT"](query, pname)
                }
                var ret;
                if (typeof param == "boolean") {
                    ret = param ? 1 : 0
                } else {
                    ret = param
                }
                writeI53ToI64(params, ret)
            }
            Module["_glGetQueryObjecti64vEXT"] = _glGetQueryObjecti64vEXT;
            _glGetQueryObjecti64vEXT.sig = "viii";

            function _glGetQueryObjectui64vEXT(id, pname, params) {
                if (!params) {
                    GL.recordError(1281);
                    return
                }
                var query = GL.queries[id];
                var param; {
                    param = GLctx.disjointTimerQueryExt["getQueryObjectEXT"](query, pname)
                }
                var ret;
                if (typeof param == "boolean") {
                    ret = param ? 1 : 0
                } else {
                    ret = param
                }
                writeI53ToI64(params, ret)
            }
            Module["_glGetQueryObjectui64vEXT"] = _glGetQueryObjectui64vEXT;
            _glGetQueryObjectui64vEXT.sig = "viii";

            function _glIsBuffer(buffer) {
                var b = GL.buffers[buffer];
                if (!b) return 0;
                return GLctx.isBuffer(b)
            }
            Module["_glIsBuffer"] = _glIsBuffer;
            _glIsBuffer.sig = "ii";

            function _glGenRenderbuffers(n, renderbuffers) {
                __glGenObject(n, renderbuffers, "createRenderbuffer", GL.renderbuffers)
            }
            Module["_glGenRenderbuffers"] = _glGenRenderbuffers;
            _glGenRenderbuffers.sig = "vii";

            function _glDeleteRenderbuffers(n, renderbuffers) {
                for (var i = 0; i < n; i++) {
                    var id = HEAP32[renderbuffers + i * 4 >> 2];
                    var renderbuffer = GL.renderbuffers[id];
                    if (!renderbuffer) continue;
                    GLctx.deleteRenderbuffer(renderbuffer);
                    renderbuffer.name = 0;
                    GL.renderbuffers[id] = null
                }
            }
            Module["_glDeleteRenderbuffers"] = _glDeleteRenderbuffers;
            _glDeleteRenderbuffers.sig = "vii";

            function _glBindRenderbuffer(target, renderbuffer) {
                GLctx.bindRenderbuffer(target, GL.renderbuffers[renderbuffer])
            }
            Module["_glBindRenderbuffer"] = _glBindRenderbuffer;
            _glBindRenderbuffer.sig = "vii";

            function _glGetRenderbufferParameteriv(target, pname, params) {
                if (!params) {
                    GL.recordError(1281);
                    return
                }
                HEAP32[params >> 2] = GLctx.getRenderbufferParameter(target, pname)
            }
            Module["_glGetRenderbufferParameteriv"] = _glGetRenderbufferParameteriv;
            _glGetRenderbufferParameteriv.sig = "viii";

            function _glIsRenderbuffer(renderbuffer) {
                var rb = GL.renderbuffers[renderbuffer];
                if (!rb) return 0;
                return GLctx.isRenderbuffer(rb)
            }
            Module["_glIsRenderbuffer"] = _glIsRenderbuffer;
            _glIsRenderbuffer.sig = "ii";

            function _glGetUniformfv(program, location, params) {
                emscriptenWebGLGetUniform(program, location, params, 2)
            }
            Module["_glGetUniformfv"] = _glGetUniformfv;
            _glGetUniformfv.sig = "viii";

            function _glGetUniformiv(program, location, params) {
                emscriptenWebGLGetUniform(program, location, params, 0)
            }
            Module["_glGetUniformiv"] = _glGetUniformiv;
            _glGetUniformiv.sig = "viii";

            function _glGetUniformLocation(program, name) {
                function getLeftBracePos(name) {
                    return name.slice(-1) == "]" && name.lastIndexOf("[")
                }
                name = UTF8ToString(name);
                if (program = GL.programs[program]) {
                    var uniformLocsById = program.uniformLocsById;
                    var uniformSizeAndIdsByName = program.uniformSizeAndIdsByName;
                    var i, j;
                    var arrayIndex = 0;
                    var uniformBaseName = name;
                    var leftBrace = getLeftBracePos(name);
                    if (!uniformLocsById) {
                        program.uniformLocsById = uniformLocsById = {};
                        program.uniformArrayNamesById = {};
                        for (i = 0; i < GLctx.getProgramParameter(program, 35718); ++i) {
                            var u = GLctx.getActiveUniform(program, i);
                            var nm = u.name;
                            var sz = u.size;
                            var lb = getLeftBracePos(nm);
                            var arrayName = lb > 0 ? nm.slice(0, lb) : nm;
                            var id = program.uniformIdCounter;
                            program.uniformIdCounter += sz;
                            uniformSizeAndIdsByName[arrayName] = [sz, id];
                            for (j = 0; j < sz; ++j) {
                                uniformLocsById[id] = j;
                                program.uniformArrayNamesById[id++] = arrayName
                            }
                        }
                    }
                    if (leftBrace > 0) {
                        arrayIndex = jstoi_q(name.slice(leftBrace + 1)) >>> 0;
                        uniformBaseName = name.slice(0, leftBrace)
                    }
                    var sizeAndId = uniformSizeAndIdsByName[uniformBaseName];
                    if (sizeAndId && arrayIndex < sizeAndId[0]) {
                        arrayIndex += sizeAndId[1];
                        if (uniformLocsById[arrayIndex] = uniformLocsById[arrayIndex] || GLctx.getUniformLocation(program, name)) {
                            return arrayIndex
                        }
                    }
                } else {
                    GL.recordError(1281)
                }
                return -1
            }
            Module["_glGetUniformLocation"] = _glGetUniformLocation;
            _glGetUniformLocation.sig = "iii";

            function _glGetVertexAttribfv(index, pname, params) {
                emscriptenWebGLGetVertexAttrib(index, pname, params, 2)
            }
            Module["_glGetVertexAttribfv"] = _glGetVertexAttribfv;
            _glGetVertexAttribfv.sig = "viii";

            function _glGetVertexAttribiv(index, pname, params) {
                emscriptenWebGLGetVertexAttrib(index, pname, params, 5)
            }
            Module["_glGetVertexAttribiv"] = _glGetVertexAttribiv;
            _glGetVertexAttribiv.sig = "viii";

            function _glGetVertexAttribPointerv(index, pname, pointer) {
                if (!pointer) {
                    GL.recordError(1281);
                    return
                }
                HEAP32[pointer >> 2] = GLctx.getVertexAttribOffset(index, pname)
            }
            Module["_glGetVertexAttribPointerv"] = _glGetVertexAttribPointerv;
            _glGetVertexAttribPointerv.sig = "viii";

            function _glUniform1f(location, v0) {
                GLctx.uniform1f(webglGetUniformLocation(location), v0)
            }
            Module["_glUniform1f"] = _glUniform1f;
            _glUniform1f.sig = "vif";

            function _glUniform2f(location, v0, v1) {
                GLctx.uniform2f(webglGetUniformLocation(location), v0, v1)
            }
            Module["_glUniform2f"] = _glUniform2f;
            _glUniform2f.sig = "viff";

            function _glUniform3f(location, v0, v1, v2) {
                GLctx.uniform3f(webglGetUniformLocation(location), v0, v1, v2)
            }
            Module["_glUniform3f"] = _glUniform3f;
            _glUniform3f.sig = "vifff";

            function _glUniform4f(location, v0, v1, v2, v3) {
                GLctx.uniform4f(webglGetUniformLocation(location), v0, v1, v2, v3)
            }
            Module["_glUniform4f"] = _glUniform4f;
            _glUniform4f.sig = "viffff";

            function _glUniform1i(location, v0) {
                GLctx.uniform1i(webglGetUniformLocation(location), v0)
            }
            Module["_glUniform1i"] = _glUniform1i;
            _glUniform1i.sig = "vii";

            function _glUniform2i(location, v0, v1) {
                GLctx.uniform2i(webglGetUniformLocation(location), v0, v1)
            }
            Module["_glUniform2i"] = _glUniform2i;
            _glUniform2i.sig = "viii";

            function _glUniform3i(location, v0, v1, v2) {
                GLctx.uniform3i(webglGetUniformLocation(location), v0, v1, v2)
            }
            Module["_glUniform3i"] = _glUniform3i;
            _glUniform3i.sig = "viiii";

            function _glUniform4i(location, v0, v1, v2, v3) {
                GLctx.uniform4i(webglGetUniformLocation(location), v0, v1, v2, v3)
            }
            Module["_glUniform4i"] = _glUniform4i;
            _glUniform4i.sig = "viiiii";

            function _glUniform1iv(location, count, value) {
                if (count <= 288) {
                    var view = __miniTempWebGLIntBuffers[count - 1];
                    for (var i = 0; i < count; ++i) {
                        view[i] = HEAP32[value + 4 * i >> 2]
                    }
                } else {
                    var view = HEAP32.subarray(value >> 2, value + count * 4 >> 2)
                }
                GLctx.uniform1iv(webglGetUniformLocation(location), view)
            }
            Module["_glUniform1iv"] = _glUniform1iv;
            _glUniform1iv.sig = "viii";

            function _glUniform2iv(location, count, value) {
                if (count <= 144) {
                    var view = __miniTempWebGLIntBuffers[2 * count - 1];
                    for (var i = 0; i < 2 * count; i += 2) {
                        view[i] = HEAP32[value + 4 * i >> 2];
                        view[i + 1] = HEAP32[value + (4 * i + 4) >> 2]
                    }
                } else {
                    var view = HEAP32.subarray(value >> 2, value + count * 8 >> 2)
                }
                GLctx.uniform2iv(webglGetUniformLocation(location), view)
            }
            Module["_glUniform2iv"] = _glUniform2iv;
            _glUniform2iv.sig = "viii";

            function _glUniform3iv(location, count, value) {
                if (count <= 96) {
                    var view = __miniTempWebGLIntBuffers[3 * count - 1];
                    for (var i = 0; i < 3 * count; i += 3) {
                        view[i] = HEAP32[value + 4 * i >> 2];
                        view[i + 1] = HEAP32[value + (4 * i + 4) >> 2];
                        view[i + 2] = HEAP32[value + (4 * i + 8) >> 2]
                    }
                } else {
                    var view = HEAP32.subarray(value >> 2, value + count * 12 >> 2)
                }
                GLctx.uniform3iv(webglGetUniformLocation(location), view)
            }
            Module["_glUniform3iv"] = _glUniform3iv;
            _glUniform3iv.sig = "viii";

            function _glUniform4iv(location, count, value) {
                if (count <= 72) {
                    var view = __miniTempWebGLIntBuffers[4 * count - 1];
                    for (var i = 0; i < 4 * count; i += 4) {
                        view[i] = HEAP32[value + 4 * i >> 2];
                        view[i + 1] = HEAP32[value + (4 * i + 4) >> 2];
                        view[i + 2] = HEAP32[value + (4 * i + 8) >> 2];
                        view[i + 3] = HEAP32[value + (4 * i + 12) >> 2]
                    }
                } else {
                    var view = HEAP32.subarray(value >> 2, value + count * 16 >> 2)
                }
                GLctx.uniform4iv(webglGetUniformLocation(location), view)
            }
            Module["_glUniform4iv"] = _glUniform4iv;
            _glUniform4iv.sig = "viii";

            function _glUniform1fv(location, count, value) {
                if (count <= 288) {
                    var view = miniTempWebGLFloatBuffers[count - 1];
                    for (var i = 0; i < count; ++i) {
                        view[i] = HEAPF32[value + 4 * i >> 2]
                    }
                } else {
                    var view = HEAPF32.subarray(value >> 2, value + count * 4 >> 2)
                }
                GLctx.uniform1fv(webglGetUniformLocation(location), view)
            }
            Module["_glUniform1fv"] = _glUniform1fv;
            _glUniform1fv.sig = "viii";

            function _glUniform2fv(location, count, value) {
                if (count <= 144) {
                    var view = miniTempWebGLFloatBuffers[2 * count - 1];
                    for (var i = 0; i < 2 * count; i += 2) {
                        view[i] = HEAPF32[value + 4 * i >> 2];
                        view[i + 1] = HEAPF32[value + (4 * i + 4) >> 2]
                    }
                } else {
                    var view = HEAPF32.subarray(value >> 2, value + count * 8 >> 2)
                }
                GLctx.uniform2fv(webglGetUniformLocation(location), view)
            }
            Module["_glUniform2fv"] = _glUniform2fv;
            _glUniform2fv.sig = "viii";

            function _glUniform3fv(location, count, value) {
                if (count <= 96) {
                    var view = miniTempWebGLFloatBuffers[3 * count - 1];
                    for (var i = 0; i < 3 * count; i += 3) {
                        view[i] = HEAPF32[value + 4 * i >> 2];
                        view[i + 1] = HEAPF32[value + (4 * i + 4) >> 2];
                        view[i + 2] = HEAPF32[value + (4 * i + 8) >> 2]
                    }
                } else {
                    var view = HEAPF32.subarray(value >> 2, value + count * 12 >> 2)
                }
                GLctx.uniform3fv(webglGetUniformLocation(location), view)
            }
            Module["_glUniform3fv"] = _glUniform3fv;
            _glUniform3fv.sig = "viii";

            function _glUniform4fv(location, count, value) {
                if (count <= 72) {
                    var view = miniTempWebGLFloatBuffers[4 * count - 1];
                    var heap = HEAPF32;
                    value >>= 2;
                    for (var i = 0; i < 4 * count; i += 4) {
                        var dst = value + i;
                        view[i] = heap[dst];
                        view[i + 1] = heap[dst + 1];
                        view[i + 2] = heap[dst + 2];
                        view[i + 3] = heap[dst + 3]
                    }
                } else {
                    var view = HEAPF32.subarray(value >> 2, value + count * 16 >> 2)
                }
                GLctx.uniform4fv(webglGetUniformLocation(location), view)
            }
            Module["_glUniform4fv"] = _glUniform4fv;
            _glUniform4fv.sig = "viii";

            function _glUniformMatrix2fv(location, count, transpose, value) {
                if (count <= 72) {
                    var view = miniTempWebGLFloatBuffers[4 * count - 1];
                    for (var i = 0; i < 4 * count; i += 4) {
                        view[i] = HEAPF32[value + 4 * i >> 2];
                        view[i + 1] = HEAPF32[value + (4 * i + 4) >> 2];
                        view[i + 2] = HEAPF32[value + (4 * i + 8) >> 2];
                        view[i + 3] = HEAPF32[value + (4 * i + 12) >> 2]
                    }
                } else {
                    var view = HEAPF32.subarray(value >> 2, value + count * 16 >> 2)
                }
                GLctx.uniformMatrix2fv(webglGetUniformLocation(location), !!transpose, view)
            }
            Module["_glUniformMatrix2fv"] = _glUniformMatrix2fv;
            _glUniformMatrix2fv.sig = "viiii";

            function _glUniformMatrix3fv(location, count, transpose, value) {
                if (count <= 32) {
                    var view = miniTempWebGLFloatBuffers[9 * count - 1];
                    for (var i = 0; i < 9 * count; i += 9) {
                        view[i] = HEAPF32[value + 4 * i >> 2];
                        view[i + 1] = HEAPF32[value + (4 * i + 4) >> 2];
                        view[i + 2] = HEAPF32[value + (4 * i + 8) >> 2];
                        view[i + 3] = HEAPF32[value + (4 * i + 12) >> 2];
                        view[i + 4] = HEAPF32[value + (4 * i + 16) >> 2];
                        view[i + 5] = HEAPF32[value + (4 * i + 20) >> 2];
                        view[i + 6] = HEAPF32[value + (4 * i + 24) >> 2];
                        view[i + 7] = HEAPF32[value + (4 * i + 28) >> 2];
                        view[i + 8] = HEAPF32[value + (4 * i + 32) >> 2]
                    }
                } else {
                    var view = HEAPF32.subarray(value >> 2, value + count * 36 >> 2)
                }
                GLctx.uniformMatrix3fv(webglGetUniformLocation(location), !!transpose, view)
            }
            Module["_glUniformMatrix3fv"] = _glUniformMatrix3fv;
            _glUniformMatrix3fv.sig = "viiii";

            function _glUniformMatrix4fv(location, count, transpose, value) {
                if (count <= 18) {
                    var view = miniTempWebGLFloatBuffers[16 * count - 1];
                    var heap = HEAPF32;
                    value >>= 2;
                    for (var i = 0; i < 16 * count; i += 16) {
                        var dst = value + i;
                        view[i] = heap[dst];
                        view[i + 1] = heap[dst + 1];
                        view[i + 2] = heap[dst + 2];
                        view[i + 3] = heap[dst + 3];
                        view[i + 4] = heap[dst + 4];
                        view[i + 5] = heap[dst + 5];
                        view[i + 6] = heap[dst + 6];
                        view[i + 7] = heap[dst + 7];
                        view[i + 8] = heap[dst + 8];
                        view[i + 9] = heap[dst + 9];
                        view[i + 10] = heap[dst + 10];
                        view[i + 11] = heap[dst + 11];
                        view[i + 12] = heap[dst + 12];
                        view[i + 13] = heap[dst + 13];
                        view[i + 14] = heap[dst + 14];
                        view[i + 15] = heap[dst + 15]
                    }
                } else {
                    var view = HEAPF32.subarray(value >> 2, value + count * 64 >> 2)
                }
                GLctx.uniformMatrix4fv(webglGetUniformLocation(location), !!transpose, view)
            }
            Module["_glUniformMatrix4fv"] = _glUniformMatrix4fv;
            _glUniformMatrix4fv.sig = "viiii";

            function _glBindBuffer(target, buffer) {
                GLctx.bindBuffer(target, GL.buffers[buffer])
            }
            Module["_glBindBuffer"] = _glBindBuffer;
            _glBindBuffer.sig = "vii";

            function _glVertexAttrib1fv(index, v) {
                GLctx.vertexAttrib1f(index, HEAPF32[v >> 2])
            }
            Module["_glVertexAttrib1fv"] = _glVertexAttrib1fv;
            _glVertexAttrib1fv.sig = "vii";

            function _glVertexAttrib2fv(index, v) {
                GLctx.vertexAttrib2f(index, HEAPF32[v >> 2], HEAPF32[v + 4 >> 2])
            }
            Module["_glVertexAttrib2fv"] = _glVertexAttrib2fv;
            _glVertexAttrib2fv.sig = "vii";

            function _glVertexAttrib3fv(index, v) {
                GLctx.vertexAttrib3f(index, HEAPF32[v >> 2], HEAPF32[v + 4 >> 2], HEAPF32[v + 8 >> 2])
            }
            Module["_glVertexAttrib3fv"] = _glVertexAttrib3fv;
            _glVertexAttrib3fv.sig = "vii";

            function _glVertexAttrib4fv(index, v) {
                GLctx.vertexAttrib4f(index, HEAPF32[v >> 2], HEAPF32[v + 4 >> 2], HEAPF32[v + 8 >> 2], HEAPF32[v + 12 >> 2])
            }
            Module["_glVertexAttrib4fv"] = _glVertexAttrib4fv;
            _glVertexAttrib4fv.sig = "vii";

            function _glGetAttribLocation(program, name) {
                return GLctx.getAttribLocation(GL.programs[program], UTF8ToString(name))
            }
            Module["_glGetAttribLocation"] = _glGetAttribLocation;
            _glGetAttribLocation.sig = "iii";

            function _glGetActiveAttrib(program, index, bufSize, length, size, type, name) {
                __glGetActiveAttribOrUniform("getActiveAttrib", program, index, bufSize, length, size, type, name)
            }
            Module["_glGetActiveAttrib"] = _glGetActiveAttrib;
            _glGetActiveAttrib.sig = "viiiiiii";

            function _glGetActiveUniform(program, index, bufSize, length, size, type, name) {
                __glGetActiveAttribOrUniform("getActiveUniform", program, index, bufSize, length, size, type, name)
            }
            Module["_glGetActiveUniform"] = _glGetActiveUniform;
            _glGetActiveUniform.sig = "viiiiiii";

            function _glCreateShader(shaderType) {
                var id = GL.getNewId(GL.shaders);
                GL.shaders[id] = GLctx.createShader(shaderType);
                return id
            }
            Module["_glCreateShader"] = _glCreateShader;
            _glCreateShader.sig = "ii";

            function _glDeleteShader(id) {
                if (!id) return;
                var shader = GL.shaders[id];
                if (!shader) {
                    GL.recordError(1281);
                    return
                }
                GLctx.deleteShader(shader);
                GL.shaders[id] = null
            }
            Module["_glDeleteShader"] = _glDeleteShader;
            _glDeleteShader.sig = "vi";

            function _glGetAttachedShaders(program, maxCount, count, shaders) {
                var result = GLctx.getAttachedShaders(GL.programs[program]);
                var len = result.length;
                if (len > maxCount) {
                    len = maxCount
                }
                HEAP32[count >> 2] = len;
                for (var i = 0; i < len; ++i) {
                    var id = GL.shaders.indexOf(result[i]);
                    HEAP32[shaders + i * 4 >> 2] = id
                }
            }
            Module["_glGetAttachedShaders"] = _glGetAttachedShaders;
            _glGetAttachedShaders.sig = "viiii";

            function _glShaderSource(shader, count, string, length) {
                var source = GL.getSource(shader, count, string, length);
                GLctx.shaderSource(GL.shaders[shader], source)
            }
            Module["_glShaderSource"] = _glShaderSource;
            _glShaderSource.sig = "viiii";

            function _glGetShaderSource(shader, bufSize, length, source) {
                var result = GLctx.getShaderSource(GL.shaders[shader]);
                if (!result) return;
                var numBytesWrittenExclNull = bufSize > 0 && source ? stringToUTF8(result, source, bufSize) : 0;
                if (length) HEAP32[length >> 2] = numBytesWrittenExclNull
            }
            Module["_glGetShaderSource"] = _glGetShaderSource;
            _glGetShaderSource.sig = "viiii";

            function _glCompileShader(shader) {
                GLctx.compileShader(GL.shaders[shader])
            }
            Module["_glCompileShader"] = _glCompileShader;
            _glCompileShader.sig = "vi";

            function _glGetShaderInfoLog(shader, maxLength, length, infoLog) {
                var log = GLctx.getShaderInfoLog(GL.shaders[shader]);
                if (log === null) log = "(unknown error)";
                var numBytesWrittenExclNull = maxLength > 0 && infoLog ? stringToUTF8(log, infoLog, maxLength) : 0;
                if (length) HEAP32[length >> 2] = numBytesWrittenExclNull
            }
            Module["_glGetShaderInfoLog"] = _glGetShaderInfoLog;
            _glGetShaderInfoLog.sig = "viiii";

            function _glGetShaderiv(shader, pname, p) {
                if (!p) {
                    GL.recordError(1281);
                    return
                }
                if (pname == 35716) {
                    var log = GLctx.getShaderInfoLog(GL.shaders[shader]);
                    if (log === null) log = "(unknown error)";
                    var logLength = log ? log.length + 1 : 0;
                    HEAP32[p >> 2] = logLength
                } else if (pname == 35720) {
                    var source = GLctx.getShaderSource(GL.shaders[shader]);
                    var sourceLength = source ? source.length + 1 : 0;
                    HEAP32[p >> 2] = sourceLength
                } else {
                    HEAP32[p >> 2] = GLctx.getShaderParameter(GL.shaders[shader], pname)
                }
            }
            Module["_glGetShaderiv"] = _glGetShaderiv;
            _glGetShaderiv.sig = "viii";

            function _glGetProgramiv(program, pname, p) {
                if (!p) {
                    GL.recordError(1281);
                    return
                }
                if (program >= GL.counter) {
                    GL.recordError(1281);
                    return
                }
                program = GL.programs[program];
                if (pname == 35716) {
                    var log = GLctx.getProgramInfoLog(program);
                    if (log === null) log = "(unknown error)";
                    HEAP32[p >> 2] = log.length + 1
                } else if (pname == 35719) {
                    if (!program.maxUniformLength) {
                        for (var i = 0; i < GLctx.getProgramParameter(program, 35718); ++i) {
                            program.maxUniformLength = Math.max(program.maxUniformLength, GLctx.getActiveUniform(program, i).name.length + 1)
                        }
                    }
                    HEAP32[p >> 2] = program.maxUniformLength
                } else if (pname == 35722) {
                    if (!program.maxAttributeLength) {
                        for (var i = 0; i < GLctx.getProgramParameter(program, 35721); ++i) {
                            program.maxAttributeLength = Math.max(program.maxAttributeLength, GLctx.getActiveAttrib(program, i).name.length + 1)
                        }
                    }
                    HEAP32[p >> 2] = program.maxAttributeLength
                } else if (pname == 35381) {
                    if (!program.maxUniformBlockNameLength) {
                        for (var i = 0; i < GLctx.getProgramParameter(program, 35382); ++i) {
                            program.maxUniformBlockNameLength = Math.max(program.maxUniformBlockNameLength, GLctx.getActiveUniformBlockName(program, i).length + 1)
                        }
                    }
                    HEAP32[p >> 2] = program.maxUniformBlockNameLength
                } else {
                    HEAP32[p >> 2] = GLctx.getProgramParameter(program, pname)
                }
            }
            Module["_glGetProgramiv"] = _glGetProgramiv;
            _glGetProgramiv.sig = "viii";

            function _glIsShader(shader) {
                var s = GL.shaders[shader];
                if (!s) return 0;
                return GLctx.isShader(s)
            }
            Module["_glIsShader"] = _glIsShader;
            _glIsShader.sig = "ii";

            function _glCreateProgram() {
                var id = GL.getNewId(GL.programs);
                var program = GLctx.createProgram();
                program.name = id;
                program.maxUniformLength = program.maxAttributeLength = program.maxUniformBlockNameLength = 0;
                program.uniformIdCounter = 1;
                GL.programs[id] = program;
                return id
            }
            Module["_glCreateProgram"] = _glCreateProgram;
            _glCreateProgram.sig = "i";

            function _glDeleteProgram(id) {
                if (!id) return;
                var program = GL.programs[id];
                if (!program) {
                    GL.recordError(1281);
                    return
                }
                GLctx.deleteProgram(program);
                program.name = 0;
                GL.programs[id] = null
            }
            Module["_glDeleteProgram"] = _glDeleteProgram;
            _glDeleteProgram.sig = "vi";

            function _glAttachShader(program, shader) {
                GLctx.attachShader(GL.programs[program], GL.shaders[shader])
            }
            Module["_glAttachShader"] = _glAttachShader;
            _glAttachShader.sig = "vii";

            function _glDetachShader(program, shader) {
                GLctx.detachShader(GL.programs[program], GL.shaders[shader])
            }
            Module["_glDetachShader"] = _glDetachShader;
            _glDetachShader.sig = "vii";

            function _glGetShaderPrecisionFormat(shaderType, precisionType, range, precision) {
                var result = GLctx.getShaderPrecisionFormat(shaderType, precisionType);
                HEAP32[range >> 2] = result.rangeMin;
                HEAP32[range + 4 >> 2] = result.rangeMax;
                HEAP32[precision >> 2] = result.precision
            }
            Module["_glGetShaderPrecisionFormat"] = _glGetShaderPrecisionFormat;
            _glGetShaderPrecisionFormat.sig = "viiii";

            function _glLinkProgram(program) {
                program = GL.programs[program];
                GLctx.linkProgram(program);
                program.uniformLocsById = 0;
                program.uniformSizeAndIdsByName = {}
            }
            Module["_glLinkProgram"] = _glLinkProgram;
            _glLinkProgram.sig = "vi";

            function _glGetProgramInfoLog(program, maxLength, length, infoLog) {
                var log = GLctx.getProgramInfoLog(GL.programs[program]);
                if (log === null) log = "(unknown error)";
                var numBytesWrittenExclNull = maxLength > 0 && infoLog ? stringToUTF8(log, infoLog, maxLength) : 0;
                if (length) HEAP32[length >> 2] = numBytesWrittenExclNull
            }
            Module["_glGetProgramInfoLog"] = _glGetProgramInfoLog;
            _glGetProgramInfoLog.sig = "viiii";

            function _glUseProgram(program) {
                program = GL.programs[program];
                GLctx.useProgram(program);
                GLctx.currentProgram = program
            }
            Module["_glUseProgram"] = _glUseProgram;
            _glUseProgram.sig = "vi";

            function _glValidateProgram(program) {
                GLctx.validateProgram(GL.programs[program])
            }
            Module["_glValidateProgram"] = _glValidateProgram;
            _glValidateProgram.sig = "vi";

            function _glIsProgram(program) {
                program = GL.programs[program];
                if (!program) return 0;
                return GLctx.isProgram(program)
            }
            Module["_glIsProgram"] = _glIsProgram;
            _glIsProgram.sig = "ii";

            function _glBindAttribLocation(program, index, name) {
                GLctx.bindAttribLocation(GL.programs[program], index, UTF8ToString(name))
            }
            Module["_glBindAttribLocation"] = _glBindAttribLocation;
            _glBindAttribLocation.sig = "viii";

            function _glBindFramebuffer(target, framebuffer) {
                GLctx.bindFramebuffer(target, GL.framebuffers[framebuffer])
            }
            Module["_glBindFramebuffer"] = _glBindFramebuffer;
            _glBindFramebuffer.sig = "vii";

            function _glGenFramebuffers(n, ids) {
                __glGenObject(n, ids, "createFramebuffer", GL.framebuffers)
            }
            Module["_glGenFramebuffers"] = _glGenFramebuffers;
            _glGenFramebuffers.sig = "vii";

            function _glDeleteFramebuffers(n, framebuffers) {
                for (var i = 0; i < n; ++i) {
                    var id = HEAP32[framebuffers + i * 4 >> 2];
                    var framebuffer = GL.framebuffers[id];
                    if (!framebuffer) continue;
                    GLctx.deleteFramebuffer(framebuffer);
                    framebuffer.name = 0;
                    GL.framebuffers[id] = null
                }
            }
            Module["_glDeleteFramebuffers"] = _glDeleteFramebuffers;
            _glDeleteFramebuffers.sig = "vii";

            function _glFramebufferRenderbuffer(target, attachment, renderbuffertarget, renderbuffer) {
                GLctx.framebufferRenderbuffer(target, attachment, renderbuffertarget, GL.renderbuffers[renderbuffer])
            }
            Module["_glFramebufferRenderbuffer"] = _glFramebufferRenderbuffer;
            _glFramebufferRenderbuffer.sig = "viiii";

            function _glFramebufferTexture2D(target, attachment, textarget, texture, level) {
                GLctx.framebufferTexture2D(target, attachment, textarget, GL.textures[texture], level)
            }
            Module["_glFramebufferTexture2D"] = _glFramebufferTexture2D;
            _glFramebufferTexture2D.sig = "viiiii";

            function _glGetFramebufferAttachmentParameteriv(target, attachment, pname, params) {
                var result = GLctx.getFramebufferAttachmentParameter(target, attachment, pname);
                if (result instanceof WebGLRenderbuffer || result instanceof WebGLTexture) {
                    result = result.name | 0
                }
                HEAP32[params >> 2] = result
            }
            Module["_glGetFramebufferAttachmentParameteriv"] = _glGetFramebufferAttachmentParameteriv;
            _glGetFramebufferAttachmentParameteriv.sig = "viiii";

            function _glIsFramebuffer(framebuffer) {
                var fb = GL.framebuffers[framebuffer];
                if (!fb) return 0;
                return GLctx.isFramebuffer(fb)
            }
            Module["_glIsFramebuffer"] = _glIsFramebuffer;
            _glIsFramebuffer.sig = "ii";

            function _glGenVertexArrays(n, arrays) {
                __glGenObject(n, arrays, "createVertexArray", GL.vaos)
            }
            Module["_glGenVertexArrays"] = _glGenVertexArrays;
            _glGenVertexArrays.sig = "vii";

            function _glDeleteVertexArrays(n, vaos) {
                for (var i = 0; i < n; i++) {
                    var id = HEAP32[vaos + i * 4 >> 2];
                    GLctx["deleteVertexArray"](GL.vaos[id]);
                    GL.vaos[id] = null
                }
            }
            Module["_glDeleteVertexArrays"] = _glDeleteVertexArrays;
            _glDeleteVertexArrays.sig = "vii";

            function _glBindVertexArray(vao) {
                GLctx["bindVertexArray"](GL.vaos[vao])
            }
            Module["_glBindVertexArray"] = _glBindVertexArray;
            _glBindVertexArray.sig = "vi";

            function _glIsVertexArray(array) {
                var vao = GL.vaos[array];
                if (!vao) return 0;
                return GLctx["isVertexArray"](vao)
            }
            Module["_glIsVertexArray"] = _glIsVertexArray;
            _glIsVertexArray.sig = "ii";

            function _glVertexPointer() {
                throw "Legacy GL function (glVertexPointer) called. If you want legacy GL emulation, you need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation."
            }
            Module["_glVertexPointer"] = _glVertexPointer;

            function _glMatrixMode() {
                throw "Legacy GL function (glMatrixMode) called. If you want legacy GL emulation, you need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation."
            }
            Module["_glMatrixMode"] = _glMatrixMode;

            function _glBegin() {
                throw "Legacy GL function (glBegin) called. If you want legacy GL emulation, you need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation."
            }
            Module["_glBegin"] = _glBegin;

            function _glLoadIdentity() {
                throw "Legacy GL function (glLoadIdentity) called. If you want legacy GL emulation, you need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation."
            }
            Module["_glLoadIdentity"] = _glLoadIdentity;

            function _glGenVertexArraysOES(n, arrays) {
                __glGenObject(n, arrays, "createVertexArray", GL.vaos)
            }
            Module["_glGenVertexArraysOES"] = _glGenVertexArraysOES;
            _glGenVertexArraysOES.sig = "vii";

            function _glDeleteVertexArraysOES(n, vaos) {
                for (var i = 0; i < n; i++) {
                    var id = HEAP32[vaos + i * 4 >> 2];
                    GLctx["deleteVertexArray"](GL.vaos[id]);
                    GL.vaos[id] = null
                }
            }
            Module["_glDeleteVertexArraysOES"] = _glDeleteVertexArraysOES;
            _glDeleteVertexArraysOES.sig = "vii";

            function _glBindVertexArrayOES(vao) {
                GLctx["bindVertexArray"](GL.vaos[vao])
            }
            Module["_glBindVertexArrayOES"] = _glBindVertexArrayOES;
            _glBindVertexArrayOES.sig = "vi";

            function _glIsVertexArrayOES(array) {
                var vao = GL.vaos[array];
                if (!vao) return 0;
                return GLctx["isVertexArray"](vao)
            }
            Module["_glIsVertexArrayOES"] = _glIsVertexArrayOES;
            _glIsVertexArrayOES.sig = "ii";

            function _glVertexAttribPointer(index, size, type, normalized, stride, ptr) {
                GLctx.vertexAttribPointer(index, size, type, !!normalized, stride, ptr)
            }
            Module["_glVertexAttribPointer"] = _glVertexAttribPointer;
            _glVertexAttribPointer.sig = "viiiiii";

            function _glEnableVertexAttribArray(index) {
                GLctx.enableVertexAttribArray(index)
            }
            Module["_glEnableVertexAttribArray"] = _glEnableVertexAttribArray;
            _glEnableVertexAttribArray.sig = "vi";

            function _glDisableVertexAttribArray(index) {
                GLctx.disableVertexAttribArray(index)
            }
            Module["_glDisableVertexAttribArray"] = _glDisableVertexAttribArray;
            _glDisableVertexAttribArray.sig = "vi";

            function _glDrawArrays(mode, first, count) {
                GLctx.drawArrays(mode, first, count)
            }
            Module["_glDrawArrays"] = _glDrawArrays;
            _glDrawArrays.sig = "viii";

            function _glDrawElements(mode, count, type, indices) {
                GLctx.drawElements(mode, count, type, indices)
            }
            Module["_glDrawElements"] = _glDrawElements;
            _glDrawElements.sig = "viiii";

            function _glShaderBinary() {
                GL.recordError(1280)
            }
            Module["_glShaderBinary"] = _glShaderBinary;
            _glShaderBinary.sig = "v";

            function _glReleaseShaderCompiler() {}
            Module["_glReleaseShaderCompiler"] = _glReleaseShaderCompiler;
            _glReleaseShaderCompiler.sig = "v";

            function _glGetError() {
                var error = GLctx.getError() || GL.lastError;
                GL.lastError = 0;
                return error
            }
            Module["_glGetError"] = _glGetError;
            _glGetError.sig = "i";

            function _glVertexAttribDivisor(index, divisor) {
                GLctx["vertexAttribDivisor"](index, divisor)
            }
            Module["_glVertexAttribDivisor"] = _glVertexAttribDivisor;
            _glVertexAttribDivisor.sig = "vii";

            function _glDrawArraysInstanced(mode, first, count, primcount) {
                GLctx["drawArraysInstanced"](mode, first, count, primcount)
            }
            Module["_glDrawArraysInstanced"] = _glDrawArraysInstanced;
            _glDrawArraysInstanced.sig = "viiii";

            function _glDrawElementsInstanced(mode, count, type, indices, primcount) {
                GLctx["drawElementsInstanced"](mode, count, type, indices, primcount)
            }
            Module["_glDrawElementsInstanced"] = _glDrawElementsInstanced;
            _glDrawElementsInstanced.sig = "viiiii";

            function _glVertexAttribDivisorNV(index, divisor) {
                GLctx["vertexAttribDivisor"](index, divisor)
            }
            Module["_glVertexAttribDivisorNV"] = _glVertexAttribDivisorNV;
            _glVertexAttribDivisorNV.sig = "vii";

            function _glDrawArraysInstancedNV(mode, first, count, primcount) {
                GLctx["drawArraysInstanced"](mode, first, count, primcount)
            }
            Module["_glDrawArraysInstancedNV"] = _glDrawArraysInstancedNV;
            _glDrawArraysInstancedNV.sig = "viiii";

            function _glDrawElementsInstancedNV(mode, count, type, indices, primcount) {
                GLctx["drawElementsInstanced"](mode, count, type, indices, primcount)
            }
            Module["_glDrawElementsInstancedNV"] = _glDrawElementsInstancedNV;
            _glDrawElementsInstancedNV.sig = "viiiii";

            function _glVertexAttribDivisorEXT(index, divisor) {
                GLctx["vertexAttribDivisor"](index, divisor)
            }
            Module["_glVertexAttribDivisorEXT"] = _glVertexAttribDivisorEXT;
            _glVertexAttribDivisorEXT.sig = "vii";

            function _glDrawArraysInstancedEXT(mode, first, count, primcount) {
                GLctx["drawArraysInstanced"](mode, first, count, primcount)
            }
            Module["_glDrawArraysInstancedEXT"] = _glDrawArraysInstancedEXT;
            _glDrawArraysInstancedEXT.sig = "viiii";

            function _glDrawElementsInstancedEXT(mode, count, type, indices, primcount) {
                GLctx["drawElementsInstanced"](mode, count, type, indices, primcount)
            }
            Module["_glDrawElementsInstancedEXT"] = _glDrawElementsInstancedEXT;
            _glDrawElementsInstancedEXT.sig = "viiiii";

            function _glVertexAttribDivisorARB(index, divisor) {
                GLctx["vertexAttribDivisor"](index, divisor)
            }
            Module["_glVertexAttribDivisorARB"] = _glVertexAttribDivisorARB;
            _glVertexAttribDivisorARB.sig = "vii";

            function _glDrawArraysInstancedARB(mode, first, count, primcount) {
                GLctx["drawArraysInstanced"](mode, first, count, primcount)
            }
            Module["_glDrawArraysInstancedARB"] = _glDrawArraysInstancedARB;
            _glDrawArraysInstancedARB.sig = "viiii";

            function _glDrawElementsInstancedARB(mode, count, type, indices, primcount) {
                GLctx["drawElementsInstanced"](mode, count, type, indices, primcount)
            }
            Module["_glDrawElementsInstancedARB"] = _glDrawElementsInstancedARB;
            _glDrawElementsInstancedARB.sig = "viiiii";

            function _glVertexAttribDivisorANGLE(index, divisor) {
                GLctx["vertexAttribDivisor"](index, divisor)
            }
            Module["_glVertexAttribDivisorANGLE"] = _glVertexAttribDivisorANGLE;
            _glVertexAttribDivisorANGLE.sig = "vii";

            function _glDrawArraysInstancedANGLE(mode, first, count, primcount) {
                GLctx["drawArraysInstanced"](mode, first, count, primcount)
            }
            Module["_glDrawArraysInstancedANGLE"] = _glDrawArraysInstancedANGLE;
            _glDrawArraysInstancedANGLE.sig = "viiii";

            function _glDrawElementsInstancedANGLE(mode, count, type, indices, primcount) {
                GLctx["drawElementsInstanced"](mode, count, type, indices, primcount)
            }
            Module["_glDrawElementsInstancedANGLE"] = _glDrawElementsInstancedANGLE;
            _glDrawElementsInstancedANGLE.sig = "viiiii";

            function _glDrawBuffers(n, bufs) {
                var bufArray = tempFixedLengthArray[n];
                for (var i = 0; i < n; i++) {
                    bufArray[i] = HEAP32[bufs + i * 4 >> 2]
                }
                GLctx["drawBuffers"](bufArray)
            }
            Module["_glDrawBuffers"] = _glDrawBuffers;
            _glDrawBuffers.sig = "vii";

            function _glDrawBuffersEXT(n, bufs) {
                var bufArray = tempFixedLengthArray[n];
                for (var i = 0; i < n; i++) {
                    bufArray[i] = HEAP32[bufs + i * 4 >> 2]
                }
                GLctx["drawBuffers"](bufArray)
            }
            Module["_glDrawBuffersEXT"] = _glDrawBuffersEXT;
            _glDrawBuffersEXT.sig = "vii";

            function _glDrawBuffersWEBGL(n, bufs) {
                var bufArray = tempFixedLengthArray[n];
                for (var i = 0; i < n; i++) {
                    bufArray[i] = HEAP32[bufs + i * 4 >> 2]
                }
                GLctx["drawBuffers"](bufArray)
            }
            Module["_glDrawBuffersWEBGL"] = _glDrawBuffersWEBGL;
            _glDrawBuffersWEBGL.sig = "vii";

            function _glColorMask(red, green, blue, alpha) {
                GLctx.colorMask(!!red, !!green, !!blue, !!alpha)
            }
            Module["_glColorMask"] = _glColorMask;
            _glColorMask.sig = "viiii";

            function _glDepthMask(flag) {
                GLctx.depthMask(!!flag)
            }
            Module["_glDepthMask"] = _glDepthMask;
            _glDepthMask.sig = "vi";

            function _glSampleCoverage(value, invert) {
                GLctx.sampleCoverage(value, !!invert)
            }
            Module["_glSampleCoverage"] = _glSampleCoverage;
            _glSampleCoverage.sig = "vii";

            function _glMultiDrawArrays(mode, firsts, counts, drawcount) {
                GLctx.multiDrawWebgl["multiDrawArraysWEBGL"](mode, HEAP32, firsts >> 2, HEAP32, counts >> 2, drawcount)
            }
            Module["_glMultiDrawArrays"] = _glMultiDrawArrays;
            _glMultiDrawArrays.sig = "viiii";

            function _glMultiDrawArraysANGLE(mode, firsts, counts, drawcount) {
                GLctx.multiDrawWebgl["multiDrawArraysWEBGL"](mode, HEAP32, firsts >> 2, HEAP32, counts >> 2, drawcount)
            }
            Module["_glMultiDrawArraysANGLE"] = _glMultiDrawArraysANGLE;
            _glMultiDrawArraysANGLE.sig = "viiii";

            function _glMultiDrawArraysWEBGL(mode, firsts, counts, drawcount) {
                GLctx.multiDrawWebgl["multiDrawArraysWEBGL"](mode, HEAP32, firsts >> 2, HEAP32, counts >> 2, drawcount)
            }
            Module["_glMultiDrawArraysWEBGL"] = _glMultiDrawArraysWEBGL;
            _glMultiDrawArraysWEBGL.sig = "viiii";

            function _glMultiDrawArraysInstancedANGLE(mode, firsts, counts, instanceCounts, drawcount) {
                GLctx.multiDrawWebgl["multiDrawArraysInstancedWEBGL"](mode, HEAP32, firsts >> 2, HEAP32, counts >> 2, HEAP32, instanceCounts >> 2, drawcount)
            }
            Module["_glMultiDrawArraysInstancedANGLE"] = _glMultiDrawArraysInstancedANGLE;
            _glMultiDrawArraysInstancedANGLE.sig = "viiiii";

            function _glMultiDrawArraysInstancedWEBGL(mode, firsts, counts, instanceCounts, drawcount) {
                GLctx.multiDrawWebgl["multiDrawArraysInstancedWEBGL"](mode, HEAP32, firsts >> 2, HEAP32, counts >> 2, HEAP32, instanceCounts >> 2, drawcount)
            }
            Module["_glMultiDrawArraysInstancedWEBGL"] = _glMultiDrawArraysInstancedWEBGL;
            _glMultiDrawArraysInstancedWEBGL.sig = "viiiii";

            function _glMultiDrawElements(mode, counts, type, offsets, drawcount) {
                GLctx.multiDrawWebgl["multiDrawElementsWEBGL"](mode, HEAP32, counts >> 2, type, HEAP32, offsets >> 2, drawcount)
            }
            Module["_glMultiDrawElements"] = _glMultiDrawElements;
            _glMultiDrawElements.sig = "viiiii";

            function _glMultiDrawElementsANGLE(mode, counts, type, offsets, drawcount) {
                GLctx.multiDrawWebgl["multiDrawElementsWEBGL"](mode, HEAP32, counts >> 2, type, HEAP32, offsets >> 2, drawcount)
            }
            Module["_glMultiDrawElementsANGLE"] = _glMultiDrawElementsANGLE;
            _glMultiDrawElementsANGLE.sig = "viiiii";

            function _glMultiDrawElementsWEBGL(mode, counts, type, offsets, drawcount) {
                GLctx.multiDrawWebgl["multiDrawElementsWEBGL"](mode, HEAP32, counts >> 2, type, HEAP32, offsets >> 2, drawcount)
            }
            Module["_glMultiDrawElementsWEBGL"] = _glMultiDrawElementsWEBGL;
            _glMultiDrawElementsWEBGL.sig = "viiiii";

            function _glMultiDrawElementsInstancedANGLE(mode, counts, type, offsets, instanceCounts, drawcount) {
                GLctx.multiDrawWebgl["multiDrawElementsInstancedWEBGL"](mode, HEAP32, counts >> 2, type, HEAP32, offsets >> 2, HEAP32, instanceCounts >> 2, drawcount)
            }
            Module["_glMultiDrawElementsInstancedANGLE"] = _glMultiDrawElementsInstancedANGLE;
            _glMultiDrawElementsInstancedANGLE.sig = "viiiiii";

            function _glMultiDrawElementsInstancedWEBGL(mode, counts, type, offsets, instanceCounts, drawcount) {
                GLctx.multiDrawWebgl["multiDrawElementsInstancedWEBGL"](mode, HEAP32, counts >> 2, type, HEAP32, offsets >> 2, HEAP32, instanceCounts >> 2, drawcount)
            }
            Module["_glMultiDrawElementsInstancedWEBGL"] = _glMultiDrawElementsInstancedWEBGL;
            _glMultiDrawElementsInstancedWEBGL.sig = "viiiiii";

            function _glFinish() {
                GLctx["finish"]()
            }
            Module["_glFinish"] = _glFinish;
            _glFinish.sig = "v";

            function _glFlush() {
                GLctx["flush"]()
            }
            Module["_glFlush"] = _glFlush;
            _glFlush.sig = "v";

            function _glClearDepth(x0) {
                GLctx["clearDepth"](x0)
            }
            Module["_glClearDepth"] = _glClearDepth;
            _glClearDepth.sig = "vi";

            function _glClearDepthf(x0) {
                GLctx["clearDepth"](x0)
            }
            Module["_glClearDepthf"] = _glClearDepthf;
            _glClearDepthf.sig = "vi";

            function _glDepthFunc(x0) {
                GLctx["depthFunc"](x0)
            }
            Module["_glDepthFunc"] = _glDepthFunc;
            _glDepthFunc.sig = "vi";

            function _glEnable(x0) {
                GLctx["enable"](x0)
            }
            Module["_glEnable"] = _glEnable;
            _glEnable.sig = "vi";

            function _glDisable(x0) {
                GLctx["disable"](x0)
            }
            Module["_glDisable"] = _glDisable;
            _glDisable.sig = "vi";

            function _glFrontFace(x0) {
                GLctx["frontFace"](x0)
            }
            Module["_glFrontFace"] = _glFrontFace;
            _glFrontFace.sig = "vi";

            function _glCullFace(x0) {
                GLctx["cullFace"](x0)
            }
            Module["_glCullFace"] = _glCullFace;
            _glCullFace.sig = "vi";

            function _glClear(x0) {
                GLctx["clear"](x0)
            }
            Module["_glClear"] = _glClear;
            _glClear.sig = "vi";

            function _glLineWidth(x0) {
                GLctx["lineWidth"](x0)
            }
            Module["_glLineWidth"] = _glLineWidth;
            _glLineWidth.sig = "vi";

            function _glClearStencil(x0) {
                GLctx["clearStencil"](x0)
            }
            Module["_glClearStencil"] = _glClearStencil;
            _glClearStencil.sig = "vi";

            function _glStencilMask(x0) {
                GLctx["stencilMask"](x0)
            }
            Module["_glStencilMask"] = _glStencilMask;
            _glStencilMask.sig = "vi";

            function _glCheckFramebufferStatus(x0) {
                return GLctx["checkFramebufferStatus"](x0)
            }
            Module["_glCheckFramebufferStatus"] = _glCheckFramebufferStatus;
            _glCheckFramebufferStatus.sig = "ii";

            function _glGenerateMipmap(x0) {
                GLctx["generateMipmap"](x0)
            }
            Module["_glGenerateMipmap"] = _glGenerateMipmap;
            _glGenerateMipmap.sig = "vi";

            function _glActiveTexture(x0) {
                GLctx["activeTexture"](x0)
            }
            Module["_glActiveTexture"] = _glActiveTexture;
            _glActiveTexture.sig = "vi";

            function _glBlendEquation(x0) {
                GLctx["blendEquation"](x0)
            }
            Module["_glBlendEquation"] = _glBlendEquation;
            _glBlendEquation.sig = "vi";

            function _glIsEnabled(x0) {
                return GLctx["isEnabled"](x0)
            }
            Module["_glIsEnabled"] = _glIsEnabled;
            _glIsEnabled.sig = "ii";

            function _glBlendFunc(x0, x1) {
                GLctx["blendFunc"](x0, x1)
            }
            Module["_glBlendFunc"] = _glBlendFunc;
            _glBlendFunc.sig = "vii";

            function _glBlendEquationSeparate(x0, x1) {
                GLctx["blendEquationSeparate"](x0, x1)
            }
            Module["_glBlendEquationSeparate"] = _glBlendEquationSeparate;
            _glBlendEquationSeparate.sig = "vii";

            function _glDepthRange(x0, x1) {
                GLctx["depthRange"](x0, x1)
            }
            Module["_glDepthRange"] = _glDepthRange;
            _glDepthRange.sig = "vii";

            function _glDepthRangef(x0, x1) {
                GLctx["depthRange"](x0, x1)
            }
            Module["_glDepthRangef"] = _glDepthRangef;
            _glDepthRangef.sig = "vii";

            function _glStencilMaskSeparate(x0, x1) {
                GLctx["stencilMaskSeparate"](x0, x1)
            }
            Module["_glStencilMaskSeparate"] = _glStencilMaskSeparate;
            _glStencilMaskSeparate.sig = "vii";

            function _glHint(x0, x1) {
                GLctx["hint"](x0, x1)
            }
            Module["_glHint"] = _glHint;
            _glHint.sig = "vii";

            function _glPolygonOffset(x0, x1) {
                GLctx["polygonOffset"](x0, x1)
            }
            Module["_glPolygonOffset"] = _glPolygonOffset;
            _glPolygonOffset.sig = "vii";

            function _glVertexAttrib1f(x0, x1) {
                GLctx["vertexAttrib1f"](x0, x1)
            }
            Module["_glVertexAttrib1f"] = _glVertexAttrib1f;
            _glVertexAttrib1f.sig = "vii";

            function _glTexParameteri(x0, x1, x2) {
                GLctx["texParameteri"](x0, x1, x2)
            }
            Module["_glTexParameteri"] = _glTexParameteri;
            _glTexParameteri.sig = "viii";

            function _glTexParameterf(x0, x1, x2) {
                GLctx["texParameterf"](x0, x1, x2)
            }
            Module["_glTexParameterf"] = _glTexParameterf;
            _glTexParameterf.sig = "viii";

            function _glVertexAttrib2f(x0, x1, x2) {
                GLctx["vertexAttrib2f"](x0, x1, x2)
            }
            Module["_glVertexAttrib2f"] = _glVertexAttrib2f;
            _glVertexAttrib2f.sig = "viii";

            function _glStencilFunc(x0, x1, x2) {
                GLctx["stencilFunc"](x0, x1, x2)
            }
            Module["_glStencilFunc"] = _glStencilFunc;
            _glStencilFunc.sig = "viii";

            function _glStencilOp(x0, x1, x2) {
                GLctx["stencilOp"](x0, x1, x2)
            }
            Module["_glStencilOp"] = _glStencilOp;
            _glStencilOp.sig = "viii";

            function _glViewport(x0, x1, x2, x3) {
                GLctx["viewport"](x0, x1, x2, x3)
            }
            Module["_glViewport"] = _glViewport;
            _glViewport.sig = "viiii";

            function _glClearColor(x0, x1, x2, x3) {
                GLctx["clearColor"](x0, x1, x2, x3)
            }
            Module["_glClearColor"] = _glClearColor;
            _glClearColor.sig = "viiii";

            function _glScissor(x0, x1, x2, x3) {
                GLctx["scissor"](x0, x1, x2, x3)
            }
            Module["_glScissor"] = _glScissor;
            _glScissor.sig = "viiii";

            function _glVertexAttrib3f(x0, x1, x2, x3) {
                GLctx["vertexAttrib3f"](x0, x1, x2, x3)
            }
            Module["_glVertexAttrib3f"] = _glVertexAttrib3f;
            _glVertexAttrib3f.sig = "viiii";

            function _glRenderbufferStorage(x0, x1, x2, x3) {
                GLctx["renderbufferStorage"](x0, x1, x2, x3)
            }
            Module["_glRenderbufferStorage"] = _glRenderbufferStorage;
            _glRenderbufferStorage.sig = "viiii";

            function _glBlendFuncSeparate(x0, x1, x2, x3) {
                GLctx["blendFuncSeparate"](x0, x1, x2, x3)
            }
            Module["_glBlendFuncSeparate"] = _glBlendFuncSeparate;
            _glBlendFuncSeparate.sig = "viiii";

            function _glBlendColor(x0, x1, x2, x3) {
                GLctx["blendColor"](x0, x1, x2, x3)
            }
            Module["_glBlendColor"] = _glBlendColor;
            _glBlendColor.sig = "vffff";

            function _glStencilFuncSeparate(x0, x1, x2, x3) {
                GLctx["stencilFuncSeparate"](x0, x1, x2, x3)
            }
            Module["_glStencilFuncSeparate"] = _glStencilFuncSeparate;
            _glStencilFuncSeparate.sig = "viiii";

            function _glStencilOpSeparate(x0, x1, x2, x3) {
                GLctx["stencilOpSeparate"](x0, x1, x2, x3)
            }
            Module["_glStencilOpSeparate"] = _glStencilOpSeparate;
            _glStencilOpSeparate.sig = "viiii";

            function _glVertexAttrib4f(x0, x1, x2, x3, x4) {
                GLctx["vertexAttrib4f"](x0, x1, x2, x3, x4)
            }
            Module["_glVertexAttrib4f"] = _glVertexAttrib4f;
            _glVertexAttrib4f.sig = "viiiii";

            function _glCopyTexImage2D(x0, x1, x2, x3, x4, x5, x6, x7) {
                GLctx["copyTexImage2D"](x0, x1, x2, x3, x4, x5, x6, x7)
            }
            Module["_glCopyTexImage2D"] = _glCopyTexImage2D;
            _glCopyTexImage2D.sig = "viiiiiiii";

            function _glCopyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7) {
                GLctx["copyTexSubImage2D"](x0, x1, x2, x3, x4, x5, x6, x7)
            }
            Module["_glCopyTexSubImage2D"] = _glCopyTexSubImage2D;
            _glCopyTexSubImage2D.sig = "viiiiiiii";

            function _emscripten_glGenVertexArrays(n, arrays) {
                __glGenObject(n, arrays, "createVertexArray", GL.vaos)
            }
            Module["_emscripten_glGenVertexArrays"] = _emscripten_glGenVertexArrays;
            _emscripten_glGenVertexArrays.sig = "vii";

            function _emscripten_glDeleteVertexArrays(n, vaos) {
                for (var i = 0; i < n; i++) {
                    var id = HEAP32[vaos + i * 4 >> 2];
                    GLctx["deleteVertexArray"](GL.vaos[id]);
                    GL.vaos[id] = null
                }
            }
            Module["_emscripten_glDeleteVertexArrays"] = _emscripten_glDeleteVertexArrays;
            _emscripten_glDeleteVertexArrays.sig = "vii";

            function _emscripten_glBindVertexArray(vao) {
                GLctx["bindVertexArray"](GL.vaos[vao])
            }
            Module["_emscripten_glBindVertexArray"] = _emscripten_glBindVertexArray;
            _emscripten_glBindVertexArray.sig = "vi";

            function _emscripten_glIsVertexArray(array) {
                var vao = GL.vaos[array];
                if (!vao) return 0;
                return GLctx["isVertexArray"](vao)
            }
            Module["_emscripten_glIsVertexArray"] = _emscripten_glIsVertexArray;
            _emscripten_glIsVertexArray.sig = "ii";

            function _emscripten_glVertexPointer() {
                throw "Legacy GL function (glVertexPointer) called. If you want legacy GL emulation, you need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation."
            }
            Module["_emscripten_glVertexPointer"] = _emscripten_glVertexPointer;

            function _emscripten_glMatrixMode() {
                throw "Legacy GL function (glMatrixMode) called. If you want legacy GL emulation, you need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation."
            }
            Module["_emscripten_glMatrixMode"] = _emscripten_glMatrixMode;

            function _emscripten_glBegin() {
                throw "Legacy GL function (glBegin) called. If you want legacy GL emulation, you need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation."
            }
            Module["_emscripten_glBegin"] = _emscripten_glBegin;

            function _emscripten_glLoadIdentity() {
                throw "Legacy GL function (glLoadIdentity) called. If you want legacy GL emulation, you need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation."
            }
            Module["_emscripten_glLoadIdentity"] = _emscripten_glLoadIdentity;

            function _emscripten_glVertexAttribDivisor(index, divisor) {
                GLctx["vertexAttribDivisor"](index, divisor)
            }
            Module["_emscripten_glVertexAttribDivisor"] = _emscripten_glVertexAttribDivisor;
            _emscripten_glVertexAttribDivisor.sig = "vii";

            function _emscripten_glDrawArraysInstanced(mode, first, count, primcount) {
                GLctx["drawArraysInstanced"](mode, first, count, primcount)
            }
            Module["_emscripten_glDrawArraysInstanced"] = _emscripten_glDrawArraysInstanced;
            _emscripten_glDrawArraysInstanced.sig = "viiii";

            function _emscripten_glDrawElementsInstanced(mode, count, type, indices, primcount) {
                GLctx["drawElementsInstanced"](mode, count, type, indices, primcount)
            }
            Module["_emscripten_glDrawElementsInstanced"] = _emscripten_glDrawElementsInstanced;
            _emscripten_glDrawElementsInstanced.sig = "viiiii";

            function _emscripten_glVertexAttribDivisorNV(index, divisor) {
                GLctx["vertexAttribDivisor"](index, divisor)
            }
            Module["_emscripten_glVertexAttribDivisorNV"] = _emscripten_glVertexAttribDivisorNV;
            _emscripten_glVertexAttribDivisorNV.sig = "vii";

            function _emscripten_glDrawArraysInstancedNV(mode, first, count, primcount) {
                GLctx["drawArraysInstanced"](mode, first, count, primcount)
            }
            Module["_emscripten_glDrawArraysInstancedNV"] = _emscripten_glDrawArraysInstancedNV;
            _emscripten_glDrawArraysInstancedNV.sig = "viiii";

            function _emscripten_glDrawElementsInstancedNV(mode, count, type, indices, primcount) {
                GLctx["drawElementsInstanced"](mode, count, type, indices, primcount)
            }
            Module["_emscripten_glDrawElementsInstancedNV"] = _emscripten_glDrawElementsInstancedNV;
            _emscripten_glDrawElementsInstancedNV.sig = "viiiii";

            function _emscripten_glVertexAttribDivisorEXT(index, divisor) {
                GLctx["vertexAttribDivisor"](index, divisor)
            }
            Module["_emscripten_glVertexAttribDivisorEXT"] = _emscripten_glVertexAttribDivisorEXT;
            _emscripten_glVertexAttribDivisorEXT.sig = "vii";

            function _emscripten_glDrawArraysInstancedEXT(mode, first, count, primcount) {
                GLctx["drawArraysInstanced"](mode, first, count, primcount)
            }
            Module["_emscripten_glDrawArraysInstancedEXT"] = _emscripten_glDrawArraysInstancedEXT;
            _emscripten_glDrawArraysInstancedEXT.sig = "viiii";

            function _emscripten_glDrawElementsInstancedEXT(mode, count, type, indices, primcount) {
                GLctx["drawElementsInstanced"](mode, count, type, indices, primcount)
            }
            Module["_emscripten_glDrawElementsInstancedEXT"] = _emscripten_glDrawElementsInstancedEXT;
            _emscripten_glDrawElementsInstancedEXT.sig = "viiiii";

            function _emscripten_glVertexAttribDivisorARB(index, divisor) {
                GLctx["vertexAttribDivisor"](index, divisor)
            }
            Module["_emscripten_glVertexAttribDivisorARB"] = _emscripten_glVertexAttribDivisorARB;
            _emscripten_glVertexAttribDivisorARB.sig = "vii";

            function _emscripten_glDrawArraysInstancedARB(mode, first, count, primcount) {
                GLctx["drawArraysInstanced"](mode, first, count, primcount)
            }
            Module["_emscripten_glDrawArraysInstancedARB"] = _emscripten_glDrawArraysInstancedARB;
            _emscripten_glDrawArraysInstancedARB.sig = "viiii";

            function _emscripten_glDrawElementsInstancedARB(mode, count, type, indices, primcount) {
                GLctx["drawElementsInstanced"](mode, count, type, indices, primcount)
            }
            Module["_emscripten_glDrawElementsInstancedARB"] = _emscripten_glDrawElementsInstancedARB;
            _emscripten_glDrawElementsInstancedARB.sig = "viiiii";

            function _emscripten_glDrawBuffers(n, bufs) {
                var bufArray = tempFixedLengthArray[n];
                for (var i = 0; i < n; i++) {
                    bufArray[i] = HEAP32[bufs + i * 4 >> 2]
                }
                GLctx["drawBuffers"](bufArray)
            }
            Module["_emscripten_glDrawBuffers"] = _emscripten_glDrawBuffers;
            _emscripten_glDrawBuffers.sig = "vii";

            function _emscripten_glDrawBuffersEXT(n, bufs) {
                var bufArray = tempFixedLengthArray[n];
                for (var i = 0; i < n; i++) {
                    bufArray[i] = HEAP32[bufs + i * 4 >> 2]
                }
                GLctx["drawBuffers"](bufArray)
            }
            Module["_emscripten_glDrawBuffersEXT"] = _emscripten_glDrawBuffersEXT;
            _emscripten_glDrawBuffersEXT.sig = "vii";

            function _emscripten_glMultiDrawArrays(mode, firsts, counts, drawcount) {
                GLctx.multiDrawWebgl["multiDrawArraysWEBGL"](mode, HEAP32, firsts >> 2, HEAP32, counts >> 2, drawcount)
            }
            Module["_emscripten_glMultiDrawArrays"] = _emscripten_glMultiDrawArrays;
            _emscripten_glMultiDrawArrays.sig = "viiii";

            function _emscripten_glMultiDrawArraysANGLE(mode, firsts, counts, drawcount) {
                GLctx.multiDrawWebgl["multiDrawArraysWEBGL"](mode, HEAP32, firsts >> 2, HEAP32, counts >> 2, drawcount)
            }
            Module["_emscripten_glMultiDrawArraysANGLE"] = _emscripten_glMultiDrawArraysANGLE;
            _emscripten_glMultiDrawArraysANGLE.sig = "viiii";

            function _emscripten_glMultiDrawArraysWEBGL(mode, firsts, counts, drawcount) {
                GLctx.multiDrawWebgl["multiDrawArraysWEBGL"](mode, HEAP32, firsts >> 2, HEAP32, counts >> 2, drawcount)
            }
            Module["_emscripten_glMultiDrawArraysWEBGL"] = _emscripten_glMultiDrawArraysWEBGL;
            _emscripten_glMultiDrawArraysWEBGL.sig = "viiii";

            function _emscripten_glMultiDrawArraysInstancedANGLE(mode, firsts, counts, instanceCounts, drawcount) {
                GLctx.multiDrawWebgl["multiDrawArraysInstancedWEBGL"](mode, HEAP32, firsts >> 2, HEAP32, counts >> 2, HEAP32, instanceCounts >> 2, drawcount)
            }
            Module["_emscripten_glMultiDrawArraysInstancedANGLE"] = _emscripten_glMultiDrawArraysInstancedANGLE;
            _emscripten_glMultiDrawArraysInstancedANGLE.sig = "viiiii";

            function _emscripten_glMultiDrawArraysInstancedWEBGL(mode, firsts, counts, instanceCounts, drawcount) {
                GLctx.multiDrawWebgl["multiDrawArraysInstancedWEBGL"](mode, HEAP32, firsts >> 2, HEAP32, counts >> 2, HEAP32, instanceCounts >> 2, drawcount)
            }
            Module["_emscripten_glMultiDrawArraysInstancedWEBGL"] = _emscripten_glMultiDrawArraysInstancedWEBGL;
            _emscripten_glMultiDrawArraysInstancedWEBGL.sig = "viiiii";

            function _emscripten_glMultiDrawElements(mode, counts, type, offsets, drawcount) {
                GLctx.multiDrawWebgl["multiDrawElementsWEBGL"](mode, HEAP32, counts >> 2, type, HEAP32, offsets >> 2, drawcount)
            }
            Module["_emscripten_glMultiDrawElements"] = _emscripten_glMultiDrawElements;
            _emscripten_glMultiDrawElements.sig = "viiiii";

            function _emscripten_glMultiDrawElementsANGLE(mode, counts, type, offsets, drawcount) {
                GLctx.multiDrawWebgl["multiDrawElementsWEBGL"](mode, HEAP32, counts >> 2, type, HEAP32, offsets >> 2, drawcount)
            }
            Module["_emscripten_glMultiDrawElementsANGLE"] = _emscripten_glMultiDrawElementsANGLE;
            _emscripten_glMultiDrawElementsANGLE.sig = "viiiii";

            function _emscripten_glMultiDrawElementsWEBGL(mode, counts, type, offsets, drawcount) {
                GLctx.multiDrawWebgl["multiDrawElementsWEBGL"](mode, HEAP32, counts >> 2, type, HEAP32, offsets >> 2, drawcount)
            }
            Module["_emscripten_glMultiDrawElementsWEBGL"] = _emscripten_glMultiDrawElementsWEBGL;
            _emscripten_glMultiDrawElementsWEBGL.sig = "viiiii";

            function _emscripten_glMultiDrawElementsInstancedANGLE(mode, counts, type, offsets, instanceCounts, drawcount) {
                GLctx.multiDrawWebgl["multiDrawElementsInstancedWEBGL"](mode, HEAP32, counts >> 2, type, HEAP32, offsets >> 2, HEAP32, instanceCounts >> 2, drawcount)
            }
            Module["_emscripten_glMultiDrawElementsInstancedANGLE"] = _emscripten_glMultiDrawElementsInstancedANGLE;
            _emscripten_glMultiDrawElementsInstancedANGLE.sig = "viiiiii";

            function _emscripten_glMultiDrawElementsInstancedWEBGL(mode, counts, type, offsets, instanceCounts, drawcount) {
                GLctx.multiDrawWebgl["multiDrawElementsInstancedWEBGL"](mode, HEAP32, counts >> 2, type, HEAP32, offsets >> 2, HEAP32, instanceCounts >> 2, drawcount)
            }
            Module["_emscripten_glMultiDrawElementsInstancedWEBGL"] = _emscripten_glMultiDrawElementsInstancedWEBGL;
            _emscripten_glMultiDrawElementsInstancedWEBGL.sig = "viiiiii";

            function _emscripten_glClearDepth(x0) {
                GLctx["clearDepth"](x0)
            }
            Module["_emscripten_glClearDepth"] = _emscripten_glClearDepth;
            _emscripten_glClearDepth.sig = "vi";

            function _emscripten_glDepthRange(x0, x1) {
                GLctx["depthRange"](x0, x1)
            }
            Module["_emscripten_glDepthRange"] = _emscripten_glDepthRange;
            _emscripten_glDepthRange.sig = "vii";

            function writeGLArray(arr, dst, dstLength, heapType) {
                var len = arr.length;
                var writeLength = dstLength < len ? dstLength : len;
                var heap = heapType ? HEAPF32 : HEAP32;
                for (var i = 0; i < writeLength; ++i) {
                    heap[(dst >> 2) + i] = arr[i]
                }
                return len
            }
            Module["writeGLArray"] = writeGLArray;

            function _emscripten_webgl_init_context_attributes(attributes) {
                var a = attributes >> 2;
                for (var i = 0; i < 56 >> 2; ++i) {
                    HEAP32[a + i] = 0
                }
                HEAP32[a + (0 >> 2)] = HEAP32[a + (4 >> 2)] = HEAP32[a + (12 >> 2)] = HEAP32[a + (16 >> 2)] = HEAP32[a + (32 >> 2)] = HEAP32[a + (40 >> 2)] = 1
            }
            Module["_emscripten_webgl_init_context_attributes"] = _emscripten_webgl_init_context_attributes;
            var __emscripten_webgl_power_preferences = ["default", "low-power", "high-performance"];
            Module["__emscripten_webgl_power_preferences"] = __emscripten_webgl_power_preferences;

            function _emscripten_webgl_do_create_context(target, attributes) {
                var a = attributes >> 2;
                var powerPreference = HEAP32[a + (24 >> 2)];
                var contextAttributes = {
                    "alpha": !!HEAP32[a + (0 >> 2)],
                    "depth": !!HEAP32[a + (4 >> 2)],
                    "stencil": !!HEAP32[a + (8 >> 2)],
                    "antialias": !!HEAP32[a + (12 >> 2)],
                    "premultipliedAlpha": !!HEAP32[a + (16 >> 2)],
                    "preserveDrawingBuffer": !!HEAP32[a + (20 >> 2)],
                    "powerPreference": __emscripten_webgl_power_preferences[powerPreference],
                    "failIfMajorPerformanceCaveat": !!HEAP32[a + (28 >> 2)],
                    majorVersion: HEAP32[a + (32 >> 2)],
                    minorVersion: HEAP32[a + (36 >> 2)],
                    enableExtensionsByDefault: HEAP32[a + (40 >> 2)],
                    explicitSwapControl: HEAP32[a + (44 >> 2)],
                    proxyContextToMainThread: HEAP32[a + (48 >> 2)],
                    renderViaOffscreenBackBuffer: HEAP32[a + (52 >> 2)]
                };
                var canvas = findCanvasEventTarget(target);
                if (!canvas) {
                    return 0
                }
                if (contextAttributes.explicitSwapControl) {
                    return 0
                }
                var contextHandle = GL.createContext(canvas, contextAttributes);
                return contextHandle
            }
            Module["_emscripten_webgl_do_create_context"] = _emscripten_webgl_do_create_context;
            _emscripten_webgl_do_create_context.sig = "iii";

            function _emscripten_webgl_create_context(a0, a1) {
                return _emscripten_webgl_do_create_context(a0, a1)
            }
            Module["_emscripten_webgl_create_context"] = _emscripten_webgl_create_context;
            _emscripten_webgl_create_context.sig = "iii";

            function _emscripten_webgl_do_get_current_context() {
                return GL.currentContext ? GL.currentContext.handle : 0
            }
            Module["_emscripten_webgl_do_get_current_context"] = _emscripten_webgl_do_get_current_context;
            _emscripten_webgl_do_get_current_context.sig = "i";

            function _emscripten_webgl_get_current_context() {
                return _emscripten_webgl_do_get_current_context()
            }
            Module["_emscripten_webgl_get_current_context"] = _emscripten_webgl_get_current_context;
            _emscripten_webgl_get_current_context.sig = "i";

            function _emscripten_webgl_do_commit_frame() {
                if (!GL.currentContext || !GL.currentContext.GLctx) {
                    return -3
                }
                if (!GL.currentContext.attributes.explicitSwapControl) {
                    return -3
                }
                return 0
            }
            Module["_emscripten_webgl_do_commit_frame"] = _emscripten_webgl_do_commit_frame;
            _emscripten_webgl_do_commit_frame.sig = "i";

            function _emscripten_webgl_commit_frame() {
                return _emscripten_webgl_do_commit_frame()
            }
            Module["_emscripten_webgl_commit_frame"] = _emscripten_webgl_commit_frame;
            _emscripten_webgl_commit_frame.sig = "i";

            function _emscripten_webgl_make_context_current(contextHandle) {
                var success = GL.makeContextCurrent(contextHandle);
                return success ? 0 : -5
            }
            Module["_emscripten_webgl_make_context_current"] = _emscripten_webgl_make_context_current;

            function _emscripten_webgl_get_drawing_buffer_size(contextHandle, width, height) {
                var GLContext = GL.getContext(contextHandle);
                if (!GLContext || !GLContext.GLctx || !width || !height) {
                    return -5
                }
                HEAP32[width >> 2] = GLContext.GLctx.drawingBufferWidth;
                HEAP32[height >> 2] = GLContext.GLctx.drawingBufferHeight;
                return 0
            }
            Module["_emscripten_webgl_get_drawing_buffer_size"] = _emscripten_webgl_get_drawing_buffer_size;
            _emscripten_webgl_get_drawing_buffer_size.sig = "iiii";

            function _emscripten_webgl_get_context_attributes(c, a) {
                if (!a) return -5;
                c = GL.contexts[c];
                if (!c) return -3;
                var t = c.GLctx;
                if (!t) return -3;
                t = t.getContextAttributes();
                HEAP32[a >> 2] = t.alpha;
                HEAP32[a + 4 >> 2] = t.depth;
                HEAP32[a + 8 >> 2] = t.stencil;
                HEAP32[a + 12 >> 2] = t.antialias;
                HEAP32[a + 16 >> 2] = t.premultipliedAlpha;
                HEAP32[a + 20 >> 2] = t.preserveDrawingBuffer;
                var power = t["powerPreference"] && __emscripten_webgl_power_preferences.indexOf(t["powerPreference"]);
                HEAP32[a + 24 >> 2] = power;
                HEAP32[a + 28 >> 2] = t.failIfMajorPerformanceCaveat;
                HEAP32[a + 32 >> 2] = c.version;
                HEAP32[a + 36 >> 2] = 0;
                HEAP32[a + 40 >> 2] = c.attributes.enableExtensionsByDefault;
                return 0
            }
            Module["_emscripten_webgl_get_context_attributes"] = _emscripten_webgl_get_context_attributes;
            _emscripten_webgl_get_context_attributes.sig = "iii";

            function _emscripten_webgl_destroy_context(contextHandle) {
                if (GL.currentContext == contextHandle) GL.currentContext = 0;
                GL.deleteContext(contextHandle)
            }
            Module["_emscripten_webgl_destroy_context"] = _emscripten_webgl_destroy_context;
            _emscripten_webgl_destroy_context.sig = "vi";

            function _emscripten_webgl_destroy_context_before_on_calling_thread(contextHandle) {
                if (_emscripten_webgl_get_current_context() == contextHandle) _emscripten_webgl_make_context_current(0)
            }
            Module["_emscripten_webgl_destroy_context_before_on_calling_thread"] = _emscripten_webgl_destroy_context_before_on_calling_thread;

            function _emscripten_webgl_enable_extension(contextHandle, extension) {
                var context = GL.getContext(contextHandle);
                var extString = UTF8ToString(extension);
                if (extString.startsWith("GL_")) extString = extString.substr(3);
                if (extString == "ANGLE_instanced_arrays") __webgl_enable_ANGLE_instanced_arrays(GLctx);
                if (extString == "OES_vertex_array_object") __webgl_enable_OES_vertex_array_object(GLctx);
                if (extString == "WEBGL_draw_buffers") __webgl_enable_WEBGL_draw_buffers(GLctx);
                if (extString == "WEBGL_multi_draw") __webgl_enable_WEBGL_multi_draw(GLctx);
                var ext = context.GLctx.getExtension(extString);
                return !!ext
            }
            Module["_emscripten_webgl_enable_extension"] = _emscripten_webgl_enable_extension;
            _emscripten_webgl_enable_extension.sig = "iii";

            function _emscripten_supports_offscreencanvas() {
                return 0
            }
            Module["_emscripten_supports_offscreencanvas"] = _emscripten_supports_offscreencanvas;

            function __registerWebGlEventCallback(target, userData, useCapture, callbackfunc, eventTypeId, eventTypeString, targetThread) {
                var webGlEventHandlerFunc = function(ev) {
                    var e = ev || event;
                    if (wasmTable.get(callbackfunc)(eventTypeId, 0, userData)) e.preventDefault()
                };
                var eventHandler = {
                    target: findEventTarget(target),
                    eventTypeString: eventTypeString,
                    callbackfunc: callbackfunc,
                    handlerFunc: webGlEventHandlerFunc,
                    useCapture: useCapture
                };
                JSEvents.registerOrRemoveHandler(eventHandler)
            }
            Module["__registerWebGlEventCallback"] = __registerWebGlEventCallback;

            function _emscripten_set_webglcontextlost_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                __registerWebGlEventCallback(target, userData, useCapture, callbackfunc, 31, "webglcontextlost", targetThread);
                return 0
            }
            Module["_emscripten_set_webglcontextlost_callback_on_thread"] = _emscripten_set_webglcontextlost_callback_on_thread;
            _emscripten_set_webglcontextlost_callback_on_thread.sig = "iiiiii";

            function _emscripten_set_webglcontextrestored_callback_on_thread(target, userData, useCapture, callbackfunc, targetThread) {
                __registerWebGlEventCallback(target, userData, useCapture, callbackfunc, 32, "webglcontextrestored", targetThread);
                return 0
            }
            Module["_emscripten_set_webglcontextrestored_callback_on_thread"] = _emscripten_set_webglcontextrestored_callback_on_thread;
            _emscripten_set_webglcontextrestored_callback_on_thread.sig = "iiiiii";

            function _emscripten_is_webgl_context_lost(contextHandle) {
                return !GL.contexts[contextHandle] || GL.contexts[contextHandle].GLctx.isContextLost()
            }
            Module["_emscripten_is_webgl_context_lost"] = _emscripten_is_webgl_context_lost;
            _emscripten_is_webgl_context_lost.sig = "ii";

            function _emscripten_webgl_get_supported_extensions() {
                return stringToNewUTF8(GLctx.getSupportedExtensions().join(" "))
            }
            Module["_emscripten_webgl_get_supported_extensions"] = _emscripten_webgl_get_supported_extensions;
            _emscripten_webgl_get_supported_extensions.sig = "i";

            function _emscripten_webgl_get_program_parameter_d(program, param) {
                return GLctx.getProgramParameter(GL.programs[program], param)
            }
            Module["_emscripten_webgl_get_program_parameter_d"] = _emscripten_webgl_get_program_parameter_d;
            _emscripten_webgl_get_program_parameter_d.sig = "fii";

            function _emscripten_webgl_get_program_info_log_utf8(program) {
                return stringToNewUTF8(GLctx.getProgramInfoLog(GL.programs[program]))
            }
            Module["_emscripten_webgl_get_program_info_log_utf8"] = _emscripten_webgl_get_program_info_log_utf8;
            _emscripten_webgl_get_program_info_log_utf8.sig = "ii";

            function _emscripten_webgl_get_shader_parameter_d(shader, param) {
                return GLctx.getShaderParameter(GL.shaders[shader], param)
            }
            Module["_emscripten_webgl_get_shader_parameter_d"] = _emscripten_webgl_get_shader_parameter_d;
            _emscripten_webgl_get_shader_parameter_d.sig = "fii";

            function _emscripten_webgl_get_shader_info_log_utf8(shader) {
                return stringToNewUTF8(GLctx.getShaderInfoLog(GL.shaders[shader]))
            }
            Module["_emscripten_webgl_get_shader_info_log_utf8"] = _emscripten_webgl_get_shader_info_log_utf8;
            _emscripten_webgl_get_shader_info_log_utf8.sig = "ii";

            function _emscripten_webgl_get_shader_source_utf8(shader) {
                return stringToNewUTF8(GLctx.getShaderSource(GL.shaders[shader]))
            }
            Module["_emscripten_webgl_get_shader_source_utf8"] = _emscripten_webgl_get_shader_source_utf8;
            _emscripten_webgl_get_shader_source_utf8.sig = "ii";

            function _emscripten_webgl_get_vertex_attrib_d(index, param) {
                return GLctx.getVertexAttrib(index, param)
            }
            Module["_emscripten_webgl_get_vertex_attrib_d"] = _emscripten_webgl_get_vertex_attrib_d;
            _emscripten_webgl_get_vertex_attrib_d.sig = "iii";

            function _emscripten_webgl_get_vertex_attrib_o(index, param) {
                var obj = GLctx.getVertexAttrib(index, param);
                return obj && obj.name
            }
            Module["_emscripten_webgl_get_vertex_attrib_o"] = _emscripten_webgl_get_vertex_attrib_o;
            _emscripten_webgl_get_vertex_attrib_o.sig = "iii";

            function _emscripten_webgl_get_vertex_attrib_v(index, param, dst, dstLength, dstType) {
                return writeGLArray(GLctx.getVertexAttrib(index, param), dst, dstLength, dstType)
            }
            Module["_emscripten_webgl_get_vertex_attrib_v"] = _emscripten_webgl_get_vertex_attrib_v;
            _emscripten_webgl_get_vertex_attrib_v.sig = "iiiiii";

            function _emscripten_webgl_get_uniform_d(program, location) {
                return GLctx.getUniform(GL.programs[program], webglGetUniformLocation(location))
            }
            Module["_emscripten_webgl_get_uniform_d"] = _emscripten_webgl_get_uniform_d;
            _emscripten_webgl_get_uniform_d.sig = "fii";

            function _emscripten_webgl_get_uniform_v(program, location, dst, dstLength, dstType) {
                return writeGLArray(GLctx.getUniform(GL.programs[program], webglGetUniformLocation(location)), dst, dstLength, dstType)
            }
            Module["_emscripten_webgl_get_uniform_v"] = _emscripten_webgl_get_uniform_v;
            _emscripten_webgl_get_uniform_v.sig = "iiiiii";

            function _emscripten_webgl_get_parameter_v(param, dst, dstLength, dstType) {
                return writeGLArray(GLctx.getParameter(param), dst, dstLength, dstType)
            }
            Module["_emscripten_webgl_get_parameter_v"] = _emscripten_webgl_get_parameter_v;
            _emscripten_webgl_get_parameter_v.sig = "iiiii";

            function _emscripten_webgl_get_parameter_d(param) {
                return GLctx.getParameter(param)
            }
            Module["_emscripten_webgl_get_parameter_d"] = _emscripten_webgl_get_parameter_d;
            _emscripten_webgl_get_parameter_d.sig = "fi";

            function _emscripten_webgl_get_parameter_o(param) {
                var obj = GLctx.getParameter(param);
                return obj && obj.name
            }
            Module["_emscripten_webgl_get_parameter_o"] = _emscripten_webgl_get_parameter_o;
            _emscripten_webgl_get_parameter_o.sig = "ii";

            function _emscripten_webgl_get_parameter_utf8(param) {
                return stringToNewUTF8(GLctx.getParameter(param))
            }
            Module["_emscripten_webgl_get_parameter_utf8"] = _emscripten_webgl_get_parameter_utf8;
            _emscripten_webgl_get_parameter_utf8.sig = "ii";

            function _emscripten_webgl_get_parameter_i64v(param, dst) {
                writeI53ToI64(dst, GLctx.getParameter(param))
            }
            Module["_emscripten_webgl_get_parameter_i64v"] = _emscripten_webgl_get_parameter_i64v;
            _emscripten_webgl_get_parameter_i64v.sig = "vii";

            function _SDL_GetTicks() {
                return Date.now() - SDL.startTime | 0
            }
            Module["_SDL_GetTicks"] = _SDL_GetTicks;
            _SDL_GetTicks.sig = "i";

            function _SDL_LockSurface(surf) {
                var surfData = SDL.surfaces[surf];
                surfData.locked++;
                if (surfData.locked > 1) return 0;
                if (!surfData.buffer) {
                    surfData.buffer = _malloc(surfData.width * surfData.height * 4);
                    HEAP32[surf + 20 >> 2] = surfData.buffer
                }
                HEAP32[surf + 20 >> 2] = surfData.buffer;
                if (surf == SDL.screen && Module.screenIsReadOnly && surfData.image) return 0;
                if (SDL.defaults.discardOnLock) {
                    if (!surfData.image) {
                        surfData.image = surfData.ctx.createImageData(surfData.width, surfData.height)
                    }
                    if (!SDL.defaults.opaqueFrontBuffer) return
                } else {
                    surfData.image = surfData.ctx.getImageData(0, 0, surfData.width, surfData.height)
                }
                if (surf == SDL.screen && SDL.defaults.opaqueFrontBuffer) {
                    var data = surfData.image.data;
                    var num = data.length;
                    for (var i = 0; i < num / 4; i++) {
                        data[i * 4 + 3] = 255
                    }
                }
                if (SDL.defaults.copyOnLock && !SDL.defaults.discardOnLock) {
                    if (surfData.isFlagSet(2097152)) {
                        throw "CopyOnLock is not supported for SDL_LockSurface with SDL_HWPALETTE flag set" + (new Error).stack
                    } else {
                        HEAPU8.set(surfData.image.data, surfData.buffer)
                    }
                }
                return 0
            }
            Module["_SDL_LockSurface"] = _SDL_LockSurface;
            _SDL_LockSurface.sig = "ii";

            function SDL_ttfContext() {
                return SDL.ttfContext
            }
            Module["SDL_ttfContext"] = SDL_ttfContext;

            function SDL_audio() {
                return SDL.audio
            }
            Module["SDL_audio"] = SDL_audio;
            var SDL = {
                defaults: {
                    width: 320,
                    height: 200,
                    copyOnLock: true,
                    discardOnLock: false,
                    opaqueFrontBuffer: true
                },
                version: null,
                surfaces: {},
                canvasPool: [],
                events: [],
                fonts: [null],
                audios: [null],
                rwops: [null],
                music: {
                    audio: null,
                    volume: 1
                },
                mixerFrequency: 22050,
                mixerFormat: 32784,
                mixerNumChannels: 2,
                mixerChunkSize: 1024,
                channelMinimumNumber: 0,
                GL: false,
                glAttributes: {
                    0: 3,
                    1: 3,
                    2: 2,
                    3: 0,
                    4: 0,
                    5: 1,
                    6: 16,
                    7: 0,
                    8: 0,
                    9: 0,
                    10: 0,
                    11: 0,
                    12: 0,
                    13: 0,
                    14: 0,
                    15: 1,
                    16: 0,
                    17: 0,
                    18: 0
                },
                keyboardState: null,
                keyboardMap: {},
                canRequestFullscreen: false,
                isRequestingFullscreen: false,
                textInput: false,
                startTime: null,
                initFlags: 0,
                buttonState: 0,
                modState: 0,
                DOMButtons: [0, 0, 0],
                DOMEventToSDLEvent: {},
                TOUCH_DEFAULT_ID: 0,
                eventHandler: null,
                eventHandlerContext: null,
                eventHandlerTemp: 0,
                keyCodes: {
                    16: 1249,
                    17: 1248,
                    18: 1250,
                    20: 1081,
                    33: 1099,
                    34: 1102,
                    35: 1101,
                    36: 1098,
                    37: 1104,
                    38: 1106,
                    39: 1103,
                    40: 1105,
                    44: 316,
                    45: 1097,
                    46: 127,
                    91: 1251,
                    93: 1125,
                    96: 1122,
                    97: 1113,
                    98: 1114,
                    99: 1115,
                    100: 1116,
                    101: 1117,
                    102: 1118,
                    103: 1119,
                    104: 1120,
                    105: 1121,
                    106: 1109,
                    107: 1111,
                    109: 1110,
                    110: 1123,
                    111: 1108,
                    112: 1082,
                    113: 1083,
                    114: 1084,
                    115: 1085,
                    116: 1086,
                    117: 1087,
                    118: 1088,
                    119: 1089,
                    120: 1090,
                    121: 1091,
                    122: 1092,
                    123: 1093,
                    124: 1128,
                    125: 1129,
                    126: 1130,
                    127: 1131,
                    128: 1132,
                    129: 1133,
                    130: 1134,
                    131: 1135,
                    132: 1136,
                    133: 1137,
                    134: 1138,
                    135: 1139,
                    144: 1107,
                    160: 94,
                    161: 33,
                    162: 34,
                    163: 35,
                    164: 36,
                    165: 37,
                    166: 38,
                    167: 95,
                    168: 40,
                    169: 41,
                    170: 42,
                    171: 43,
                    172: 124,
                    173: 45,
                    174: 123,
                    175: 125,
                    176: 126,
                    181: 127,
                    182: 129,
                    183: 128,
                    188: 44,
                    190: 46,
                    191: 47,
                    192: 96,
                    219: 91,
                    220: 92,
                    221: 93,
                    222: 39,
                    224: 1251
                },
                scanCodes: {
                    8: 42,
                    9: 43,
                    13: 40,
                    27: 41,
                    32: 44,
                    35: 204,
                    39: 53,
                    44: 54,
                    46: 55,
                    47: 56,
                    48: 39,
                    49: 30,
                    50: 31,
                    51: 32,
                    52: 33,
                    53: 34,
                    54: 35,
                    55: 36,
                    56: 37,
                    57: 38,
                    58: 203,
                    59: 51,
                    61: 46,
                    91: 47,
                    92: 49,
                    93: 48,
                    96: 52,
                    97: 4,
                    98: 5,
                    99: 6,
                    100: 7,
                    101: 8,
                    102: 9,
                    103: 10,
                    104: 11,
                    105: 12,
                    106: 13,
                    107: 14,
                    108: 15,
                    109: 16,
                    110: 17,
                    111: 18,
                    112: 19,
                    113: 20,
                    114: 21,
                    115: 22,
                    116: 23,
                    117: 24,
                    118: 25,
                    119: 26,
                    120: 27,
                    121: 28,
                    122: 29,
                    127: 76,
                    305: 224,
                    308: 226,
                    316: 70
                },
                loadRect: function(rect) {
                    return {
                        x: HEAP32[rect + 0 >> 2],
                        y: HEAP32[rect + 4 >> 2],
                        w: HEAP32[rect + 8 >> 2],
                        h: HEAP32[rect + 12 >> 2]
                    }
                },
                updateRect: function(rect, r) {
                    HEAP32[rect >> 2] = r.x;
                    HEAP32[rect + 4 >> 2] = r.y;
                    HEAP32[rect + 8 >> 2] = r.w;
                    HEAP32[rect + 12 >> 2] = r.h
                },
                intersectionOfRects: function(first, second) {
                    var leftX = Math.max(first.x, second.x);
                    var leftY = Math.max(first.y, second.y);
                    var rightX = Math.min(first.x + first.w, second.x + second.w);
                    var rightY = Math.min(first.y + first.h, second.y + second.h);
                    return {
                        x: leftX,
                        y: leftY,
                        w: Math.max(leftX, rightX) - leftX,
                        h: Math.max(leftY, rightY) - leftY
                    }
                },
                checkPixelFormat: function(fmt) {},
                loadColorToCSSRGB: function(color) {
                    var rgba = HEAP32[color >> 2];
                    return "rgb(" + (rgba & 255) + "," + (rgba >> 8 & 255) + "," + (rgba >> 16 & 255) + ")"
                },
                loadColorToCSSRGBA: function(color) {
                    var rgba = HEAP32[color >> 2];
                    return "rgba(" + (rgba & 255) + "," + (rgba >> 8 & 255) + "," + (rgba >> 16 & 255) + "," + (rgba >> 24 & 255) / 255 + ")"
                },
                translateColorToCSSRGBA: function(rgba) {
                    return "rgba(" + (rgba & 255) + "," + (rgba >> 8 & 255) + "," + (rgba >> 16 & 255) + "," + (rgba >>> 24) / 255 + ")"
                },
                translateRGBAToCSSRGBA: function(r, g, b, a) {
                    return "rgba(" + (r & 255) + "," + (g & 255) + "," + (b & 255) + "," + (a & 255) / 255 + ")"
                },
                translateRGBAToColor: function(r, g, b, a) {
                    return r | g << 8 | b << 16 | a << 24
                },
                makeSurface: function(width, height, flags, usePageCanvas, source, rmask, gmask, bmask, amask) {
                    flags = flags || 0;
                    var is_SDL_HWSURFACE = flags & 1;
                    var is_SDL_HWPALETTE = flags & 2097152;
                    var is_SDL_OPENGL = flags & 67108864;
                    var surf = _malloc(60);
                    var pixelFormat = _malloc(44);
                    var bpp = is_SDL_HWPALETTE ? 1 : 4;
                    var buffer = 0;
                    if (!is_SDL_HWSURFACE && !is_SDL_OPENGL) {
                        buffer = _malloc(width * height * 4)
                    }
                    HEAP32[surf >> 2] = flags;
                    HEAP32[surf + 4 >> 2] = pixelFormat;
                    HEAP32[surf + 8 >> 2] = width;
                    HEAP32[surf + 12 >> 2] = height;
                    HEAP32[surf + 16 >> 2] = width * bpp;
                    HEAP32[surf + 20 >> 2] = buffer;
                    HEAP32[surf + 36 >> 2] = 0;
                    HEAP32[surf + 40 >> 2] = 0;
                    HEAP32[surf + 44 >> 2] = Module["canvas"].width;
                    HEAP32[surf + 48 >> 2] = Module["canvas"].height;
                    HEAP32[surf + 56 >> 2] = 1;
                    HEAP32[pixelFormat >> 2] = -2042224636;
                    HEAP32[pixelFormat + 4 >> 2] = 0;
                    HEAP8[pixelFormat + 8 >> 0] = bpp * 8;
                    HEAP8[pixelFormat + 9 >> 0] = bpp;
                    HEAP32[pixelFormat + 12 >> 2] = rmask || 255;
                    HEAP32[pixelFormat + 16 >> 2] = gmask || 65280;
                    HEAP32[pixelFormat + 20 >> 2] = bmask || 16711680;
                    HEAP32[pixelFormat + 24 >> 2] = amask || 4278190080;
                    SDL.GL = SDL.GL || is_SDL_OPENGL;
                    var canvas;
                    if (!usePageCanvas) {
                        if (SDL.canvasPool.length > 0) {
                            canvas = SDL.canvasPool.pop()
                        } else {
                            canvas = document.createElement("canvas")
                        }
                        canvas.width = width;
                        canvas.height = height
                    } else {
                        canvas = Module["canvas"]
                    }
                    var webGLContextAttributes = {
                        antialias: SDL.glAttributes[13] != 0 && SDL.glAttributes[14] > 1,
                        depth: SDL.glAttributes[6] > 0,
                        stencil: SDL.glAttributes[7] > 0,
                        alpha: SDL.glAttributes[3] > 0
                    };
                    var ctx = Browser.createContext(canvas, is_SDL_OPENGL, usePageCanvas, webGLContextAttributes);
                    SDL.surfaces[surf] = {
                        width: width,
                        height: height,
                        canvas: canvas,
                        ctx: ctx,
                        surf: surf,
                        buffer: buffer,
                        pixelFormat: pixelFormat,
                        alpha: 255,
                        flags: flags,
                        locked: 0,
                        usePageCanvas: usePageCanvas,
                        source: source,
                        isFlagSet: function(flag) {
                            return flags & flag
                        }
                    };
                    return surf
                },
                copyIndexedColorData: function(surfData, rX, rY, rW, rH) {
                    if (!surfData.colors) {
                        return
                    }
                    var fullWidth = Module["canvas"].width;
                    var fullHeight = Module["canvas"].height;
                    var startX = rX || 0;
                    var startY = rY || 0;
                    var endX = (rW || fullWidth - startX) + startX;
                    var endY = (rH || fullHeight - startY) + startY;
                    var buffer = surfData.buffer;
                    if (!surfData.image.data32) {
                        surfData.image.data32 = new Uint32Array(surfData.image.data.buffer)
                    }
                    var data32 = surfData.image.data32;
                    var colors32 = surfData.colors32;
                    for (var y = startY; y < endY; ++y) {
                        var base = y * fullWidth;
                        for (var x = startX; x < endX; ++x) {
                            data32[base + x] = colors32[HEAPU8[buffer + base + x >> 0]]
                        }
                    }
                },
                freeSurface: function(surf) {
                    var refcountPointer = surf + 56;
                    var refcount = HEAP32[refcountPointer >> 2];
                    if (refcount > 1) {
                        HEAP32[refcountPointer >> 2] = refcount - 1;
                        return
                    }
                    var info = SDL.surfaces[surf];
                    if (!info.usePageCanvas && info.canvas) SDL.canvasPool.push(info.canvas);
                    if (info.buffer) _free(info.buffer);
                    _free(info.pixelFormat);
                    _free(surf);
                    SDL.surfaces[surf] = null;
                    if (surf === SDL.screen) {
                        SDL.screen = null
                    }
                },
                blitSurface: function(src, srcrect, dst, dstrect, scale) {
                    var srcData = SDL.surfaces[src];
                    var dstData = SDL.surfaces[dst];
                    var sr, dr;
                    if (srcrect) {
                        sr = SDL.loadRect(srcrect)
                    } else {
                        sr = {
                            x: 0,
                            y: 0,
                            w: srcData.width,
                            h: srcData.height
                        }
                    }
                    if (dstrect) {
                        dr = SDL.loadRect(dstrect)
                    } else {
                        dr = {
                            x: 0,
                            y: 0,
                            w: srcData.width,
                            h: srcData.height
                        }
                    }
                    if (dstData.clipRect) {
                        var widthScale = !scale || sr.w === 0 ? 1 : sr.w / dr.w;
                        var heightScale = !scale || sr.h === 0 ? 1 : sr.h / dr.h;
                        dr = SDL.intersectionOfRects(dstData.clipRect, dr);
                        sr.w = dr.w * widthScale;
                        sr.h = dr.h * heightScale;
                        if (dstrect) {
                            SDL.updateRect(dstrect, dr)
                        }
                    }
                    var blitw, blith;
                    if (scale) {
                        blitw = dr.w;
                        blith = dr.h
                    } else {
                        blitw = sr.w;
                        blith = sr.h
                    }
                    if (sr.w === 0 || sr.h === 0 || blitw === 0 || blith === 0) {
                        return 0
                    }
                    var oldAlpha = dstData.ctx.globalAlpha;
                    dstData.ctx.globalAlpha = srcData.alpha / 255;
                    dstData.ctx.drawImage(srcData.canvas, sr.x, sr.y, sr.w, sr.h, dr.x, dr.y, blitw, blith);
                    dstData.ctx.globalAlpha = oldAlpha;
                    if (dst != SDL.screen) {
                        warnOnce("WARNING: copying canvas data to memory for compatibility");
                        _SDL_LockSurface(dst);
                        dstData.locked--
                    }
                    return 0
                },
                downFingers: {},
                savedKeydown: null,
                receiveEvent: function(event) {
                    function unpressAllPressedKeys() {
                        for (var code in SDL.keyboardMap) {
                            SDL.events.push({
                                type: "keyup",
                                keyCode: SDL.keyboardMap[code]
                            })
                        }
                    }
                    switch (event.type) {
                        case "touchstart":
                        case "touchmove": {
                            event.preventDefault();
                            var touches = [];
                            if (event.type === "touchstart") {
                                for (var i = 0; i < event.touches.length; i++) {
                                    var touch = event.touches[i];
                                    if (SDL.downFingers[touch.identifier] != true) {
                                        SDL.downFingers[touch.identifier] = true;
                                        touches.push(touch)
                                    }
                                }
                            } else {
                                touches = event.touches
                            }
                            var firstTouch = touches[0];
                            if (firstTouch) {
                                if (event.type == "touchstart") {
                                    SDL.DOMButtons[0] = 1
                                }
                                var mouseEventType;
                                switch (event.type) {
                                    case "touchstart":
                                        mouseEventType = "mousedown";
                                        break;
                                    case "touchmove":
                                        mouseEventType = "mousemove";
                                        break
                                }
                                var mouseEvent = {
                                    type: mouseEventType,
                                    button: 0,
                                    pageX: firstTouch.clientX,
                                    pageY: firstTouch.clientY
                                };
                                SDL.events.push(mouseEvent)
                            }
                            for (var i = 0; i < touches.length; i++) {
                                var touch = touches[i];
                                SDL.events.push({
                                    type: event.type,
                                    touch: touch
                                })
                            }
                            break
                        }
                        case "touchend": {
                            event.preventDefault();
                            for (var i = 0; i < event.changedTouches.length; i++) {
                                var touch = event.changedTouches[i];
                                if (SDL.downFingers[touch.identifier] === true) {
                                    delete SDL.downFingers[touch.identifier]
                                }
                            }
                            var mouseEvent = {
                                type: "mouseup",
                                button: 0,
                                pageX: event.changedTouches[0].clientX,
                                pageY: event.changedTouches[0].clientY
                            };
                            SDL.DOMButtons[0] = 0;
                            SDL.events.push(mouseEvent);
                            for (var i = 0; i < event.changedTouches.length; i++) {
                                var touch = event.changedTouches[i];
                                SDL.events.push({
                                    type: "touchend",
                                    touch: touch
                                })
                            }
                            break
                        }
                        case "DOMMouseScroll":
                        case "mousewheel":
                        case "wheel":
                            var delta = -Browser.getMouseWheelDelta(event);
                            delta = delta == 0 ? 0 : delta > 0 ? Math.max(delta, 1) : Math.min(delta, -1);
                            var button = delta > 0 ? 3 : 4;
                            SDL.events.push({
                                type: "mousedown",
                                button: button,
                                pageX: event.pageX,
                                pageY: event.pageY
                            });
                            SDL.events.push({
                                type: "mouseup",
                                button: button,
                                pageX: event.pageX,
                                pageY: event.pageY
                            });
                            SDL.events.push({
                                type: "wheel",
                                deltaX: 0,
                                deltaY: delta
                            });
                            event.preventDefault();
                            break;
                        case "mousemove":
                            if (SDL.DOMButtons[0] === 1) {
                                SDL.events.push({
                                    type: "touchmove",
                                    touch: {
                                        identifier: 0,
                                        deviceID: -1,
                                        pageX: event.pageX,
                                        pageY: event.pageY
                                    }
                                })
                            }
                            if (Browser.pointerLock) {
                                if ("mozMovementX" in event) {
                                    event["movementX"] = event["mozMovementX"];
                                    event["movementY"] = event["mozMovementY"]
                                }
                                if (event["movementX"] == 0 && event["movementY"] == 0) {
                                    event.preventDefault();
                                    return
                                }
                            }
                            case "keydown":
                            case "keyup":
                            case "keypress":
                            case "mousedown":
                            case "mouseup":
                                if (event.type !== "keydown" || !SDL_unicode() && !SDL.textInput || (event.keyCode === 8 || event.keyCode === 9)) {
                                    event.preventDefault()
                                }
                                if (event.type == "mousedown") {
                                    SDL.DOMButtons[event.button] = 1;
                                    SDL.events.push({
                                        type: "touchstart",
                                        touch: {
                                            identifier: 0,
                                            deviceID: -1,
                                            pageX: event.pageX,
                                            pageY: event.pageY
                                        }
                                    })
                                } else if (event.type == "mouseup") {
                                    if (!SDL.DOMButtons[event.button]) {
                                        return
                                    }
                                    SDL.events.push({
                                        type: "touchend",
                                        touch: {
                                            identifier: 0,
                                            deviceID: -1,
                                            pageX: event.pageX,
                                            pageY: event.pageY
                                        }
                                    });
                                    SDL.DOMButtons[event.button] = 0
                                }
                                if (event.type === "keydown" || event.type === "mousedown") {
                                    SDL.canRequestFullscreen = true
                                } else if (event.type === "keyup" || event.type === "mouseup") {
                                    if (SDL.isRequestingFullscreen) {
                                        Module["requestFullscreen"](true, true);
                                        SDL.isRequestingFullscreen = false
                                    }
                                    SDL.canRequestFullscreen = false
                                }
                                if (event.type === "keypress" && SDL.savedKeydown) {
                                    SDL.savedKeydown.keypressCharCode = event.charCode;
                                    SDL.savedKeydown = null
                                } else if (event.type === "keydown") {
                                    SDL.savedKeydown = event
                                }
                                if (event.type !== "keypress" || SDL.textInput) {
                                    SDL.events.push(event)
                                }
                                break;
                            case "mouseout":
                                for (var i = 0; i < 3; i++) {
                                    if (SDL.DOMButtons[i]) {
                                        SDL.events.push({
                                            type: "mouseup",
                                            button: i,
                                            pageX: event.pageX,
                                            pageY: event.pageY
                                        });
                                        SDL.DOMButtons[i] = 0
                                    }
                                }
                                event.preventDefault();
                                break;
                            case "focus":
                                SDL.events.push(event);
                                event.preventDefault();
                                break;
                            case "blur":
                                SDL.events.push(event);
                                unpressAllPressedKeys();
                                event.preventDefault();
                                break;
                            case "visibilitychange":
                                SDL.events.push({
                                    type: "visibilitychange",
                                    visible: !document.hidden
                                });
                                unpressAllPressedKeys();
                                event.preventDefault();
                                break;
                            case "unload":
                                if (Browser.mainLoop.runner) {
                                    SDL.events.push(event);
                                    Browser.mainLoop.runner()
                                }
                                return;
                            case "resize":
                                SDL.events.push(event);
                                if (event.preventDefault) {
                                    event.preventDefault()
                                }
                                break
                    }
                    if (SDL.events.length >= 1e4) {
                        err("SDL event queue full, dropping events");
                        SDL.events = SDL.events.slice(0, 1e4)
                    }
                    SDL.flushEventsToHandler();
                    return
                },
                lookupKeyCodeForEvent: function(event) {
                    var code = event.keyCode;
                    if (code >= 65 && code <= 90) {
                        code += 32
                    } else {
                        code = SDL.keyCodes[event.keyCode] || event.keyCode;
                        if (event.location === 2 && code >= (224 | 1 << 10) && code <= (227 | 1 << 10)) {
                            code += 4
                        }
                    }
                    return code
                },
                handleEvent: function(event) {
                    if (event.handled) return;
                    event.handled = true;
                    switch (event.type) {
                        case "touchstart":
                        case "touchend":
                        case "touchmove": {
                            Browser.calculateMouseEvent(event);
                            break
                        }
                        case "keydown":
                        case "keyup": {
                            var down = event.type === "keydown";
                            var code = SDL.lookupKeyCodeForEvent(event);
                            HEAP8[SDL.keyboardState + code >> 0] = down;
                            SDL.modState = (HEAP8[SDL.keyboardState + 1248 >> 0] ? 64 : 0) | (HEAP8[SDL.keyboardState + 1249 >> 0] ? 1 : 0) | (HEAP8[SDL.keyboardState + 1250 >> 0] ? 256 : 0) | (HEAP8[SDL.keyboardState + 1252 >> 0] ? 128 : 0) | (HEAP8[SDL.keyboardState + 1253 >> 0] ? 2 : 0) | (HEAP8[SDL.keyboardState + 1254 >> 0] ? 512 : 0);
                            if (down) {
                                SDL.keyboardMap[code] = event.keyCode
                            } else {
                                delete SDL.keyboardMap[code]
                            }
                            break
                        }
                        case "mousedown":
                        case "mouseup":
                            if (event.type == "mousedown") {
                                SDL.buttonState |= 1 << event.button
                            } else if (event.type == "mouseup") {
                                SDL.buttonState &= ~(1 << event.button)
                            }
                            case "mousemove": {
                                Browser.calculateMouseEvent(event);
                                break
                            }
                    }
                },
                flushEventsToHandler: function() {
                    if (!SDL.eventHandler) return;
                    while (SDL.pollEvent(SDL.eventHandlerTemp)) {
                        wasmTable.get(SDL.eventHandler)(SDL.eventHandlerContext, SDL.eventHandlerTemp)
                    }
                },
                pollEvent: function(ptr) {
                    if (SDL.initFlags & 512 && SDL.joystickEventState) {
                        SDL.queryJoysticks()
                    }
                    if (ptr) {
                        while (SDL.events.length > 0) {
                            if (SDL.makeCEvent(SDL.events.shift(), ptr) !== false) return 1
                        }
                        return 0
                    } else {
                        return SDL.events.length > 0
                    }
                },
                makeCEvent: function(event, ptr) {
                    if (typeof event === "number") {
                        _memcpy(ptr, event, 28);
                        _free(event);
                        return
                    }
                    SDL.handleEvent(event);
                    switch (event.type) {
                        case "keydown":
                        case "keyup": {
                            var down = event.type === "keydown";
                            var key = SDL.lookupKeyCodeForEvent(event);
                            var scan;
                            if (key >= 1024) {
                                scan = key - 1024
                            } else {
                                scan = SDL.scanCodes[key] || key
                            }
                            HEAP32[ptr >> 2] = SDL.DOMEventToSDLEvent[event.type];
                            HEAP8[ptr + 8 >> 0] = down ? 1 : 0;
                            HEAP8[ptr + 9 >> 0] = 0;
                            HEAP32[ptr + 12 >> 2] = scan;
                            HEAP32[ptr + 16 >> 2] = key;
                            HEAP16[ptr + 20 >> 1] = SDL.modState;
                            HEAP32[ptr + 24 >> 2] = event.keypressCharCode || key;
                            break
                        }
                        case "keypress": {
                            HEAP32[ptr >> 2] = SDL.DOMEventToSDLEvent[event.type];
                            var cStr = intArrayFromString(String.fromCharCode(event.charCode));
                            for (var i = 0; i < cStr.length; ++i) {
                                HEAP8[ptr + (8 + i) >> 0] = cStr[i]
                            }
                            break
                        }
                        case "mousedown":
                        case "mouseup":
                        case "mousemove": {
                            if (event.type != "mousemove") {
                                var down = event.type === "mousedown";
                                HEAP32[ptr >> 2] = SDL.DOMEventToSDLEvent[event.type];
                                HEAP32[ptr + 4 >> 2] = 0;
                                HEAP32[ptr + 8 >> 2] = 0;
                                HEAP32[ptr + 12 >> 2] = 0;
                                HEAP8[ptr + 16 >> 0] = event.button + 1;
                                HEAP8[ptr + 17 >> 0] = down ? 1 : 0;
                                HEAP32[ptr + 20 >> 2] = Browser.mouseX;
                                HEAP32[ptr + 24 >> 2] = Browser.mouseY
                            } else {
                                HEAP32[ptr >> 2] = SDL.DOMEventToSDLEvent[event.type];
                                HEAP32[ptr + 4 >> 2] = 0;
                                HEAP32[ptr + 8 >> 2] = 0;
                                HEAP32[ptr + 12 >> 2] = 0;
                                HEAP32[ptr + 16 >> 2] = SDL.buttonState;
                                HEAP32[ptr + 20 >> 2] = Browser.mouseX;
                                HEAP32[ptr + 24 >> 2] = Browser.mouseY;
                                HEAP32[ptr + 28 >> 2] = Browser.mouseMovementX;
                                HEAP32[ptr + 32 >> 2] = Browser.mouseMovementY
                            }
                            break
                        }
                        case "wheel": {
                            HEAP32[ptr >> 2] = SDL.DOMEventToSDLEvent[event.type];
                            HEAP32[ptr + 16 >> 2] = event.deltaX;
                            HEAP32[ptr + 20 >> 2] = event.deltaY;
                            break
                        }
                        case "touchstart":
                        case "touchend":
                        case "touchmove": {
                            var touch = event.touch;
                            if (!Browser.touches[touch.identifier]) break;
                            var w = Module["canvas"].width;
                            var h = Module["canvas"].height;
                            var x = Browser.touches[touch.identifier].x / w;
                            var y = Browser.touches[touch.identifier].y / h;
                            var lx = Browser.lastTouches[touch.identifier].x / w;
                            var ly = Browser.lastTouches[touch.identifier].y / h;
                            var dx = x - lx;
                            var dy = y - ly;
                            if (touch["deviceID"] === undefined) touch.deviceID = SDL.TOUCH_DEFAULT_ID;
                            if (dx === 0 && dy === 0 && event.type === "touchmove") return false;
                            HEAP32[ptr >> 2] = SDL.DOMEventToSDLEvent[event.type];
                            HEAP32[ptr + 4 >> 2] = _SDL_GetTicks();
                            tempI64 = [touch.deviceID >>> 0, (tempDouble = touch.deviceID, +Math.abs(tempDouble) >= 1 ? tempDouble > 0 ? (Math.min(+Math.floor(tempDouble / 4294967296), 4294967295) | 0) >>> 0 : ~~+Math.ceil((tempDouble - +(~~tempDouble >>> 0)) / 4294967296) >>> 0 : 0)], HEAP32[ptr + 8 >> 2] = tempI64[0], HEAP32[ptr + 12 >> 2] = tempI64[1];
                            tempI64 = [touch.identifier >>> 0, (tempDouble = touch.identifier, +Math.abs(tempDouble) >= 1 ? tempDouble > 0 ? (Math.min(+Math.floor(tempDouble / 4294967296), 4294967295) | 0) >>> 0 : ~~+Math.ceil((tempDouble - +(~~tempDouble >>> 0)) / 4294967296) >>> 0 : 0)], HEAP32[ptr + 16 >> 2] = tempI64[0], HEAP32[ptr + 20 >> 2] = tempI64[1];
                            HEAPF32[ptr + 24 >> 2] = x;
                            HEAPF32[ptr + 28 >> 2] = y;
                            HEAPF32[ptr + 32 >> 2] = dx;
                            HEAPF32[ptr + 36 >> 2] = dy;
                            if (touch.force !== undefined) {
                                HEAPF32[ptr + 40 >> 2] = touch.force
                            } else {
                                HEAPF32[ptr + 40 >> 2] = event.type == "touchend" ? 0 : 1
                            }
                            break
                        }
                        case "unload": {
                            HEAP32[ptr >> 2] = SDL.DOMEventToSDLEvent[event.type];
                            break
                        }
                        case "resize": {
                            HEAP32[ptr >> 2] = SDL.DOMEventToSDLEvent[event.type];
                            HEAP32[ptr + 4 >> 2] = event.w;
                            HEAP32[ptr + 8 >> 2] = event.h;
                            break
                        }
                        case "joystick_button_up":
                        case "joystick_button_down": {
                            var state = event.type === "joystick_button_up" ? 0 : 1;
                            HEAP32[ptr >> 2] = SDL.DOMEventToSDLEvent[event.type];
                            HEAP8[ptr + 4 >> 0] = event.index;
                            HEAP8[ptr + 5 >> 0] = event.button;
                            HEAP8[ptr + 6 >> 0] = state;
                            break
                        }
                        case "joystick_axis_motion": {
                            HEAP32[ptr >> 2] = SDL.DOMEventToSDLEvent[event.type];
                            HEAP8[ptr + 4 >> 0] = event.index;
                            HEAP8[ptr + 5 >> 0] = event.axis;
                            HEAP32[ptr + 8 >> 2] = SDL.joystickAxisValueConversion(event.value);
                            break
                        }
                        case "focus": {
                            var SDL_WINDOWEVENT_FOCUS_GAINED = 12;
                            HEAP32[ptr >> 2] = SDL.DOMEventToSDLEvent[event.type];
                            HEAP32[ptr + 4 >> 2] = 0;
                            HEAP8[ptr + 8 >> 0] = SDL_WINDOWEVENT_FOCUS_GAINED;
                            break
                        }
                        case "blur": {
                            var SDL_WINDOWEVENT_FOCUS_LOST = 13;
                            HEAP32[ptr >> 2] = SDL.DOMEventToSDLEvent[event.type];
                            HEAP32[ptr + 4 >> 2] = 0;
                            HEAP8[ptr + 8 >> 0] = SDL_WINDOWEVENT_FOCUS_LOST;
                            break
                        }
                        case "visibilitychange": {
                            var SDL_WINDOWEVENT_SHOWN = 1;
                            var SDL_WINDOWEVENT_HIDDEN = 2;
                            var visibilityEventID = event.visible ? SDL_WINDOWEVENT_SHOWN : SDL_WINDOWEVENT_HIDDEN;
                            HEAP32[ptr >> 2] = SDL.DOMEventToSDLEvent[event.type];
                            HEAP32[ptr + 4 >> 2] = 0;
                            HEAP8[ptr + 8 >> 0] = visibilityEventID;
                            break
                        }
                        default:
                            throw "Unhandled SDL event: " + event.type
                    }
                },
                makeFontString: function(height, fontName) {
                    if (fontName.charAt(0) != "'" && fontName.charAt(0) != '"') {
                        fontName = '"' + fontName + '"'
                    }
                    return height + "px " + fontName + ", serif"
                },
                estimateTextWidth: function(fontData, text) {
                    var h = fontData.size;
                    var fontString = SDL.makeFontString(h, fontData.name);
                    var tempCtx = SDL_ttfContext();
                    tempCtx.font = fontString;
                    var ret = tempCtx.measureText(text).width | 0;
                    return ret
                },
                allocateChannels: function(num) {
                    if (SDL.numChannels && SDL.numChannels >= num && num != 0) return;
                    SDL.numChannels = num;
                    SDL.channels = [];
                    for (var i = 0; i < num; i++) {
                        SDL.channels[i] = {
                            audio: null,
                            volume: 1
                        }
                    }
                },
                setGetVolume: function(info, volume) {
                    if (!info) return 0;
                    var ret = info.volume * 128;
                    if (volume != -1) {
                        info.volume = Math.min(Math.max(volume, 0), 128) / 128;
                        if (info.audio) {
                            try {
                                info.audio.volume = info.volume;
                                if (info.audio.webAudioGainNode) info.audio.webAudioGainNode["gain"]["value"] = info.volume
                            } catch (e) {
                                err("setGetVolume failed to set audio volume: " + e)
                            }
                        }
                    }
                    return ret
                },
                setPannerPosition: function(info, x, y, z) {
                    if (!info) return;
                    if (info.audio) {
                        if (info.audio.webAudioPannerNode) {
                            info.audio.webAudioPannerNode["setPosition"](x, y, z)
                        }
                    }
                },
                playWebAudio: function(audio) {
                    if (!audio) return;
                    if (audio.webAudioNode) return;
                    if (!SDL.webAudioAvailable()) return;
                    try {
                        var webAudio = audio.resource.webAudio;
                        audio.paused = false;
                        if (!webAudio.decodedBuffer) {
                            if (webAudio.onDecodeComplete === undefined) abort("Cannot play back audio object that was not loaded");
                            webAudio.onDecodeComplete.push(function() {
                                if (!audio.paused) SDL.playWebAudio(audio)
                            });
                            return
                        }
                        audio.webAudioNode = SDL.audioContext["createBufferSource"]();
                        audio.webAudioNode["buffer"] = webAudio.decodedBuffer;
                        audio.webAudioNode["loop"] = audio.loop;
                        audio.webAudioNode["onended"] = function() {
                            audio["onended"]()
                        };
                        audio.webAudioPannerNode = SDL.audioContext["createPanner"]();
                        audio.webAudioPannerNode["setPosition"](0, 0, -.5);
                        audio.webAudioPannerNode["panningModel"] = "equalpower";
                        audio.webAudioGainNode = SDL.audioContext["createGain"]();
                        audio.webAudioGainNode["gain"]["value"] = audio.volume;
                        audio.webAudioNode["connect"](audio.webAudioPannerNode);
                        audio.webAudioPannerNode["connect"](audio.webAudioGainNode);
                        audio.webAudioGainNode["connect"](SDL.audioContext["destination"]);
                        audio.webAudioNode["start"](0, audio.currentPosition);
                        audio.startTime = SDL.audioContext["currentTime"] - audio.currentPosition
                    } catch (e) {
                        err("playWebAudio failed: " + e)
                    }
                },
                pauseWebAudio: function(audio) {
                    if (!audio) return;
                    if (audio.webAudioNode) {
                        try {
                            audio.currentPosition = (SDL.audioContext["currentTime"] - audio.startTime) % audio.resource.webAudio.decodedBuffer.duration;
                            audio.webAudioNode["onended"] = undefined;
                            audio.webAudioNode.stop(0);
                            audio.webAudioNode = undefined
                        } catch (e) {
                            err("pauseWebAudio failed: " + e)
                        }
                    }
                    audio.paused = true
                },
                openAudioContext: function() {
                    if (!SDL.audioContext) {
                        if (typeof AudioContext !== "undefined") SDL.audioContext = new AudioContext;
                        else if (typeof webkitAudioContext !== "undefined") SDL.audioContext = new webkitAudioContext
                    }
                },
                webAudioAvailable: function() {
                    return !!SDL.audioContext
                },
                fillWebAudioBufferFromHeap: function(heapPtr, sizeSamplesPerChannel, dstAudioBuffer) {
                    var audio = SDL_audio();
                    var numChannels = audio.channels;
                    for (var c = 0; c < numChannels; ++c) {
                        var channelData = dstAudioBuffer["getChannelData"](c);
                        if (channelData.length != sizeSamplesPerChannel) {
                            throw "Web Audio output buffer length mismatch! Destination size: " + channelData.length + " samples vs expected " + sizeSamplesPerChannel + " samples!"
                        }
                        if (audio.format == 32784) {
                            for (var j = 0; j < sizeSamplesPerChannel; ++j) {
                                channelData[j] = HEAP16[heapPtr + (j * numChannels + c) * 2 >> 1] / 32768
                            }
                        } else if (audio.format == 8) {
                            for (var j = 0; j < sizeSamplesPerChannel; ++j) {
                                var v = HEAP8[heapPtr + (j * numChannels + c) >> 0];
                                channelData[j] = (v >= 0 ? v - 128 : v + 128) / 128
                            }
                        } else if (audio.format == 33056) {
                            for (var j = 0; j < sizeSamplesPerChannel; ++j) {
                                channelData[j] = HEAPF32[heapPtr + (j * numChannels + c) * 4 >> 2]
                            }
                        } else {
                            throw "Invalid SDL audio format " + audio.format + "!"
                        }
                    }
                },
                debugSurface: function(surfData) {
                    console.log("dumping surface " + [surfData.surf, surfData.source, surfData.width, surfData.height]);
                    var image = surfData.ctx.getImageData(0, 0, surfData.width, surfData.height);
                    var data = image.data;
                    var num = Math.min(surfData.width, surfData.height);
                    for (var i = 0; i < num; i++) {
                        console.log("   diagonal " + i + ":" + [data[i * surfData.width * 4 + i * 4 + 0], data[i * surfData.width * 4 + i * 4 + 1], data[i * surfData.width * 4 + i * 4 + 2], data[i * surfData.width * 4 + i * 4 + 3]])
                    }
                },
                joystickEventState: 1,
                lastJoystickState: {},
                joystickNamePool: {},
                recordJoystickState: function(joystick, state) {
                    var buttons = new Array(state.buttons.length);
                    for (var i = 0; i < state.buttons.length; i++) {
                        buttons[i] = SDL.getJoystickButtonState(state.buttons[i])
                    }
                    SDL.lastJoystickState[joystick] = {
                        buttons: buttons,
                        axes: state.axes.slice(0),
                        timestamp: state.timestamp,
                        index: state.index,
                        id: state.id
                    }
                },
                getJoystickButtonState: function(button) {
                    if (typeof button === "object") {
                        return button["pressed"]
                    } else {
                        return button > 0
                    }
                },
                queryJoysticks: function() {
                    for (var joystick in SDL.lastJoystickState) {
                        var state = SDL.getGamepad(joystick - 1);
                        var prevState = SDL.lastJoystickState[joystick];
                        if (typeof state === "undefined") return;
                        if (state === null) return;
                        if (typeof state.timestamp !== "number" || state.timestamp !== prevState.timestamp || !state.timestamp) {
                            var i;
                            for (i = 0; i < state.buttons.length; i++) {
                                var buttonState = SDL.getJoystickButtonState(state.buttons[i]);
                                if (buttonState !== prevState.buttons[i]) {
                                    SDL.events.push({
                                        type: buttonState ? "joystick_button_down" : "joystick_button_up",
                                        joystick: joystick,
                                        index: joystick - 1,
                                        button: i
                                    })
                                }
                            }
                            for (i = 0; i < state.axes.length; i++) {
                                if (state.axes[i] !== prevState.axes[i]) {
                                    SDL.events.push({
                                        type: "joystick_axis_motion",
                                        joystick: joystick,
                                        index: joystick - 1,
                                        axis: i,
                                        value: state.axes[i]
                                    })
                                }
                            }
                            SDL.recordJoystickState(joystick, state)
                        }
                    }
                },
                joystickAxisValueConversion: function(value) {
                    value = Math.min(1, Math.max(value, -1));
                    return Math.ceil((value + 1) * 32767.5 - 32768)
                },
                getGamepads: function() {
                    var fcn = navigator.getGamepads || navigator.webkitGamepads || navigator.mozGamepads || navigator.gamepads || navigator.webkitGetGamepads;
                    if (fcn !== undefined) {
                        return fcn.apply(navigator)
                    } else {
                        return []
                    }
                },
                getGamepad: function(deviceIndex) {
                    var gamepads = SDL.getGamepads();
                    if (gamepads.length > deviceIndex && deviceIndex >= 0) {
                        return gamepads[deviceIndex]
                    }
                    return null
                }
            };
            Module["SDL"] = SDL;

            function SDL_unicode() {
                return SDL.unicode
            }
            Module["SDL_unicode"] = SDL_unicode;

            function _SDL_Linked_Version() {
                if (SDL.version === null) {
                    SDL.version = _malloc(3);
                    HEAP8[SDL.version + 0 >> 0] = 1;
                    HEAP8[SDL.version + 1 >> 0] = 3;
                    HEAP8[SDL.version + 2 >> 0] = 0
                }
                return SDL.version
            }
            Module["_SDL_Linked_Version"] = _SDL_Linked_Version;
            _SDL_Linked_Version.sig = "i";

            function _SDL_Init(initFlags) {
                SDL.startTime = Date.now();
                SDL.initFlags = initFlags;
                if (!Module["doNotCaptureKeyboard"]) {
                    var keyboardListeningElement = Module["keyboardListeningElement"] || document;
                    keyboardListeningElement.addEventListener("keydown", SDL.receiveEvent);
                    keyboardListeningElement.addEventListener("keyup", SDL.receiveEvent);
                    keyboardListeningElement.addEventListener("keypress", SDL.receiveEvent);
                    window.addEventListener("focus", SDL.receiveEvent);
                    window.addEventListener("blur", SDL.receiveEvent);
                    document.addEventListener("visibilitychange", SDL.receiveEvent)
                }
                window.addEventListener("unload", SDL.receiveEvent);
                SDL.keyboardState = _malloc(65536);
                _memset(SDL.keyboardState, 0, 65536);
                SDL.DOMEventToSDLEvent["keydown"] = 768;
                SDL.DOMEventToSDLEvent["keyup"] = 769;
                SDL.DOMEventToSDLEvent["keypress"] = 771;
                SDL.DOMEventToSDLEvent["mousedown"] = 1025;
                SDL.DOMEventToSDLEvent["mouseup"] = 1026;
                SDL.DOMEventToSDLEvent["mousemove"] = 1024;
                SDL.DOMEventToSDLEvent["wheel"] = 1027;
                SDL.DOMEventToSDLEvent["touchstart"] = 1792;
                SDL.DOMEventToSDLEvent["touchend"] = 1793;
                SDL.DOMEventToSDLEvent["touchmove"] = 1794;
                SDL.DOMEventToSDLEvent["unload"] = 256;
                SDL.DOMEventToSDLEvent["resize"] = 28673;
                SDL.DOMEventToSDLEvent["visibilitychange"] = 512;
                SDL.DOMEventToSDLEvent["focus"] = 512;
                SDL.DOMEventToSDLEvent["blur"] = 512;
                SDL.DOMEventToSDLEvent["joystick_axis_motion"] = 1536;
                SDL.DOMEventToSDLEvent["joystick_button_down"] = 1539;
                SDL.DOMEventToSDLEvent["joystick_button_up"] = 1540;
                return 0
            }
            Module["_SDL_Init"] = _SDL_Init;
            _SDL_Init.sig = "ii";

            function _SDL_WasInit() {
                if (SDL.startTime === null) {
                    _SDL_Init()
                }
                return 1
            }
            Module["_SDL_WasInit"] = _SDL_WasInit;
            _SDL_WasInit.sig = "i";

            function _SDL_GetVideoInfo() {
                var ret = _malloc(5 * 4);
                HEAP32[ret + 0 >> 2] = 0;
                HEAP32[ret + 4 >> 2] = 0;
                HEAP32[ret + 8 >> 2] = 0;
                HEAP32[ret + 12 >> 2] = Module["canvas"].width;
                HEAP32[ret + 16 >> 2] = Module["canvas"].height;
                return ret
            }
            Module["_SDL_GetVideoInfo"] = _SDL_GetVideoInfo;
            _SDL_GetVideoInfo.sig = "i";

            function _SDL_ListModes(format, flags) {
                return -1
            }
            Module["_SDL_ListModes"] = _SDL_ListModes;

            function _SDL_VideoModeOK(width, height, depth, flags) {
                return depth
            }
            Module["_SDL_VideoModeOK"] = _SDL_VideoModeOK;

            function _SDL_VideoDriverName(buf, max_size) {
                if (SDL.startTime === null) {
                    return 0
                }
                var driverName = [101, 109, 115, 99, 114, 105, 112, 116, 101, 110, 95, 115, 100, 108, 95, 100, 114, 105, 118, 101, 114];
                var index = 0;
                var size = driverName.length;
                if (max_size <= size) {
                    size = max_size - 1
                }
                while (index < size) {
                    var value = driverName[index];
                    HEAP8[buf + index >> 0] = value;
                    index++
                }
                HEAP8[buf + index >> 0] = 0;
                return buf
            }
            Module["_SDL_VideoDriverName"] = _SDL_VideoDriverName;
            _SDL_VideoDriverName.sig = "iii";

            function _SDL_AudioDriverName(buf, max_size) {
                return _SDL_VideoDriverName(buf, max_size)
            }
            Module["_SDL_AudioDriverName"] = _SDL_AudioDriverName;

            function _SDL_SetVideoMode(width, height, depth, flags) {
                ["touchstart", "touchend", "touchmove", "mousedown", "mouseup", "mousemove", "DOMMouseScroll", "mousewheel", "wheel", "mouseout"].forEach(function(event) {
                    Module["canvas"].addEventListener(event, SDL.receiveEvent, true)
                });
                var canvas = Module["canvas"];
                if (width == 0 && height == 0) {
                    width = canvas.width;
                    height = canvas.height
                }
                if (!SDL.addedResizeListener) {
                    SDL.addedResizeListener = true;
                    Browser.resizeListeners.push(function(w, h) {
                        if (!SDL.settingVideoMode) {
                            SDL.receiveEvent({
                                type: "resize",
                                w: w,
                                h: h
                            })
                        }
                    })
                }
                SDL.settingVideoMode = true;
                Browser.setCanvasSize(width, height);
                SDL.settingVideoMode = false;
                if (SDL.screen) {
                    SDL.freeSurface(SDL.screen);
                    assert(!SDL.screen)
                }
                if (SDL.GL) flags = flags | 67108864;
                SDL.screen = SDL.makeSurface(width, height, flags, true, "screen");
                return SDL.screen
            }
            Module["_SDL_SetVideoMode"] = _SDL_SetVideoMode;
            _SDL_SetVideoMode.sig = "iiiii";

            function _SDL_GetVideoSurface() {
                return SDL.screen
            }
            Module["_SDL_GetVideoSurface"] = _SDL_GetVideoSurface;
            _SDL_GetVideoSurface.sig = "i";

            function _SDL_AudioQuit() {
                for (var i = 0; i < SDL.numChannels; ++i) {
                    if (SDL.channels[i].audio) {
                        SDL.channels[i].audio.pause();
                        SDL.channels[i].audio = undefined
                    }
                }
                if (SDL.music.audio) SDL.music.audio.pause();
                SDL.music.audio = undefined
            }
            Module["_SDL_AudioQuit"] = _SDL_AudioQuit;
            _SDL_AudioQuit.sig = "v";

            function _SDL_VideoQuit() {
                out("SDL_VideoQuit called (and ignored)")
            }
            Module["_SDL_VideoQuit"] = _SDL_VideoQuit;

            function _SDL_QuitSubSystem(flags) {
                out("SDL_QuitSubSystem called (and ignored)")
            }
            Module["_SDL_QuitSubSystem"] = _SDL_QuitSubSystem;

            function _SDL_Quit() {
                _SDL_AudioQuit();
                out("SDL_Quit called (and ignored)")
            }
            Module["_SDL_Quit"] = _SDL_Quit;

            function _SDL_UnlockSurface(surf) {
                assert(!SDL.GL);
                var surfData = SDL.surfaces[surf];
                if (!surfData.locked || --surfData.locked > 0) {
                    return
                }
                if (surfData.isFlagSet(2097152)) {
                    SDL.copyIndexedColorData(surfData)
                } else if (!surfData.colors) {
                    var data = surfData.image.data;
                    var buffer = surfData.buffer;
                    assert(buffer % 4 == 0, "Invalid buffer offset: " + buffer);
                    var src = buffer >> 2;
                    var dst = 0;
                    var isScreen = surf == SDL.screen;
                    var num;
                    if (typeof CanvasPixelArray !== "undefined" && data instanceof CanvasPixelArray) {
                        num = data.length;
                        while (dst < num) {
                            var val = HEAP32[src];
                            data[dst] = val & 255;
                            data[dst + 1] = val >> 8 & 255;
                            data[dst + 2] = val >> 16 & 255;
                            data[dst + 3] = isScreen ? 255 : val >> 24 & 255;
                            src++;
                            dst += 4
                        }
                    } else {
                        var data32 = new Uint32Array(data.buffer);
                        if (isScreen && SDL.defaults.opaqueFrontBuffer) {
                            num = data32.length;
                            data32.set(HEAP32.subarray(src, src + num));
                            var data8 = new Uint8Array(data.buffer);
                            var i = 3;
                            var j = i + 4 * num;
                            if (num % 8 == 0) {
                                while (i < j) {
                                    data8[i] = 255;
                                    i = i + 4 | 0;
                                    data8[i] = 255;
                                    i = i + 4 | 0;
                                    data8[i] = 255;
                                    i = i + 4 | 0;
                                    data8[i] = 255;
                                    i = i + 4 | 0;
                                    data8[i] = 255;
                                    i = i + 4 | 0;
                                    data8[i] = 255;
                                    i = i + 4 | 0;
                                    data8[i] = 255;
                                    i = i + 4 | 0;
                                    data8[i] = 255;
                                    i = i + 4 | 0
                                }
                            } else {
                                while (i < j) {
                                    data8[i] = 255;
                                    i = i + 4 | 0
                                }
                            }
                        } else {
                            data32.set(HEAP32.subarray(src, src + data32.length))
                        }
                    }
                } else {
                    var width = Module["canvas"].width;
                    var height = Module["canvas"].height;
                    var s = surfData.buffer;
                    var data = surfData.image.data;
                    var colors = surfData.colors;
                    for (var y = 0; y < height; y++) {
                        var base = y * width * 4;
                        for (var x = 0; x < width; x++) {
                            var val = HEAPU8[s++ >> 0] * 4;
                            var start = base + x * 4;
                            data[start] = colors[val];
                            data[start + 1] = colors[val + 1];
                            data[start + 2] = colors[val + 2]
                        }
                        s += width * 3
                    }
                }
                surfData.ctx.putImageData(surfData.image, 0, 0)
            }
            Module["_SDL_UnlockSurface"] = _SDL_UnlockSurface;
            _SDL_UnlockSurface.sig = "vi";

            function _SDL_Flip(surf) {}
            Module["_SDL_Flip"] = _SDL_Flip;

            function _SDL_UpdateRect(surf, x, y, w, h) {}
            Module["_SDL_UpdateRect"] = _SDL_UpdateRect;

            function _SDL_UpdateRects(surf, numrects, rects) {}
            Module["_SDL_UpdateRects"] = _SDL_UpdateRects;

            function _SDL_Delay(delay) {
                if (!ENVIRONMENT_IS_WORKER) abort("SDL_Delay called on the main thread! Potential infinite loop, quitting. (consider building with async support like ASYNCIFY)");
                var now = Date.now();
                while (Date.now() - now < delay) {}
            }
            Module["_SDL_Delay"] = _SDL_Delay;

            function _SDL_WM_SetCaption(title, icon) {
                if (title && typeof setWindowTitle !== "undefined") {
                    setWindowTitle(UTF8ToString(title))
                }
                icon = icon && UTF8ToString(icon)
            }
            Module["_SDL_WM_SetCaption"] = _SDL_WM_SetCaption;
            _SDL_WM_SetCaption.sig = "vii";

            function _SDL_EnableKeyRepeat(delay, interval) {}
            Module["_SDL_EnableKeyRepeat"] = _SDL_EnableKeyRepeat;

            function _SDL_GetKeyboardState(numKeys) {
                if (numKeys) {
                    HEAP32[numKeys >> 2] = 65536
                }
                return SDL.keyboardState
            }
            Module["_SDL_GetKeyboardState"] = _SDL_GetKeyboardState;
            _SDL_GetKeyboardState.sig = "ii";

            function _SDL_GetKeyState() {
                return _SDL_GetKeyboardState()
            }
            Module["_SDL_GetKeyState"] = _SDL_GetKeyState;

            function _SDL_GetKeyName(key) {
                if (!SDL.keyName) {
                    SDL.keyName = allocate(intArrayFromString("unknown key"), ALLOC_NORMAL)
                }
                return SDL.keyName
            }
            Module["_SDL_GetKeyName"] = _SDL_GetKeyName;
            _SDL_GetKeyName.sig = "ii";

            function _SDL_GetModState() {
                return SDL.modState
            }
            Module["_SDL_GetModState"] = _SDL_GetModState;
            _SDL_GetModState.sig = "i";

            function _SDL_GetMouseState(x, y) {
                if (x) HEAP32[x >> 2] = Browser.mouseX;
                if (y) HEAP32[y >> 2] = Browser.mouseY;
                return SDL.buttonState
            }
            Module["_SDL_GetMouseState"] = _SDL_GetMouseState;
            _SDL_GetMouseState.sig = "iii";

            function _SDL_WarpMouse(x, y) {
                return
            }
            Module["_SDL_WarpMouse"] = _SDL_WarpMouse;
            _SDL_WarpMouse.sig = "vii";

            function _SDL_ShowCursor(toggle) {
                switch (toggle) {
                    case 0:
                        if (Browser.isFullscreen) {
                            Module["canvas"].requestPointerLock();
                            return 0
                        } else {
                            return 1
                        }
                        break;
                    case 1:
                        Module["canvas"].exitPointerLock();
                        return 1;
                        break;
                    case -1:
                        return !Browser.pointerLock;
                        break;
                    default:
                        console.log("SDL_ShowCursor called with unknown toggle parameter value: " + toggle + ".");
                        break
                }
            }
            Module["_SDL_ShowCursor"] = _SDL_ShowCursor;
            _SDL_ShowCursor.sig = "ii";

            function _SDL_GetError() {
                if (!SDL.errorMessage) {
                    SDL.errorMessage = allocate(intArrayFromString("unknown SDL-emscripten error"), ALLOC_NORMAL)
                }
                return SDL.errorMessage
            }
            Module["_SDL_GetError"] = _SDL_GetError;
            _SDL_GetError.sig = "i";

            function _SDL_SetError() {}
            Module["_SDL_SetError"] = _SDL_SetError;

            function _SDL_malloc(size) {
                return _malloc(size)
            }
            Module["_SDL_malloc"] = _SDL_malloc;
            _SDL_malloc.sig = "ii";

            function _SDL_free(ptr) {
                _free(ptr)
            }
            Module["_SDL_free"] = _SDL_free;
            _SDL_free.sig = "vi";

            function _SDL_CreateRGBSurface(flags, width, height, depth, rmask, gmask, bmask, amask) {
                return SDL.makeSurface(width, height, flags, false, "CreateRGBSurface", rmask, gmask, bmask, amask)
            }
            Module["_SDL_CreateRGBSurface"] = _SDL_CreateRGBSurface;
            _SDL_CreateRGBSurface.sig = "iiiiiiiii";

            function _SDL_CreateRGBSurfaceFrom(pixels, width, height, depth, pitch, rmask, gmask, bmask, amask) {
                var surf = SDL.makeSurface(width, height, 0, false, "CreateRGBSurfaceFrom", rmask, gmask, bmask, amask);
                if (depth !== 32) {
                    console.log("TODO: Partially unimplemented SDL_CreateRGBSurfaceFrom called!");
                    return surf
                }
                var data = SDL.surfaces[surf];
                var image = data.ctx.createImageData(width, height);
                var pitchOfDst = width * 4;
                for (var row = 0; row < height; ++row) {
                    var baseOfSrc = row * pitch;
                    var baseOfDst = row * pitchOfDst;
                    for (var col = 0; col < width * 4; ++col) {
                        image.data[baseOfDst + col] = HEAPU8[pixels + (baseOfDst + col) >> 0]
                    }
                }
                data.ctx.putImageData(image, 0, 0);
                return surf
            }
            Module["_SDL_CreateRGBSurfaceFrom"] = _SDL_CreateRGBSurfaceFrom;
            _SDL_CreateRGBSurfaceFrom.sig = "iiiiiiiiii";

            function _SDL_ConvertSurface(surf, format, flags) {
                if (format) {
                    SDL.checkPixelFormat(format)
                }
                var oldData = SDL.surfaces[surf];
                var ret = SDL.makeSurface(oldData.width, oldData.height, oldData.flags, false, "copy:" + oldData.source);
                var newData = SDL.surfaces[ret];
                newData.ctx.globalCompositeOperation = "copy";
                newData.ctx.drawImage(oldData.canvas, 0, 0);
                newData.ctx.globalCompositeOperation = oldData.ctx.globalCompositeOperation;
                return ret
            }
            Module["_SDL_ConvertSurface"] = _SDL_ConvertSurface;
            _SDL_ConvertSurface.sig = "iiii";

            function _SDL_DisplayFormatAlpha(surf) {
                return _SDL_ConvertSurface(surf)
            }
            Module["_SDL_DisplayFormatAlpha"] = _SDL_DisplayFormatAlpha;

            function _SDL_FreeSurface(surf) {
                if (surf) SDL.freeSurface(surf)
            }
            Module["_SDL_FreeSurface"] = _SDL_FreeSurface;
            _SDL_FreeSurface.sig = "vi";

            function _SDL_UpperBlit(src, srcrect, dst, dstrect) {
                return SDL.blitSurface(src, srcrect, dst, dstrect, false)
            }
            Module["_SDL_UpperBlit"] = _SDL_UpperBlit;
            _SDL_UpperBlit.sig = "iiiii";

            function _SDL_UpperBlitScaled(src, srcrect, dst, dstrect) {
                return SDL.blitSurface(src, srcrect, dst, dstrect, true)
            }
            Module["_SDL_UpperBlitScaled"] = _SDL_UpperBlitScaled;
            _SDL_UpperBlitScaled.sig = "iiiii";

            function _SDL_LowerBlit(a0, a1, a2, a3) {
                return _SDL_UpperBlit(a0, a1, a2, a3)
            }
            Module["_SDL_LowerBlit"] = _SDL_LowerBlit;
            _SDL_LowerBlit.sig = "iiiii";

            function _SDL_LowerBlitScaled(a0, a1, a2, a3) {
                return _SDL_UpperBlitScaled(a0, a1, a2, a3)
            }
            Module["_SDL_LowerBlitScaled"] = _SDL_LowerBlitScaled;
            _SDL_LowerBlitScaled.sig = "iiiii";

            function _SDL_GetClipRect(surf, rect) {
                assert(rect);
                var surfData = SDL.surfaces[surf];
                var r = surfData.clipRect || {
                    x: 0,
                    y: 0,
                    w: surfData.width,
                    h: surfData.height
                };
                SDL.updateRect(rect, r)
            }
            Module["_SDL_GetClipRect"] = _SDL_GetClipRect;
            _SDL_GetClipRect.sig = "vii";

            function _SDL_SetClipRect(surf, rect) {
                var surfData = SDL.surfaces[surf];
                if (rect) {
                    surfData.clipRect = SDL.intersectionOfRects({
                        x: 0,
                        y: 0,
                        w: surfData.width,
                        h: surfData.height
                    }, SDL.loadRect(rect))
                } else {
                    delete surfData.clipRect
                }
            }
            Module["_SDL_SetClipRect"] = _SDL_SetClipRect;
            _SDL_SetClipRect.sig = "vii";

            function _SDL_FillRect(surf, rect, color) {
                var surfData = SDL.surfaces[surf];
                assert(!surfData.locked);
                if (surfData.isFlagSet(2097152)) {
                    color = surfData.colors32[color]
                }
                var r = rect ? SDL.loadRect(rect) : {
                    x: 0,
                    y: 0,
                    w: surfData.width,
                    h: surfData.height
                };
                if (surfData.clipRect) {
                    r = SDL.intersectionOfRects(surfData.clipRect, r);
                    if (rect) {
                        SDL.updateRect(rect, r)
                    }
                }
                surfData.ctx.save();
                surfData.ctx.fillStyle = SDL.translateColorToCSSRGBA(color);
                surfData.ctx.fillRect(r.x, r.y, r.w, r.h);
                surfData.ctx.restore();
                return 0
            }
            Module["_SDL_FillRect"] = _SDL_FillRect;
            _SDL_FillRect.sig = "iiii";

            function _SDL_BlitSurface(src, srcrect, dst, dstrect) {
                return SDL.blitSurface(src, srcrect, dst, dstrect, false)
            }
            Module["_SDL_BlitSurface"] = _SDL_BlitSurface;
            _SDL_BlitSurface.sig = "iiiii";

            function _SDL_BlitScaled(src, srcrect, dst, dstrect) {
                return SDL.blitSurface(src, srcrect, dst, dstrect, true)
            }
            Module["_SDL_BlitScaled"] = _SDL_BlitScaled;
            _SDL_BlitScaled.sig = "iiiii";

            function _zoomSurface(src, x, y, smooth) {
                var srcData = SDL.surfaces[src];
                var w = srcData.width * x;
                var h = srcData.height * y;
                var ret = SDL.makeSurface(Math.abs(w), Math.abs(h), srcData.flags, false, "zoomSurface");
                var dstData = SDL.surfaces[ret];
                if (x >= 0 && y >= 0) dstData.ctx.drawImage(srcData.canvas, 0, 0, w, h);
                else {
                    dstData.ctx.save();
                    dstData.ctx.scale(x < 0 ? -1 : 1, y < 0 ? -1 : 1);
                    dstData.ctx.drawImage(srcData.canvas, w < 0 ? w : 0, h < 0 ? h : 0, Math.abs(w), Math.abs(h));
                    dstData.ctx.restore()
                }
                return ret
            }
            Module["_zoomSurface"] = _zoomSurface;

            function _rotozoomSurface(src, angle, zoom, smooth) {
                if (angle % 360 === 0) {
                    return _zoomSurface(src, zoom, zoom, smooth)
                }
                var srcData = SDL.surfaces[src];
                var w = srcData.width * zoom;
                var h = srcData.height * zoom;
                var diagonal = Math.ceil(Math.sqrt(Math.pow(w, 2) + Math.pow(h, 2)));
                var ret = SDL.makeSurface(diagonal, diagonal, srcData.flags, false, "rotozoomSurface");
                var dstData = SDL.surfaces[ret];
                dstData.ctx.translate(diagonal / 2, diagonal / 2);
                dstData.ctx.rotate(-angle * Math.PI / 180);
                dstData.ctx.drawImage(srcData.canvas, -w / 2, -h / 2, w, h);
                return ret
            }
            Module["_rotozoomSurface"] = _rotozoomSurface;

            function _SDL_SetAlpha(surf, flag, alpha) {
                var surfData = SDL.surfaces[surf];
                surfData.alpha = alpha;
                if (!(flag & 65536)) {
                    surfData.alpha = 255
                }
            }
            Module["_SDL_SetAlpha"] = _SDL_SetAlpha;
            _SDL_SetAlpha.sig = "iiii";

            function _SDL_SetColorKey(surf, flag, key) {
                warnOnce("SDL_SetColorKey is a no-op for performance reasons");
                return 0
            }
            Module["_SDL_SetColorKey"] = _SDL_SetColorKey;

            function _SDL_PollEvent(ptr) {
                return SDL.pollEvent(ptr)
            }
            Module["_SDL_PollEvent"] = _SDL_PollEvent;
            _SDL_PollEvent.sig = "ii";

            function _SDL_PushEvent(ptr) {
                var copy = _malloc(28);
                _memcpy(copy, ptr, 28);
                SDL.events.push(copy);
                return 0
            }
            Module["_SDL_PushEvent"] = _SDL_PushEvent;
            _SDL_PushEvent.sig = "ii";

            function _SDL_PeepEvents(events, requestedEventCount, action, from, to) {
                switch (action) {
                    case 2: {
                        assert(requestedEventCount == 1);
                        var index = 0;
                        var retrievedEventCount = 0;
                        while (index < SDL.events.length && retrievedEventCount < requestedEventCount) {
                            var event = SDL.events[index];
                            var type = SDL.DOMEventToSDLEvent[event.type];
                            if (from <= type && type <= to) {
                                if (SDL.makeCEvent(event, events) === false) {
                                    index++
                                } else {
                                    SDL.events.splice(index, 1);
                                    retrievedEventCount++
                                }
                            } else {
                                index++
                            }
                        }
                        return retrievedEventCount
                    }
                    default:
                        throw "SDL_PeepEvents does not yet support that action: " + action
                }
            }
            Module["_SDL_PeepEvents"] = _SDL_PeepEvents;
            _SDL_PeepEvents.sig = "iiiiii";

            function _SDL_PumpEvents() {
                SDL.events.forEach(function(event) {
                    SDL.handleEvent(event)
                })
            }
            Module["_SDL_PumpEvents"] = _SDL_PumpEvents;
            _SDL_PumpEvents.sig = "v";

            function _emscripten_SDL_SetEventHandler(handler, userdata) {
                SDL.eventHandler = handler;
                SDL.eventHandlerContext = userdata;
                if (!SDL.eventHandlerTemp) SDL.eventHandlerTemp = _malloc(28)
            }
            Module["_emscripten_SDL_SetEventHandler"] = _emscripten_SDL_SetEventHandler;
            _emscripten_SDL_SetEventHandler.sig = "vii";

            function _SDL_SetColors(surf, colors, firstColor, nColors) {
                var surfData = SDL.surfaces[surf];
                if (!surfData.colors) {
                    var buffer = new ArrayBuffer(256 * 4);
                    surfData.colors = new Uint8Array(buffer);
                    surfData.colors32 = new Uint32Array(buffer)
                }
                for (var i = 0; i < nColors; ++i) {
                    var index = (firstColor + i) * 4;
                    surfData.colors[index] = HEAPU8[colors + i * 4 >> 0];
                    surfData.colors[index + 1] = HEAPU8[colors + (i * 4 + 1) >> 0];
                    surfData.colors[index + 2] = HEAPU8[colors + (i * 4 + 2) >> 0];
                    surfData.colors[index + 3] = 255
                }
                return 1
            }
            Module["_SDL_SetColors"] = _SDL_SetColors;
            _SDL_SetColors.sig = "iiiii";

            function _SDL_SetPalette(surf, flags, colors, firstColor, nColors) {
                return _SDL_SetColors(surf, colors, firstColor, nColors)
            }
            Module["_SDL_SetPalette"] = _SDL_SetPalette;

            function _SDL_MapRGB(fmt, r, g, b) {
                SDL.checkPixelFormat(fmt);
                return r & 255 | (g & 255) << 8 | (b & 255) << 16 | 4278190080
            }
            Module["_SDL_MapRGB"] = _SDL_MapRGB;
            _SDL_MapRGB.sig = "iiiii";

            function _SDL_MapRGBA(fmt, r, g, b, a) {
                SDL.checkPixelFormat(fmt);
                return r & 255 | (g & 255) << 8 | (b & 255) << 16 | (a & 255) << 24
            }
            Module["_SDL_MapRGBA"] = _SDL_MapRGBA;
            _SDL_MapRGBA.sig = "iiiiii";

            function _SDL_GetRGB(pixel, fmt, r, g, b) {
                SDL.checkPixelFormat(fmt);
                if (r) {
                    HEAP8[r >> 0] = pixel & 255
                }
                if (g) {
                    HEAP8[g >> 0] = pixel >> 8 & 255
                }
                if (b) {
                    HEAP8[b >> 0] = pixel >> 16 & 255
                }
            }
            Module["_SDL_GetRGB"] = _SDL_GetRGB;
            _SDL_GetRGB.sig = "viiiii";

            function _SDL_GetRGBA(pixel, fmt, r, g, b, a) {
                SDL.checkPixelFormat(fmt);
                if (r) {
                    HEAP8[r >> 0] = pixel & 255
                }
                if (g) {
                    HEAP8[g >> 0] = pixel >> 8 & 255
                }
                if (b) {
                    HEAP8[b >> 0] = pixel >> 16 & 255
                }
                if (a) {
                    HEAP8[a >> 0] = pixel >> 24 & 255
                }
            }
            Module["_SDL_GetRGBA"] = _SDL_GetRGBA;
            _SDL_GetRGBA.sig = "viiiiii";

            function _SDL_GetAppState() {
                var state = 0;
                if (Browser.pointerLock) {
                    state |= 1
                }
                if (document.hasFocus()) {
                    state |= 2
                }
                state |= 4;
                return state
            }
            Module["_SDL_GetAppState"] = _SDL_GetAppState;
            _SDL_GetAppState.sig = "i";

            function _SDL_WM_GrabInput() {}
            Module["_SDL_WM_GrabInput"] = _SDL_WM_GrabInput;

            function _SDL_WM_ToggleFullScreen(surf) {
                if (Browser.exitFullscreen()) {
                    return 1
                } else {
                    if (!SDL.canRequestFullscreen) {
                        return 0
                    }
                    SDL.isRequestingFullscreen = true;
                    return 1
                }
            }
            Module["_SDL_WM_ToggleFullScreen"] = _SDL_WM_ToggleFullScreen;
            _SDL_WM_ToggleFullScreen.sig = "ii";

            function _IMG_Init(flags) {
                return flags
            }
            Module["_IMG_Init"] = _IMG_Init;

            function _SDL_FreeRW(rwopsID) {
                SDL.rwops[rwopsID] = null;
                while (SDL.rwops.length > 0 && SDL.rwops[SDL.rwops.length - 1] === null) {
                    SDL.rwops.pop()
                }
            }
            Module["_SDL_FreeRW"] = _SDL_FreeRW;
            _SDL_FreeRW.sig = "vi";

            function _IMG_Load_RW(rwopsID, freeSrc) {
                try {
                    var cleanup = function() {
                        if (rwops && freeSrc) _SDL_FreeRW(rwopsID)
                    };
                    var addCleanup = function(func) {
                        var old = cleanup;
                        cleanup = function added_cleanup() {
                            old();
                            func()
                        }
                    };
                    var callStbImage = function(func, params) {
                        var x = Module["_malloc"](4);
                        var y = Module["_malloc"](4);
                        var comp = Module["_malloc"](4);
                        addCleanup(function() {
                            Module["_free"](x);
                            Module["_free"](y);
                            Module["_free"](comp);
                            if (data) Module["_stbi_image_free"](data)
                        });
                        var data = Module["_" + func].apply(null, params.concat([x, y, comp, 0]));
                        if (!data) return null;
                        return {
                            rawData: true,
                            data: data,
                            width: HEAP32[x >> 2],
                            height: HEAP32[y >> 2],
                            size: HEAP32[x >> 2] * HEAP32[y >> 2] * HEAP32[comp >> 2],
                            bpp: HEAP32[comp >> 2]
                        }
                    };
                    var rwops = SDL.rwops[rwopsID];
                    if (rwops === undefined) {
                        return 0
                    }
                    var raw;
                    var filename = rwops.filename;
                    if (filename === undefined) {
                        warnOnce("Only file names that have been preloaded are supported for IMG_Load_RW. Consider using STB_IMAGE=1 if you want synchronous image decoding (see settings.js), or package files with --use-preload-plugins");
                        return 0
                    }
                    if (!raw) {
                        filename = PATH_FS.resolve(filename);
                        raw = Module["preloadedImages"][filename];
                        if (!raw) {
                            if (raw === null) err("Trying to reuse preloaded image, but freePreloadedMediaOnUse is set!");
                            warnOnce("Cannot find preloaded image " + filename);
                            warnOnce("Cannot find preloaded image " + filename + ". Consider using STB_IMAGE=1 if you want synchronous image decoding (see settings.js), or package files with --use-preload-plugins");
                            return 0
                        } else if (Module["freePreloadedMediaOnUse"]) {
                            Module["preloadedImages"][filename] = null
                        }
                    }
                    var surf = SDL.makeSurface(raw.width, raw.height, 0, false, "load:" + filename);
                    var surfData = SDL.surfaces[surf];
                    surfData.ctx.globalCompositeOperation = "copy";
                    if (!raw.rawData) {
                        surfData.ctx.drawImage(raw, 0, 0, raw.width, raw.height, 0, 0, raw.width, raw.height)
                    } else {
                        var imageData = surfData.ctx.getImageData(0, 0, surfData.width, surfData.height);
                        if (raw.bpp == 4) {
                            imageData.data.set(HEAPU8.subarray(raw.data, raw.data + raw.size))
                        } else if (raw.bpp == 3) {
                            var pixels = raw.size / 3;
                            var data = imageData.data;
                            var sourcePtr = raw.data;
                            var destPtr = 0;
                            for (var i = 0; i < pixels; i++) {
                                data[destPtr++] = HEAPU8[sourcePtr++ >> 0];
                                data[destPtr++] = HEAPU8[sourcePtr++ >> 0];
                                data[destPtr++] = HEAPU8[sourcePtr++ >> 0];
                                data[destPtr++] = 255
                            }
                        } else if (raw.bpp == 2) {
                            var pixels = raw.size;
                            var data = imageData.data;
                            var sourcePtr = raw.data;
                            var destPtr = 0;
                            for (var i = 0; i < pixels; i++) {
                                var gray = HEAPU8[sourcePtr++ >> 0];
                                var alpha = HEAPU8[sourcePtr++ >> 0];
                                data[destPtr++] = gray;
                                data[destPtr++] = gray;
                                data[destPtr++] = gray;
                                data[destPtr++] = alpha
                            }
                        } else if (raw.bpp == 1) {
                            var pixels = raw.size;
                            var data = imageData.data;
                            var sourcePtr = raw.data;
                            var destPtr = 0;
                            for (var i = 0; i < pixels; i++) {
                                var value = HEAPU8[sourcePtr++ >> 0];
                                data[destPtr++] = value;
                                data[destPtr++] = value;
                                data[destPtr++] = value;
                                data[destPtr++] = 255
                            }
                        } else {
                            err("cannot handle bpp " + raw.bpp);
                            return 0
                        }
                        surfData.ctx.putImageData(imageData, 0, 0)
                    }
                    surfData.ctx.globalCompositeOperation = "source-over";
                    _SDL_LockSurface(surf);
                    surfData.locked--;
                    if (SDL.GL) {
                        surfData.canvas = surfData.ctx = null
                    }
                    return surf
                } finally {
                    cleanup()
                }
            }
            Module["_IMG_Load_RW"] = _IMG_Load_RW;
            _IMG_Load_RW.sig = "iii";

            function _SDL_RWFromFile(_name, mode) {
                var id = SDL.rwops.length;
                var name = UTF8ToString(_name);
                SDL.rwops.push({
                    filename: name,
                    mimetype: Browser.getMimetype(name)
                });
                return id
            }
            Module["_SDL_RWFromFile"] = _SDL_RWFromFile;
            _SDL_RWFromFile.sig = "iii";

            function _IMG_Load(filename) {
                var rwops = _SDL_RWFromFile(filename);
                var result = _IMG_Load_RW(rwops, 1);
                return result
            }
            Module["_IMG_Load"] = _IMG_Load;
            _IMG_Load.sig = "ii";

            function _SDL_LoadBMP(a0) {
                return _IMG_Load(a0)
            }
            Module["_SDL_LoadBMP"] = _SDL_LoadBMP;
            _SDL_LoadBMP.sig = "ii";

            function _SDL_LoadBMP_RW(a0, a1) {
                return _IMG_Load_RW(a0, a1)
            }
            Module["_SDL_LoadBMP_RW"] = _SDL_LoadBMP_RW;
            _SDL_LoadBMP_RW.sig = "iii";

            function _IMG_Quit() {
                out("IMG_Quit called (and ignored)")
            }
            Module["_IMG_Quit"] = _IMG_Quit;

            function _SDL_OpenAudio(desired, obtained) {
                try {
                    SDL.audio = {
                        freq: HEAPU32[desired >> 2],
                        format: HEAPU16[desired + 4 >> 1],
                        channels: HEAPU8[desired + 6 >> 0],
                        samples: HEAPU16[desired + 8 >> 1],
                        callback: HEAPU32[desired + 16 >> 2],
                        userdata: HEAPU32[desired + 20 >> 2],
                        paused: true,
                        timer: null
                    };
                    if (SDL.audio.format == 8) {
                        SDL.audio.silence = 128
                    } else if (SDL.audio.format == 32784) {
                        SDL.audio.silence = 0
                    } else if (SDL.audio.format == 33056) {
                        SDL.audio.silence = 0
                    } else {
                        throw "Invalid SDL audio format " + SDL.audio.format + "!"
                    }
                    if (SDL.audio.freq <= 0) {
                        throw "Unsupported sound frequency " + SDL.audio.freq + "!"
                    } else if (SDL.audio.freq <= 22050) {
                        SDL.audio.freq = 22050
                    } else if (SDL.audio.freq <= 32e3) {
                        SDL.audio.freq = 32e3
                    } else if (SDL.audio.freq <= 44100) {
                        SDL.audio.freq = 44100
                    } else if (SDL.audio.freq <= 48e3) {
                        SDL.audio.freq = 48e3
                    } else if (SDL.audio.freq <= 96e3) {
                        SDL.audio.freq = 96e3
                    } else {
                        throw "Unsupported sound frequency " + SDL.audio.freq + "!"
                    }
                    if (SDL.audio.channels == 0) {
                        SDL.audio.channels = 1
                    } else if (SDL.audio.channels < 0 || SDL.audio.channels > 32) {
                        throw "Unsupported number of audio channels for SDL audio: " + SDL.audio.channels + "!"
                    } else if (SDL.audio.channels != 1 && SDL.audio.channels != 2) {
                        console.log("Warning: Using untested number of audio channels " + SDL.audio.channels)
                    }
                    if (SDL.audio.samples < 128 || SDL.audio.samples > 524288) {
                        throw "Unsupported audio callback buffer size " + SDL.audio.samples + "!"
                    } else if ((SDL.audio.samples & SDL.audio.samples - 1) != 0) {
                        throw "Audio callback buffer size " + SDL.audio.samples + " must be a power-of-two!"
                    }
                    var totalSamples = SDL.audio.samples * SDL.audio.channels;
                    if (SDL.audio.format == 8) {
                        SDL.audio.bytesPerSample = 1
                    } else if (SDL.audio.format == 32784) {
                        SDL.audio.bytesPerSample = 2
                    } else if (SDL.audio.format == 33056) {
                        SDL.audio.bytesPerSample = 4
                    } else {
                        throw "Invalid SDL audio format " + SDL.audio.format + "!"
                    }
                    SDL.audio.bufferSize = totalSamples * SDL.audio.bytesPerSample;
                    SDL.audio.bufferDurationSecs = SDL.audio.bufferSize / SDL.audio.bytesPerSample / SDL.audio.channels / SDL.audio.freq;
                    SDL.audio.bufferingDelay = 50 / 1e3;
                    SDL.audio.buffer = _malloc(SDL.audio.bufferSize);
                    SDL.audio.numSimultaneouslyQueuedBuffers = Module["SDL_numSimultaneouslyQueuedBuffers"] || 5;
                    SDL.audio.queueNewAudioData = function SDL_queueNewAudioData() {
                        if (!SDL.audio) return;
                        for (var i = 0; i < SDL.audio.numSimultaneouslyQueuedBuffers; ++i) {
                            var secsUntilNextPlayStart = SDL.audio.nextPlayTime - SDL.audioContext["currentTime"];
                            if (secsUntilNextPlayStart >= SDL.audio.bufferingDelay + SDL.audio.bufferDurationSecs * SDL.audio.numSimultaneouslyQueuedBuffers) return;
                            wasmTable.get(SDL.audio.callback)(SDL.audio.userdata, SDL.audio.buffer, SDL.audio.bufferSize);
                            SDL.audio.pushAudio(SDL.audio.buffer, SDL.audio.bufferSize)
                        }
                    };
                    SDL.audio.caller = function SDL_audioCaller() {
                        if (!SDL.audio) return;
                        --SDL.audio.numAudioTimersPending;
                        SDL.audio.queueNewAudioData();
                        var secsUntilNextPlayStart = SDL.audio.nextPlayTime - SDL.audioContext["currentTime"];
                        var preemptBufferFeedSecs = SDL.audio.bufferDurationSecs / 2;
                        if (SDL.audio.numAudioTimersPending < SDL.audio.numSimultaneouslyQueuedBuffers) {
                            ++SDL.audio.numAudioTimersPending;
                            SDL.audio.timer = Browser.safeSetTimeout(SDL.audio.caller, Math.max(0, 1e3 * (secsUntilNextPlayStart - preemptBufferFeedSecs)));
                            if (SDL.audio.numAudioTimersPending < SDL.audio.numSimultaneouslyQueuedBuffers) {
                                ++SDL.audio.numAudioTimersPending;
                                Browser.safeSetTimeout(SDL.audio.caller, 1)
                            }
                        }
                    };
                    SDL.audio.audioOutput = new Audio;
                    SDL.openAudioContext();
                    if (!SDL.audioContext) throw "Web Audio API is not available!";
                    autoResumeAudioContext(SDL.audioContext);
                    SDL.audio.nextPlayTime = 0;
                    SDL.audio.pushAudio = function(ptr, sizeBytes) {
                        try {
                            if (SDL.audio.paused) return;
                            var sizeSamples = sizeBytes / SDL.audio.bytesPerSample;
                            var sizeSamplesPerChannel = sizeSamples / SDL.audio.channels;
                            if (sizeSamplesPerChannel != SDL.audio.samples) {
                                throw "Received mismatching audio buffer size!"
                            }
                            var source = SDL.audioContext["createBufferSource"]();
                            var soundBuffer = SDL.audioContext["createBuffer"](SDL.audio.channels, sizeSamplesPerChannel, SDL.audio.freq);
                            source["connect"](SDL.audioContext["destination"]);
                            SDL.fillWebAudioBufferFromHeap(ptr, sizeSamplesPerChannel, soundBuffer);
                            source["buffer"] = soundBuffer;
                            var curtime = SDL.audioContext["currentTime"];
                            var playtime = Math.max(curtime + SDL.audio.bufferingDelay, SDL.audio.nextPlayTime);
                            if (typeof source["start"] !== "undefined") {
                                source["start"](playtime)
                            } else if (typeof source["noteOn"] !== "undefined") {
                                source["noteOn"](playtime)
                            }
                            SDL.audio.nextPlayTime = playtime + SDL.audio.bufferDurationSecs
                        } catch (e) {
                            console.log("Web Audio API error playing back audio: " + e.toString())
                        }
                    };
                    if (obtained) {
                        HEAP32[obtained >> 2] = SDL.audio.freq;
                        HEAP16[obtained + 4 >> 1] = SDL.audio.format;
                        HEAP8[obtained + 6 >> 0] = SDL.audio.channels;
                        HEAP8[obtained + 7 >> 0] = SDL.audio.silence;
                        HEAP16[obtained + 8 >> 1] = SDL.audio.samples;
                        HEAP32[obtained + 16 >> 2] = SDL.audio.callback;
                        HEAP32[obtained + 20 >> 2] = SDL.audio.userdata
                    }
                    SDL.allocateChannels(32)
                } catch (e) {
                    console.log('Initializing SDL audio threw an exception: "' + e.toString() + '"! Continuing without audio.');
                    SDL.audio = null;
                    SDL.allocateChannels(0);
                    if (obtained) {
                        HEAP32[obtained >> 2] = 0;
                        HEAP16[obtained + 4 >> 1] = 0;
                        HEAP8[obtained + 6 >> 0] = 0;
                        HEAP8[obtained + 7 >> 0] = 0;
                        HEAP16[obtained + 8 >> 1] = 0;
                        HEAP32[obtained + 16 >> 2] = 0;
                        HEAP32[obtained + 20 >> 2] = 0
                    }
                }
                if (!SDL.audio) {
                    return -1
                }
                return 0
            }
            Module["_SDL_OpenAudio"] = _SDL_OpenAudio;
            _SDL_OpenAudio.sig = "iii";

            function _SDL_PauseAudio(pauseOn) {
                if (!SDL.audio) {
                    return
                }
                if (pauseOn) {
                    if (SDL.audio.timer !== undefined) {
                        clearTimeout(SDL.audio.timer);
                        SDL.audio.numAudioTimersPending = 0;
                        SDL.audio.timer = undefined
                    }
                } else if (!SDL.audio.timer) {
                    SDL.audio.numAudioTimersPending = 1;
                    SDL.audio.timer = Browser.safeSetTimeout(SDL.audio.caller, 1)
                }
                SDL.audio.paused = pauseOn
            }
            Module["_SDL_PauseAudio"] = _SDL_PauseAudio;
            _SDL_PauseAudio.sig = "vi";

            function _SDL_CloseAudio() {
                if (SDL.audio) {
                    if (SDL.audio.callbackRemover) {
                        SDL.audio.callbackRemover();
                        SDL.audio.callbackRemover = null
                    }
                    _SDL_PauseAudio(1);
                    _free(SDL.audio.buffer);
                    SDL.audio = null;
                    SDL.allocateChannels(0)
                }
            }
            Module["_SDL_CloseAudio"] = _SDL_CloseAudio;
            _SDL_CloseAudio.sig = "v";

            function _SDL_LockAudio() {}
            Module["_SDL_LockAudio"] = _SDL_LockAudio;

            function _SDL_UnlockAudio() {}
            Module["_SDL_UnlockAudio"] = _SDL_UnlockAudio;

            function _SDL_CreateMutex() {
                return 0
            }
            Module["_SDL_CreateMutex"] = _SDL_CreateMutex;

            function _SDL_LockMutex() {}
            Module["_SDL_LockMutex"] = _SDL_LockMutex;

            function _SDL_UnlockMutex() {}
            Module["_SDL_UnlockMutex"] = _SDL_UnlockMutex;

            function _SDL_mutexP() {
                return 0
            }
            Module["_SDL_mutexP"] = _SDL_mutexP;

            function _SDL_mutexV() {
                return 0
            }
            Module["_SDL_mutexV"] = _SDL_mutexV;

            function _SDL_DestroyMutex() {}
            Module["_SDL_DestroyMutex"] = _SDL_DestroyMutex;

            function _SDL_CreateCond() {
                return 0
            }
            Module["_SDL_CreateCond"] = _SDL_CreateCond;

            function _SDL_CondSignal() {}
            Module["_SDL_CondSignal"] = _SDL_CondSignal;

            function _SDL_CondWait() {}
            Module["_SDL_CondWait"] = _SDL_CondWait;

            function _SDL_DestroyCond() {}
            Module["_SDL_DestroyCond"] = _SDL_DestroyCond;

            function _SDL_StartTextInput() {
                SDL.textInput = true
            }
            Module["_SDL_StartTextInput"] = _SDL_StartTextInput;
            _SDL_StartTextInput.sig = "v";

            function _SDL_StopTextInput() {
                SDL.textInput = false
            }
            Module["_SDL_StopTextInput"] = _SDL_StopTextInput;
            _SDL_StopTextInput.sig = "v";

            function _Mix_Init(flags) {
                if (!flags) return 0;
                return 8
            }
            Module["_Mix_Init"] = _Mix_Init;

            function _Mix_Quit() {}
            Module["_Mix_Quit"] = _Mix_Quit;

            function _Mix_OpenAudio(frequency, format, channels, chunksize) {
                SDL.openAudioContext();
                autoResumeAudioContext(SDL.audioContext);
                SDL.allocateChannels(32);
                SDL.mixerFrequency = frequency;
                SDL.mixerFormat = format;
                SDL.mixerNumChannels = channels;
                SDL.mixerChunkSize = chunksize;
                return 0
            }
            Module["_Mix_OpenAudio"] = _Mix_OpenAudio;
            _Mix_OpenAudio.sig = "iiiii";

            function _Mix_CloseAudio() {
                _SDL_CloseAudio()
            }
            Module["_Mix_CloseAudio"] = _Mix_CloseAudio;
            _Mix_CloseAudio.sig = "v";

            function _Mix_AllocateChannels(num) {
                SDL.allocateChannels(num);
                return num
            }
            Module["_Mix_AllocateChannels"] = _Mix_AllocateChannels;
            _Mix_AllocateChannels.sig = "ii";

            function _Mix_ChannelFinished(func) {
                SDL.channelFinished = func
            }
            Module["_Mix_ChannelFinished"] = _Mix_ChannelFinished;
            _Mix_ChannelFinished.sig = "vi";

            function _Mix_Volume(channel, volume) {
                if (channel == -1) {
                    for (var i = 0; i < SDL.numChannels - 1; i++) {
                        _Mix_Volume(i, volume)
                    }
                    return _Mix_Volume(SDL.numChannels - 1, volume)
                }
                return SDL.setGetVolume(SDL.channels[channel], volume)
            }
            Module["_Mix_Volume"] = _Mix_Volume;
            _Mix_Volume.sig = "iii";

            function _Mix_SetPanning(channel, left, right) {
                left /= 255;
                right /= 255;
                SDL.setPannerPosition(SDL.channels[channel], right - left, 0, .1);
                return 1
            }
            Module["_Mix_SetPanning"] = _Mix_SetPanning;
            _Mix_SetPanning.sig = "iiii";

            function _Mix_LoadWAV_RW(rwopsID, freesrc) {
                var rwops = SDL.rwops[rwopsID];
                if (rwops === undefined) return 0;
                var filename = "";
                var audio;
                var webAudio;
                var bytes;
                if (rwops.filename !== undefined) {
                    filename = PATH_FS.resolve(rwops.filename);
                    var raw = Module["preloadedAudios"][filename];
                    if (!raw) {
                        if (raw === null) err("Trying to reuse preloaded audio, but freePreloadedMediaOnUse is set!");
                        if (!Module.noAudioDecoding) warnOnce("Cannot find preloaded audio " + filename);
                        try {
                            bytes = FS.readFile(filename)
                        } catch (e) {
                            err("Couldn't find file for: " + filename);
                            return 0
                        }
                    }
                    if (Module["freePreloadedMediaOnUse"]) {
                        Module["preloadedAudios"][filename] = null
                    }
                    audio = raw
                } else if (rwops.bytes !== undefined) {
                    if (SDL.webAudioAvailable()) bytes = HEAPU8.buffer.slice(rwops.bytes, rwops.bytes + rwops.count);
                    else bytes = HEAPU8.subarray(rwops.bytes, rwops.bytes + rwops.count)
                } else {
                    return 0
                }
                var arrayBuffer = bytes ? bytes.buffer || bytes : bytes;
                var canPlayWithWebAudio = Module["SDL_canPlayWithWebAudio"] === undefined || Module["SDL_canPlayWithWebAudio"](filename, arrayBuffer);
                if (bytes !== undefined && SDL.webAudioAvailable() && canPlayWithWebAudio) {
                    audio = undefined;
                    webAudio = {};
                    webAudio.onDecodeComplete = [];
                    var onDecodeComplete = function(data) {
                        webAudio.decodedBuffer = data;
                        webAudio.onDecodeComplete.forEach(function(e) {
                            e()
                        });
                        webAudio.onDecodeComplete = undefined
                    };
                    SDL.audioContext["decodeAudioData"](arrayBuffer, onDecodeComplete)
                } else if (audio === undefined && bytes) {
                    var blob = new Blob([bytes], {
                        type: rwops.mimetype
                    });
                    var url = URL.createObjectURL(blob);
                    audio = new Audio;
                    audio.src = url;
                    audio.mozAudioChannelType = "content"
                }
                var id = SDL.audios.length;
                SDL.audios.push({
                    source: filename,
                    audio: audio,
                    webAudio: webAudio
                });
                return id
            }
            Module["_Mix_LoadWAV_RW"] = _Mix_LoadWAV_RW;
            _Mix_LoadWAV_RW.sig = "iii";

            function _Mix_LoadWAV(filename) {
                var rwops = _SDL_RWFromFile(filename);
                var result = _Mix_LoadWAV_RW(rwops);
                _SDL_FreeRW(rwops);
                return result
            }
            Module["_Mix_LoadWAV"] = _Mix_LoadWAV;
            _Mix_LoadWAV.sig = "ii";

            function _Mix_QuickLoad_RAW(mem, len) {
                var audio;
                var webAudio;
                var numSamples = len >> 1;
                var buffer = new Float32Array(numSamples);
                for (var i = 0; i < numSamples; ++i) {
                    buffer[i] = HEAP16[mem + i * 2 >> 1] / 32768
                }
                if (SDL.webAudioAvailable()) {
                    webAudio = {};
                    webAudio.decodedBuffer = buffer
                } else {
                    audio = new Audio;
                    audio.mozAudioChannelType = "content";
                    audio.numChannels = SDL.mixerNumChannels;
                    audio.frequency = SDL.mixerFrequency
                }
                var id = SDL.audios.length;
                SDL.audios.push({
                    source: "",
                    audio: audio,
                    webAudio: webAudio,
                    buffer: buffer
                });
                return id
            }
            Module["_Mix_QuickLoad_RAW"] = _Mix_QuickLoad_RAW;
            _Mix_QuickLoad_RAW.sig = "iii";

            function _Mix_FreeChunk(id) {
                SDL.audios[id] = null
            }
            Module["_Mix_FreeChunk"] = _Mix_FreeChunk;
            _Mix_FreeChunk.sig = "vi";

            function _Mix_ReserveChannels(num) {
                SDL.channelMinimumNumber = num
            }
            Module["_Mix_ReserveChannels"] = _Mix_ReserveChannels;
            _Mix_ReserveChannels.sig = "ii";

            function _Mix_PlayChannel(channel, id, loops) {
                var info = SDL.audios[id];
                if (!info) return -1;
                if (!info.audio && !info.webAudio) return -1;
                if (channel == -1) {
                    for (var i = SDL.channelMinimumNumber; i < SDL.numChannels; i++) {
                        if (!SDL.channels[i].audio) {
                            channel = i;
                            break
                        }
                    }
                    if (channel == -1) {
                        err("All " + SDL.numChannels + " channels in use!");
                        return -1
                    }
                }
                var channelInfo = SDL.channels[channel];
                var audio;
                if (info.webAudio) {
                    audio = {};
                    audio.resource = info;
                    audio.paused = false;
                    audio.currentPosition = 0;
                    audio.play = function() {
                        SDL.playWebAudio(this)
                    };
                    audio.pause = function() {
                        SDL.pauseWebAudio(this)
                    }
                } else {
                    audio = info.audio.cloneNode(true);
                    audio.numChannels = info.audio.numChannels;
                    audio.frequency = info.audio.frequency
                }
                audio["onended"] = function SDL_audio_onended() {
                    if (channelInfo.audio == this) {
                        channelInfo.audio.paused = true;
                        channelInfo.audio = null
                    }
                    if (SDL.channelFinished) wasmTable.get(SDL.channelFinished)(channel)
                };
                channelInfo.audio = audio;
                audio.loop = loops != 0;
                audio.volume = channelInfo.volume;
                audio.play();
                return channel
            }
            Module["_Mix_PlayChannel"] = _Mix_PlayChannel;
            _Mix_PlayChannel.sig = "iiii";

            function _Mix_PlayChannelTimed(a0, a1, a2) {
                return _Mix_PlayChannel(a0, a1, a2)
            }
            Module["_Mix_PlayChannelTimed"] = _Mix_PlayChannelTimed;
            _Mix_PlayChannelTimed.sig = "iiii";

            function _Mix_FadingChannel(channel) {
                return 0
            }
            Module["_Mix_FadingChannel"] = _Mix_FadingChannel;

            function _Mix_HaltChannel(channel) {
                function halt(channel) {
                    var info = SDL.channels[channel];
                    if (info.audio) {
                        info.audio.pause();
                        info.audio = null
                    }
                    if (SDL.channelFinished) {
                        wasmTable.get(SDL.channelFinished)(channel)
                    }
                }
                if (channel != -1) {
                    halt(channel)
                } else {
                    for (var i = 0; i < SDL.channels.length; ++i) halt(i)
                }
                return 0
            }
            Module["_Mix_HaltChannel"] = _Mix_HaltChannel;
            _Mix_HaltChannel.sig = "ii";

            function _Mix_HaltMusic() {
                var audio = SDL.music.audio;
                if (audio) {
                    audio.src = audio.src;
                    audio.currentPosition = 0;
                    audio.pause()
                }
                SDL.music.audio = null;
                if (SDL.hookMusicFinished) {
                    wasmTable.get(SDL.hookMusicFinished)()
                }
                return 0
            }
            Module["_Mix_HaltMusic"] = _Mix_HaltMusic;
            _Mix_HaltMusic.sig = "i";

            function _Mix_HookMusicFinished(func) {
                SDL.hookMusicFinished = func;
                if (SDL.music.audio) {
                    SDL.music.audio["onended"] = _Mix_HaltMusic
                }
            }
            Module["_Mix_HookMusicFinished"] = _Mix_HookMusicFinished;
            _Mix_HookMusicFinished.sig = "vi";

            function _Mix_VolumeMusic(volume) {
                return SDL.setGetVolume(SDL.music, volume)
            }
            Module["_Mix_VolumeMusic"] = _Mix_VolumeMusic;
            _Mix_VolumeMusic.sig = "ii";

            function _Mix_LoadMUS_RW(a0, a1) {
                return _Mix_LoadWAV_RW(a0, a1)
            }
            Module["_Mix_LoadMUS_RW"] = _Mix_LoadMUS_RW;
            _Mix_LoadMUS_RW.sig = "iii";

            function _Mix_LoadMUS(filename) {
                var rwops = _SDL_RWFromFile(filename);
                var result = _Mix_LoadMUS_RW(rwops);
                _SDL_FreeRW(rwops);
                return result
            }
            Module["_Mix_LoadMUS"] = _Mix_LoadMUS;
            _Mix_LoadMUS.sig = "ii";

            function _Mix_FreeMusic(a0) {
                return _Mix_FreeChunk(a0)
            }
            Module["_Mix_FreeMusic"] = _Mix_FreeMusic;
            _Mix_FreeMusic.sig = "vi";

            function _Mix_PlayMusic(id, loops) {
                if (SDL.music.audio) {
                    if (!SDL.music.audio.paused) err("Music is already playing. " + SDL.music.source);
                    SDL.music.audio.pause()
                }
                var info = SDL.audios[id];
                var audio;
                if (info.webAudio) {
                    audio = {};
                    audio.resource = info;
                    audio.paused = false;
                    audio.currentPosition = 0;
                    audio.play = function() {
                        SDL.playWebAudio(this)
                    };
                    audio.pause = function() {
                        SDL.pauseWebAudio(this)
                    }
                } else if (info.audio) {
                    audio = info.audio
                }
                audio["onended"] = function() {
                    if (SDL.music.audio == this) _Mix_HaltMusic()
                };
                audio.loop = loops != 0 && loops != 1;
                audio.volume = SDL.music.volume;
                SDL.music.audio = audio;
                audio.play();
                return 0
            }
            Module["_Mix_PlayMusic"] = _Mix_PlayMusic;
            _Mix_PlayMusic.sig = "iii";

            function _Mix_PauseMusic() {
                var audio = SDL.music.audio;
                if (audio) audio.pause()
            }
            Module["_Mix_PauseMusic"] = _Mix_PauseMusic;
            _Mix_PauseMusic.sig = "v";

            function _Mix_ResumeMusic() {
                var audio = SDL.music.audio;
                if (audio) audio.play()
            }
            Module["_Mix_ResumeMusic"] = _Mix_ResumeMusic;
            _Mix_ResumeMusic.sig = "v";

            function _Mix_FadeInMusicPos(a0, a1) {
                return _Mix_PlayMusic(a0, a1)
            }
            Module["_Mix_FadeInMusicPos"] = _Mix_FadeInMusicPos;
            _Mix_FadeInMusicPos.sig = "iii";

            function _Mix_FadeOutMusic() {
                return _Mix_HaltMusic()
            }
            Module["_Mix_FadeOutMusic"] = _Mix_FadeOutMusic;
            _Mix_FadeOutMusic.sig = "i";

            function _Mix_PlayingMusic() {
                return SDL.music.audio && !SDL.music.audio.paused ? 1 : 0
            }
            Module["_Mix_PlayingMusic"] = _Mix_PlayingMusic;
            _Mix_PlayingMusic.sig = "i";

            function _Mix_Playing(channel) {
                if (channel === -1) {
                    var count = 0;
                    for (var i = 0; i < SDL.channels.length; i++) {
                        count += _Mix_Playing(i)
                    }
                    return count
                }
                var info = SDL.channels[channel];
                if (info && info.audio && !info.audio.paused) {
                    return 1
                }
                return 0
            }
            Module["_Mix_Playing"] = _Mix_Playing;
            _Mix_Playing.sig = "ii";

            function _Mix_Pause(channel) {
                if (channel === -1) {
                    for (var i = 0; i < SDL.channels.length; i++) {
                        _Mix_Pause(i)
                    }
                    return
                }
                var info = SDL.channels[channel];
                if (info && info.audio) {
                    info.audio.pause()
                } else {}
            }
            Module["_Mix_Pause"] = _Mix_Pause;
            _Mix_Pause.sig = "vi";

            function _Mix_Paused(channel) {
                if (channel === -1) {
                    var pausedCount = 0;
                    for (var i = 0; i < SDL.channels.length; i++) {
                        pausedCount += _Mix_Paused(i)
                    }
                    return pausedCount
                }
                var info = SDL.channels[channel];
                if (info && info.audio && info.audio.paused) {
                    return 1
                }
                return 0
            }
            Module["_Mix_Paused"] = _Mix_Paused;
            _Mix_Paused.sig = "ii";

            function _Mix_PausedMusic() {
                return SDL.music.audio && SDL.music.audio.paused ? 1 : 0
            }
            Module["_Mix_PausedMusic"] = _Mix_PausedMusic;
            _Mix_PausedMusic.sig = "i";

            function _Mix_Resume(channel) {
                if (channel === -1) {
                    for (var i = 0; i < SDL.channels.length; i++) {
                        _Mix_Resume(i)
                    }
                    return
                }
                var info = SDL.channels[channel];
                if (info && info.audio) info.audio.play()
            }
            Module["_Mix_Resume"] = _Mix_Resume;
            _Mix_Resume.sig = "vi";

            function _TTF_Init() {
                try {
                    var offscreenCanvas = new OffscreenCanvas(0, 0);
                    SDL.ttfContext = offscreenCanvas.getContext("2d")
                } catch (ex) {
                    var canvas = document.createElement("canvas");
                    SDL.ttfContext = canvas.getContext("2d")
                }
                return 0
            }
            Module["_TTF_Init"] = _TTF_Init;
            _TTF_Init.sig = "i";

            function _TTF_OpenFont(filename, size) {
                filename = PATH.normalize(UTF8ToString(filename));
                var id = SDL.fonts.length;
                SDL.fonts.push({
                    name: filename,
                    size: size
                });
                return id
            }
            Module["_TTF_OpenFont"] = _TTF_OpenFont;
            _TTF_OpenFont.sig = "iii";

            function _TTF_CloseFont(font) {
                SDL.fonts[font] = null
            }
            Module["_TTF_CloseFont"] = _TTF_CloseFont;
            _TTF_CloseFont.sig = "vi";

            function _TTF_RenderText_Solid(font, text, color) {
                text = UTF8ToString(text) || " ";
                var fontData = SDL.fonts[font];
                var w = SDL.estimateTextWidth(fontData, text);
                var h = fontData.size;
                color = SDL.loadColorToCSSRGB(color);
                var fontString = SDL.makeFontString(h, fontData.name);
                var surf = SDL.makeSurface(w, h, 0, false, "text:" + text);
                var surfData = SDL.surfaces[surf];
                surfData.ctx.save();
                surfData.ctx.fillStyle = color;
                surfData.ctx.font = fontString;
                surfData.ctx.textBaseline = "bottom";
                surfData.ctx.fillText(text, 0, h | 0);
                surfData.ctx.restore();
                return surf
            }
            Module["_TTF_RenderText_Solid"] = _TTF_RenderText_Solid;
            _TTF_RenderText_Solid.sig = "iiii";

            function _TTF_RenderText_Blended(a0, a1, a2) {
                return _TTF_RenderText_Solid(a0, a1, a2)
            }
            Module["_TTF_RenderText_Blended"] = _TTF_RenderText_Blended;
            _TTF_RenderText_Blended.sig = "iiii";

            function _TTF_RenderText_Shaded(a0, a1, a2) {
                return _TTF_RenderText_Solid(a0, a1, a2)
            }
            Module["_TTF_RenderText_Shaded"] = _TTF_RenderText_Shaded;
            _TTF_RenderText_Shaded.sig = "iiii";

            function _TTF_RenderUTF8_Solid(a0, a1, a2) {
                return _TTF_RenderText_Solid(a0, a1, a2)
            }
            Module["_TTF_RenderUTF8_Solid"] = _TTF_RenderUTF8_Solid;
            _TTF_RenderUTF8_Solid.sig = "iiii";

            function _TTF_SizeText(font, text, w, h) {
                var fontData = SDL.fonts[font];
                if (w) {
                    HEAP32[w >> 2] = SDL.estimateTextWidth(fontData, UTF8ToString(text))
                }
                if (h) {
                    HEAP32[h >> 2] = fontData.size
                }
                return 0
            }
            Module["_TTF_SizeText"] = _TTF_SizeText;
            _TTF_SizeText.sig = "iiiii";

            function _TTF_SizeUTF8(a0, a1, a2, a3) {
                return _TTF_SizeText(a0, a1, a2, a3)
            }
            Module["_TTF_SizeUTF8"] = _TTF_SizeUTF8;
            _TTF_SizeUTF8.sig = "iiiii";

            function _TTF_GlyphMetrics(font, ch, minx, maxx, miny, maxy, advance) {
                var fontData = SDL.fonts[font];
                var width = SDL.estimateTextWidth(fontData, String.fromCharCode(ch));
                if (advance) {
                    HEAP32[advance >> 2] = width
                }
                if (minx) {
                    HEAP32[minx >> 2] = 0
                }
                if (maxx) {
                    HEAP32[maxx >> 2] = width
                }
                if (miny) {
                    HEAP32[miny >> 2] = 0
                }
                if (maxy) {
                    HEAP32[maxy >> 2] = fontData.size
                }
            }
            Module["_TTF_GlyphMetrics"] = _TTF_GlyphMetrics;
            _TTF_GlyphMetrics.sig = "iiiiiiii";

            function _TTF_FontAscent(font) {
                var fontData = SDL.fonts[font];
                return fontData.size * .98 | 0
            }
            Module["_TTF_FontAscent"] = _TTF_FontAscent;
            _TTF_FontAscent.sig = "ii";

            function _TTF_FontDescent(font) {
                var fontData = SDL.fonts[font];
                return fontData.size * .02 | 0
            }
            Module["_TTF_FontDescent"] = _TTF_FontDescent;
            _TTF_FontDescent.sig = "ii";

            function _TTF_FontHeight(font) {
                var fontData = SDL.fonts[font];
                return fontData.size
            }
            Module["_TTF_FontHeight"] = _TTF_FontHeight;
            _TTF_FontHeight.sig = "ii";

            function _TTF_FontLineSkip(a0) {
                return _TTF_FontHeight(a0)
            }
            Module["_TTF_FontLineSkip"] = _TTF_FontLineSkip;
            _TTF_FontLineSkip.sig = "ii";

            function _TTF_Quit() {
                out("TTF_Quit called (and ignored)")
            }
            Module["_TTF_Quit"] = _TTF_Quit;
            var SDL_gfx = {
                drawRectangle: function(surf, x1, y1, x2, y2, action, cssColor) {
                    x1 = x1 << 16 >> 16;
                    y1 = y1 << 16 >> 16;
                    x2 = x2 << 16 >> 16;
                    y2 = y2 << 16 >> 16;
                    var surfData = SDL.surfaces[surf];
                    assert(!surfData.locked);
                    var x = x1 < x2 ? x1 : x2;
                    var y = y1 < y2 ? y1 : y2;
                    var w = Math.abs(x2 - x1);
                    var h = Math.abs(y2 - y1);
                    surfData.ctx.save();
                    surfData.ctx[action + "Style"] = cssColor;
                    surfData.ctx[action + "Rect"](x, y, w, h);
                    surfData.ctx.restore()
                },
                drawLine: function(surf, x1, y1, x2, y2, cssColor) {
                    x1 = x1 << 16 >> 16;
                    y1 = y1 << 16 >> 16;
                    x2 = x2 << 16 >> 16;
                    y2 = y2 << 16 >> 16;
                    var surfData = SDL.surfaces[surf];
                    assert(!surfData.locked);
                    surfData.ctx.save();
                    surfData.ctx.strokeStyle = cssColor;
                    surfData.ctx.beginPath();
                    surfData.ctx.moveTo(x1, y1);
                    surfData.ctx.lineTo(x2, y2);
                    surfData.ctx.stroke();
                    surfData.ctx.restore()
                },
                drawEllipse: function(surf, x, y, rx, ry, action, cssColor) {
                    x = x << 16 >> 16;
                    y = y << 16 >> 16;
                    rx = rx << 16 >> 16;
                    ry = ry << 16 >> 16;
                    var surfData = SDL.surfaces[surf];
                    assert(!surfData.locked);
                    surfData.ctx.save();
                    surfData.ctx.beginPath();
                    surfData.ctx.translate(x, y);
                    surfData.ctx.scale(rx, ry);
                    surfData.ctx.arc(0, 0, 1, 0, 2 * Math.PI);
                    surfData.ctx.restore();
                    surfData.ctx.save();
                    surfData.ctx[action + "Style"] = cssColor;
                    surfData.ctx[action]();
                    surfData.ctx.restore()
                },
                translateColorToCSSRGBA: function(rgba) {
                    return "rgba(" + (rgba >>> 24) + "," + (rgba >> 16 & 255) + "," + (rgba >> 8 & 255) + "," + (rgba & 255) + ")"
                }
            };
            Module["SDL_gfx"] = SDL_gfx;

            function _boxColor(surf, x1, y1, x2, y2, color) {
                return SDL_gfx.drawRectangle(surf, x1, y1, x2, y2, "fill", SDL_gfx.translateColorToCSSRGBA(color))
            }
            Module["_boxColor"] = _boxColor;

            function _boxRGBA(surf, x1, y1, x2, y2, r, g, b, a) {
                return SDL_gfx.drawRectangle(surf, x1, y1, x2, y2, "fill", SDL.translateRGBAToCSSRGBA(r, g, b, a))
            }
            Module["_boxRGBA"] = _boxRGBA;

            function _rectangleColor(surf, x1, y1, x2, y2, color) {
                return SDL_gfx.drawRectangle(surf, x1, y1, x2, y2, "stroke", SDL_gfx.translateColorToCSSRGBA(color))
            }
            Module["_rectangleColor"] = _rectangleColor;

            function _rectangleRGBA(surf, x1, y1, x2, y2, r, g, b, a) {
                return SDL_gfx.drawRectangle(surf, x1, y1, x2, y2, "stroke", SDL.translateRGBAToCSSRGBA(r, g, b, a))
            }
            Module["_rectangleRGBA"] = _rectangleRGBA;

            function _ellipseColor(surf, x, y, rx, ry, color) {
                return SDL_gfx.drawEllipse(surf, x, y, rx, ry, "stroke", SDL_gfx.translateColorToCSSRGBA(color))
            }
            Module["_ellipseColor"] = _ellipseColor;

            function _ellipseRGBA(surf, x, y, rx, ry, r, g, b, a) {
                return SDL_gfx.drawEllipse(surf, x, y, rx, ry, "stroke", SDL.translateRGBAToCSSRGBA(r, g, b, a))
            }
            Module["_ellipseRGBA"] = _ellipseRGBA;

            function _filledEllipseColor(surf, x, y, rx, ry, color) {
                return SDL_gfx.drawEllipse(surf, x, y, rx, ry, "fill", SDL_gfx.translateColorToCSSRGBA(color))
            }
            Module["_filledEllipseColor"] = _filledEllipseColor;

            function _filledEllipseRGBA(surf, x, y, rx, ry, r, g, b, a) {
                return SDL_gfx.drawEllipse(surf, x, y, rx, ry, "fill", SDL.translateRGBAToCSSRGBA(r, g, b, a))
            }
            Module["_filledEllipseRGBA"] = _filledEllipseRGBA;

            function _lineColor(surf, x1, y1, x2, y2, color) {
                return SDL_gfx.drawLine(surf, x1, y1, x2, y2, SDL_gfx.translateColorToCSSRGBA(color))
            }
            Module["_lineColor"] = _lineColor;

            function _lineRGBA(surf, x1, y1, x2, y2, r, g, b, a) {
                return SDL_gfx.drawLine(surf, x1, y1, x2, y2, SDL.translateRGBAToCSSRGBA(r, g, b, a))
            }
            Module["_lineRGBA"] = _lineRGBA;

            function _pixelRGBA(surf, x1, y1, r, g, b, a) {
                _boxRGBA(surf, x1, y1, x1, y1, r, g, b, a)
            }
            Module["_pixelRGBA"] = _pixelRGBA;

            function _SDL_GL_SetAttribute(attr, value) {
                if (!(attr in SDL.glAttributes)) {
                    abort("Unknown SDL GL attribute (" + attr + "). Please check if your SDL version is supported.")
                }
                SDL.glAttributes[attr] = value
            }
            Module["_SDL_GL_SetAttribute"] = _SDL_GL_SetAttribute;
            _SDL_GL_SetAttribute.sig = "iii";

            function _SDL_GL_GetAttribute(attr, value) {
                if (!(attr in SDL.glAttributes)) {
                    abort("Unknown SDL GL attribute (" + attr + "). Please check if your SDL version is supported.")
                }
                if (value) HEAP32[value >> 2] = SDL.glAttributes[attr];
                return 0
            }
            Module["_SDL_GL_GetAttribute"] = _SDL_GL_GetAttribute;
            _SDL_GL_GetAttribute.sig = "iii";

            function _SDL_GL_SwapBuffers() {
                if (Browser.doSwapBuffers) Browser.doSwapBuffers()
            }
            Module["_SDL_GL_SwapBuffers"] = _SDL_GL_SwapBuffers;
            _SDL_GL_SwapBuffers.sig = "v";

            function _SDL_GL_ExtensionSupported(extension) {
                return Module.ctx.getExtension(extension) | 0
            }
            Module["_SDL_GL_ExtensionSupported"] = _SDL_GL_ExtensionSupported;
            _SDL_GL_ExtensionSupported.sig = "ii";

            function _SDL_DestroyWindow(window) {}
            Module["_SDL_DestroyWindow"] = _SDL_DestroyWindow;

            function _SDL_DestroyRenderer(renderer) {}
            Module["_SDL_DestroyRenderer"] = _SDL_DestroyRenderer;

            function _SDL_GetWindowFlags() {}
            Module["_SDL_GetWindowFlags"] = _SDL_GetWindowFlags;
            _SDL_GetWindowFlags.sig = "iii";

            function _SDL_GL_SwapWindow(window) {}
            Module["_SDL_GL_SwapWindow"] = _SDL_GL_SwapWindow;

            function _SDL_GL_MakeCurrent(window, context) {}
            Module["_SDL_GL_MakeCurrent"] = _SDL_GL_MakeCurrent;

            function _SDL_GL_DeleteContext(context) {}
            Module["_SDL_GL_DeleteContext"] = _SDL_GL_DeleteContext;

            function _SDL_GL_GetSwapInterval(state) {
                if (Browser.mainLoop.timingMode == 1) return Browser.mainLoop.timingValue;
                else return 0
            }
            Module["_SDL_GL_GetSwapInterval"] = _SDL_GL_GetSwapInterval;
            _SDL_GL_GetSwapInterval.sig = "ii";

            function _SDL_GL_SetSwapInterval(state) {
                _emscripten_set_main_loop_timing(1, state)
            }
            Module["_SDL_GL_SetSwapInterval"] = _SDL_GL_SetSwapInterval;

            function _SDL_SetWindowTitle(window, title) {
                if (title) document.title = UTF8ToString(title)
            }
            Module["_SDL_SetWindowTitle"] = _SDL_SetWindowTitle;
            _SDL_SetWindowTitle.sig = "vii";

            function _SDL_GetWindowSize(window, width, height) {
                var w = Module["canvas"].width;
                var h = Module["canvas"].height;
                if (width) HEAP32[width >> 2] = w;
                if (height) HEAP32[height >> 2] = h
            }
            Module["_SDL_GetWindowSize"] = _SDL_GetWindowSize;
            _SDL_GetWindowSize.sig = "viii";

            function _SDL_LogSetOutputFunction(callback, userdata) {}
            Module["_SDL_LogSetOutputFunction"] = _SDL_LogSetOutputFunction;

            function _SDL_SetWindowFullscreen(window, fullscreen) {
                if (Browser.isFullscreen) {
                    Module["canvas"].exitFullscreen();
                    return 1
                } else {
                    return 0
                }
            }
            Module["_SDL_SetWindowFullscreen"] = _SDL_SetWindowFullscreen;
            _SDL_SetWindowFullscreen.sig = "iii";

            function _SDL_ClearError() {}
            Module["_SDL_ClearError"] = _SDL_ClearError;

            function _SDL_SetGamma(r, g, b) {
                return -1
            }
            Module["_SDL_SetGamma"] = _SDL_SetGamma;

            function _SDL_SetGammaRamp(redTable, greenTable, blueTable) {
                return -1
            }
            Module["_SDL_SetGammaRamp"] = _SDL_SetGammaRamp;

            function _SDL_NumJoysticks() {
                var count = 0;
                var gamepads = SDL.getGamepads();
                for (var i = 0; i < gamepads.length; i++) {
                    if (gamepads[i] !== undefined) count++
                }
                return count
            }
            Module["_SDL_NumJoysticks"] = _SDL_NumJoysticks;
            _SDL_NumJoysticks.sig = "i";

            function _SDL_JoystickName(deviceIndex) {
                var gamepad = SDL.getGamepad(deviceIndex);
                if (gamepad) {
                    var name = gamepad.id;
                    if (SDL.joystickNamePool.hasOwnProperty(name)) {
                        return SDL.joystickNamePool[name]
                    }
                    return SDL.joystickNamePool[name] = allocate(intArrayFromString(name), ALLOC_NORMAL)
                }
                return 0
            }
            Module["_SDL_JoystickName"] = _SDL_JoystickName;
            _SDL_JoystickName.sig = "ii";

            function _SDL_JoystickOpen(deviceIndex) {
                var gamepad = SDL.getGamepad(deviceIndex);
                if (gamepad) {
                    var joystick = deviceIndex + 1;
                    SDL.recordJoystickState(joystick, gamepad);
                    return joystick
                }
                return 0
            }
            Module["_SDL_JoystickOpen"] = _SDL_JoystickOpen;
            _SDL_JoystickOpen.sig = "ii";

            function _SDL_JoystickOpened(deviceIndex) {
                return SDL.lastJoystickState.hasOwnProperty(deviceIndex + 1) ? 1 : 0
            }
            Module["_SDL_JoystickOpened"] = _SDL_JoystickOpened;
            _SDL_JoystickOpened.sig = "ii";

            function _SDL_JoystickIndex(joystick) {
                return joystick - 1
            }
            Module["_SDL_JoystickIndex"] = _SDL_JoystickIndex;

            function _SDL_JoystickNumAxes(joystick) {
                var gamepad = SDL.getGamepad(joystick - 1);
                if (gamepad) {
                    return gamepad.axes.length
                }
                return 0
            }
            Module["_SDL_JoystickNumAxes"] = _SDL_JoystickNumAxes;
            _SDL_JoystickNumAxes.sig = "ii";

            function _SDL_JoystickNumBalls(joystick) {
                return 0
            }
            Module["_SDL_JoystickNumBalls"] = _SDL_JoystickNumBalls;

            function _SDL_JoystickNumHats(joystick) {
                return 0
            }
            Module["_SDL_JoystickNumHats"] = _SDL_JoystickNumHats;

            function _SDL_JoystickNumButtons(joystick) {
                var gamepad = SDL.getGamepad(joystick - 1);
                if (gamepad) {
                    return gamepad.buttons.length
                }
                return 0
            }
            Module["_SDL_JoystickNumButtons"] = _SDL_JoystickNumButtons;
            _SDL_JoystickNumButtons.sig = "ii";

            function _SDL_JoystickUpdate() {
                SDL.queryJoysticks()
            }
            Module["_SDL_JoystickUpdate"] = _SDL_JoystickUpdate;
            _SDL_JoystickUpdate.sig = "v";

            function _SDL_JoystickEventState(state) {
                if (state < 0) {
                    return SDL.joystickEventState
                }
                return SDL.joystickEventState = state
            }
            Module["_SDL_JoystickEventState"] = _SDL_JoystickEventState;
            _SDL_JoystickEventState.sig = "ii";

            function _SDL_JoystickGetAxis(joystick, axis) {
                var gamepad = SDL.getGamepad(joystick - 1);
                if (gamepad && gamepad.axes.length > axis) {
                    return SDL.joystickAxisValueConversion(gamepad.axes[axis])
                }
                return 0
            }
            Module["_SDL_JoystickGetAxis"] = _SDL_JoystickGetAxis;
            _SDL_JoystickGetAxis.sig = "iii";

            function _SDL_JoystickGetHat(joystick, hat) {
                return 0
            }
            Module["_SDL_JoystickGetHat"] = _SDL_JoystickGetHat;

            function _SDL_JoystickGetBall(joystick, ball, dxptr, dyptr) {
                return -1
            }
            Module["_SDL_JoystickGetBall"] = _SDL_JoystickGetBall;

            function _SDL_JoystickGetButton(joystick, button) {
                var gamepad = SDL.getGamepad(joystick - 1);
                if (gamepad && gamepad.buttons.length > button) {
                    return SDL.getJoystickButtonState(gamepad.buttons[button]) ? 1 : 0
                }
                return 0
            }
            Module["_SDL_JoystickGetButton"] = _SDL_JoystickGetButton;
            _SDL_JoystickGetButton.sig = "iii";

            function _SDL_JoystickClose(joystick) {
                delete SDL.lastJoystickState[joystick]
            }
            Module["_SDL_JoystickClose"] = _SDL_JoystickClose;
            _SDL_JoystickClose.sig = "vi";

            function _SDL_InitSubSystem(flags) {
                return 0
            }
            Module["_SDL_InitSubSystem"] = _SDL_InitSubSystem;

            function _SDL_RWFromConstMem(mem, size) {
                var id = SDL.rwops.length;
                SDL.rwops.push({
                    bytes: mem,
                    count: size
                });
                return id
            }
            Module["_SDL_RWFromConstMem"] = _SDL_RWFromConstMem;
            _SDL_RWFromConstMem.sig = "iii";

            function _SDL_RWFromMem(a0, a1) {
                return _SDL_RWFromConstMem(a0, a1)
            }
            Module["_SDL_RWFromMem"] = _SDL_RWFromMem;
            _SDL_RWFromMem.sig = "iii";

            function _SDL_GetNumAudioDrivers() {
                return 1
            }
            Module["_SDL_GetNumAudioDrivers"] = _SDL_GetNumAudioDrivers;

            function _SDL_GetCurrentAudioDriver() {
                return allocate(intArrayFromString("Emscripten Audio"), ALLOC_NORMAL)
            }
            Module["_SDL_GetCurrentAudioDriver"] = _SDL_GetCurrentAudioDriver;

            function _SDL_GetAudioDriver(index) {
                return _SDL_GetCurrentAudioDriver()
            }
            Module["_SDL_GetAudioDriver"] = _SDL_GetAudioDriver;

            function _SDL_EnableUNICODE(on) {
                var ret = SDL.unicode || 0;
                SDL.unicode = on;
                return ret
            }
            Module["_SDL_EnableUNICODE"] = _SDL_EnableUNICODE;
            _SDL_EnableUNICODE.sig = "ii";

            function _SDL_AddTimer(interval, callback, param) {
                return window.setTimeout(function() {
                    wasmTable.get(callback)(interval, param)
                }, interval)
            }
            Module["_SDL_AddTimer"] = _SDL_AddTimer;
            _SDL_AddTimer.sig = "iiii";

            function _SDL_RemoveTimer(id) {
                window.clearTimeout(id);
                return true
            }
            Module["_SDL_RemoveTimer"] = _SDL_RemoveTimer;
            _SDL_RemoveTimer.sig = "ii";

            function _SDL_CreateThread() {
                throw "SDL threads cannot be supported in the web platform because they assume shared state. See emscripten_create_worker etc. for a message-passing concurrency model that does let you run code in another thread."
            }
            Module["_SDL_CreateThread"] = _SDL_CreateThread;

            function _SDL_WaitThread() {
                throw "SDL_WaitThread"
            }
            Module["_SDL_WaitThread"] = _SDL_WaitThread;

            function _SDL_GetThreadID() {
                throw "SDL_GetThreadID"
            }
            Module["_SDL_GetThreadID"] = _SDL_GetThreadID;

            function _SDL_ThreadID() {
                return 0
            }
            Module["_SDL_ThreadID"] = _SDL_ThreadID;

            function _SDL_AllocRW() {
                throw "SDL_AllocRW: TODO"
            }
            Module["_SDL_AllocRW"] = _SDL_AllocRW;

            function _SDL_CondBroadcast() {
                throw "SDL_CondBroadcast: TODO"
            }
            Module["_SDL_CondBroadcast"] = _SDL_CondBroadcast;

            function _SDL_CondWaitTimeout() {
                throw "SDL_CondWaitTimeout: TODO"
            }
            Module["_SDL_CondWaitTimeout"] = _SDL_CondWaitTimeout;

            function _SDL_WM_IconifyWindow() {
                throw "SDL_WM_IconifyWindow TODO"
            }
            Module["_SDL_WM_IconifyWindow"] = _SDL_WM_IconifyWindow;

            function _Mix_SetPostMix() {
                warnOnce("Mix_SetPostMix: TODO")
            }
            Module["_Mix_SetPostMix"] = _Mix_SetPostMix;

            function _Mix_VolumeChunk(chunk, volume) {
                throw "Mix_VolumeChunk: TODO"
            }
            Module["_Mix_VolumeChunk"] = _Mix_VolumeChunk;

            function _Mix_SetPosition(channel, angle, distance) {
                throw "Mix_SetPosition: TODO"
            }
            Module["_Mix_SetPosition"] = _Mix_SetPosition;

            function _Mix_QuerySpec() {
                throw "Mix_QuerySpec: TODO"
            }
            Module["_Mix_QuerySpec"] = _Mix_QuerySpec;

            function _Mix_FadeInChannelTimed() {
                throw "Mix_FadeInChannelTimed"
            }
            Module["_Mix_FadeInChannelTimed"] = _Mix_FadeInChannelTimed;

            function _Mix_FadeOutChannel() {
                throw "Mix_FadeOutChannel"
            }
            Module["_Mix_FadeOutChannel"] = _Mix_FadeOutChannel;

            function _Mix_Linked_Version() {
                throw "Mix_Linked_Version: TODO"
            }
            Module["_Mix_Linked_Version"] = _Mix_Linked_Version;

            function _SDL_SaveBMP_RW() {
                throw "SDL_SaveBMP_RW: TODO"
            }
            Module["_SDL_SaveBMP_RW"] = _SDL_SaveBMP_RW;

            function _SDL_WM_SetIcon() {}
            Module["_SDL_WM_SetIcon"] = _SDL_WM_SetIcon;

            function _SDL_HasRDTSC() {
                return 0
            }
            Module["_SDL_HasRDTSC"] = _SDL_HasRDTSC;

            function _SDL_HasMMX() {
                return 0
            }
            Module["_SDL_HasMMX"] = _SDL_HasMMX;

            function _SDL_HasMMXExt() {
                return 0
            }
            Module["_SDL_HasMMXExt"] = _SDL_HasMMXExt;

            function _SDL_Has3DNow() {
                return 0
            }
            Module["_SDL_Has3DNow"] = _SDL_Has3DNow;

            function _SDL_Has3DNowExt() {
                return 0
            }
            Module["_SDL_Has3DNowExt"] = _SDL_Has3DNowExt;

            function _SDL_HasSSE() {
                return 0
            }
            Module["_SDL_HasSSE"] = _SDL_HasSSE;

            function _SDL_HasSSE2() {
                return 0
            }
            Module["_SDL_HasSSE2"] = _SDL_HasSSE2;

            function _SDL_HasAltiVec() {
                return 0
            }
            Module["_SDL_HasAltiVec"] = _SDL_HasAltiVec;

            function _glutPostRedisplay() {
                if (GLUT.displayFunc && !GLUT.requestedAnimationFrame) {
                    GLUT.requestedAnimationFrame = true;
                    Browser.requestAnimationFrame(function() {
                        GLUT.requestedAnimationFrame = false;
                        Browser.mainLoop.runIter(function() {
                            wasmTable.get(GLUT.displayFunc)()
                        })
                    })
                }
            }
            Module["_glutPostRedisplay"] = _glutPostRedisplay;
            _glutPostRedisplay.sig = "v";
            var GLUT = {
                initTime: null,
                idleFunc: null,
                displayFunc: null,
                keyboardFunc: null,
                keyboardUpFunc: null,
                specialFunc: null,
                specialUpFunc: null,
                reshapeFunc: null,
                motionFunc: null,
                passiveMotionFunc: null,
                mouseFunc: null,
                buttons: 0,
                modifiers: 0,
                initWindowWidth: 256,
                initWindowHeight: 256,
                initDisplayMode: 18,
                windowX: 0,
                windowY: 0,
                windowWidth: 0,
                windowHeight: 0,
                requestedAnimationFrame: false,
                saveModifiers: function(event) {
                    GLUT.modifiers = 0;
                    if (event["shiftKey"]) GLUT.modifiers += 1;
                    if (event["ctrlKey"]) GLUT.modifiers += 2;
                    if (event["altKey"]) GLUT.modifiers += 4
                },
                onMousemove: function(event) {
                    var lastX = Browser.mouseX;
                    var lastY = Browser.mouseY;
                    Browser.calculateMouseEvent(event);
                    var newX = Browser.mouseX;
                    var newY = Browser.mouseY;
                    if (newX == lastX && newY == lastY) return;
                    if (GLUT.buttons == 0 && event.target == Module["canvas"] && GLUT.passiveMotionFunc) {
                        event.preventDefault();
                        GLUT.saveModifiers(event);
                        wasmTable.get(GLUT.passiveMotionFunc)(lastX, lastY)
                    } else if (GLUT.buttons != 0 && GLUT.motionFunc) {
                        event.preventDefault();
                        GLUT.saveModifiers(event);
                        wasmTable.get(GLUT.motionFunc)(lastX, lastY)
                    }
                },
                getSpecialKey: function(keycode) {
                    var key = null;
                    switch (keycode) {
                        case 8:
                            key = 120;
                            break;
                        case 46:
                            key = 111;
                            break;
                        case 112:
                            key = 1;
                            break;
                        case 113:
                            key = 2;
                            break;
                        case 114:
                            key = 3;
                            break;
                        case 115:
                            key = 4;
                            break;
                        case 116:
                            key = 5;
                            break;
                        case 117:
                            key = 6;
                            break;
                        case 118:
                            key = 7;
                            break;
                        case 119:
                            key = 8;
                            break;
                        case 120:
                            key = 9;
                            break;
                        case 121:
                            key = 10;
                            break;
                        case 122:
                            key = 11;
                            break;
                        case 123:
                            key = 12;
                            break;
                        case 37:
                            key = 100;
                            break;
                        case 38:
                            key = 101;
                            break;
                        case 39:
                            key = 102;
                            break;
                        case 40:
                            key = 103;
                            break;
                        case 33:
                            key = 104;
                            break;
                        case 34:
                            key = 105;
                            break;
                        case 36:
                            key = 106;
                            break;
                        case 35:
                            key = 107;
                            break;
                        case 45:
                            key = 108;
                            break;
                        case 16:
                        case 5:
                            key = 112;
                            break;
                        case 6:
                            key = 113;
                            break;
                        case 17:
                        case 3:
                            key = 114;
                            break;
                        case 4:
                            key = 115;
                            break;
                        case 18:
                        case 2:
                            key = 116;
                            break;
                        case 1:
                            key = 117;
                            break
                    }
                    return key
                },
                getASCIIKey: function(event) {
                    if (event["ctrlKey"] || event["altKey"] || event["metaKey"]) return null;
                    var keycode = event["keyCode"];
                    if (48 <= keycode && keycode <= 57) return keycode;
                    if (65 <= keycode && keycode <= 90) return event["shiftKey"] ? keycode : keycode + 32;
                    if (96 <= keycode && keycode <= 105) return keycode - 48;
                    if (106 <= keycode && keycode <= 111) return keycode - 106 + 42;
                    switch (keycode) {
                        case 9:
                        case 13:
                        case 27:
                        case 32:
                        case 61:
                            return keycode
                    }
                    var s = event["shiftKey"];
                    switch (keycode) {
                        case 186:
                            return s ? 58 : 59;
                        case 187:
                            return s ? 43 : 61;
                        case 188:
                            return s ? 60 : 44;
                        case 189:
                            return s ? 95 : 45;
                        case 190:
                            return s ? 62 : 46;
                        case 191:
                            return s ? 63 : 47;
                        case 219:
                            return s ? 123 : 91;
                        case 220:
                            return s ? 124 : 47;
                        case 221:
                            return s ? 125 : 93;
                        case 222:
                            return s ? 34 : 39
                    }
                    return null
                },
                onKeydown: function(event) {
                    if (GLUT.specialFunc || GLUT.keyboardFunc) {
                        var key = GLUT.getSpecialKey(event["keyCode"]);
                        if (key !== null) {
                            if (GLUT.specialFunc) {
                                event.preventDefault();
                                GLUT.saveModifiers(event);
                                wasmTable.get(GLUT.specialFunc)(key, Browser.mouseX, Browser.mouseY)
                            }
                        } else {
                            key = GLUT.getASCIIKey(event);
                            if (key !== null && GLUT.keyboardFunc) {
                                event.preventDefault();
                                GLUT.saveModifiers(event);
                                wasmTable.get(GLUT.keyboardFunc)(key, Browser.mouseX, Browser.mouseY)
                            }
                        }
                    }
                },
                onKeyup: function(event) {
                    if (GLUT.specialUpFunc || GLUT.keyboardUpFunc) {
                        var key = GLUT.getSpecialKey(event["keyCode"]);
                        if (key !== null) {
                            if (GLUT.specialUpFunc) {
                                event.preventDefault();
                                GLUT.saveModifiers(event);
                                wasmTable.get(GLUT.specialUpFunc)(key, Browser.mouseX, Browser.mouseY)
                            }
                        } else {
                            key = GLUT.getASCIIKey(event);
                            if (key !== null && GLUT.keyboardUpFunc) {
                                event.preventDefault();
                                GLUT.saveModifiers(event);
                                wasmTable.get(GLUT.keyboardUpFunc)(key, Browser.mouseX, Browser.mouseY)
                            }
                        }
                    }
                },
                touchHandler: function(event) {
                    if (event.target != Module["canvas"]) {
                        return
                    }
                    var touches = event.changedTouches,
                        main = touches[0],
                        type = "";
                    switch (event.type) {
                        case "touchstart":
                            type = "mousedown";
                            break;
                        case "touchmove":
                            type = "mousemove";
                            break;
                        case "touchend":
                            type = "mouseup";
                            break;
                        default:
                            return
                    }
                    var simulatedEvent = document.createEvent("MouseEvent");
                    simulatedEvent.initMouseEvent(type, true, true, window, 1, main.screenX, main.screenY, main.clientX, main.clientY, false, false, false, false, 0, null);
                    main.target.dispatchEvent(simulatedEvent);
                    event.preventDefault()
                },
                onMouseButtonDown: function(event) {
                    Browser.calculateMouseEvent(event);
                    GLUT.buttons |= 1 << event["button"];
                    if (event.target == Module["canvas"] && GLUT.mouseFunc) {
                        try {
                            event.target.setCapture()
                        } catch (e) {}
                        event.preventDefault();
                        GLUT.saveModifiers(event);
                        wasmTable.get(GLUT.mouseFunc)(event["button"], 0, Browser.mouseX, Browser.mouseY)
                    }
                },
                onMouseButtonUp: function(event) {
                    Browser.calculateMouseEvent(event);
                    GLUT.buttons &= ~(1 << event["button"]);
                    if (GLUT.mouseFunc) {
                        event.preventDefault();
                        GLUT.saveModifiers(event);
                        wasmTable.get(GLUT.mouseFunc)(event["button"], 1, Browser.mouseX, Browser.mouseY)
                    }
                },
                onMouseWheel: function(event) {
                    Browser.calculateMouseEvent(event);
                    var e = window.event || event;
                    var delta = -Browser.getMouseWheelDelta(event);
                    delta = delta == 0 ? 0 : delta > 0 ? Math.max(delta, 1) : Math.min(delta, -1);
                    var button = 3;
                    if (delta < 0) {
                        button = 4
                    }
                    if (GLUT.mouseFunc) {
                        event.preventDefault();
                        GLUT.saveModifiers(event);
                        wasmTable.get(GLUT.mouseFunc)(button, 0, Browser.mouseX, Browser.mouseY)
                    }
                },
                onFullscreenEventChange: function(event) {
                    var width;
                    var height;
                    if (document["fullscreen"] || document["fullScreen"] || document["mozFullScreen"] || document["webkitIsFullScreen"]) {
                        width = screen["width"];
                        height = screen["height"]
                    } else {
                        width = GLUT.windowWidth;
                        height = GLUT.windowHeight;
                        document.removeEventListener("fullscreenchange", GLUT.onFullscreenEventChange, true);
                        document.removeEventListener("mozfullscreenchange", GLUT.onFullscreenEventChange, true);
                        document.removeEventListener("webkitfullscreenchange", GLUT.onFullscreenEventChange, true)
                    }
                    Browser.setCanvasSize(width, height, true);
                    if (GLUT.reshapeFunc) {
                        wasmTable.get(GLUT.reshapeFunc)(width, height)
                    }
                    _glutPostRedisplay()
                }
            };
            Module["GLUT"] = GLUT;

            function _glutGetModifiers() {
                return GLUT.modifiers
            }
            Module["_glutGetModifiers"] = _glutGetModifiers;
            _glutGetModifiers.sig = "i";

            function _glutInit(argcp, argv) {
                GLUT.initTime = Date.now();
                var isTouchDevice = "ontouchstart" in document.documentElement;
                if (isTouchDevice) {
                    window.addEventListener("touchmove", GLUT.touchHandler, true);
                    window.addEventListener("touchstart", GLUT.touchHandler, true);
                    window.addEventListener("touchend", GLUT.touchHandler, true)
                }
                window.addEventListener("keydown", GLUT.onKeydown, true);
                window.addEventListener("keyup", GLUT.onKeyup, true);
                window.addEventListener("mousemove", GLUT.onMousemove, true);
                window.addEventListener("mousedown", GLUT.onMouseButtonDown, true);
                window.addEventListener("mouseup", GLUT.onMouseButtonUp, true);
                window.addEventListener("mousewheel", GLUT.onMouseWheel, true);
                window.addEventListener("DOMMouseScroll", GLUT.onMouseWheel, true);
                Browser.resizeListeners.push(function(width, height) {
                    if (GLUT.reshapeFunc) {
                        wasmTable.get(GLUT.reshapeFunc)(width, height)
                    }
                });
                __ATEXIT__.push(function() {
                    if (isTouchDevice) {
                        window.removeEventListener("touchmove", GLUT.touchHandler, true);
                        window.removeEventListener("touchstart", GLUT.touchHandler, true);
                        window.removeEventListener("touchend", GLUT.touchHandler, true)
                    }
                    window.removeEventListener("keydown", GLUT.onKeydown, true);
                    window.removeEventListener("keyup", GLUT.onKeyup, true);
                    window.removeEventListener("mousemove", GLUT.onMousemove, true);
                    window.removeEventListener("mousedown", GLUT.onMouseButtonDown, true);
                    window.removeEventListener("mouseup", GLUT.onMouseButtonUp, true);
                    window.removeEventListener("mousewheel", GLUT.onMouseWheel, true);
                    window.removeEventListener("DOMMouseScroll", GLUT.onMouseWheel, true);
                    Module["canvas"].width = Module["canvas"].height = 1
                })
            }
            Module["_glutInit"] = _glutInit;
            _glutInit.sig = "vii";

            function _glutInitWindowSize(width, height) {
                Browser.setCanvasSize(GLUT.initWindowWidth = width, GLUT.initWindowHeight = height)
            }
            Module["_glutInitWindowSize"] = _glutInitWindowSize;
            _glutInitWindowSize.sig = "vii";

            function _glutInitWindowPosition(x, y) {}
            Module["_glutInitWindowPosition"] = _glutInitWindowPosition;
            _glutInitWindowPosition.sig = "vii";

            function _glutGet(type) {
                switch (type) {
                    case 100:
                        return 0;
                    case 101:
                        return 0;
                    case 102:
                        return Module["canvas"].width;
                    case 103:
                        return Module["canvas"].height;
                    case 200:
                        return Module["canvas"].width;
                    case 201:
                        return Module["canvas"].height;
                    case 500:
                        return 0;
                    case 501:
                        return 0;
                    case 502:
                        return GLUT.initWindowWidth;
                    case 503:
                        return GLUT.initWindowHeight;
                    case 700:
                        var now = Date.now();
                        return now - GLUT.initTime;
                    case 105:
                        return Module.ctx.getContextAttributes().stencil ? 8 : 0;
                    case 106:
                        return Module.ctx.getContextAttributes().depth ? 8 : 0;
                    case 110:
                        return Module.ctx.getContextAttributes().alpha ? 8 : 0;
                    case 120:
                        return Module.ctx.getContextAttributes().antialias ? 1 : 0;
                    default:
                        throw "glutGet(" + type + ") not implemented yet"
                }
            }
            Module["_glutGet"] = _glutGet;

            function _glutIdleFunc(func) {
                function callback() {
                    if (GLUT.idleFunc) {
                        wasmTable.get(GLUT.idleFunc)();
                        Browser.safeSetTimeout(callback, 4)
                    }
                }
                if (!GLUT.idleFunc) {
                    Browser.safeSetTimeout(callback, 0)
                }
                GLUT.idleFunc = func
            }
            Module["_glutIdleFunc"] = _glutIdleFunc;
            _glutIdleFunc.sig = "vi";

            function _glutTimerFunc(msec, func, value) {
                Browser.safeSetTimeout(function() {
                    wasmTable.get(func)(value)
                }, msec)
            }
            Module["_glutTimerFunc"] = _glutTimerFunc;
            _glutTimerFunc.sig = "viii";

            function _glutDisplayFunc(func) {
                GLUT.displayFunc = func
            }
            Module["_glutDisplayFunc"] = _glutDisplayFunc;
            _glutDisplayFunc.sig = "vi";

            function _glutKeyboardFunc(func) {
                GLUT.keyboardFunc = func
            }
            Module["_glutKeyboardFunc"] = _glutKeyboardFunc;
            _glutKeyboardFunc.sig = "vi";

            function _glutKeyboardUpFunc(func) {
                GLUT.keyboardUpFunc = func
            }
            Module["_glutKeyboardUpFunc"] = _glutKeyboardUpFunc;
            _glutKeyboardUpFunc.sig = "vi";

            function _glutSpecialFunc(func) {
                GLUT.specialFunc = func
            }
            Module["_glutSpecialFunc"] = _glutSpecialFunc;
            _glutSpecialFunc.sig = "vi";

            function _glutSpecialUpFunc(func) {
                GLUT.specialUpFunc = func
            }
            Module["_glutSpecialUpFunc"] = _glutSpecialUpFunc;
            _glutSpecialUpFunc.sig = "vi";

            function _glutReshapeFunc(func) {
                GLUT.reshapeFunc = func
            }
            Module["_glutReshapeFunc"] = _glutReshapeFunc;
            _glutReshapeFunc.sig = "vi";

            function _glutMotionFunc(func) {
                GLUT.motionFunc = func
            }
            Module["_glutMotionFunc"] = _glutMotionFunc;
            _glutMotionFunc.sig = "vi";

            function _glutPassiveMotionFunc(func) {
                GLUT.passiveMotionFunc = func
            }
            Module["_glutPassiveMotionFunc"] = _glutPassiveMotionFunc;
            _glutPassiveMotionFunc.sig = "vi";

            function _glutMouseFunc(func) {
                GLUT.mouseFunc = func
            }
            Module["_glutMouseFunc"] = _glutMouseFunc;
            _glutMouseFunc.sig = "vi";

            function _glutSetCursor(cursor) {
                var cursorStyle = "auto";
                switch (cursor) {
                    case 0:
                        break;
                    case 1:
                        break;
                    case 2:
                        cursorStyle = "pointer";
                        break;
                    case 3:
                        break;
                    case 4:
                        cursorStyle = "help";
                        break;
                    case 5:
                        break;
                    case 6:
                        break;
                    case 7:
                        cursorStyle = "wait";
                        break;
                    case 8:
                        cursorStyle = "text";
                        break;
                    case 9:
                    case 102:
                        cursorStyle = "crosshair";
                        break;
                    case 10:
                        cursorStyle = "ns-resize";
                        break;
                    case 11:
                        cursorStyle = "ew-resize";
                        break;
                    case 12:
                        cursorStyle = "n-resize";
                        break;
                    case 13:
                        cursorStyle = "s-resize";
                        break;
                    case 14:
                        cursorStyle = "w-resize";
                        break;
                    case 15:
                        cursorStyle = "e-resize";
                        break;
                    case 16:
                        cursorStyle = "nw-resize";
                        break;
                    case 17:
                        cursorStyle = "ne-resize";
                        break;
                    case 18:
                        cursorStyle = "se-resize";
                        break;
                    case 19:
                        cursorStyle = "sw-resize";
                        break;
                    case 100:
                        break;
                    case 101:
                        cursorStyle = "none";
                        break;
                    default:
                        throw "glutSetCursor: Unknown cursor type: " + cursor
                }
                Module["canvas"].style.cursor = cursorStyle
            }
            Module["_glutSetCursor"] = _glutSetCursor;
            _glutSetCursor.sig = "vi";

            function _glutCreateWindow(name) {
                var contextAttributes = {
                    antialias: (GLUT.initDisplayMode & 128) != 0,
                    depth: (GLUT.initDisplayMode & 16) != 0,
                    stencil: (GLUT.initDisplayMode & 32) != 0,
                    alpha: (GLUT.initDisplayMode & 8) != 0
                };
                Module.ctx = Browser.createContext(Module["canvas"], true, true, contextAttributes);
                return Module.ctx ? 1 : 0
            }
            Module["_glutCreateWindow"] = _glutCreateWindow;
            _glutCreateWindow.sig = "ii";

            function _glutDestroyWindow(name) {
                Module.ctx = Browser.destroyContext(Module["canvas"], true, true);
                return 1
            }
            Module["_glutDestroyWindow"] = _glutDestroyWindow;
            _glutDestroyWindow.sig = "ii";

            function _glutReshapeWindow(width, height) {
                Browser.exitFullscreen();
                Browser.setCanvasSize(width, height, true);
                if (GLUT.reshapeFunc) {
                    wasmTable.get(GLUT.reshapeFunc)(width, height)
                }
                _glutPostRedisplay()
            }
            Module["_glutReshapeWindow"] = _glutReshapeWindow;
            _glutReshapeWindow.sig = "vi";

            function _glutPositionWindow(x, y) {
                Browser.exitFullscreen();
                _glutPostRedisplay()
            }
            Module["_glutPositionWindow"] = _glutPositionWindow;
            _glutPositionWindow.sig = "vii";

            function _glutFullScreen() {
                GLUT.windowX = 0;
                GLUT.windowY = 0;
                GLUT.windowWidth = Module["canvas"].width;
                GLUT.windowHeight = Module["canvas"].height;
                document.addEventListener("fullscreenchange", GLUT.onFullscreenEventChange, true);
                document.addEventListener("mozfullscreenchange", GLUT.onFullscreenEventChange, true);
                document.addEventListener("webkitfullscreenchange", GLUT.onFullscreenEventChange, true);
                Browser.requestFullscreen(false, false)
            }
            Module["_glutFullScreen"] = _glutFullScreen;
            _glutFullScreen.sig = "v";

            function _glutInitDisplayMode(mode) {
                GLUT.initDisplayMode = mode
            }
            Module["_glutInitDisplayMode"] = _glutInitDisplayMode;
            _glutInitDisplayMode.sig = "vi";

            function _glutSwapBuffers() {}
            Module["_glutSwapBuffers"] = _glutSwapBuffers;
            _glutSwapBuffers.sig = "v";

            function _glutMainLoop() {
                _glutReshapeWindow(Module["canvas"].width, Module["canvas"].height);
                _glutPostRedisplay();
                throw "unwind"
            }
            Module["_glutMainLoop"] = _glutMainLoop;
            _glutMainLoop.sig = "v";

            function _XOpenDisplay() {
                return 1
            }
            Module["_XOpenDisplay"] = _XOpenDisplay;

            function _XCreateWindow(display, parent, x, y, width, height, border_width, depth, class_, visual, valuemask, attributes) {
                Browser.setCanvasSize(width, height);
                return 2
            }
            Module["_XCreateWindow"] = _XCreateWindow;

            function _XChangeWindowAttributes() {}
            Module["_XChangeWindowAttributes"] = _XChangeWindowAttributes;

            function _XSetWMHints() {}
            Module["_XSetWMHints"] = _XSetWMHints;

            function _XMapWindow() {}
            Module["_XMapWindow"] = _XMapWindow;

            function _XStoreName() {}
            Module["_XStoreName"] = _XStoreName;

            function _XInternAtom(display, name_, hmm) {
                return 0
            }
            Module["_XInternAtom"] = _XInternAtom;

            function _XSendEvent() {}
            Module["_XSendEvent"] = _XSendEvent;

            function _XPending(display) {
                return 0
            }
            Module["_XPending"] = _XPending;
            var EGL = {
                errorCode: 12288,
                defaultDisplayInitialized: false,
                currentContext: 0,
                currentReadSurface: 0,
                currentDrawSurface: 0,
                contextAttributes: {
                    alpha: false,
                    depth: false,
                    stencil: false,
                    antialias: false
                },
                stringCache: {},
                setErrorCode: function(code) {
                    EGL.errorCode = code
                },
                chooseConfig: function(display, attribList, config, config_size, numConfigs) {
                    if (display != 62e3) {
                        EGL.setErrorCode(12296);
                        return 0
                    }
                    if (attribList) {
                        for (;;) {
                            var param = HEAP32[attribList >> 2];
                            if (param == 12321) {
                                var alphaSize = HEAP32[attribList + 4 >> 2];
                                EGL.contextAttributes.alpha = alphaSize > 0
                            } else if (param == 12325) {
                                var depthSize = HEAP32[attribList + 4 >> 2];
                                EGL.contextAttributes.depth = depthSize > 0
                            } else if (param == 12326) {
                                var stencilSize = HEAP32[attribList + 4 >> 2];
                                EGL.contextAttributes.stencil = stencilSize > 0
                            } else if (param == 12337) {
                                var samples = HEAP32[attribList + 4 >> 2];
                                EGL.contextAttributes.antialias = samples > 0
                            } else if (param == 12338) {
                                var samples = HEAP32[attribList + 4 >> 2];
                                EGL.contextAttributes.antialias = samples == 1
                            } else if (param == 12544) {
                                var requestedPriority = HEAP32[attribList + 4 >> 2];
                                EGL.contextAttributes.lowLatency = requestedPriority != 12547
                            } else if (param == 12344) {
                                break
                            }
                            attribList += 8
                        }
                    }
                    if ((!config || !config_size) && !numConfigs) {
                        EGL.setErrorCode(12300);
                        return 0
                    }
                    if (numConfigs) {
                        HEAP32[numConfigs >> 2] = 1
                    }
                    if (config && config_size > 0) {
                        HEAP32[config >> 2] = 62002
                    }
                    EGL.setErrorCode(12288);
                    return 1
                }
            };
            Module["EGL"] = EGL;

            function _eglGetDisplay(nativeDisplayType) {
                EGL.setErrorCode(12288);
                return 62e3
            }
            Module["_eglGetDisplay"] = _eglGetDisplay;
            _eglGetDisplay.sig = "ii";

            function _eglInitialize(display, majorVersion, minorVersion) {
                if (display == 62e3) {
                    if (majorVersion) {
                        HEAP32[majorVersion >> 2] = 1
                    }
                    if (minorVersion) {
                        HEAP32[minorVersion >> 2] = 4
                    }
                    EGL.defaultDisplayInitialized = true;
                    EGL.setErrorCode(12288);
                    return 1
                } else {
                    EGL.setErrorCode(12296);
                    return 0
                }
            }
            Module["_eglInitialize"] = _eglInitialize;
            _eglInitialize.sig = "iiii";

            function _eglTerminate(display) {
                if (display != 62e3) {
                    EGL.setErrorCode(12296);
                    return 0
                }
                EGL.currentContext = 0;
                EGL.currentReadSurface = 0;
                EGL.currentDrawSurface = 0;
                EGL.defaultDisplayInitialized = false;
                EGL.setErrorCode(12288);
                return 1
            }
            Module["_eglTerminate"] = _eglTerminate;
            _eglTerminate.sig = "ii";

            function _eglGetConfigs(display, configs, config_size, numConfigs) {
                return EGL.chooseConfig(display, 0, configs, config_size, numConfigs)
            }
            Module["_eglGetConfigs"] = _eglGetConfigs;
            _eglGetConfigs.sig = "iiiii";

            function _eglChooseConfig(display, attrib_list, configs, config_size, numConfigs) {
                return EGL.chooseConfig(display, attrib_list, configs, config_size, numConfigs)
            }
            Module["_eglChooseConfig"] = _eglChooseConfig;
            _eglChooseConfig.sig = "iiiiii";

            function _eglGetConfigAttrib(display, config, attribute, value) {
                if (display != 62e3) {
                    EGL.setErrorCode(12296);
                    return 0
                }
                if (config != 62002) {
                    EGL.setErrorCode(12293);
                    return 0
                }
                if (!value) {
                    EGL.setErrorCode(12300);
                    return 0
                }
                EGL.setErrorCode(12288);
                switch (attribute) {
                    case 12320:
                        HEAP32[value >> 2] = EGL.contextAttributes.alpha ? 32 : 24;
                        return 1;
                    case 12321:
                        HEAP32[value >> 2] = EGL.contextAttributes.alpha ? 8 : 0;
                        return 1;
                    case 12322:
                        HEAP32[value >> 2] = 8;
                        return 1;
                    case 12323:
                        HEAP32[value >> 2] = 8;
                        return 1;
                    case 12324:
                        HEAP32[value >> 2] = 8;
                        return 1;
                    case 12325:
                        HEAP32[value >> 2] = EGL.contextAttributes.depth ? 24 : 0;
                        return 1;
                    case 12326:
                        HEAP32[value >> 2] = EGL.contextAttributes.stencil ? 8 : 0;
                        return 1;
                    case 12327:
                        HEAP32[value >> 2] = 12344;
                        return 1;
                    case 12328:
                        HEAP32[value >> 2] = 62002;
                        return 1;
                    case 12329:
                        HEAP32[value >> 2] = 0;
                        return 1;
                    case 12330:
                        HEAP32[value >> 2] = 4096;
                        return 1;
                    case 12331:
                        HEAP32[value >> 2] = 16777216;
                        return 1;
                    case 12332:
                        HEAP32[value >> 2] = 4096;
                        return 1;
                    case 12333:
                        HEAP32[value >> 2] = 0;
                        return 1;
                    case 12334:
                        HEAP32[value >> 2] = 0;
                        return 1;
                    case 12335:
                        HEAP32[value >> 2] = 12344;
                        return 1;
                    case 12337:
                        HEAP32[value >> 2] = EGL.contextAttributes.antialias ? 4 : 0;
                        return 1;
                    case 12338:
                        HEAP32[value >> 2] = EGL.contextAttributes.antialias ? 1 : 0;
                        return 1;
                    case 12339:
                        HEAP32[value >> 2] = 4;
                        return 1;
                    case 12340:
                        HEAP32[value >> 2] = 12344;
                        return 1;
                    case 12341:
                    case 12342:
                    case 12343:
                        HEAP32[value >> 2] = -1;
                        return 1;
                    case 12345:
                    case 12346:
                        HEAP32[value >> 2] = 0;
                        return 1;
                    case 12347:
                        HEAP32[value >> 2] = 0;
                        return 1;
                    case 12348:
                        HEAP32[value >> 2] = 1;
                        return 1;
                    case 12349:
                    case 12350:
                        HEAP32[value >> 2] = 0;
                        return 1;
                    case 12351:
                        HEAP32[value >> 2] = 12430;
                        return 1;
                    case 12352:
                        HEAP32[value >> 2] = 4;
                        return 1;
                    case 12354:
                        HEAP32[value >> 2] = 0;
                        return 1;
                    default:
                        EGL.setErrorCode(12292);
                        return 0
                }
            }
            Module["_eglGetConfigAttrib"] = _eglGetConfigAttrib;
            _eglGetConfigAttrib.sig = "iiiii";

            function _eglCreateWindowSurface(display, config, win, attrib_list) {
                if (display != 62e3) {
                    EGL.setErrorCode(12296);
                    return 0
                }
                if (config != 62002) {
                    EGL.setErrorCode(12293);
                    return 0
                }
                EGL.setErrorCode(12288);
                return 62006
            }
            Module["_eglCreateWindowSurface"] = _eglCreateWindowSurface;
            _eglCreateWindowSurface.sig = "iiiii";

            function _eglDestroySurface(display, surface) {
                if (display != 62e3) {
                    EGL.setErrorCode(12296);
                    return 0
                }
                if (surface != 62006) {
                    EGL.setErrorCode(12301);
                    return 1
                }
                if (EGL.currentReadSurface == surface) {
                    EGL.currentReadSurface = 0
                }
                if (EGL.currentDrawSurface == surface) {
                    EGL.currentDrawSurface = 0
                }
                EGL.setErrorCode(12288);
                return 1
            }
            Module["_eglDestroySurface"] = _eglDestroySurface;
            _eglDestroySurface.sig = "iii";

            function _eglCreateContext(display, config, hmm, contextAttribs) {
                if (display != 62e3) {
                    EGL.setErrorCode(12296);
                    return 0
                }
                var glesContextVersion = 1;
                for (;;) {
                    var param = HEAP32[contextAttribs >> 2];
                    if (param == 12440) {
                        glesContextVersion = HEAP32[contextAttribs + 4 >> 2]
                    } else if (param == 12344) {
                        break
                    } else {
                        EGL.setErrorCode(12292);
                        return 0
                    }
                    contextAttribs += 8
                }
                if (glesContextVersion != 2) {
                    EGL.setErrorCode(12293);
                    return 0
                }
                EGL.contextAttributes.majorVersion = glesContextVersion - 1;
                EGL.contextAttributes.minorVersion = 0;
                EGL.context = GL.createContext(Module["canvas"], EGL.contextAttributes);
                if (EGL.context != 0) {
                    EGL.setErrorCode(12288);
                    GL.makeContextCurrent(EGL.context);
                    Module.useWebGL = true;
                    Browser.moduleContextCreatedCallbacks.forEach(function(callback) {
                        callback()
                    });
                    GL.makeContextCurrent(null);
                    return 62004
                } else {
                    EGL.setErrorCode(12297);
                    return 0
                }
            }
            Module["_eglCreateContext"] = _eglCreateContext;
            _eglCreateContext.sig = "iiiii";

            function _eglDestroyContext(display, context) {
                if (display != 62e3) {
                    EGL.setErrorCode(12296);
                    return 0
                }
                if (context != 62004) {
                    EGL.setErrorCode(12294);
                    return 0
                }
                GL.deleteContext(EGL.context);
                EGL.setErrorCode(12288);
                if (EGL.currentContext == context) {
                    EGL.currentContext = 0
                }
                return 1
            }
            Module["_eglDestroyContext"] = _eglDestroyContext;
            _eglDestroyContext.sig = "iii";

            function _eglQuerySurface(display, surface, attribute, value) {
                if (display != 62e3) {
                    EGL.setErrorCode(12296);
                    return 0
                }
                if (surface != 62006) {
                    EGL.setErrorCode(12301);
                    return 0
                }
                if (!value) {
                    EGL.setErrorCode(12300);
                    return 0
                }
                EGL.setErrorCode(12288);
                switch (attribute) {
                    case 12328:
                        HEAP32[value >> 2] = 62002;
                        return 1;
                    case 12376:
                        return 1;
                    case 12375:
                        HEAP32[value >> 2] = Module["canvas"].width;
                        return 1;
                    case 12374:
                        HEAP32[value >> 2] = Module["canvas"].height;
                        return 1;
                    case 12432:
                        HEAP32[value >> 2] = -1;
                        return 1;
                    case 12433:
                        HEAP32[value >> 2] = -1;
                        return 1;
                    case 12434:
                        HEAP32[value >> 2] = -1;
                        return 1;
                    case 12422:
                        HEAP32[value >> 2] = 12420;
                        return 1;
                    case 12441:
                        HEAP32[value >> 2] = 12442;
                        return 1;
                    case 12435:
                        HEAP32[value >> 2] = 12437;
                        return 1;
                    case 12416:
                    case 12417:
                    case 12418:
                    case 12419:
                        return 1;
                    default:
                        EGL.setErrorCode(12292);
                        return 0
                }
            }
            Module["_eglQuerySurface"] = _eglQuerySurface;
            _eglQuerySurface.sig = "iiiii";

            function _eglQueryContext(display, context, attribute, value) {
                if (display != 62e3) {
                    EGL.setErrorCode(12296);
                    return 0
                }
                if (context != 62004) {
                    EGL.setErrorCode(12294);
                    return 0
                }
                if (!value) {
                    EGL.setErrorCode(12300);
                    return 0
                }
                EGL.setErrorCode(12288);
                switch (attribute) {
                    case 12328:
                        HEAP32[value >> 2] = 62002;
                        return 1;
                    case 12439:
                        HEAP32[value >> 2] = 12448;
                        return 1;
                    case 12440:
                        HEAP32[value >> 2] = EGL.contextAttributes.majorVersion + 1;
                        return 1;
                    case 12422:
                        HEAP32[value >> 2] = 12420;
                        return 1;
                    default:
                        EGL.setErrorCode(12292);
                        return 0
                }
            }
            Module["_eglQueryContext"] = _eglQueryContext;
            _eglQueryContext.sig = "iiiii";

            function _eglGetError() {
                return EGL.errorCode
            }
            Module["_eglGetError"] = _eglGetError;
            _eglGetError.sig = "i";

            function _eglQueryString(display, name) {
                if (display != 62e3) {
                    EGL.setErrorCode(12296);
                    return 0
                }
                EGL.setErrorCode(12288);
                if (EGL.stringCache[name]) return EGL.stringCache[name];
                var ret;
                switch (name) {
                    case 12371:
                        ret = allocateUTF8("Emscripten");
                        break;
                    case 12372:
                        ret = allocateUTF8("1.4 Emscripten EGL");
                        break;
                    case 12373:
                        ret = allocateUTF8("");
                        break;
                    case 12429:
                        ret = allocateUTF8("OpenGL_ES");
                        break;
                    default:
                        EGL.setErrorCode(12300);
                        return 0
                }
                EGL.stringCache[name] = ret;
                return ret
            }
            Module["_eglQueryString"] = _eglQueryString;
            _eglQueryString.sig = "iii";

            function _eglBindAPI(api) {
                if (api == 12448) {
                    EGL.setErrorCode(12288);
                    return 1
                } else {
                    EGL.setErrorCode(12300);
                    return 0
                }
            }
            Module["_eglBindAPI"] = _eglBindAPI;
            _eglBindAPI.sig = "ii";

            function _eglQueryAPI() {
                EGL.setErrorCode(12288);
                return 12448
            }
            Module["_eglQueryAPI"] = _eglQueryAPI;
            _eglQueryAPI.sig = "i";

            function _eglWaitClient() {
                EGL.setErrorCode(12288);
                return 1
            }
            Module["_eglWaitClient"] = _eglWaitClient;
            _eglWaitClient.sig = "i";

            function _eglWaitNative(nativeEngineId) {
                EGL.setErrorCode(12288);
                return 1
            }
            Module["_eglWaitNative"] = _eglWaitNative;
            _eglWaitNative.sig = "ii";

            function _eglWaitGL() {
                return _eglWaitClient()
            }
            Module["_eglWaitGL"] = _eglWaitGL;
            _eglWaitGL.sig = "i";

            function _eglSwapInterval(display, interval) {
                if (display != 62e3) {
                    EGL.setErrorCode(12296);
                    return 0
                }
                if (interval == 0) _emscripten_set_main_loop_timing(0, 0);
                else _emscripten_set_main_loop_timing(1, interval);
                EGL.setErrorCode(12288);
                return 1
            }
            Module["_eglSwapInterval"] = _eglSwapInterval;
            _eglSwapInterval.sig = "iii";

            function _eglMakeCurrent(display, draw, read, context) {
                if (display != 62e3) {
                    EGL.setErrorCode(12296);
                    return 0
                }
                if (context != 0 && context != 62004) {
                    EGL.setErrorCode(12294);
                    return 0
                }
                if (read != 0 && read != 62006 || draw != 0 && draw != 62006) {
                    EGL.setErrorCode(12301);
                    return 0
                }
                GL.makeContextCurrent(context ? EGL.context : null);
                EGL.currentContext = context;
                EGL.currentDrawSurface = draw;
                EGL.currentReadSurface = read;
                EGL.setErrorCode(12288);
                return 1
            }
            Module["_eglMakeCurrent"] = _eglMakeCurrent;
            _eglMakeCurrent.sig = "iiiii";

            function _eglGetCurrentContext() {
                return EGL.currentContext
            }
            Module["_eglGetCurrentContext"] = _eglGetCurrentContext;
            _eglGetCurrentContext.sig = "i";

            function _eglGetCurrentSurface(readdraw) {
                if (readdraw == 12378) {
                    return EGL.currentReadSurface
                } else if (readdraw == 12377) {
                    return EGL.currentDrawSurface
                } else {
                    EGL.setErrorCode(12300);
                    return 0
                }
            }
            Module["_eglGetCurrentSurface"] = _eglGetCurrentSurface;
            _eglGetCurrentSurface.sig = "ii";

            function _eglGetCurrentDisplay() {
                return EGL.currentContext ? 62e3 : 0
            }
            Module["_eglGetCurrentDisplay"] = _eglGetCurrentDisplay;
            _eglGetCurrentDisplay.sig = "i";

            function _eglSwapBuffers() {
                if (!EGL.defaultDisplayInitialized) {
                    EGL.setErrorCode(12289)
                } else if (!Module.ctx) {
                    EGL.setErrorCode(12290)
                } else if (Module.ctx.isContextLost()) {
                    EGL.setErrorCode(12302)
                } else {
                    EGL.setErrorCode(12288);
                    return 1
                }
                return 0
            }
            Module["_eglSwapBuffers"] = _eglSwapBuffers;
            _eglSwapBuffers.sig = "iii";

            function _eglReleaseThread() {
                EGL.currentContext = 0;
                EGL.currentReadSurface = 0;
                EGL.currentDrawSurface = 0;
                EGL.setErrorCode(12288);
                return 1
            }
            Module["_eglReleaseThread"] = _eglReleaseThread;
            _eglReleaseThread.sig = "i";
            var GLFW = {
                WindowFromId: function(id) {
                    if (id <= 0 || !GLFW.windows) return null;
                    return GLFW.windows[id - 1]
                },
                joystickFunc: null,
                errorFunc: null,
                monitorFunc: null,
                active: null,
                windows: null,
                monitors: null,
                monitorString: null,
                versionString: null,
                initialTime: null,
                extensions: null,
                hints: null,
                defaultHints: {
                    131073: 0,
                    131074: 0,
                    131075: 1,
                    131076: 1,
                    131077: 1,
                    135169: 8,
                    135170: 8,
                    135171: 8,
                    135172: 8,
                    135173: 24,
                    135174: 8,
                    135175: 0,
                    135176: 0,
                    135177: 0,
                    135178: 0,
                    135179: 0,
                    135180: 0,
                    135181: 0,
                    135182: 0,
                    135183: 0,
                    139265: 196609,
                    139266: 1,
                    139267: 0,
                    139268: 0,
                    139269: 0,
                    139270: 0,
                    139271: 0,
                    139272: 0
                },
                DOMToGLFWKeyCode: function(keycode) {
                    switch (keycode) {
                        case 32:
                            return 32;
                        case 222:
                            return 39;
                        case 188:
                            return 44;
                        case 173:
                            return 45;
                        case 189:
                            return 45;
                        case 190:
                            return 46;
                        case 191:
                            return 47;
                        case 48:
                            return 48;
                        case 49:
                            return 49;
                        case 50:
                            return 50;
                        case 51:
                            return 51;
                        case 52:
                            return 52;
                        case 53:
                            return 53;
                        case 54:
                            return 54;
                        case 55:
                            return 55;
                        case 56:
                            return 56;
                        case 57:
                            return 57;
                        case 59:
                            return 59;
                        case 61:
                            return 61;
                        case 187:
                            return 61;
                        case 65:
                            return 65;
                        case 66:
                            return 66;
                        case 67:
                            return 67;
                        case 68:
                            return 68;
                        case 69:
                            return 69;
                        case 70:
                            return 70;
                        case 71:
                            return 71;
                        case 72:
                            return 72;
                        case 73:
                            return 73;
                        case 74:
                            return 74;
                        case 75:
                            return 75;
                        case 76:
                            return 76;
                        case 77:
                            return 77;
                        case 78:
                            return 78;
                        case 79:
                            return 79;
                        case 80:
                            return 80;
                        case 81:
                            return 81;
                        case 82:
                            return 82;
                        case 83:
                            return 83;
                        case 84:
                            return 84;
                        case 85:
                            return 85;
                        case 86:
                            return 86;
                        case 87:
                            return 87;
                        case 88:
                            return 88;
                        case 89:
                            return 89;
                        case 90:
                            return 90;
                        case 219:
                            return 91;
                        case 220:
                            return 92;
                        case 221:
                            return 93;
                        case 192:
                            return 94;
                        case 27:
                            return 256 + 1;
                        case 112:
                            return 256 + 2;
                        case 113:
                            return 256 + 3;
                        case 114:
                            return 256 + 4;
                        case 115:
                            return 256 + 5;
                        case 116:
                            return 256 + 6;
                        case 117:
                            return 256 + 7;
                        case 118:
                            return 256 + 8;
                        case 119:
                            return 256 + 9;
                        case 120:
                            return 256 + 10;
                        case 121:
                            return 256 + 11;
                        case 122:
                            return 256 + 12;
                        case 123:
                            return 256 + 13;
                        case 124:
                            return 256 + 14;
                        case 125:
                            return 256 + 15;
                        case 126:
                            return 256 + 16;
                        case 127:
                            return 256 + 17;
                        case 128:
                            return 256 + 18;
                        case 129:
                            return 256 + 19;
                        case 130:
                            return 256 + 20;
                        case 131:
                            return 256 + 21;
                        case 132:
                            return 256 + 22;
                        case 133:
                            return 256 + 23;
                        case 134:
                            return 256 + 24;
                        case 135:
                            return 256 + 25;
                        case 136:
                            return 256 + 26;
                        case 39:
                            return 256 + 30;
                        case 37:
                            return 256 + 29;
                        case 40:
                            return 256 + 28;
                        case 38:
                            return 256 + 27;
                        case 16:
                            return 256 + 31;
                        case 17:
                            return 256 + 33;
                        case 18:
                            return 256 + 35;
                        case 9:
                            return 256 + 37;
                        case 13:
                            return 256 + 38;
                        case 8:
                            return 256 + 39;
                        case 45:
                            return 256 + 40;
                        case 46:
                            return 256 + 41;
                        case 33:
                            return 256 + 42;
                        case 34:
                            return 256 + 43;
                        case 36:
                            return 256 + 44;
                        case 35:
                            return 256 + 45;
                        case 96:
                            return 256 + 46;
                        case 97:
                            return 256 + 47;
                        case 98:
                            return 256 + 48;
                        case 99:
                            return 256 + 49;
                        case 100:
                            return 256 + 50;
                        case 101:
                            return 256 + 51;
                        case 102:
                            return 256 + 52;
                        case 103:
                            return 256 + 53;
                        case 104:
                            return 256 + 54;
                        case 105:
                            return 256 + 55;
                        case 111:
                            return 256 + 56;
                        case 106:
                            return 256 + 57;
                        case 109:
                            return 256 + 58;
                        case 107:
                            return 256 + 59;
                        case 110:
                            return 256 + 60;
                        case 144:
                            return 256 + 63;
                        case 20:
                            return 256 + 64;
                        case 145:
                            return 256 + 65;
                        case 19:
                            return 256 + 66;
                        case 91:
                            return 256 + 67;
                        case 93:
                            return 256 + 69;
                        default:
                            return -1
                    }
                },
                getModBits: function(win) {
                    var mod = 0;
                    if (win.keys[340]) mod |= 1;
                    if (win.keys[341]) mod |= 2;
                    if (win.keys[342]) mod |= 4;
                    if (win.keys[343]) mod |= 8;
                    return mod
                },
                onKeyPress: function(event) {
                    if (!GLFW.active || !GLFW.active.charFunc) return;
                    if (event.ctrlKey || event.metaKey) return;
                    var charCode = event.charCode;
                    if (charCode == 0 || charCode >= 0 && charCode <= 31) return;
                    wasmTable.get(GLFW.active.charFunc)(charCode, 1)
                },
                onKeyChanged: function(keyCode, status) {
                    if (!GLFW.active) return;
                    var key = GLFW.DOMToGLFWKeyCode(keyCode);
                    if (key == -1) return;
                    GLFW.active.keys[key] = status;
                    GLFW.active.domKeys[keyCode] = status;
                    if (!GLFW.active.keyFunc) return;
                    wasmTable.get(GLFW.active.keyFunc)(key, status)
                },
                onGamepadConnected: function(event) {
                    GLFW.refreshJoysticks()
                },
                onGamepadDisconnected: function(event) {
                    GLFW.refreshJoysticks()
                },
                onKeydown: function(event) {
                    GLFW.onKeyChanged(event.keyCode, 1);
                    if (event.keyCode === 8 || event.keyCode === 9) {
                        event.preventDefault()
                    }
                },
                onKeyup: function(event) {
                    GLFW.onKeyChanged(event.keyCode, 0)
                },
                onBlur: function(event) {
                    if (!GLFW.active) return;
                    for (var i = 0; i < GLFW.active.domKeys.length; ++i) {
                        if (GLFW.active.domKeys[i]) {
                            GLFW.onKeyChanged(i, 0)
                        }
                    }
                },
                onMousemove: function(event) {
                    if (!GLFW.active) return;
                    Browser.calculateMouseEvent(event);
                    if (event.target != Module["canvas"] || !GLFW.active.cursorPosFunc) return;
                    wasmTable.get(GLFW.active.cursorPosFunc)(Browser.mouseX, Browser.mouseY)
                },
                DOMToGLFWMouseButton: function(event) {
                    var eventButton = event["button"];
                    if (eventButton > 0) {
                        if (eventButton == 1) {
                            eventButton = 2
                        } else {
                            eventButton = 1
                        }
                    }
                    return eventButton
                },
                onMouseenter: function(event) {
                    if (!GLFW.active) return;
                    if (event.target != Module["canvas"] || !GLFW.active.cursorEnterFunc) return
                },
                onMouseleave: function(event) {
                    if (!GLFW.active) return;
                    if (event.target != Module["canvas"] || !GLFW.active.cursorEnterFunc) return
                },
                onMouseButtonChanged: function(event, status) {
                    if (!GLFW.active) return;
                    Browser.calculateMouseEvent(event);
                    if (event.target != Module["canvas"]) return;
                    var eventButton = GLFW.DOMToGLFWMouseButton(event);
                    if (status == 1) {
                        GLFW.active.buttons |= 1 << eventButton;
                        try {
                            event.target.setCapture()
                        } catch (e) {}
                    } else {
                        GLFW.active.buttons &= ~(1 << eventButton)
                    }
                    if (!GLFW.active.mouseButtonFunc) return;
                    wasmTable.get(GLFW.active.mouseButtonFunc)(eventButton, status)
                },
                onMouseButtonDown: function(event) {
                    if (!GLFW.active) return;
                    GLFW.onMouseButtonChanged(event, 1)
                },
                onMouseButtonUp: function(event) {
                    if (!GLFW.active) return;
                    GLFW.onMouseButtonChanged(event, 0)
                },
                onMouseWheel: function(event) {
                    var delta = -Browser.getMouseWheelDelta(event);
                    delta = delta == 0 ? 0 : delta > 0 ? Math.max(delta, 1) : Math.min(delta, -1);
                    GLFW.wheelPos += delta;
                    if (!GLFW.active || !GLFW.active.scrollFunc || event.target != Module["canvas"]) return;
                    wasmTable.get(GLFW.active.scrollFunc)(GLFW.wheelPos);
                    event.preventDefault()
                },
                onCanvasResize: function(width, height) {
                    if (!GLFW.active) return;
                    var resizeNeeded = true;
                    if (document["fullscreen"] || document["fullScreen"] || document["mozFullScreen"] || document["webkitIsFullScreen"]) {
                        GLFW.active.storedX = GLFW.active.x;
                        GLFW.active.storedY = GLFW.active.y;
                        GLFW.active.storedWidth = GLFW.active.width;
                        GLFW.active.storedHeight = GLFW.active.height;
                        GLFW.active.x = GLFW.active.y = 0;
                        GLFW.active.width = screen.width;
                        GLFW.active.height = screen.height;
                        GLFW.active.fullscreen = true
                    } else if (GLFW.active.fullscreen == true) {
                        GLFW.active.x = GLFW.active.storedX;
                        GLFW.active.y = GLFW.active.storedY;
                        GLFW.active.width = GLFW.active.storedWidth;
                        GLFW.active.height = GLFW.active.storedHeight;
                        GLFW.active.fullscreen = false
                    } else if (GLFW.active.width != width || GLFW.active.height != height) {
                        GLFW.active.width = width;
                        GLFW.active.height = height
                    } else {
                        resizeNeeded = false
                    }
                    if (resizeNeeded) {
                        Browser.setCanvasSize(GLFW.active.width, GLFW.active.height, true);
                        GLFW.onWindowSizeChanged();
                        GLFW.onFramebufferSizeChanged()
                    }
                },
                onWindowSizeChanged: function() {
                    if (!GLFW.active) return;
                    if (!GLFW.active.windowSizeFunc) return;
                    wasmTable.get(GLFW.active.windowSizeFunc)(GLFW.active.width, GLFW.active.height)
                },
                onFramebufferSizeChanged: function() {
                    if (!GLFW.active) return;
                    if (!GLFW.active.framebufferSizeFunc) return
                },
                getTime: function() {
                    return _emscripten_get_now() / 1e3
                },
                setWindowTitle: function(winid, title) {
                    var win = GLFW.WindowFromId(winid);
                    if (!win) return;
                    win.title = UTF8ToString(title);
                    if (GLFW.active.id == win.id) {
                        document.title = win.title
                    }
                },
                setJoystickCallback: function(cbfun) {
                    GLFW.joystickFunc = cbfun;
                    GLFW.refreshJoysticks()
                },
                joys: {},
                lastGamepadState: null,
                lastGamepadStateFrame: null,
                refreshJoysticks: function() {
                    if (Browser.mainLoop.currentFrameNumber !== GLFW.lastGamepadStateFrame || !Browser.mainLoop.currentFrameNumber) {
                        GLFW.lastGamepadState = navigator.getGamepads ? navigator.getGamepads() : navigator.webkitGetGamepads ? navigator.webkitGetGamepads : null;
                        GLFW.lastGamepadStateFrame = Browser.mainLoop.currentFrameNumber;
                        for (var joy = 0; joy < GLFW.lastGamepadState.length; ++joy) {
                            var gamepad = GLFW.lastGamepadState[joy];
                            if (gamepad) {
                                if (!GLFW.joys[joy]) {
                                    console.log("glfw joystick connected:", joy);
                                    GLFW.joys[joy] = {
                                        id: allocate(intArrayFromString(gamepad.id), ALLOC_NORMAL),
                                        buttonsCount: gamepad.buttons.length,
                                        axesCount: gamepad.axes.length,
                                        buttons: allocate(new Array(gamepad.buttons.length), ALLOC_NORMAL),
                                        axes: allocate(new Array(gamepad.axes.length * 4), ALLOC_NORMAL)
                                    };
                                    if (GLFW.joystickFunc) {
                                        wasmTable.get(GLFW.joystickFunc)(joy, 262145)
                                    }
                                }
                                var data = GLFW.joys[joy];
                                for (var i = 0; i < gamepad.buttons.length; ++i) {
                                    setValue(data.buttons + i, gamepad.buttons[i].pressed, "i8")
                                }
                                for (var i = 0; i < gamepad.axes.length; ++i) {
                                    setValue(data.axes + i * 4, gamepad.axes[i], "float")
                                }
                            } else {
                                if (GLFW.joys[joy]) {
                                    console.log("glfw joystick disconnected", joy);
                                    if (GLFW.joystickFunc) {
                                        wasmTable.get(GLFW.joystickFunc)(joy, 262146)
                                    }
                                    _free(GLFW.joys[joy].id);
                                    _free(GLFW.joys[joy].buttons);
                                    _free(GLFW.joys[joy].axes);
                                    delete GLFW.joys[joy]
                                }
                            }
                        }
                    }
                },
                setKeyCallback: function(winid, cbfun) {
                    var win = GLFW.WindowFromId(winid);
                    if (!win) return null;
                    var prevcbfun = win.keyFunc;
                    win.keyFunc = cbfun;
                    return prevcbfun
                },
                setCharCallback: function(winid, cbfun) {
                    var win = GLFW.WindowFromId(winid);
                    if (!win) return null;
                    var prevcbfun = win.charFunc;
                    win.charFunc = cbfun;
                    return prevcbfun
                },
                setMouseButtonCallback: function(winid, cbfun) {
                    var win = GLFW.WindowFromId(winid);
                    if (!win) return null;
                    var prevcbfun = win.mouseButtonFunc;
                    win.mouseButtonFunc = cbfun;
                    return prevcbfun
                },
                setCursorPosCallback: function(winid, cbfun) {
                    var win = GLFW.WindowFromId(winid);
                    if (!win) return null;
                    var prevcbfun = win.cursorPosFunc;
                    win.cursorPosFunc = cbfun;
                    return prevcbfun
                },
                setScrollCallback: function(winid, cbfun) {
                    var win = GLFW.WindowFromId(winid);
                    if (!win) return null;
                    var prevcbfun = win.scrollFunc;
                    win.scrollFunc = cbfun;
                    return prevcbfun
                },
                setDropCallback: function(winid, cbfun) {
                    var win = GLFW.WindowFromId(winid);
                    if (!win) return null;
                    var prevcbfun = win.dropFunc;
                    win.dropFunc = cbfun;
                    return prevcbfun
                },
                onDrop: function(event) {
                    if (!GLFW.active || !GLFW.active.dropFunc) return;
                    if (!event.dataTransfer || !event.dataTransfer.files || event.dataTransfer.files.length == 0) return;
                    event.preventDefault();
                    var filenames = allocate(new Array(event.dataTransfer.files.length * 4), ALLOC_NORMAL);
                    var filenamesArray = [];
                    var count = event.dataTransfer.files.length;
                    var written = 0;
                    var drop_dir = ".glfw_dropped_files";
                    FS.createPath("/", drop_dir);

                    function save(file) {
                        var path = "/" + drop_dir + "/" + file.name.replace(/\//g, "_");
                        var reader = new FileReader;
                        reader.onloadend = function(e) {
                            if (reader.readyState != 2) {
                                ++written;
                                console.log("failed to read dropped file: " + file.name + ": " + reader.error);
                                return
                            }
                            var data = e.target.result;
                            FS.writeFile(path, new Uint8Array(data));
                            if (++written === count) {
                                wasmTable.get(GLFW.active.dropFunc)(GLFW.active.id, count, filenames);
                                for (var i = 0; i < filenamesArray.length; ++i) {
                                    _free(filenamesArray[i])
                                }
                                _free(filenames)
                            }
                        };
                        reader.readAsArrayBuffer(file);
                        var filename = allocate(intArrayFromString(path), ALLOC_NORMAL);
                        filenamesArray.push(filename);
                        setValue(filenames + i * 4, filename, "i8*")
                    }
                    for (var i = 0; i < count; ++i) {
                        save(event.dataTransfer.files[i])
                    }
                    return false
                },
                onDragover: function(event) {
                    if (!GLFW.active || !GLFW.active.dropFunc) return;
                    event.preventDefault();
                    return false
                },
                setWindowSizeCallback: function(winid, cbfun) {
                    var win = GLFW.WindowFromId(winid);
                    if (!win) return null;
                    var prevcbfun = win.windowSizeFunc;
                    win.windowSizeFunc = cbfun;
                    if (!win.windowSizeFunc) return null;
                    wasmTable.get(win.windowSizeFunc)(win.width, win.height);
                    return prevcbfun
                },
                setWindowCloseCallback: function(winid, cbfun) {
                    var win = GLFW.WindowFromId(winid);
                    if (!win) return null;
                    var prevcbfun = win.windowCloseFunc;
                    win.windowCloseFunc = cbfun;
                    return prevcbfun
                },
                setWindowRefreshCallback: function(winid, cbfun) {
                    var win = GLFW.WindowFromId(winid);
                    if (!win) return null;
                    var prevcbfun = win.windowRefreshFunc;
                    win.windowRefreshFunc = cbfun;
                    return prevcbfun
                },
                onClickRequestPointerLock: function(e) {
                    if (!Browser.pointerLock && Module["canvas"].requestPointerLock) {
                        Module["canvas"].requestPointerLock();
                        e.preventDefault()
                    }
                },
                setInputMode: function(winid, mode, value) {
                    var win = GLFW.WindowFromId(winid);
                    if (!win) return;
                    switch (mode) {
                        case 208897: {
                            switch (value) {
                                case 212993: {
                                    win.inputModes[mode] = value;
                                    Module["canvas"].removeEventListener("click", GLFW.onClickRequestPointerLock, true);
                                    Module["canvas"].exitPointerLock();
                                    break
                                }
                                case 212994: {
                                    console.log("glfwSetInputMode called with GLFW_CURSOR_HIDDEN value not implemented.");
                                    break
                                }
                                case 212995: {
                                    win.inputModes[mode] = value;
                                    Module["canvas"].addEventListener("click", GLFW.onClickRequestPointerLock, true);
                                    Module["canvas"].requestPointerLock();
                                    break
                                }
                                default: {
                                    console.log("glfwSetInputMode called with unknown value parameter value: " + value + ".");
                                    break
                                }
                            }
                            break
                        }
                        case 208898: {
                            console.log("glfwSetInputMode called with GLFW_STICKY_KEYS mode not implemented.");
                            break
                        }
                        case 208899: {
                            console.log("glfwSetInputMode called with GLFW_STICKY_MOUSE_BUTTONS mode not implemented.");
                            break
                        }
                        default: {
                            console.log("glfwSetInputMode called with unknown mode parameter value: " + mode + ".");
                            break
                        }
                    }
                },
                getKey: function(winid, key) {
                    var win = GLFW.WindowFromId(winid);
                    if (!win) return 0;
                    return win.keys[key]
                },
                getMouseButton: function(winid, button) {
                    var win = GLFW.WindowFromId(winid);
                    if (!win) return 0;
                    return (win.buttons & 1 << button) > 0
                },
                getCursorPos: function(winid, x, y) {
                    setValue(x, Browser.mouseX, "double");
                    setValue(y, Browser.mouseY, "double")
                },
                getMousePos: function(winid, x, y) {
                    setValue(x, Browser.mouseX, "i32");
                    setValue(y, Browser.mouseY, "i32")
                },
                setCursorPos: function(winid, x, y) {},
                getWindowPos: function(winid, x, y) {
                    var wx = 0;
                    var wy = 0;
                    var win = GLFW.WindowFromId(winid);
                    if (win) {
                        wx = win.x;
                        wy = win.y
                    }
                    if (x) {
                        setValue(x, wx, "i32")
                    }
                    if (y) {
                        setValue(y, wy, "i32")
                    }
                },
                setWindowPos: function(winid, x, y) {
                    var win = GLFW.WindowFromId(winid);
                    if (!win) return;
                    win.x = x;
                    win.y = y
                },
                getWindowSize: function(winid, width, height) {
                    var ww = 0;
                    var wh = 0;
                    var win = GLFW.WindowFromId(winid);
                    if (win) {
                        ww = win.width;
                        wh = win.height
                    }
                    if (width) {
                        setValue(width, ww, "i32")
                    }
                    if (height) {
                        setValue(height, wh, "i32")
                    }
                },
                setWindowSize: function(winid, width, height) {
                    var win = GLFW.WindowFromId(winid);
                    if (!win) return;
                    if (GLFW.active.id == win.id) {
                        if (width == screen.width && height == screen.height) {
                            Browser.requestFullscreen()
                        } else {
                            Browser.exitFullscreen();
                            Browser.setCanvasSize(width, height);
                            win.width = width;
                            win.height = height
                        }
                    }
                    if (!win.windowSizeFunc) return;
                    wasmTable.get(win.windowSizeFunc)(width, height)
                },
                createWindow: function(width, height, title, monitor, share) {
                    var i, id;
                    for (i = 0; i < GLFW.windows.length && GLFW.windows[i] !== null; i++) {}
                    if (i > 0) throw "glfwCreateWindow only supports one window at time currently";
                    id = i + 1;
                    if (width <= 0 || height <= 0) return 0;
                    if (monitor) {
                        Browser.requestFullscreen()
                    } else {
                        Browser.setCanvasSize(width, height)
                    }
                    for (i = 0; i < GLFW.windows.length && GLFW.windows[i] == null; i++) {}
                    var useWebGL = GLFW.hints[139265] > 0;
                    if (i == GLFW.windows.length) {
                        if (useWebGL) {
                            var contextAttributes = {
                                antialias: GLFW.hints[135181] > 1,
                                depth: GLFW.hints[135173] > 0,
                                stencil: GLFW.hints[135174] > 0,
                                alpha: GLFW.hints[135172] > 0
                            };
                            Module.ctx = Browser.createContext(Module["canvas"], true, true, contextAttributes)
                        } else {
                            Browser.init()
                        }
                    }
                    if (!Module.ctx && useWebGL) return 0;
                    var win = new GLFW_Window(id, width, height, title, monitor, share);
                    if (id - 1 == GLFW.windows.length) {
                        GLFW.windows.push(win)
                    } else {
                        GLFW.windows[id - 1] = win
                    }
                    GLFW.active = win;
                    return win.id
                },
                destroyWindow: function(winid) {
                    var win = GLFW.WindowFromId(winid);
                    if (!win) return;
                    GLFW.windows[win.id - 1] = null;
                    if (GLFW.active.id == win.id) GLFW.active = null;
                    for (var i = 0; i < GLFW.windows.length; i++)
                        if (GLFW.windows[i] !== null) return;
                    Module.ctx = Browser.destroyContext(Module["canvas"], true, true)
                },
                swapBuffers: function(winid) {},
                GLFW2ParamToGLFW3Param: function(param) {
                    var table = {
                        196609: 0,
                        196610: 0,
                        196611: 0,
                        196612: 0,
                        196613: 0,
                        196614: 0,
                        131073: 0,
                        131074: 0,
                        131075: 0,
                        131076: 0,
                        131077: 135169,
                        131078: 135170,
                        131079: 135171,
                        131080: 135172,
                        131081: 135173,
                        131082: 135174,
                        131083: 135183,
                        131084: 135175,
                        131085: 135176,
                        131086: 135177,
                        131087: 135178,
                        131088: 135179,
                        131089: 135180,
                        131090: 0,
                        131091: 135181,
                        131092: 139266,
                        131093: 139267,
                        131094: 139270,
                        131095: 139271,
                        131096: 139272
                    };
                    return table[param]
                }
            };
            Module["GLFW"] = GLFW;

            function GLFW_Window(id, width, height, title, monitor, share) {
                this.id = id;
                this.x = 0;
                this.y = 0;
                this.fullscreen = false;
                this.storedX = 0;
                this.storedY = 0;
                this.width = width;
                this.height = height;
                this.storedWidth = width;
                this.storedHeight = height;
                this.title = title;
                this.monitor = monitor;
                this.share = share;
                this.attributes = GLFW.hints;
                this.inputModes = {
                    208897: 212993,
                    208898: 0,
                    208899: 0
                };
                this.buttons = 0;
                this.keys = new Array;
                this.domKeys = new Array;
                this.shouldClose = 0;
                this.title = null;
                this.windowPosFunc = null;
                this.windowSizeFunc = null;
                this.windowCloseFunc = null;
                this.windowRefreshFunc = null;
                this.windowFocusFunc = null;
                this.windowIconifyFunc = null;
                this.framebufferSizeFunc = null;
                this.mouseButtonFunc = null;
                this.cursorPosFunc = null;
                this.cursorEnterFunc = null;
                this.scrollFunc = null;
                this.dropFunc = null;
                this.keyFunc = null;
                this.charFunc = null;
                this.userptr = null
            }
            Module["GLFW_Window"] = GLFW_Window;

            function _glfwInit() {
                if (GLFW.windows) return 1;
                GLFW.initialTime = GLFW.getTime();
                GLFW.hints = GLFW.defaultHints;
                GLFW.windows = new Array;
                GLFW.active = null;
                window.addEventListener("gamepadconnected", GLFW.onGamepadConnected, true);
                window.addEventListener("gamepaddisconnected", GLFW.onGamepadDisconnected, true);
                window.addEventListener("keydown", GLFW.onKeydown, true);
                window.addEventListener("keypress", GLFW.onKeyPress, true);
                window.addEventListener("keyup", GLFW.onKeyup, true);
                window.addEventListener("blur", GLFW.onBlur, true);
                Module["canvas"].addEventListener("touchmove", GLFW.onMousemove, true);
                Module["canvas"].addEventListener("touchstart", GLFW.onMouseButtonDown, true);
                Module["canvas"].addEventListener("touchcancel", GLFW.onMouseButtonUp, true);
                Module["canvas"].addEventListener("touchend", GLFW.onMouseButtonUp, true);
                Module["canvas"].addEventListener("mousemove", GLFW.onMousemove, true);
                Module["canvas"].addEventListener("mousedown", GLFW.onMouseButtonDown, true);
                Module["canvas"].addEventListener("mouseup", GLFW.onMouseButtonUp, true);
                Module["canvas"].addEventListener("wheel", GLFW.onMouseWheel, true);
                Module["canvas"].addEventListener("mousewheel", GLFW.onMouseWheel, true);
                Module["canvas"].addEventListener("mouseenter", GLFW.onMouseenter, true);
                Module["canvas"].addEventListener("mouseleave", GLFW.onMouseleave, true);
                Module["canvas"].addEventListener("drop", GLFW.onDrop, true);
                Module["canvas"].addEventListener("dragover", GLFW.onDragover, true);
                Browser.resizeListeners.push(function(width, height) {
                    GLFW.onCanvasResize(width, height)
                });
                return 1
            }
            Module["_glfwInit"] = _glfwInit;
            _glfwInit.sig = "i";

            function _glfwTerminate() {
                window.removeEventListener("gamepadconnected", GLFW.onGamepadConnected, true);
                window.removeEventListener("gamepaddisconnected", GLFW.onGamepadDisconnected, true);
                window.removeEventListener("keydown", GLFW.onKeydown, true);
                window.removeEventListener("keypress", GLFW.onKeyPress, true);
                window.removeEventListener("keyup", GLFW.onKeyup, true);
                window.removeEventListener("blur", GLFW.onBlur, true);
                Module["canvas"].removeEventListener("touchmove", GLFW.onMousemove, true);
                Module["canvas"].removeEventListener("touchstart", GLFW.onMouseButtonDown, true);
                Module["canvas"].removeEventListener("touchcancel", GLFW.onMouseButtonUp, true);
                Module["canvas"].removeEventListener("touchend", GLFW.onMouseButtonUp, true);
                Module["canvas"].removeEventListener("mousemove", GLFW.onMousemove, true);
                Module["canvas"].removeEventListener("mousedown", GLFW.onMouseButtonDown, true);
                Module["canvas"].removeEventListener("mouseup", GLFW.onMouseButtonUp, true);
                Module["canvas"].removeEventListener("wheel", GLFW.onMouseWheel, true);
                Module["canvas"].removeEventListener("mousewheel", GLFW.onMouseWheel, true);
                Module["canvas"].removeEventListener("mouseenter", GLFW.onMouseenter, true);
                Module["canvas"].removeEventListener("mouseleave", GLFW.onMouseleave, true);
                Module["canvas"].removeEventListener("drop", GLFW.onDrop, true);
                Module["canvas"].removeEventListener("dragover", GLFW.onDragover, true);
                Module["canvas"].width = Module["canvas"].height = 1;
                GLFW.windows = null;
                GLFW.active = null
            }
            Module["_glfwTerminate"] = _glfwTerminate;
            _glfwTerminate.sig = "v";

            function _glfwGetVersion(major, minor, rev) {
                setValue(major, 2, "i32");
                setValue(minor, 7, "i32");
                setValue(rev, 7, "i32")
            }
            Module["_glfwGetVersion"] = _glfwGetVersion;
            _glfwGetVersion.sig = "viii";

            function _glfwPollEvents() {}
            Module["_glfwPollEvents"] = _glfwPollEvents;
            _glfwPollEvents.sig = "v";

            function _glfwWaitEvents() {}
            Module["_glfwWaitEvents"] = _glfwWaitEvents;
            _glfwWaitEvents.sig = "v";

            function _glfwGetTime() {
                return GLFW.getTime() - GLFW.initialTime
            }
            Module["_glfwGetTime"] = _glfwGetTime;
            _glfwGetTime.sig = "d";

            function _glfwSetTime(time) {
                GLFW.initialTime = GLFW.getTime() - time
            }
            Module["_glfwSetTime"] = _glfwSetTime;
            _glfwSetTime.sig = "vd";

            function _glfwExtensionSupported(extension) {
                if (!GLFW.extensions) {
                    GLFW.extensions = UTF8ToString(_glGetString(7939)).split(" ")
                }
                if (GLFW.extensions.includes(extension)) return 1;
                return GLFW.extensions.includes("GL_" + extension)
            }
            Module["_glfwExtensionSupported"] = _glfwExtensionSupported;
            _glfwExtensionSupported.sig = "ii";

            function _glfwSwapInterval(interval) {
                interval = Math.abs(interval);
                if (interval == 0) _emscripten_set_main_loop_timing(0, 0);
                else _emscripten_set_main_loop_timing(1, interval)
            }
            Module["_glfwSwapInterval"] = _glfwSwapInterval;
            _glfwSwapInterval.sig = "vi";

            function _glfwOpenWindow(width, height, redbits, greenbits, bluebits, alphabits, depthbits, stencilbits, mode) {
                GLFW.hints[135169] = redbits;
                GLFW.hints[135170] = greenbits;
                GLFW.hints[135171] = bluebits;
                GLFW.hints[135172] = alphabits;
                GLFW.hints[135173] = depthbits;
                GLFW.hints[135174] = stencilbits;
                GLFW.createWindow(width, height, "GLFW2 Window", 0, 0);
                return 1
            }
            Module["_glfwOpenWindow"] = _glfwOpenWindow;

            function _glfwCloseWindow() {
                GLFW.destroyWindow(GLFW.active.id)
            }
            Module["_glfwCloseWindow"] = _glfwCloseWindow;

            function _glfwOpenWindowHint(target, hint) {
                target = GLFW.GLFW2ParamToGLFW3Param(target);
                GLFW.hints[target] = hint
            }
            Module["_glfwOpenWindowHint"] = _glfwOpenWindowHint;

            function _glfwGetWindowSize(width, height) {
                GLFW.getWindowSize(GLFW.active.id, width, height)
            }
            Module["_glfwGetWindowSize"] = _glfwGetWindowSize;

            function _glfwSetWindowSize(width, height) {
                GLFW.setWindowSize(GLFW.active.id, width, height)
            }
            Module["_glfwSetWindowSize"] = _glfwSetWindowSize;

            function _glfwGetWindowPos(x, y) {
                GLFW.getWindowPos(GLFW.active.id, x, y)
            }
            Module["_glfwGetWindowPos"] = _glfwGetWindowPos;

            function _glfwSetWindowPos(x, y) {
                GLFW.setWindowPos(GLFW.active.id, x, y)
            }
            Module["_glfwSetWindowPos"] = _glfwSetWindowPos;

            function _glfwSetWindowTitle(title) {
                GLFW.setWindowTitle(GLFW.active.id, title)
            }
            Module["_glfwSetWindowTitle"] = _glfwSetWindowTitle;

            function _glfwIconifyWindow() {}
            Module["_glfwIconifyWindow"] = _glfwIconifyWindow;

            function _glfwRestoreWindow() {}
            Module["_glfwRestoreWindow"] = _glfwRestoreWindow;

            function _glfwSwapBuffers() {
                GLFW.swapBuffers(GLFW.active.id)
            }
            Module["_glfwSwapBuffers"] = _glfwSwapBuffers;

            function _glfwGetWindowParam(param) {
                param = GLFW.GLFW2ParamToGLFW3Param(param);
                return GLFW.hints[param]
            }
            Module["_glfwGetWindowParam"] = _glfwGetWindowParam;

            function _glfwSetWindowSizeCallback(cbfun) {
                GLFW.setWindowSizeCallback(GLFW.active.id, cbfun)
            }
            Module["_glfwSetWindowSizeCallback"] = _glfwSetWindowSizeCallback;

            function _glfwSetWindowCloseCallback(cbfun) {
                GLFW.setWindowCloseCallback(GLFW.active.id, cbfun)
            }
            Module["_glfwSetWindowCloseCallback"] = _glfwSetWindowCloseCallback;

            function _glfwSetWindowRefreshCallback(cbfun) {
                GLFW.setWindowRefreshCallback(GLFW.active.id, cbfun)
            }
            Module["_glfwSetWindowRefreshCallback"] = _glfwSetWindowRefreshCallback;

            function _glfwGetKey(key) {
                return GLFW.getKey(GLFW.active.id, key)
            }
            Module["_glfwGetKey"] = _glfwGetKey;

            function _glfwGetMouseButton(button) {
                return GLFW.getMouseButton(GLFW.active.id, button)
            }
            Module["_glfwGetMouseButton"] = _glfwGetMouseButton;

            function _glfwGetMousePos(x, y) {
                GLFW.getMousePos(GLFW.active.id, x, y)
            }
            Module["_glfwGetMousePos"] = _glfwGetMousePos;

            function _glfwSetMousePos(x, y) {
                GLFW.setCursorPos(GLFW.active.id, x, y)
            }
            Module["_glfwSetMousePos"] = _glfwSetMousePos;

            function _glfwGetMouseWheel() {
                return 0
            }
            Module["_glfwGetMouseWheel"] = _glfwGetMouseWheel;

            function _glfwSetMouseWheel(pos) {}
            Module["_glfwSetMouseWheel"] = _glfwSetMouseWheel;

            function _glfwSetKeyCallback(cbfun) {
                GLFW.setKeyCallback(GLFW.active.id, cbfun)
            }
            Module["_glfwSetKeyCallback"] = _glfwSetKeyCallback;

            function _glfwSetCharCallback(cbfun) {
                GLFW.setCharCallback(GLFW.active.id, cbfun)
            }
            Module["_glfwSetCharCallback"] = _glfwSetCharCallback;

            function _glfwSetMouseButtonCallback(cbfun) {
                GLFW.setMouseButtonCallback(GLFW.active.id, cbfun)
            }
            Module["_glfwSetMouseButtonCallback"] = _glfwSetMouseButtonCallback;

            function _glfwSetMousePosCallback(cbfun) {
                GLFW.setCursorPosCallback(GLFW.active.id, cbfun)
            }
            Module["_glfwSetMousePosCallback"] = _glfwSetMousePosCallback;

            function _glfwSetMouseWheelCallback(cbfun) {
                GLFW.setScrollCallback(GLFW.active.id, cbfun)
            }
            Module["_glfwSetMouseWheelCallback"] = _glfwSetMouseWheelCallback;

            function _glfwGetDesktopMode(mode) {
                throw "glfwGetDesktopMode is not implemented."
            }
            Module["_glfwGetDesktopMode"] = _glfwGetDesktopMode;

            function _glfwSleep(time) {
                _sleep(time)
            }
            Module["_glfwSleep"] = _glfwSleep;

            function _glfwEnable(target) {
                target = GLFW.GLFW2ParamToGLFW3Param(target);
                GLFW.hints[target] = false
            }
            Module["_glfwEnable"] = _glfwEnable;

            function _glfwDisable(target) {
                target = GLFW.GLFW2ParamToGLFW3Param(target);
                GLFW.hints[target] = true
            }
            Module["_glfwDisable"] = _glfwDisable;

            function _glfwGetGLVersion(major, minor, rev) {
                setValue(major, 0, "i32");
                setValue(minor, 0, "i32");
                setValue(rev, 1, "i32")
            }
            Module["_glfwGetGLVersion"] = _glfwGetGLVersion;

            function _glfwCreateThread(fun, arg) {
                wasmTable.get(fun)(arg);
                return 0
            }
            Module["_glfwCreateThread"] = _glfwCreateThread;

            function _glfwDestroyThread(ID) {}
            Module["_glfwDestroyThread"] = _glfwDestroyThread;

            function _glfwWaitThread(ID, waitmode) {}
            Module["_glfwWaitThread"] = _glfwWaitThread;

            function _glfwGetThreadID() {
                return 0
            }
            Module["_glfwGetThreadID"] = _glfwGetThreadID;

            function _glfwCreateMutex() {
                throw "glfwCreateMutex is not implemented."
            }
            Module["_glfwCreateMutex"] = _glfwCreateMutex;

            function _glfwDestroyMutex(mutex) {
                throw "glfwDestroyMutex is not implemented."
            }
            Module["_glfwDestroyMutex"] = _glfwDestroyMutex;

            function _glfwLockMutex(mutex) {
                throw "glfwLockMutex is not implemented."
            }
            Module["_glfwLockMutex"] = _glfwLockMutex;

            function _glfwUnlockMutex(mutex) {
                throw "glfwUnlockMutex is not implemented."
            }
            Module["_glfwUnlockMutex"] = _glfwUnlockMutex;

            function _glfwCreateCond() {
                throw "glfwCreateCond is not implemented."
            }
            Module["_glfwCreateCond"] = _glfwCreateCond;

            function _glfwDestroyCond(cond) {
                throw "glfwDestroyCond is not implemented."
            }
            Module["_glfwDestroyCond"] = _glfwDestroyCond;

            function _glfwWaitCond(cond, mutex, timeout) {
                throw "glfwWaitCond is not implemented."
            }
            Module["_glfwWaitCond"] = _glfwWaitCond;

            function _glfwSignalCond(cond) {
                throw "glfwSignalCond is not implemented."
            }
            Module["_glfwSignalCond"] = _glfwSignalCond;

            function _glfwBroadcastCond(cond) {
                throw "glfwBroadcastCond is not implemented."
            }
            Module["_glfwBroadcastCond"] = _glfwBroadcastCond;

            function _glfwGetNumberOfProcessors() {
                return 1
            }
            Module["_glfwGetNumberOfProcessors"] = _glfwGetNumberOfProcessors;

            function _glfwReadImage(name, img, flags) {
                throw "glfwReadImage is not implemented."
            }
            Module["_glfwReadImage"] = _glfwReadImage;

            function _glfwReadMemoryImage(data, size, img, flags) {
                throw "glfwReadMemoryImage is not implemented."
            }
            Module["_glfwReadMemoryImage"] = _glfwReadMemoryImage;

            function _glfwFreeImage(img) {
                throw "glfwFreeImage is not implemented."
            }
            Module["_glfwFreeImage"] = _glfwFreeImage;

            function _glfwLoadTexture2D(name, flags) {
                throw "glfwLoadTexture2D is not implemented."
            }
            Module["_glfwLoadTexture2D"] = _glfwLoadTexture2D;

            function _glfwLoadMemoryTexture2D(data, size, flags) {
                throw "glfwLoadMemoryTexture2D is not implemented."
            }
            Module["_glfwLoadMemoryTexture2D"] = _glfwLoadMemoryTexture2D;

            function _glfwLoadTextureImage2D(img, flags) {
                throw "glfwLoadTextureImage2D is not implemented."
            }
            Module["_glfwLoadTextureImage2D"] = _glfwLoadTextureImage2D;

            function _uuid_clear(uu) {
                _memset(uu, 0, 16)
            }
            Module["_uuid_clear"] = _uuid_clear;

            function _uuid_compare(uu1, uu2) {
                return _memcmp(uu1, uu2, 16)
            }
            Module["_uuid_compare"] = _uuid_compare;

            function _uuid_copy(dst, src) {
                _memcpy(dst, src, 16)
            }
            Module["_uuid_copy"] = _uuid_copy;

            function _uuid_generate(out) {
                var uuid = null;
                if (ENVIRONMENT_IS_NODE) {
                    try {
                        var rb = require("crypto")["randomBytes"];
                        uuid = rb(16)
                    } catch (e) {}
                } else if (ENVIRONMENT_IS_WEB && typeof window.crypto !== "undefined" && typeof window.crypto.getRandomValues !== "undefined") {
                    uuid = new Uint8Array(16);
                    window.crypto.getRandomValues(uuid)
                }
                if (!uuid) {
                    uuid = new Array(16);
                    var d = (new Date).getTime();
                    for (var i = 0; i < 16; i++) {
                        var r = (d + Math.random() * 256) % 256 | 0;
                        d = d / 256 | 0;
                        uuid[i] = r
                    }
                }
                uuid[6] = uuid[6] & 15 | 64;
                uuid[8] = uuid[8] & 63 | 128;
                writeArrayToMemory(uuid, out)
            }
            Module["_uuid_generate"] = _uuid_generate;

            function _uuid_is_null(uu) {
                for (var i = 0; i < 4; i++, uu = uu + 4 | 0) {
                    var val = HEAP32[uu >> 2];
                    if (val) {
                        return 0
                    }
                }
                return 1
            }
            Module["_uuid_is_null"] = _uuid_is_null;

            function _uuid_parse(inp, uu) {
                inp = UTF8ToString(inp);
                if (inp.length === 36) {
                    var i = 0;
                    var uuid = new Array(16);
                    inp.toLowerCase().replace(/[0-9a-f]{2}/g, function(byte) {
                        if (i < 16) {
                            uuid[i++] = parseInt(byte, 16)
                        }
                    });
                    if (i < 16) {
                        return -1
                    } else {
                        writeArrayToMemory(uuid, uu);
                        return 0
                    }
                } else {
                    return -1
                }
            }
            Module["_uuid_parse"] = _uuid_parse;

            function _uuid_unparse(uu, out, upper) {
                var i = 0;
                var uuid = "xxxx-xx-xx-xx-xxxxxx".replace(/[x]/g, function(c) {
                    var r = upper ? HEAPU8[uu + i >> 0].toString(16).toUpperCase() : HEAPU8[uu + i >> 0].toString(16);
                    r = r.length === 1 ? "0" + r : r;
                    i++;
                    return r
                });
                stringToUTF8(uuid, out, 37)
            }
            Module["_uuid_unparse"] = _uuid_unparse;

            function _uuid_unparse_lower(uu, out) {
                _uuid_unparse(uu, out)
            }
            Module["_uuid_unparse_lower"] = _uuid_unparse_lower;

            function _uuid_unparse_upper(uu, out) {
                _uuid_unparse(uu, out, true)
            }
            Module["_uuid_unparse_upper"] = _uuid_unparse_upper;

            function _uuid_type(uu) {
                return 4
            }
            Module["_uuid_type"] = _uuid_type;

            function _uuid_variant(uu) {
                return 1
            }
            Module["_uuid_variant"] = _uuid_variant;
            var GLEW = {
                isLinaroFork: 1,
                extensions: null,
                error: {
                    0: null,
                    1: null,
                    2: null,
                    3: null,
                    4: null,
                    5: null,
                    6: null,
                    7: null,
                    8: null
                },
                version: {
                    1: null,
                    2: null,
                    3: null,
                    4: null
                },
                errorStringConstantFromCode: function(error) {
                    if (GLEW.isLinaroFork) {
                        switch (error) {
                            case 4:
                                return "OpenGL ES lib expected, found OpenGL lib";
                            case 5:
                                return "OpenGL lib expected, found OpenGL ES lib";
                            case 6:
                                return "Missing EGL version";
                            case 7:
                                return "EGL 1.1 and up are supported";
                            default:
                                break
                        }
                    }
                    switch (error) {
                        case 0:
                            return "No error";
                        case 1:
                            return "Missing GL version";
                        case 2:
                            return "GL 1.1 and up are supported";
                        case 3:
                            return "GLX 1.2 and up are supported";
                        default:
                            return null
                    }
                },
                errorString: function(error) {
                    if (!GLEW.error[error]) {
                        var string = GLEW.errorStringConstantFromCode(error);
                        if (!string) {
                            string = "Unknown error";
                            error = 8
                        }
                        GLEW.error[error] = allocate(intArrayFromString(string), ALLOC_NORMAL)
                    }
                    return GLEW.error[error]
                },
                versionStringConstantFromCode: function(name) {
                    switch (name) {
                        case 1:
                            return "1.10.0";
                        case 2:
                            return "1";
                        case 3:
                            return "10";
                        case 4:
                            return "0";
                        default:
                            return null
                    }
                },
                versionString: function(name) {
                    if (!GLEW.version[name]) {
                        var string = GLEW.versionStringConstantFromCode(name);
                        if (!string) return 0;
                        GLEW.version[name] = allocate(intArrayFromString(string), ALLOC_NORMAL)
                    }
                    return GLEW.version[name]
                },
                extensionIsSupported: function(name) {
                    if (!GLEW.extensions) {
                        GLEW.extensions = UTF8ToString(_glGetString(7939)).split(" ")
                    }
                    if (GLEW.extensions.includes(name)) return 1;
                    return GLEW.extensions.includes("GL_" + name)
                }
            };
            Module["GLEW"] = GLEW;

            function _glewInit() {
                return 0
            }
            Module["_glewInit"] = _glewInit;

            function _glewIsSupported(name) {
                var exts = UTF8ToString(name).split(" ");
                for (var i = 0; i < exts.length; ++i) {
                    if (!GLEW.extensionIsSupported(exts[i])) return 0
                }
                return 1
            }
            Module["_glewIsSupported"] = _glewIsSupported;

            function _glewGetExtension(name) {
                return GLEW.extensionIsSupported(UTF8ToString(name))
            }
            Module["_glewGetExtension"] = _glewGetExtension;

            function _glewGetErrorString(error) {
                return GLEW.errorString(error)
            }
            Module["_glewGetErrorString"] = _glewGetErrorString;
            _glewGetErrorString.sig = "ii";

            function _glewGetString(name) {
                return GLEW.versionString(name)
            }
            Module["_glewGetString"] = _glewGetString;
            var IDBStore = {
                indexedDB: function() {
                    if (typeof indexedDB !== "undefined") return indexedDB;
                    var ret = null;
                    if (typeof window === "object") ret = window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
                    assert(ret, "IDBStore used, but indexedDB not supported");
                    return ret
                },
                DB_VERSION: 22,
                DB_STORE_NAME: "FILE_DATA",
                dbs: {},
                blobs: [0],
                getDB: function(name, callback) {
                    var db = IDBStore.dbs[name];
                    if (db) {
                        return callback(null, db)
                    }
                    var req;
                    try {
                        req = IDBStore.indexedDB().open(name, IDBStore.DB_VERSION)
                    } catch (e) {
                        return callback(e)
                    }
                    req.onupgradeneeded = function(e) {
                        var db = e.target.result;
                        var transaction = e.target.transaction;
                        var fileStore;
                        if (db.objectStoreNames.contains(IDBStore.DB_STORE_NAME)) {
                            fileStore = transaction.objectStore(IDBStore.DB_STORE_NAME)
                        } else {
                            fileStore = db.createObjectStore(IDBStore.DB_STORE_NAME)
                        }
                    };
                    req.onsuccess = function() {
                        db = req.result;
                        IDBStore.dbs[name] = db;
                        callback(null, db)
                    };
                    req.onerror = function(e) {
                        callback(this.error);
                        e.preventDefault()
                    }
                },
                getStore: function(dbName, type, callback) {
                    IDBStore.getDB(dbName, function(error, db) {
                        if (error) return callback(error);
                        var transaction = db.transaction([IDBStore.DB_STORE_NAME], type);
                        transaction.onerror = function(e) {
                            callback(this.error || "unknown error");
                            e.preventDefault()
                        };
                        var store = transaction.objectStore(IDBStore.DB_STORE_NAME);
                        callback(null, store)
                    })
                },
                getFile: function(dbName, id, callback) {
                    IDBStore.getStore(dbName, "readonly", function(err, store) {
                        if (err) return callback(err);
                        var req = store.get(id);
                        req.onsuccess = function(event) {
                            var result = event.target.result;
                            if (!result) {
                                return callback("file " + id + " not found")
                            } else {
                                return callback(null, result)
                            }
                        };
                        req.onerror = function(error) {
                            callback(error)
                        }
                    })
                },
                setFile: function(dbName, id, data, callback) {
                    IDBStore.getStore(dbName, "readwrite", function(err, store) {
                        if (err) return callback(err);
                        var req = store.put(data, id);
                        req.onsuccess = function(event) {
                            callback()
                        };
                        req.onerror = function(error) {
                            callback(error)
                        }
                    })
                },
                deleteFile: function(dbName, id, callback) {
                    IDBStore.getStore(dbName, "readwrite", function(err, store) {
                        if (err) return callback(err);
                        var req = store.delete(id);
                        req.onsuccess = function(event) {
                            callback()
                        };
                        req.onerror = function(error) {
                            callback(error)
                        }
                    })
                },
                existsFile: function(dbName, id, callback) {
                    IDBStore.getStore(dbName, "readonly", function(err, store) {
                        if (err) return callback(err);
                        var req = store.count(id);
                        req.onsuccess = function(event) {
                            callback(null, event.target.result > 0)
                        };
                        req.onerror = function(error) {
                            callback(error)
                        }
                    })
                }
            };
            Module["IDBStore"] = IDBStore;

            function _emscripten_idb_async_load(db, id, arg, onload, onerror) {
                IDBStore.getFile(UTF8ToString(db), UTF8ToString(id), function(error, byteArray) {
                    if (error) {
                        if (onerror) wasmTable.get(onerror)(arg);
                        return
                    }
                    var buffer = _malloc(byteArray.length);
                    HEAPU8.set(byteArray, buffer);
                    wasmTable.get(onload)(arg, buffer, byteArray.length);
                    _free(buffer)
                })
            }
            Module["_emscripten_idb_async_load"] = _emscripten_idb_async_load;

            function _emscripten_idb_async_store(db, id, ptr, num, arg, onstore, onerror) {
                IDBStore.setFile(UTF8ToString(db), UTF8ToString(id), new Uint8Array(HEAPU8.subarray(ptr, ptr + num)), function(error) {
                    if (error) {
                        if (onerror) wasmTable.get(onerror)(arg);
                        return
                    }
                    if (onstore) wasmTable.get(onstore)(arg)
                })
            }
            Module["_emscripten_idb_async_store"] = _emscripten_idb_async_store;

            function _emscripten_idb_async_delete(db, id, arg, ondelete, onerror) {
                IDBStore.deleteFile(UTF8ToString(db), UTF8ToString(id), function(error) {
                    if (error) {
                        if (onerror) wasmTable.get(onerror)(arg);
                        return
                    }
                    if (ondelete) wasmTable.get(ondelete)(arg)
                })
            }
            Module["_emscripten_idb_async_delete"] = _emscripten_idb_async_delete;

            function _emscripten_idb_async_exists(db, id, arg, oncheck, onerror) {
                IDBStore.existsFile(UTF8ToString(db), UTF8ToString(id), function(error, exists) {
                    if (error) {
                        if (onerror) wasmTable.get(onerror)(arg);
                        return
                    }
                    if (oncheck) wasmTable.get(oncheck)(arg, exists)
                })
            }
            Module["_emscripten_idb_async_exists"] = _emscripten_idb_async_exists;

            function _emscripten_idb_load() {
                throw "Please compile your program with async support in order to use synchronous operations like emscripten_idb_load, etc."
            }
            Module["_emscripten_idb_load"] = _emscripten_idb_load;

            function _emscripten_idb_store() {
                throw "Please compile your program with async support in order to use synchronous operations like emscripten_idb_store, etc."
            }
            Module["_emscripten_idb_store"] = _emscripten_idb_store;

            function _emscripten_idb_delete() {
                throw "Please compile your program with async support in order to use synchronous operations like emscripten_idb_delete, etc."
            }
            Module["_emscripten_idb_delete"] = _emscripten_idb_delete;

            function _emscripten_idb_exists() {
                throw "Please compile your program with async support in order to use synchronous operations like emscripten_idb_exists, etc."
            }
            Module["_emscripten_idb_exists"] = _emscripten_idb_exists;

            function runAndAbortIfError(func) {
                try {
                    return func()
                } catch (e) {
                    abort(e)
                }
            }
            Module["runAndAbortIfError"] = runAndAbortIfError;

            function _emscripten_sleep() {
                throw "Please compile your program with async support in order to use asynchronous operations like emscripten_sleep"
            }
            Module["_emscripten_sleep"] = _emscripten_sleep;

            function _emscripten_wget() {
                throw "Please compile your program with async support in order to use asynchronous operations like emscripten_wget"
            }
            Module["_emscripten_wget"] = _emscripten_wget;

            function _emscripten_wget_data() {
                throw "Please compile your program with async support in order to use asynchronous operations like emscripten_wget_data"
            }
            Module["_emscripten_wget_data"] = _emscripten_wget_data;

            function _emscripten_scan_registers() {
                throw "Please compile your program with async support in order to use asynchronous operations like emscripten_scan_registers"
            }
            Module["_emscripten_scan_registers"] = _emscripten_scan_registers;

            function _emscripten_fiber_init() {
                throw "Please compile your program with async support in order to use asynchronous operations like emscripten_fiber_init"
            }
            Module["_emscripten_fiber_init"] = _emscripten_fiber_init;

            function _emscripten_fiber_init_from_current_context() {
                throw "Please compile your program with async support in order to use asynchronous operations like emscripten_fiber_init_from_current_context"
            }
            Module["_emscripten_fiber_init_from_current_context"] = _emscripten_fiber_init_from_current_context;

            function _emscripten_fiber_swap() {
                throw "Please compile your program with async support in order to use asynchronous operations like emscripten_fiber_swap"
            }
            Module["_emscripten_fiber_swap"] = _emscripten_fiber_swap;

            function _emscripten_is_main_browser_thread() {
                return !ENVIRONMENT_IS_WORKER
            }
            Module["_emscripten_is_main_browser_thread"] = _emscripten_is_main_browser_thread;
            var FSNode = function(parent, name, mode, rdev) {
                if (!parent) {
                    parent = this
                }
                this.parent = parent;
                this.mount = parent.mount;
                this.mounted = null;
                this.id = FS.nextInode++;
                this.name = name;
                this.mode = mode;
                this.node_ops = {};
                this.stream_ops = {};
                this.rdev = rdev
            };
            var readMode = 292 | 73;
            var writeMode = 146;
            Object.defineProperties(FSNode.prototype, {
                read: {
                    get: function() {
                        return (this.mode & readMode) === readMode
                    },
                    set: function(val) {
                        val ? this.mode |= readMode : this.mode &= ~readMode
                    }
                },
                write: {
                    get: function() {
                        return (this.mode & writeMode) === writeMode
                    },
                    set: function(val) {
                        val ? this.mode |= writeMode : this.mode &= ~writeMode
                    }
                },
                isFolder: {
                    get: function() {
                        return FS.isDir(this.mode)
                    }
                },
                isDevice: {
                    get: function() {
                        return FS.isChrdev(this.mode)
                    }
                }
            });
            FS.FSNode = FSNode;
            FS.staticInit();
            Module["requestFullscreen"] = function Module_requestFullscreen(lockPointer, resizeCanvas) {
                Browser.requestFullscreen(lockPointer, resizeCanvas)
            };
            Module["requestAnimationFrame"] = function Module_requestAnimationFrame(func) {
                Browser.requestAnimationFrame(func)
            };
            Module["setCanvasSize"] = function Module_setCanvasSize(width, height, noUpdates) {
                Browser.setCanvasSize(width, height, noUpdates)
            };
            Module["pauseMainLoop"] = function Module_pauseMainLoop() {
                Browser.mainLoop.pause()
            };
            Module["resumeMainLoop"] = function Module_resumeMainLoop() {
                Browser.mainLoop.resume()
            };
            Module["getUserMedia"] = function Module_getUserMedia() {
                Browser.getUserMedia()
            };
            Module["createContext"] = function Module_createContext(canvas, useWebGL, setInModule, webGLContextAttributes) {
                return Browser.createContext(canvas, useWebGL, setInModule, webGLContextAttributes)
            };
            var GLctx;
            for (var i = 0; i < 32; ++i) tempFixedLengthArray.push(new Array(i));
            var miniTempWebGLFloatBuffersStorage = new Float32Array(288);
            for (var i = 0; i < 288; ++i) {
                miniTempWebGLFloatBuffers[i] = miniTempWebGLFloatBuffersStorage.subarray(0, i + 1)
            }
            var __miniTempWebGLIntBuffersStorage = new Int32Array(288);
            for (var i = 0; i < 288; ++i) {
                __miniTempWebGLIntBuffers[i] = __miniTempWebGLIntBuffersStorage.subarray(0, i + 1)
            }
            var emSetImmediate;
            var emClearImmediate;
            if (typeof setImmediate !== "undefined") {
                emSetImmediate = setImmediate;
                emClearImmediate = clearImmediate
            } else if (typeof addEventListener === "function") {
                var __setImmediate_id_counter = 0;
                var __setImmediate_queue = [];
                var __setImmediate_message_id = "_si";

                function __setImmediate_cb(e) {
                    if (e.data === __setImmediate_message_id) {
                        e.stopPropagation();
                        __setImmediate_queue.shift()();
                        ++__setImmediate_id_counter
                    }
                }
                addEventListener("message", __setImmediate_cb, true);
                emSetImmediate = function(func) {
                    postMessage(__setImmediate_message_id, "*");
                    return __setImmediate_id_counter + __setImmediate_queue.push(func) - 1
                };
                emClearImmediate = function(id) {
                    var index = id - __setImmediate_id_counter;
                    if (index >= 0 && index < __setImmediate_queue.length) __setImmediate_queue[index] = function() {}
                }
            }
            var ASSERTIONS = false;

            function intArrayFromString(stringy, dontAddNull, length) {
                var len = length > 0 ? length : lengthBytesUTF8(stringy) + 1;
                var u8array = new Array(len);
                var numBytesWritten = stringToUTF8Array(stringy, u8array, 0, u8array.length);
                if (dontAddNull) u8array.length = numBytesWritten;
                return u8array
            }

            function intArrayToString(array) {
                var ret = [];
                for (var i = 0; i < array.length; i++) {
                    var chr = array[i];
                    if (chr > 255) {
                        if (ASSERTIONS) {
                            assert(false, "Character code " + chr + " (" + String.fromCharCode(chr) + ")  at offset " + i + " not in 0x00-0xFF.")
                        }
                        chr &= 255
                    }
                    ret.push(String.fromCharCode(chr))
                }
                return ret.join("")
            }
            var asmLibraryArg = {
                "__asctime": ___asctime,
                "__clock_gettime": ___clock_gettime,
                "__cxa_atexit": ___cxa_atexit,
                "__gmtime_r": ___gmtime_r,
                "__heap_base": ___heap_base,
                "__indirect_function_table": wasmTable,
                "__localtime_r": ___localtime_r,
                "__map_file": ___map_file,
                "__memory_base": ___memory_base,
                "__stack_pointer": ___stack_pointer,
                "__sys__newselect": ___sys__newselect,
                "__sys_accept4": ___sys_accept4,
                "__sys_access": ___sys_access,
                "__sys_acct": ___sys_acct,
                "__sys_bind": ___sys_bind,
                "__sys_chdir": ___sys_chdir,
                "__sys_chmod": ___sys_chmod,
                "__sys_chown32": ___sys_chown32,
                "__sys_connect": ___sys_connect,
                "__sys_dup": ___sys_dup,
                "__sys_dup2": ___sys_dup2,
                "__sys_dup3": ___sys_dup3,
                "__sys_fadvise64_64": ___sys_fadvise64_64,
                "__sys_fallocate": ___sys_fallocate,
                "__sys_fchdir": ___sys_fchdir,
                "__sys_fchmod": ___sys_fchmod,
                "__sys_fchmodat": ___sys_fchmodat,
                "__sys_fchown32": ___sys_fchown32,
                "__sys_fchownat": ___sys_fchownat,
                "__sys_fcntl64": ___sys_fcntl64,
                "__sys_fdatasync": ___sys_fdatasync,
                "__sys_fstat64": ___sys_fstat64,
                "__sys_fstatat64": ___sys_fstatat64,
                "__sys_fstatfs64": ___sys_fstatfs64,
                "__sys_ftruncate64": ___sys_ftruncate64,
                "__sys_getcwd": ___sys_getcwd,
                "__sys_getdents64": ___sys_getdents64,
                "__sys_getegid32": ___sys_getegid32,
                "__sys_geteuid32": ___sys_geteuid32,
                "__sys_getgid32": ___sys_getgid32,
                "__sys_getgroups32": ___sys_getgroups32,
                "__sys_getpeername": ___sys_getpeername,
                "__sys_getpgid": ___sys_getpgid,
                "__sys_getpid": ___sys_getpid,
                "__sys_getppid": ___sys_getppid,
                "__sys_getpriority": ___sys_getpriority,
                "__sys_getresgid32": ___sys_getresgid32,
                "__sys_getresuid32": ___sys_getresuid32,
                "__sys_getrusage": ___sys_getrusage,
                "__sys_getsid": ___sys_getsid,
                "__sys_getsockname": ___sys_getsockname,
                "__sys_getsockopt": ___sys_getsockopt,
                "__sys_getuid32": ___sys_getuid32,
                "__sys_ioctl": ___sys_ioctl,
                "__sys_lchown32": ___sys_lchown32,
                "__sys_link": ___sys_link,
                "__sys_linkat": ___sys_linkat,
                "__sys_listen": ___sys_listen,
                "__sys_lstat64": ___sys_lstat64,
                "__sys_madvise1": ___sys_madvise1,
                "__sys_mincore": ___sys_mincore,
                "__sys_mkdir": ___sys_mkdir,
                "__sys_mkdirat": ___sys_mkdirat,
                "__sys_mknod": ___sys_mknod,
                "__sys_mknodat": ___sys_mknodat,
                "__sys_mlock": ___sys_mlock,
                "__sys_mlockall": ___sys_mlockall,
                "__sys_mmap2": ___sys_mmap2,
                "__sys_mprotect": ___sys_mprotect,
                "__sys_mremap": ___sys_mremap,
                "__sys_msync": ___sys_msync,
                "__sys_munlock": ___sys_munlock,
                "__sys_munlockall": ___sys_munlockall,
                "__sys_munmap": ___sys_munmap,
                "__sys_nice": ___sys_nice,
                "__sys_open": ___sys_open,
                "__sys_openat": ___sys_openat,
                "__sys_pause": ___sys_pause,
                "__sys_pipe": ___sys_pipe,
                "__sys_pipe2": ___sys_pipe2,
                "__sys_poll": ___sys_poll,
                "__sys_prlimit64": ___sys_prlimit64,
                "__sys_pselect6": ___sys_pselect6,
                "__sys_readlink": ___sys_readlink,
                "__sys_readlinkat": ___sys_readlinkat,
                "__sys_recvfrom": ___sys_recvfrom,
                "__sys_recvmmsg": ___sys_recvmmsg,
                "__sys_recvmsg": ___sys_recvmsg,
                "__sys_rename": ___sys_rename,
                "__sys_renameat": ___sys_renameat,
                "__sys_rmdir": ___sys_rmdir,
                "__sys_sendmmsg": ___sys_sendmmsg,
                "__sys_sendmsg": ___sys_sendmsg,
                "__sys_sendto": ___sys_sendto,
                "__sys_setdomainname": ___sys_setdomainname,
                "__sys_setpgid": ___sys_setpgid,
                "__sys_setpriority": ___sys_setpriority,
                "__sys_setrlimit": ___sys_setrlimit,
                "__sys_setsid": ___sys_setsid,
                "__sys_setsockopt": ___sys_setsockopt,
                "__sys_shutdown": ___sys_shutdown,
                "__sys_socket": ___sys_socket,
                "__sys_socketpair": ___sys_socketpair,
                "__sys_stat64": ___sys_stat64,
                "__sys_statfs64": ___sys_statfs64,
                "__sys_symlink": ___sys_symlink,
                "__sys_symlinkat": ___sys_symlinkat,
                "__sys_sync": ___sys_sync,
                "__sys_truncate64": ___sys_truncate64,
                "__sys_ugetrlimit": ___sys_ugetrlimit,
                "__sys_umask": ___sys_umask,
                "__sys_uname": ___sys_uname,
                "__sys_unlink": ___sys_unlink,
                "__sys_unlinkat": ___sys_unlinkat,
                "__sys_utimensat": ___sys_utimensat,
                "__sys_wait4": ___sys_wait4,
                "__table_base": ___table_base,
                "_exit": __exit,
                "abort": _abort,
                "alBuffer3f": _alBuffer3f,
                "alBuffer3i": _alBuffer3i,
                "alBufferData": _alBufferData,
                "alBufferf": _alBufferf,
                "alBufferfv": _alBufferfv,
                "alBufferi": _alBufferi,
                "alBufferiv": _alBufferiv,
                "alDeleteBuffers": _alDeleteBuffers,
                "alDeleteSources": _alDeleteSources,
                "alDisable": _alDisable,
                "alDistanceModel": _alDistanceModel,
                "alDopplerFactor": _alDopplerFactor,
                "alDopplerVelocity": _alDopplerVelocity,
                "alEnable": _alEnable,
                "alGenBuffers": _alGenBuffers,
                "alGenSources": _alGenSources,
                "alGetBoolean": _alGetBoolean,
                "alGetBooleanv": _alGetBooleanv,
                "alGetBuffer3f": _alGetBuffer3f,
                "alGetBuffer3i": _alGetBuffer3i,
                "alGetBufferf": _alGetBufferf,
                "alGetBufferfv": _alGetBufferfv,
                "alGetBufferi": _alGetBufferi,
                "alGetBufferiv": _alGetBufferiv,
                "alGetDouble": _alGetDouble,
                "alGetDoublev": _alGetDoublev,
                "alGetEnumValue": _alGetEnumValue,
                "alGetError": _alGetError,
                "alGetFloat": _alGetFloat,
                "alGetFloatv": _alGetFloatv,
                "alGetInteger": _alGetInteger,
                "alGetIntegerv": _alGetIntegerv,
                "alGetListener3f": _alGetListener3f,
                "alGetListener3i": _alGetListener3i,
                "alGetListenerf": _alGetListenerf,
                "alGetListenerfv": _alGetListenerfv,
                "alGetListeneri": _alGetListeneri,
                "alGetListeneriv": _alGetListeneriv,
                "alGetSource3f": _alGetSource3f,
                "alGetSource3i": _alGetSource3i,
                "alGetSourcef": _alGetSourcef,
                "alGetSourcefv": _alGetSourcefv,
                "alGetSourcei": _alGetSourcei,
                "alGetSourceiv": _alGetSourceiv,
                "alGetString": _alGetString,
                "alIsBuffer": _alIsBuffer,
                "alIsEnabled": _alIsEnabled,
                "alIsExtensionPresent": _alIsExtensionPresent,
                "alIsSource": _alIsSource,
                "alListener3f": _alListener3f,
                "alListener3i": _alListener3i,
                "alListenerf": _alListenerf,
                "alListenerfv": _alListenerfv,
                "alListeneri": _alListeneri,
                "alListeneriv": _alListeneriv,
                "alSource3f": _alSource3f,
                "alSource3i": _alSource3i,
                "alSourcePause": _alSourcePause,
                "alSourcePausev": _alSourcePausev,
                "alSourcePlay": _alSourcePlay,
                "alSourcePlayv": _alSourcePlayv,
                "alSourceQueueBuffers": _alSourceQueueBuffers,
                "alSourceRewind": _alSourceRewind,
                "alSourceRewindv": _alSourceRewindv,
                "alSourceStop": _alSourceStop,
                "alSourceStopv": _alSourceStopv,
                "alSourceUnqueueBuffers": _alSourceUnqueueBuffers,
                "alSourcef": _alSourcef,
                "alSourcefv": _alSourcefv,
                "alSourcei": _alSourcei,
                "alSourceiv": _alSourceiv,
                "alSpeedOfSound": _alSpeedOfSound,
                "alcCaptureCloseDevice": _alcCaptureCloseDevice,
                "alcCaptureOpenDevice": _alcCaptureOpenDevice,
                "alcCaptureSamples": _alcCaptureSamples,
                "alcCaptureStart": _alcCaptureStart,
                "alcCaptureStop": _alcCaptureStop,
                "alcCloseDevice": _alcCloseDevice,
                "alcCreateContext": _alcCreateContext,
                "alcDestroyContext": _alcDestroyContext,
                "alcGetContextsDevice": _alcGetContextsDevice,
                "alcGetCurrentContext": _alcGetCurrentContext,
                "alcGetEnumValue": _alcGetEnumValue,
                "alcGetError": _alcGetError,
                "alcGetIntegerv": _alcGetIntegerv,
                "alcGetString": _alcGetString,
                "alcIsExtensionPresent": _alcIsExtensionPresent,
                "alcMakeContextCurrent": _alcMakeContextCurrent,
                "alcOpenDevice": _alcOpenDevice,
                "alcProcessContext": _alcProcessContext,
                "alcSuspendContext": _alcSuspendContext,
                "clock_gettime": _clock_gettime,
                "emscripten_alcDevicePauseSOFT": _emscripten_alcDevicePauseSOFT,
                "emscripten_alcDeviceResumeSOFT": _emscripten_alcDeviceResumeSOFT,
                "emscripten_alcGetStringiSOFT": _emscripten_alcGetStringiSOFT,
                "emscripten_alcResetDeviceSOFT": _emscripten_alcResetDeviceSOFT,
                "emscripten_asm_const_int": _emscripten_asm_const_int,
                "emscripten_get_heap_max": _emscripten_get_heap_max,
                "emscripten_glActiveTexture": _emscripten_glActiveTexture,
                "emscripten_glAttachShader": _emscripten_glAttachShader,
                "emscripten_glBeginQueryEXT": _emscripten_glBeginQueryEXT,
                "emscripten_glBindAttribLocation": _emscripten_glBindAttribLocation,
                "emscripten_glBindBuffer": _emscripten_glBindBuffer,
                "emscripten_glBindFramebuffer": _emscripten_glBindFramebuffer,
                "emscripten_glBindRenderbuffer": _emscripten_glBindRenderbuffer,
                "emscripten_glBindTexture": _emscripten_glBindTexture,
                "emscripten_glBindVertexArrayOES": _emscripten_glBindVertexArrayOES,
                "emscripten_glBlendColor": _emscripten_glBlendColor,
                "emscripten_glBlendEquation": _emscripten_glBlendEquation,
                "emscripten_glBlendEquationSeparate": _emscripten_glBlendEquationSeparate,
                "emscripten_glBlendFunc": _emscripten_glBlendFunc,
                "emscripten_glBlendFuncSeparate": _emscripten_glBlendFuncSeparate,
                "emscripten_glBufferData": _emscripten_glBufferData,
                "emscripten_glBufferSubData": _emscripten_glBufferSubData,
                "emscripten_glCheckFramebufferStatus": _emscripten_glCheckFramebufferStatus,
                "emscripten_glClear": _emscripten_glClear,
                "emscripten_glClearColor": _emscripten_glClearColor,
                "emscripten_glClearDepthf": _emscripten_glClearDepthf,
                "emscripten_glClearStencil": _emscripten_glClearStencil,
                "emscripten_glColorMask": _emscripten_glColorMask,
                "emscripten_glCompileShader": _emscripten_glCompileShader,
                "emscripten_glCompressedTexImage2D": _emscripten_glCompressedTexImage2D,
                "emscripten_glCompressedTexSubImage2D": _emscripten_glCompressedTexSubImage2D,
                "emscripten_glCopyTexImage2D": _emscripten_glCopyTexImage2D,
                "emscripten_glCopyTexSubImage2D": _emscripten_glCopyTexSubImage2D,
                "emscripten_glCreateProgram": _emscripten_glCreateProgram,
                "emscripten_glCreateShader": _emscripten_glCreateShader,
                "emscripten_glCullFace": _emscripten_glCullFace,
                "emscripten_glDeleteBuffers": _emscripten_glDeleteBuffers,
                "emscripten_glDeleteFramebuffers": _emscripten_glDeleteFramebuffers,
                "emscripten_glDeleteProgram": _emscripten_glDeleteProgram,
                "emscripten_glDeleteQueriesEXT": _emscripten_glDeleteQueriesEXT,
                "emscripten_glDeleteRenderbuffers": _emscripten_glDeleteRenderbuffers,
                "emscripten_glDeleteShader": _emscripten_glDeleteShader,
                "emscripten_glDeleteTextures": _emscripten_glDeleteTextures,
                "emscripten_glDeleteVertexArraysOES": _emscripten_glDeleteVertexArraysOES,
                "emscripten_glDepthFunc": _emscripten_glDepthFunc,
                "emscripten_glDepthMask": _emscripten_glDepthMask,
                "emscripten_glDepthRangef": _emscripten_glDepthRangef,
                "emscripten_glDetachShader": _emscripten_glDetachShader,
                "emscripten_glDisable": _emscripten_glDisable,
                "emscripten_glDisableVertexAttribArray": _emscripten_glDisableVertexAttribArray,
                "emscripten_glDrawArrays": _emscripten_glDrawArrays,
                "emscripten_glDrawArraysInstancedANGLE": _emscripten_glDrawArraysInstancedANGLE,
                "emscripten_glDrawBuffersWEBGL": _emscripten_glDrawBuffersWEBGL,
                "emscripten_glDrawElements": _emscripten_glDrawElements,
                "emscripten_glDrawElementsInstancedANGLE": _emscripten_glDrawElementsInstancedANGLE,
                "emscripten_glEnable": _emscripten_glEnable,
                "emscripten_glEnableVertexAttribArray": _emscripten_glEnableVertexAttribArray,
                "emscripten_glEndQueryEXT": _emscripten_glEndQueryEXT,
                "emscripten_glFinish": _emscripten_glFinish,
                "emscripten_glFlush": _emscripten_glFlush,
                "emscripten_glFramebufferRenderbuffer": _emscripten_glFramebufferRenderbuffer,
                "emscripten_glFramebufferTexture2D": _emscripten_glFramebufferTexture2D,
                "emscripten_glFrontFace": _emscripten_glFrontFace,
                "emscripten_glGenBuffers": _emscripten_glGenBuffers,
                "emscripten_glGenFramebuffers": _emscripten_glGenFramebuffers,
                "emscripten_glGenQueriesEXT": _emscripten_glGenQueriesEXT,
                "emscripten_glGenRenderbuffers": _emscripten_glGenRenderbuffers,
                "emscripten_glGenTextures": _emscripten_glGenTextures,
                "emscripten_glGenVertexArraysOES": _emscripten_glGenVertexArraysOES,
                "emscripten_glGenerateMipmap": _emscripten_glGenerateMipmap,
                "emscripten_glGetActiveAttrib": _emscripten_glGetActiveAttrib,
                "emscripten_glGetActiveUniform": _emscripten_glGetActiveUniform,
                "emscripten_glGetAttachedShaders": _emscripten_glGetAttachedShaders,
                "emscripten_glGetAttribLocation": _emscripten_glGetAttribLocation,
                "emscripten_glGetBooleanv": _emscripten_glGetBooleanv,
                "emscripten_glGetBufferParameteriv": _emscripten_glGetBufferParameteriv,
                "emscripten_glGetError": _emscripten_glGetError,
                "emscripten_glGetFloatv": _emscripten_glGetFloatv,
                "emscripten_glGetFramebufferAttachmentParameteriv": _emscripten_glGetFramebufferAttachmentParameteriv,
                "emscripten_glGetIntegerv": _emscripten_glGetIntegerv,
                "emscripten_glGetProgramInfoLog": _emscripten_glGetProgramInfoLog,
                "emscripten_glGetProgramiv": _emscripten_glGetProgramiv,
                "emscripten_glGetQueryObjecti64vEXT": _emscripten_glGetQueryObjecti64vEXT,
                "emscripten_glGetQueryObjectivEXT": _emscripten_glGetQueryObjectivEXT,
                "emscripten_glGetQueryObjectui64vEXT": _emscripten_glGetQueryObjectui64vEXT,
                "emscripten_glGetQueryObjectuivEXT": _emscripten_glGetQueryObjectuivEXT,
                "emscripten_glGetQueryivEXT": _emscripten_glGetQueryivEXT,
                "emscripten_glGetRenderbufferParameteriv": _emscripten_glGetRenderbufferParameteriv,
                "emscripten_glGetShaderInfoLog": _emscripten_glGetShaderInfoLog,
                "emscripten_glGetShaderPrecisionFormat": _emscripten_glGetShaderPrecisionFormat,
                "emscripten_glGetShaderSource": _emscripten_glGetShaderSource,
                "emscripten_glGetShaderiv": _emscripten_glGetShaderiv,
                "emscripten_glGetString": _emscripten_glGetString,
                "emscripten_glGetTexParameterfv": _emscripten_glGetTexParameterfv,
                "emscripten_glGetTexParameteriv": _emscripten_glGetTexParameteriv,
                "emscripten_glGetUniformLocation": _emscripten_glGetUniformLocation,
                "emscripten_glGetUniformfv": _emscripten_glGetUniformfv,
                "emscripten_glGetUniformiv": _emscripten_glGetUniformiv,
                "emscripten_glGetVertexAttribPointerv": _emscripten_glGetVertexAttribPointerv,
                "emscripten_glGetVertexAttribfv": _emscripten_glGetVertexAttribfv,
                "emscripten_glGetVertexAttribiv": _emscripten_glGetVertexAttribiv,
                "emscripten_glHint": _emscripten_glHint,
                "emscripten_glIsBuffer": _emscripten_glIsBuffer,
                "emscripten_glIsEnabled": _emscripten_glIsEnabled,
                "emscripten_glIsFramebuffer": _emscripten_glIsFramebuffer,
                "emscripten_glIsProgram": _emscripten_glIsProgram,
                "emscripten_glIsQueryEXT": _emscripten_glIsQueryEXT,
                "emscripten_glIsRenderbuffer": _emscripten_glIsRenderbuffer,
                "emscripten_glIsShader": _emscripten_glIsShader,
                "emscripten_glIsTexture": _emscripten_glIsTexture,
                "emscripten_glIsVertexArrayOES": _emscripten_glIsVertexArrayOES,
                "emscripten_glLineWidth": _emscripten_glLineWidth,
                "emscripten_glLinkProgram": _emscripten_glLinkProgram,
                "emscripten_glPixelStorei": _emscripten_glPixelStorei,
                "emscripten_glPolygonOffset": _emscripten_glPolygonOffset,
                "emscripten_glQueryCounterEXT": _emscripten_glQueryCounterEXT,
                "emscripten_glReadPixels": _emscripten_glReadPixels,
                "emscripten_glReleaseShaderCompiler": _emscripten_glReleaseShaderCompiler,
                "emscripten_glRenderbufferStorage": _emscripten_glRenderbufferStorage,
                "emscripten_glSampleCoverage": _emscripten_glSampleCoverage,
                "emscripten_glScissor": _emscripten_glScissor,
                "emscripten_glShaderBinary": _emscripten_glShaderBinary,
                "emscripten_glShaderSource": _emscripten_glShaderSource,
                "emscripten_glStencilFunc": _emscripten_glStencilFunc,
                "emscripten_glStencilFuncSeparate": _emscripten_glStencilFuncSeparate,
                "emscripten_glStencilMask": _emscripten_glStencilMask,
                "emscripten_glStencilMaskSeparate": _emscripten_glStencilMaskSeparate,
                "emscripten_glStencilOp": _emscripten_glStencilOp,
                "emscripten_glStencilOpSeparate": _emscripten_glStencilOpSeparate,
                "emscripten_glTexImage2D": _emscripten_glTexImage2D,
                "emscripten_glTexParameterf": _emscripten_glTexParameterf,
                "emscripten_glTexParameterfv": _emscripten_glTexParameterfv,
                "emscripten_glTexParameteri": _emscripten_glTexParameteri,
                "emscripten_glTexParameteriv": _emscripten_glTexParameteriv,
                "emscripten_glTexSubImage2D": _emscripten_glTexSubImage2D,
                "emscripten_glUniform1f": _emscripten_glUniform1f,
                "emscripten_glUniform1fv": _emscripten_glUniform1fv,
                "emscripten_glUniform1i": _emscripten_glUniform1i,
                "emscripten_glUniform1iv": _emscripten_glUniform1iv,
                "emscripten_glUniform2f": _emscripten_glUniform2f,
                "emscripten_glUniform2fv": _emscripten_glUniform2fv,
                "emscripten_glUniform2i": _emscripten_glUniform2i,
                "emscripten_glUniform2iv": _emscripten_glUniform2iv,
                "emscripten_glUniform3f": _emscripten_glUniform3f,
                "emscripten_glUniform3fv": _emscripten_glUniform3fv,
                "emscripten_glUniform3i": _emscripten_glUniform3i,
                "emscripten_glUniform3iv": _emscripten_glUniform3iv,
                "emscripten_glUniform4f": _emscripten_glUniform4f,
                "emscripten_glUniform4fv": _emscripten_glUniform4fv,
                "emscripten_glUniform4i": _emscripten_glUniform4i,
                "emscripten_glUniform4iv": _emscripten_glUniform4iv,
                "emscripten_glUniformMatrix2fv": _emscripten_glUniformMatrix2fv,
                "emscripten_glUniformMatrix3fv": _emscripten_glUniformMatrix3fv,
                "emscripten_glUniformMatrix4fv": _emscripten_glUniformMatrix4fv,
                "emscripten_glUseProgram": _emscripten_glUseProgram,
                "emscripten_glValidateProgram": _emscripten_glValidateProgram,
                "emscripten_glVertexAttrib1f": _emscripten_glVertexAttrib1f,
                "emscripten_glVertexAttrib1fv": _emscripten_glVertexAttrib1fv,
                "emscripten_glVertexAttrib2f": _emscripten_glVertexAttrib2f,
                "emscripten_glVertexAttrib2fv": _emscripten_glVertexAttrib2fv,
                "emscripten_glVertexAttrib3f": _emscripten_glVertexAttrib3f,
                "emscripten_glVertexAttrib3fv": _emscripten_glVertexAttrib3fv,
                "emscripten_glVertexAttrib4f": _emscripten_glVertexAttrib4f,
                "emscripten_glVertexAttrib4fv": _emscripten_glVertexAttrib4fv,
                "emscripten_glVertexAttribDivisorANGLE": _emscripten_glVertexAttribDivisorANGLE,
                "emscripten_glVertexAttribPointer": _emscripten_glVertexAttribPointer,
                "emscripten_glViewport": _emscripten_glViewport,
                "emscripten_memcpy_big": _emscripten_memcpy_big,
                "emscripten_resize_heap": _emscripten_resize_heap,
                "emscripten_thread_sleep": _emscripten_thread_sleep,
                "environ_get": _environ_get,
                "environ_sizes_get": _environ_sizes_get,
                "execve": _execve,
                "exit": _exit,
                "fd_close": _fd_close,
                "fd_fdstat_get": _fd_fdstat_get,
                "fd_pread": _fd_pread,
                "fd_pwrite": _fd_pwrite,
                "fd_read": _fd_read,
                "fd_seek": _fd_seek,
                "fd_sync": _fd_sync,
                "fd_write": _fd_write,
                "fork": _fork,
                "getTempRet0": getTempRet0,
                "getentropy": _getentropy,
                "getnameinfo": _getnameinfo,
                "gmtime_r": _gmtime_r,
                "memory": wasmMemory,
                "pthread_cleanup_pop": _pthread_cleanup_pop,
                "pthread_cleanup_push": _pthread_cleanup_push,
                "pthread_create": _pthread_create,
                "pthread_join": _pthread_join,
                "pthread_sigmask": _pthread_sigmask,
                "setTempRet0": setTempRet0,
                "setitimer": _setitimer,
                "sigfillset": _sigfillset,
                "strftime": _strftime,
                "strftime_l": _strftime_l,
                "time": _time
            };
            var asm = createWasm();
            var ___wasm_call_ctors = Module["___wasm_call_ctors"] = function() {
                return (___wasm_call_ctors = Module["___wasm_call_ctors"] = Module["asm"]["__wasm_call_ctors"]).apply(null, arguments)
            };
            var _hysteresis_decision = Module["_hysteresis_decision"] = function() {
                return (_hysteresis_decision = Module["_hysteresis_decision"] = Module["asm"]["hysteresis_decision"]).apply(null, arguments)
            };
            var _celt_lcg_rand = Module["_celt_lcg_rand"] = function() {
                return (_celt_lcg_rand = Module["_celt_lcg_rand"] = Module["asm"]["celt_lcg_rand"]).apply(null, arguments)
            };
            var _bitexact_cos = Module["_bitexact_cos"] = function() {
                return (_bitexact_cos = Module["_bitexact_cos"] = Module["asm"]["bitexact_cos"]).apply(null, arguments)
            };
            var _bitexact_log2tan = Module["_bitexact_log2tan"] = function() {
                return (_bitexact_log2tan = Module["_bitexact_log2tan"] = Module["asm"]["bitexact_log2tan"]).apply(null, arguments)
            };
            var _compute_band_energies = Module["_compute_band_energies"] = function() {
                return (_compute_band_energies = Module["_compute_band_energies"] = Module["asm"]["compute_band_energies"]).apply(null, arguments)
            };
            var _normalise_bands = Module["_normalise_bands"] = function() {
                return (_normalise_bands = Module["_normalise_bands"] = Module["asm"]["normalise_bands"]).apply(null, arguments)
            };
            var _denormalise_bands = Module["_denormalise_bands"] = function() {
                return (_denormalise_bands = Module["_denormalise_bands"] = Module["asm"]["denormalise_bands"]).apply(null, arguments)
            };
            var _memset = Module["_memset"] = function() {
                return (_memset = Module["_memset"] = Module["asm"]["memset"]).apply(null, arguments)
            };
            var _exp = Module["_exp"] = function() {
                return (_exp = Module["_exp"] = Module["asm"]["exp"]).apply(null, arguments)
            };
            var _celt_fatal = Module["_celt_fatal"] = function() {
                return (_celt_fatal = Module["_celt_fatal"] = Module["asm"]["celt_fatal"]).apply(null, arguments)
            };
            var _anti_collapse = Module["_anti_collapse"] = function() {
                return (_anti_collapse = Module["_anti_collapse"] = Module["asm"]["anti_collapse"]).apply(null, arguments)
            };
            var _renormalise_vector = Module["_renormalise_vector"] = function() {
                return (_renormalise_vector = Module["_renormalise_vector"] = Module["asm"]["renormalise_vector"]).apply(null, arguments)
            };
            var _spreading_decision = Module["_spreading_decision"] = function() {
                return (_spreading_decision = Module["_spreading_decision"] = Module["asm"]["spreading_decision"]).apply(null, arguments)
            };
            var _haar1 = Module["_haar1"] = function() {
                return (_haar1 = Module["_haar1"] = Module["asm"]["haar1"]).apply(null, arguments)
            };
            var _quant_all_bands = Module["_quant_all_bands"] = function() {
                return (_quant_all_bands = Module["_quant_all_bands"] = Module["asm"]["quant_all_bands"]).apply(null, arguments)
            };
            var _ec_tell_frac = Module["_ec_tell_frac"] = function() {
                return (_ec_tell_frac = Module["_ec_tell_frac"] = Module["asm"]["ec_tell_frac"]).apply(null, arguments)
            };
            var _memcpy = Module["_memcpy"] = function() {
                return (_memcpy = Module["_memcpy"] = Module["asm"]["memcpy"]).apply(null, arguments)
            };
            var _ec_enc_bits = Module["_ec_enc_bits"] = function() {
                return (_ec_enc_bits = Module["_ec_enc_bits"] = Module["asm"]["ec_enc_bits"]).apply(null, arguments)
            };
            var _ec_dec_bits = Module["_ec_dec_bits"] = function() {
                return (_ec_dec_bits = Module["_ec_dec_bits"] = Module["asm"]["ec_dec_bits"]).apply(null, arguments)
            };
            var _alg_quant = Module["_alg_quant"] = function() {
                return (_alg_quant = Module["_alg_quant"] = Module["asm"]["alg_quant"]).apply(null, arguments)
            };
            var _alg_unquant = Module["_alg_unquant"] = function() {
                return (_alg_unquant = Module["_alg_unquant"] = Module["asm"]["alg_unquant"]).apply(null, arguments)
            };
            var _stereo_itheta = Module["_stereo_itheta"] = function() {
                return (_stereo_itheta = Module["_stereo_itheta"] = Module["asm"]["stereo_itheta"]).apply(null, arguments)
            };
            var _ec_encode = Module["_ec_encode"] = function() {
                return (_ec_encode = Module["_ec_encode"] = Module["asm"]["ec_encode"]).apply(null, arguments)
            };
            var _ec_decode = Module["_ec_decode"] = function() {
                return (_ec_decode = Module["_ec_decode"] = Module["asm"]["ec_decode"]).apply(null, arguments)
            };
            var _ec_dec_update = Module["_ec_dec_update"] = function() {
                return (_ec_dec_update = Module["_ec_dec_update"] = Module["asm"]["ec_dec_update"]).apply(null, arguments)
            };
            var _ec_dec_uint = Module["_ec_dec_uint"] = function() {
                return (_ec_dec_uint = Module["_ec_dec_uint"] = Module["asm"]["ec_dec_uint"]).apply(null, arguments)
            };
            var _isqrt32 = Module["_isqrt32"] = function() {
                return (_isqrt32 = Module["_isqrt32"] = Module["asm"]["isqrt32"]).apply(null, arguments)
            };
            var _ec_enc_bit_logp = Module["_ec_enc_bit_logp"] = function() {
                return (_ec_enc_bit_logp = Module["_ec_enc_bit_logp"] = Module["asm"]["ec_enc_bit_logp"]).apply(null, arguments)
            };
            var _ec_dec_bit_logp = Module["_ec_dec_bit_logp"] = function() {
                return (_ec_dec_bit_logp = Module["_ec_dec_bit_logp"] = Module["asm"]["ec_dec_bit_logp"]).apply(null, arguments)
            };
            var _ec_enc_uint = Module["_ec_enc_uint"] = function() {
                return (_ec_enc_uint = Module["_ec_enc_uint"] = Module["asm"]["ec_enc_uint"]).apply(null, arguments)
            };
            var _fiprintf = Module["_fiprintf"] = function() {
                return (_fiprintf = Module["_fiprintf"] = Module["asm"]["fiprintf"]).apply(null, arguments)
            };
            var _resampling_factor = Module["_resampling_factor"] = function() {
                return (_resampling_factor = Module["_resampling_factor"] = Module["asm"]["resampling_factor"]).apply(null, arguments)
            };
            var _comb_filter = Module["_comb_filter"] = function() {
                return (_comb_filter = Module["_comb_filter"] = Module["asm"]["comb_filter"]).apply(null, arguments)
            };
            var _memmove = Module["_memmove"] = function() {
                return (_memmove = Module["_memmove"] = Module["asm"]["memmove"]).apply(null, arguments)
            };
            var _init_caps = Module["_init_caps"] = function() {
                return (_init_caps = Module["_init_caps"] = Module["asm"]["init_caps"]).apply(null, arguments)
            };
            var _opus_strerror = Module["_opus_strerror"] = function() {
                return (_opus_strerror = Module["_opus_strerror"] = Module["asm"]["opus_strerror"]).apply(null, arguments)
            };
            var _opus_get_version_string = Module["_opus_get_version_string"] = function() {
                return (_opus_get_version_string = Module["_opus_get_version_string"] = Module["asm"]["opus_get_version_string"]).apply(null, arguments)
            };
            var _celt_encoder_get_size = Module["_celt_encoder_get_size"] = function() {
                return (_celt_encoder_get_size = Module["_celt_encoder_get_size"] = Module["asm"]["celt_encoder_get_size"]).apply(null, arguments)
            };
            var _opus_custom_mode_create = Module["_opus_custom_mode_create"] = function() {
                return (_opus_custom_mode_create = Module["_opus_custom_mode_create"] = Module["asm"]["opus_custom_mode_create"]).apply(null, arguments)
            };
            var _celt_encoder_init = Module["_celt_encoder_init"] = function() {
                return (_celt_encoder_init = Module["_celt_encoder_init"] = Module["asm"]["celt_encoder_init"]).apply(null, arguments)
            };
            var _opus_custom_encoder_ctl = Module["_opus_custom_encoder_ctl"] = function() {
                return (_opus_custom_encoder_ctl = Module["_opus_custom_encoder_ctl"] = Module["asm"]["opus_custom_encoder_ctl"]).apply(null, arguments)
            };
            var _celt_preemphasis = Module["_celt_preemphasis"] = function() {
                return (_celt_preemphasis = Module["_celt_preemphasis"] = Module["asm"]["celt_preemphasis"]).apply(null, arguments)
            };
            var _celt_encode_with_ec = Module["_celt_encode_with_ec"] = function() {
                return (_celt_encode_with_ec = Module["_celt_encode_with_ec"] = Module["asm"]["celt_encode_with_ec"]).apply(null, arguments)
            };
            var _ec_enc_init = Module["_ec_enc_init"] = function() {
                return (_ec_enc_init = Module["_ec_enc_init"] = Module["asm"]["ec_enc_init"]).apply(null, arguments)
            };
            var _ec_enc_shrink = Module["_ec_enc_shrink"] = function() {
                return (_ec_enc_shrink = Module["_ec_enc_shrink"] = Module["asm"]["ec_enc_shrink"]).apply(null, arguments)
            };
            var _ec_enc_icdf = Module["_ec_enc_icdf"] = function() {
                return (_ec_enc_icdf = Module["_ec_enc_icdf"] = Module["asm"]["ec_enc_icdf"]).apply(null, arguments)
            };
            var _amp2Log2 = Module["_amp2Log2"] = function() {
                return (_amp2Log2 = Module["_amp2Log2"] = Module["asm"]["amp2Log2"]).apply(null, arguments)
            };
            var _quant_coarse_energy = Module["_quant_coarse_energy"] = function() {
                return (_quant_coarse_energy = Module["_quant_coarse_energy"] = Module["asm"]["quant_coarse_energy"]).apply(null, arguments)
            };
            var _clt_compute_allocation = Module["_clt_compute_allocation"] = function() {
                return (_clt_compute_allocation = Module["_clt_compute_allocation"] = Module["asm"]["clt_compute_allocation"]).apply(null, arguments)
            };
            var _quant_fine_energy = Module["_quant_fine_energy"] = function() {
                return (_quant_fine_energy = Module["_quant_fine_energy"] = Module["asm"]["quant_fine_energy"]).apply(null, arguments)
            };
            var _quant_energy_finalise = Module["_quant_energy_finalise"] = function() {
                return (_quant_energy_finalise = Module["_quant_energy_finalise"] = Module["asm"]["quant_energy_finalise"]).apply(null, arguments)
            };
            var _ec_enc_done = Module["_ec_enc_done"] = function() {
                return (_ec_enc_done = Module["_ec_enc_done"] = Module["asm"]["ec_enc_done"]).apply(null, arguments)
            };
            var _pitch_downsample = Module["_pitch_downsample"] = function() {
                return (_pitch_downsample = Module["_pitch_downsample"] = Module["asm"]["pitch_downsample"]).apply(null, arguments)
            };
            var _pitch_search = Module["_pitch_search"] = function() {
                return (_pitch_search = Module["_pitch_search"] = Module["asm"]["pitch_search"]).apply(null, arguments)
            };
            var _remove_doubling = Module["_remove_doubling"] = function() {
                return (_remove_doubling = Module["_remove_doubling"] = Module["asm"]["remove_doubling"]).apply(null, arguments)
            };
            var _clt_mdct_forward_c = Module["_clt_mdct_forward_c"] = function() {
                return (_clt_mdct_forward_c = Module["_clt_mdct_forward_c"] = Module["asm"]["clt_mdct_forward_c"]).apply(null, arguments)
            };
            var _log = Module["_log"] = function() {
                return (_log = Module["_log"] = Module["asm"]["log"]).apply(null, arguments)
            };
            var _validate_celt_decoder = Module["_validate_celt_decoder"] = function() {
                return (_validate_celt_decoder = Module["_validate_celt_decoder"] = Module["asm"]["validate_celt_decoder"]).apply(null, arguments)
            };
            var _celt_decoder_get_size = Module["_celt_decoder_get_size"] = function() {
                return (_celt_decoder_get_size = Module["_celt_decoder_get_size"] = Module["asm"]["celt_decoder_get_size"]).apply(null, arguments)
            };
            var _celt_decoder_init = Module["_celt_decoder_init"] = function() {
                return (_celt_decoder_init = Module["_celt_decoder_init"] = Module["asm"]["celt_decoder_init"]).apply(null, arguments)
            };
            var _opus_custom_decoder_ctl = Module["_opus_custom_decoder_ctl"] = function() {
                return (_opus_custom_decoder_ctl = Module["_opus_custom_decoder_ctl"] = Module["asm"]["opus_custom_decoder_ctl"]).apply(null, arguments)
            };
            var _celt_decode_with_ec = Module["_celt_decode_with_ec"] = function() {
                return (_celt_decode_with_ec = Module["_celt_decode_with_ec"] = Module["asm"]["celt_decode_with_ec"]).apply(null, arguments)
            };
            var _ec_dec_init = Module["_ec_dec_init"] = function() {
                return (_ec_dec_init = Module["_ec_dec_init"] = Module["asm"]["ec_dec_init"]).apply(null, arguments)
            };
            var _ec_dec_icdf = Module["_ec_dec_icdf"] = function() {
                return (_ec_dec_icdf = Module["_ec_dec_icdf"] = Module["asm"]["ec_dec_icdf"]).apply(null, arguments)
            };
            var _unquant_coarse_energy = Module["_unquant_coarse_energy"] = function() {
                return (_unquant_coarse_energy = Module["_unquant_coarse_energy"] = Module["asm"]["unquant_coarse_energy"]).apply(null, arguments)
            };
            var _unquant_fine_energy = Module["_unquant_fine_energy"] = function() {
                return (_unquant_fine_energy = Module["_unquant_fine_energy"] = Module["asm"]["unquant_fine_energy"]).apply(null, arguments)
            };
            var _unquant_energy_finalise = Module["_unquant_energy_finalise"] = function() {
                return (_unquant_energy_finalise = Module["_unquant_energy_finalise"] = Module["asm"]["unquant_energy_finalise"]).apply(null, arguments)
            };
            var __celt_autocorr = Module["__celt_autocorr"] = function() {
                return (__celt_autocorr = Module["__celt_autocorr"] = Module["asm"]["_celt_autocorr"]).apply(null, arguments)
            };
            var __celt_lpc = Module["__celt_lpc"] = function() {
                return (__celt_lpc = Module["__celt_lpc"] = Module["asm"]["_celt_lpc"]).apply(null, arguments)
            };
            var _celt_fir_c = Module["_celt_fir_c"] = function() {
                return (_celt_fir_c = Module["_celt_fir_c"] = Module["asm"]["celt_fir_c"]).apply(null, arguments)
            };
            var _celt_iir = Module["_celt_iir"] = function() {
                return (_celt_iir = Module["_celt_iir"] = Module["asm"]["celt_iir"]).apply(null, arguments)
            };
            var _clt_mdct_backward_c = Module["_clt_mdct_backward_c"] = function() {
                return (_clt_mdct_backward_c = Module["_clt_mdct_backward_c"] = Module["asm"]["clt_mdct_backward_c"]).apply(null, arguments)
            };
            var _encode_pulses = Module["_encode_pulses"] = function() {
                return (_encode_pulses = Module["_encode_pulses"] = Module["asm"]["encode_pulses"]).apply(null, arguments)
            };
            var _decode_pulses = Module["_decode_pulses"] = function() {
                return (_decode_pulses = Module["_decode_pulses"] = Module["asm"]["decode_pulses"]).apply(null, arguments)
            };
            var _ec_decode_bin = Module["_ec_decode_bin"] = function() {
                return (_ec_decode_bin = Module["_ec_decode_bin"] = Module["asm"]["ec_decode_bin"]).apply(null, arguments)
            };
            var _ec_encode_bin = Module["_ec_encode_bin"] = function() {
                return (_ec_encode_bin = Module["_ec_encode_bin"] = Module["asm"]["ec_encode_bin"]).apply(null, arguments)
            };
            var _ec_enc_patch_initial_bits = Module["_ec_enc_patch_initial_bits"] = function() {
                return (_ec_enc_patch_initial_bits = Module["_ec_enc_patch_initial_bits"] = Module["asm"]["ec_enc_patch_initial_bits"]).apply(null, arguments)
            };
            var _opus_fft_impl = Module["_opus_fft_impl"] = function() {
                return (_opus_fft_impl = Module["_opus_fft_impl"] = Module["asm"]["opus_fft_impl"]).apply(null, arguments)
            };
            var _opus_fft_c = Module["_opus_fft_c"] = function() {
                return (_opus_fft_c = Module["_opus_fft_c"] = Module["asm"]["opus_fft_c"]).apply(null, arguments)
            };
            var _opus_ifft_c = Module["_opus_ifft_c"] = function() {
                return (_opus_ifft_c = Module["_opus_ifft_c"] = Module["asm"]["opus_ifft_c"]).apply(null, arguments)
            };
            var _ec_laplace_encode = Module["_ec_laplace_encode"] = function() {
                return (_ec_laplace_encode = Module["_ec_laplace_encode"] = Module["asm"]["ec_laplace_encode"]).apply(null, arguments)
            };
            var _ec_laplace_decode = Module["_ec_laplace_decode"] = function() {
                return (_ec_laplace_decode = Module["_ec_laplace_decode"] = Module["asm"]["ec_laplace_decode"]).apply(null, arguments)
            };
            var _celt_pitch_xcorr_c = Module["_celt_pitch_xcorr_c"] = function() {
                return (_celt_pitch_xcorr_c = Module["_celt_pitch_xcorr_c"] = Module["asm"]["celt_pitch_xcorr_c"]).apply(null, arguments)
            };
            var _exp_rotation = Module["_exp_rotation"] = function() {
                return (_exp_rotation = Module["_exp_rotation"] = Module["asm"]["exp_rotation"]).apply(null, arguments)
            };
            var _cos = Module["_cos"] = function() {
                return (_cos = Module["_cos"] = Module["asm"]["cos"]).apply(null, arguments)
            };
            var _op_pvq_search_c = Module["_op_pvq_search_c"] = function() {
                return (_op_pvq_search_c = Module["_op_pvq_search_c"] = Module["asm"]["op_pvq_search_c"]).apply(null, arguments)
            };
            var _silk_CNG_Reset = Module["_silk_CNG_Reset"] = function() {
                return (_silk_CNG_Reset = Module["_silk_CNG_Reset"] = Module["asm"]["silk_CNG_Reset"]).apply(null, arguments)
            };
            var _silk_CNG = Module["_silk_CNG"] = function() {
                return (_silk_CNG = Module["_silk_CNG"] = Module["asm"]["silk_CNG"]).apply(null, arguments)
            };
            var _silk_NLSF2A = Module["_silk_NLSF2A"] = function() {
                return (_silk_NLSF2A = Module["_silk_NLSF2A"] = Module["asm"]["silk_NLSF2A"]).apply(null, arguments)
            };
            var _silk_encode_signs = Module["_silk_encode_signs"] = function() {
                return (_silk_encode_signs = Module["_silk_encode_signs"] = Module["asm"]["silk_encode_signs"]).apply(null, arguments)
            };
            var _silk_decode_signs = Module["_silk_decode_signs"] = function() {
                return (_silk_decode_signs = Module["_silk_decode_signs"] = Module["asm"]["silk_decode_signs"]).apply(null, arguments)
            };
            var _silk_init_decoder = Module["_silk_init_decoder"] = function() {
                return (_silk_init_decoder = Module["_silk_init_decoder"] = Module["asm"]["silk_init_decoder"]).apply(null, arguments)
            };
            var _silk_PLC_Reset = Module["_silk_PLC_Reset"] = function() {
                return (_silk_PLC_Reset = Module["_silk_PLC_Reset"] = Module["asm"]["silk_PLC_Reset"]).apply(null, arguments)
            };
            var _silk_decode_core = Module["_silk_decode_core"] = function() {
                return (_silk_decode_core = Module["_silk_decode_core"] = Module["asm"]["silk_decode_core"]).apply(null, arguments)
            };
            var _silk_LPC_analysis_filter = Module["_silk_LPC_analysis_filter"] = function() {
                return (_silk_LPC_analysis_filter = Module["_silk_LPC_analysis_filter"] = Module["asm"]["silk_LPC_analysis_filter"]).apply(null, arguments)
            };
            var _silk_decode_frame = Module["_silk_decode_frame"] = function() {
                return (_silk_decode_frame = Module["_silk_decode_frame"] = Module["asm"]["silk_decode_frame"]).apply(null, arguments)
            };
            var _silk_decode_indices = Module["_silk_decode_indices"] = function() {
                return (_silk_decode_indices = Module["_silk_decode_indices"] = Module["asm"]["silk_decode_indices"]).apply(null, arguments)
            };
            var _silk_decode_pulses = Module["_silk_decode_pulses"] = function() {
                return (_silk_decode_pulses = Module["_silk_decode_pulses"] = Module["asm"]["silk_decode_pulses"]).apply(null, arguments)
            };
            var _silk_decode_parameters = Module["_silk_decode_parameters"] = function() {
                return (_silk_decode_parameters = Module["_silk_decode_parameters"] = Module["asm"]["silk_decode_parameters"]).apply(null, arguments)
            };
            var _silk_PLC = Module["_silk_PLC"] = function() {
                return (_silk_PLC = Module["_silk_PLC"] = Module["asm"]["silk_PLC"]).apply(null, arguments)
            };
            var _silk_PLC_glue_frames = Module["_silk_PLC_glue_frames"] = function() {
                return (_silk_PLC_glue_frames = Module["_silk_PLC_glue_frames"] = Module["asm"]["silk_PLC_glue_frames"]).apply(null, arguments)
            };
            var _silk_gains_dequant = Module["_silk_gains_dequant"] = function() {
                return (_silk_gains_dequant = Module["_silk_gains_dequant"] = Module["asm"]["silk_gains_dequant"]).apply(null, arguments)
            };
            var _silk_NLSF_decode = Module["_silk_NLSF_decode"] = function() {
                return (_silk_NLSF_decode = Module["_silk_NLSF_decode"] = Module["asm"]["silk_NLSF_decode"]).apply(null, arguments)
            };
            var _silk_bwexpander = Module["_silk_bwexpander"] = function() {
                return (_silk_bwexpander = Module["_silk_bwexpander"] = Module["asm"]["silk_bwexpander"]).apply(null, arguments)
            };
            var _silk_decode_pitch = Module["_silk_decode_pitch"] = function() {
                return (_silk_decode_pitch = Module["_silk_decode_pitch"] = Module["asm"]["silk_decode_pitch"]).apply(null, arguments)
            };
            var _silk_NLSF_unpack = Module["_silk_NLSF_unpack"] = function() {
                return (_silk_NLSF_unpack = Module["_silk_NLSF_unpack"] = Module["asm"]["silk_NLSF_unpack"]).apply(null, arguments)
            };
            var _silk_shell_decoder = Module["_silk_shell_decoder"] = function() {
                return (_silk_shell_decoder = Module["_silk_shell_decoder"] = Module["asm"]["silk_shell_decoder"]).apply(null, arguments)
            };
            var _silk_decoder_set_fs = Module["_silk_decoder_set_fs"] = function() {
                return (_silk_decoder_set_fs = Module["_silk_decoder_set_fs"] = Module["asm"]["silk_decoder_set_fs"]).apply(null, arguments)
            };
            var _silk_resampler_init = Module["_silk_resampler_init"] = function() {
                return (_silk_resampler_init = Module["_silk_resampler_init"] = Module["asm"]["silk_resampler_init"]).apply(null, arguments)
            };
            var _silk_Get_Decoder_Size = Module["_silk_Get_Decoder_Size"] = function() {
                return (_silk_Get_Decoder_Size = Module["_silk_Get_Decoder_Size"] = Module["asm"]["silk_Get_Decoder_Size"]).apply(null, arguments)
            };
            var _silk_InitDecoder = Module["_silk_InitDecoder"] = function() {
                return (_silk_InitDecoder = Module["_silk_InitDecoder"] = Module["asm"]["silk_InitDecoder"]).apply(null, arguments)
            };
            var _silk_Decode = Module["_silk_Decode"] = function() {
                return (_silk_Decode = Module["_silk_Decode"] = Module["asm"]["silk_Decode"]).apply(null, arguments)
            };
            var _silk_stereo_decode_pred = Module["_silk_stereo_decode_pred"] = function() {
                return (_silk_stereo_decode_pred = Module["_silk_stereo_decode_pred"] = Module["asm"]["silk_stereo_decode_pred"]).apply(null, arguments)
            };
            var _silk_stereo_decode_mid_only = Module["_silk_stereo_decode_mid_only"] = function() {
                return (_silk_stereo_decode_mid_only = Module["_silk_stereo_decode_mid_only"] = Module["asm"]["silk_stereo_decode_mid_only"]).apply(null, arguments)
            };
            var _silk_stereo_MS_to_LR = Module["_silk_stereo_MS_to_LR"] = function() {
                return (_silk_stereo_MS_to_LR = Module["_silk_stereo_MS_to_LR"] = Module["asm"]["silk_stereo_MS_to_LR"]).apply(null, arguments)
            };
            var _silk_resampler = Module["_silk_resampler"] = function() {
                return (_silk_resampler = Module["_silk_resampler"] = Module["asm"]["silk_resampler"]).apply(null, arguments)
            };
            var _silk_Get_Encoder_Size = Module["_silk_Get_Encoder_Size"] = function() {
                return (_silk_Get_Encoder_Size = Module["_silk_Get_Encoder_Size"] = Module["asm"]["silk_Get_Encoder_Size"]).apply(null, arguments)
            };
            var _silk_InitEncoder = Module["_silk_InitEncoder"] = function() {
                return (_silk_InitEncoder = Module["_silk_InitEncoder"] = Module["asm"]["silk_InitEncoder"]).apply(null, arguments)
            };
            var _silk_init_encoder = Module["_silk_init_encoder"] = function() {
                return (_silk_init_encoder = Module["_silk_init_encoder"] = Module["asm"]["silk_init_encoder"]).apply(null, arguments)
            };
            var _silk_Encode = Module["_silk_Encode"] = function() {
                return (_silk_Encode = Module["_silk_Encode"] = Module["asm"]["silk_Encode"]).apply(null, arguments)
            };
            var _check_control_input = Module["_check_control_input"] = function() {
                return (_check_control_input = Module["_check_control_input"] = Module["asm"]["check_control_input"]).apply(null, arguments)
            };
            var _silk_control_encoder = Module["_silk_control_encoder"] = function() {
                return (_silk_control_encoder = Module["_silk_control_encoder"] = Module["asm"]["silk_control_encoder"]).apply(null, arguments)
            };
            var _silk_stereo_encode_pred = Module["_silk_stereo_encode_pred"] = function() {
                return (_silk_stereo_encode_pred = Module["_silk_stereo_encode_pred"] = Module["asm"]["silk_stereo_encode_pred"]).apply(null, arguments)
            };
            var _silk_stereo_encode_mid_only = Module["_silk_stereo_encode_mid_only"] = function() {
                return (_silk_stereo_encode_mid_only = Module["_silk_stereo_encode_mid_only"] = Module["asm"]["silk_stereo_encode_mid_only"]).apply(null, arguments)
            };
            var _silk_encode_indices = Module["_silk_encode_indices"] = function() {
                return (_silk_encode_indices = Module["_silk_encode_indices"] = Module["asm"]["silk_encode_indices"]).apply(null, arguments)
            };
            var _silk_encode_pulses = Module["_silk_encode_pulses"] = function() {
                return (_silk_encode_pulses = Module["_silk_encode_pulses"] = Module["asm"]["silk_encode_pulses"]).apply(null, arguments)
            };
            var _silk_HP_variable_cutoff = Module["_silk_HP_variable_cutoff"] = function() {
                return (_silk_HP_variable_cutoff = Module["_silk_HP_variable_cutoff"] = Module["asm"]["silk_HP_variable_cutoff"]).apply(null, arguments)
            };
            var _silk_stereo_LR_to_MS = Module["_silk_stereo_LR_to_MS"] = function() {
                return (_silk_stereo_LR_to_MS = Module["_silk_stereo_LR_to_MS"] = Module["asm"]["silk_stereo_LR_to_MS"]).apply(null, arguments)
            };
            var _silk_encode_do_VAD_FLP = Module["_silk_encode_do_VAD_FLP"] = function() {
                return (_silk_encode_do_VAD_FLP = Module["_silk_encode_do_VAD_FLP"] = Module["asm"]["silk_encode_do_VAD_FLP"]).apply(null, arguments)
            };
            var _silk_control_SNR = Module["_silk_control_SNR"] = function() {
                return (_silk_control_SNR = Module["_silk_control_SNR"] = Module["asm"]["silk_control_SNR"]).apply(null, arguments)
            };
            var _silk_encode_frame_FLP = Module["_silk_encode_frame_FLP"] = function() {
                return (_silk_encode_frame_FLP = Module["_silk_encode_frame_FLP"] = Module["asm"]["silk_encode_frame_FLP"]).apply(null, arguments)
            };
            var _silk_shell_encoder = Module["_silk_shell_encoder"] = function() {
                return (_silk_shell_encoder = Module["_silk_shell_encoder"] = Module["asm"]["silk_shell_encoder"]).apply(null, arguments)
            };
            var _silk_gains_quant = Module["_silk_gains_quant"] = function() {
                return (_silk_gains_quant = Module["_silk_gains_quant"] = Module["asm"]["silk_gains_quant"]).apply(null, arguments)
            };
            var _silk_lin2log = Module["_silk_lin2log"] = function() {
                return (_silk_lin2log = Module["_silk_lin2log"] = Module["asm"]["silk_lin2log"]).apply(null, arguments)
            };
            var _silk_log2lin = Module["_silk_log2lin"] = function() {
                return (_silk_log2lin = Module["_silk_log2lin"] = Module["asm"]["silk_log2lin"]).apply(null, arguments)
            };
            var _silk_gains_ID = Module["_silk_gains_ID"] = function() {
                return (_silk_gains_ID = Module["_silk_gains_ID"] = Module["asm"]["silk_gains_ID"]).apply(null, arguments)
            };
            var _silk_interpolate = Module["_silk_interpolate"] = function() {
                return (_silk_interpolate = Module["_silk_interpolate"] = Module["asm"]["silk_interpolate"]).apply(null, arguments)
            };
            var _silk_LP_variable_cutoff = Module["_silk_LP_variable_cutoff"] = function() {
                return (_silk_LP_variable_cutoff = Module["_silk_LP_variable_cutoff"] = Module["asm"]["silk_LP_variable_cutoff"]).apply(null, arguments)
            };
            var _silk_biquad_alt_stride1 = Module["_silk_biquad_alt_stride1"] = function() {
                return (_silk_biquad_alt_stride1 = Module["_silk_biquad_alt_stride1"] = Module["asm"]["silk_biquad_alt_stride1"]).apply(null, arguments)
            };
            var _silk_NLSF_stabilize = Module["_silk_NLSF_stabilize"] = function() {
                return (_silk_NLSF_stabilize = Module["_silk_NLSF_stabilize"] = Module["asm"]["silk_NLSF_stabilize"]).apply(null, arguments)
            };
            var _silk_NSQ_c = Module["_silk_NSQ_c"] = function() {
                return (_silk_NSQ_c = Module["_silk_NSQ_c"] = Module["asm"]["silk_NSQ_c"]).apply(null, arguments)
            };
            var _silk_NSQ_del_dec_c = Module["_silk_NSQ_del_dec_c"] = function() {
                return (_silk_NSQ_del_dec_c = Module["_silk_NSQ_del_dec_c"] = Module["asm"]["silk_NSQ_del_dec_c"]).apply(null, arguments)
            };
            var _silk_LPC_inverse_pred_gain_c = Module["_silk_LPC_inverse_pred_gain_c"] = function() {
                return (_silk_LPC_inverse_pred_gain_c = Module["_silk_LPC_inverse_pred_gain_c"] = Module["asm"]["silk_LPC_inverse_pred_gain_c"]).apply(null, arguments)
            };
            var _silk_sum_sqr_shift = Module["_silk_sum_sqr_shift"] = function() {
                return (_silk_sum_sqr_shift = Module["_silk_sum_sqr_shift"] = Module["asm"]["silk_sum_sqr_shift"]).apply(null, arguments)
            };
            var _silk_VAD_Init = Module["_silk_VAD_Init"] = function() {
                return (_silk_VAD_Init = Module["_silk_VAD_Init"] = Module["asm"]["silk_VAD_Init"]).apply(null, arguments)
            };
            var _silk_VAD_GetSA_Q8_c = Module["_silk_VAD_GetSA_Q8_c"] = function() {
                return (_silk_VAD_GetSA_Q8_c = Module["_silk_VAD_GetSA_Q8_c"] = Module["asm"]["silk_VAD_GetSA_Q8_c"]).apply(null, arguments)
            };
            var _silk_ana_filt_bank_1 = Module["_silk_ana_filt_bank_1"] = function() {
                return (_silk_ana_filt_bank_1 = Module["_silk_ana_filt_bank_1"] = Module["asm"]["silk_ana_filt_bank_1"]).apply(null, arguments)
            };
            var _silk_sigm_Q15 = Module["_silk_sigm_Q15"] = function() {
                return (_silk_sigm_Q15 = Module["_silk_sigm_Q15"] = Module["asm"]["silk_sigm_Q15"]).apply(null, arguments)
            };
            var _silk_control_audio_bandwidth = Module["_silk_control_audio_bandwidth"] = function() {
                return (_silk_control_audio_bandwidth = Module["_silk_control_audio_bandwidth"] = Module["asm"]["silk_control_audio_bandwidth"]).apply(null, arguments)
            };
            var _silk_quant_LTP_gains = Module["_silk_quant_LTP_gains"] = function() {
                return (_silk_quant_LTP_gains = Module["_silk_quant_LTP_gains"] = Module["asm"]["silk_quant_LTP_gains"]).apply(null, arguments)
            };
            var _silk_VQ_WMat_EC_c = Module["_silk_VQ_WMat_EC_c"] = function() {
                return (_silk_VQ_WMat_EC_c = Module["_silk_VQ_WMat_EC_c"] = Module["asm"]["silk_VQ_WMat_EC_c"]).apply(null, arguments)
            };
            var _silk_NLSF_encode = Module["_silk_NLSF_encode"] = function() {
                return (_silk_NLSF_encode = Module["_silk_NLSF_encode"] = Module["asm"]["silk_NLSF_encode"]).apply(null, arguments)
            };
            var _silk_NLSF_VQ = Module["_silk_NLSF_VQ"] = function() {
                return (_silk_NLSF_VQ = Module["_silk_NLSF_VQ"] = Module["asm"]["silk_NLSF_VQ"]).apply(null, arguments)
            };
            var _silk_insertion_sort_increasing = Module["_silk_insertion_sort_increasing"] = function() {
                return (_silk_insertion_sort_increasing = Module["_silk_insertion_sort_increasing"] = Module["asm"]["silk_insertion_sort_increasing"]).apply(null, arguments)
            };
            var _silk_NLSF_del_dec_quant = Module["_silk_NLSF_del_dec_quant"] = function() {
                return (_silk_NLSF_del_dec_quant = Module["_silk_NLSF_del_dec_quant"] = Module["asm"]["silk_NLSF_del_dec_quant"]).apply(null, arguments)
            };
            var _silk_process_NLSFs = Module["_silk_process_NLSFs"] = function() {
                return (_silk_process_NLSFs = Module["_silk_process_NLSFs"] = Module["asm"]["silk_process_NLSFs"]).apply(null, arguments)
            };
            var _silk_NLSF_VQ_weights_laroia = Module["_silk_NLSF_VQ_weights_laroia"] = function() {
                return (_silk_NLSF_VQ_weights_laroia = Module["_silk_NLSF_VQ_weights_laroia"] = Module["asm"]["silk_NLSF_VQ_weights_laroia"]).apply(null, arguments)
            };
            var _silk_stereo_find_predictor = Module["_silk_stereo_find_predictor"] = function() {
                return (_silk_stereo_find_predictor = Module["_silk_stereo_find_predictor"] = Module["asm"]["silk_stereo_find_predictor"]).apply(null, arguments)
            };
            var _silk_stereo_quant_pred = Module["_silk_stereo_quant_pred"] = function() {
                return (_silk_stereo_quant_pred = Module["_silk_stereo_quant_pred"] = Module["asm"]["silk_stereo_quant_pred"]).apply(null, arguments)
            };
            var _lrintf = Module["_lrintf"] = function() {
                return (_lrintf = Module["_lrintf"] = Module["asm"]["lrintf"]).apply(null, arguments)
            };
            var _silk_A2NLSF = Module["_silk_A2NLSF"] = function() {
                return (_silk_A2NLSF = Module["_silk_A2NLSF"] = Module["asm"]["silk_A2NLSF"]).apply(null, arguments)
            };
            var _silk_bwexpander_32 = Module["_silk_bwexpander_32"] = function() {
                return (_silk_bwexpander_32 = Module["_silk_bwexpander_32"] = Module["asm"]["silk_bwexpander_32"]).apply(null, arguments)
            };
            var _silk_biquad_alt_stride2_c = Module["_silk_biquad_alt_stride2_c"] = function() {
                return (_silk_biquad_alt_stride2_c = Module["_silk_biquad_alt_stride2_c"] = Module["asm"]["silk_biquad_alt_stride2_c"]).apply(null, arguments)
            };
            var _silk_inner_prod_aligned_scale = Module["_silk_inner_prod_aligned_scale"] = function() {
                return (_silk_inner_prod_aligned_scale = Module["_silk_inner_prod_aligned_scale"] = Module["asm"]["silk_inner_prod_aligned_scale"]).apply(null, arguments)
            };
            var _silk_LPC_fit = Module["_silk_LPC_fit"] = function() {
                return (_silk_LPC_fit = Module["_silk_LPC_fit"] = Module["asm"]["silk_LPC_fit"]).apply(null, arguments)
            };
            var _silk_insertion_sort_increasing_all_values_int16 = Module["_silk_insertion_sort_increasing_all_values_int16"] = function() {
                return (_silk_insertion_sort_increasing_all_values_int16 = Module["_silk_insertion_sort_increasing_all_values_int16"] = Module["asm"]["silk_insertion_sort_increasing_all_values_int16"]).apply(null, arguments)
            };
            var _silk_resampler_private_up2_HQ_wrapper = Module["_silk_resampler_private_up2_HQ_wrapper"] = function() {
                return (_silk_resampler_private_up2_HQ_wrapper = Module["_silk_resampler_private_up2_HQ_wrapper"] = Module["asm"]["silk_resampler_private_up2_HQ_wrapper"]).apply(null, arguments)
            };
            var _silk_resampler_private_IIR_FIR = Module["_silk_resampler_private_IIR_FIR"] = function() {
                return (_silk_resampler_private_IIR_FIR = Module["_silk_resampler_private_IIR_FIR"] = Module["asm"]["silk_resampler_private_IIR_FIR"]).apply(null, arguments)
            };
            var _silk_resampler_private_down_FIR = Module["_silk_resampler_private_down_FIR"] = function() {
                return (_silk_resampler_private_down_FIR = Module["_silk_resampler_private_down_FIR"] = Module["asm"]["silk_resampler_private_down_FIR"]).apply(null, arguments)
            };
            var _silk_resampler_down2_3 = Module["_silk_resampler_down2_3"] = function() {
                return (_silk_resampler_down2_3 = Module["_silk_resampler_down2_3"] = Module["asm"]["silk_resampler_down2_3"]).apply(null, arguments)
            };
            var _silk_resampler_private_AR2 = Module["_silk_resampler_private_AR2"] = function() {
                return (_silk_resampler_private_AR2 = Module["_silk_resampler_private_AR2"] = Module["asm"]["silk_resampler_private_AR2"]).apply(null, arguments)
            };
            var _silk_resampler_down2 = Module["_silk_resampler_down2"] = function() {
                return (_silk_resampler_down2 = Module["_silk_resampler_down2"] = Module["asm"]["silk_resampler_down2"]).apply(null, arguments)
            };
            var _silk_resampler_private_up2_HQ = Module["_silk_resampler_private_up2_HQ"] = function() {
                return (_silk_resampler_private_up2_HQ = Module["_silk_resampler_private_up2_HQ"] = Module["asm"]["silk_resampler_private_up2_HQ"]).apply(null, arguments)
            };
            var _silk_apply_sine_window_FLP = Module["_silk_apply_sine_window_FLP"] = function() {
                return (_silk_apply_sine_window_FLP = Module["_silk_apply_sine_window_FLP"] = Module["asm"]["silk_apply_sine_window_FLP"]).apply(null, arguments)
            };
            var _silk_corrVector_FLP = Module["_silk_corrVector_FLP"] = function() {
                return (_silk_corrVector_FLP = Module["_silk_corrVector_FLP"] = Module["asm"]["silk_corrVector_FLP"]).apply(null, arguments)
            };
            var _silk_inner_product_FLP = Module["_silk_inner_product_FLP"] = function() {
                return (_silk_inner_product_FLP = Module["_silk_inner_product_FLP"] = Module["asm"]["silk_inner_product_FLP"]).apply(null, arguments)
            };
            var _silk_corrMatrix_FLP = Module["_silk_corrMatrix_FLP"] = function() {
                return (_silk_corrMatrix_FLP = Module["_silk_corrMatrix_FLP"] = Module["asm"]["silk_corrMatrix_FLP"]).apply(null, arguments)
            };
            var _silk_energy_FLP = Module["_silk_energy_FLP"] = function() {
                return (_silk_energy_FLP = Module["_silk_energy_FLP"] = Module["asm"]["silk_energy_FLP"]).apply(null, arguments)
            };
            var _silk_find_pitch_lags_FLP = Module["_silk_find_pitch_lags_FLP"] = function() {
                return (_silk_find_pitch_lags_FLP = Module["_silk_find_pitch_lags_FLP"] = Module["asm"]["silk_find_pitch_lags_FLP"]).apply(null, arguments)
            };
            var _silk_noise_shape_analysis_FLP = Module["_silk_noise_shape_analysis_FLP"] = function() {
                return (_silk_noise_shape_analysis_FLP = Module["_silk_noise_shape_analysis_FLP"] = Module["asm"]["silk_noise_shape_analysis_FLP"]).apply(null, arguments)
            };
            var _silk_find_pred_coefs_FLP = Module["_silk_find_pred_coefs_FLP"] = function() {
                return (_silk_find_pred_coefs_FLP = Module["_silk_find_pred_coefs_FLP"] = Module["asm"]["silk_find_pred_coefs_FLP"]).apply(null, arguments)
            };
            var _silk_process_gains_FLP = Module["_silk_process_gains_FLP"] = function() {
                return (_silk_process_gains_FLP = Module["_silk_process_gains_FLP"] = Module["asm"]["silk_process_gains_FLP"]).apply(null, arguments)
            };
            var _silk_NSQ_wrapper_FLP = Module["_silk_NSQ_wrapper_FLP"] = function() {
                return (_silk_NSQ_wrapper_FLP = Module["_silk_NSQ_wrapper_FLP"] = Module["asm"]["silk_NSQ_wrapper_FLP"]).apply(null, arguments)
            };
            var _silk_find_LPC_FLP = Module["_silk_find_LPC_FLP"] = function() {
                return (_silk_find_LPC_FLP = Module["_silk_find_LPC_FLP"] = Module["asm"]["silk_find_LPC_FLP"]).apply(null, arguments)
            };
            var _silk_burg_modified_FLP = Module["_silk_burg_modified_FLP"] = function() {
                return (_silk_burg_modified_FLP = Module["_silk_burg_modified_FLP"] = Module["asm"]["silk_burg_modified_FLP"]).apply(null, arguments)
            };
            var _silk_A2NLSF_FLP = Module["_silk_A2NLSF_FLP"] = function() {
                return (_silk_A2NLSF_FLP = Module["_silk_A2NLSF_FLP"] = Module["asm"]["silk_A2NLSF_FLP"]).apply(null, arguments)
            };
            var _silk_NLSF2A_FLP = Module["_silk_NLSF2A_FLP"] = function() {
                return (_silk_NLSF2A_FLP = Module["_silk_NLSF2A_FLP"] = Module["asm"]["silk_NLSF2A_FLP"]).apply(null, arguments)
            };
            var _silk_LPC_analysis_filter_FLP = Module["_silk_LPC_analysis_filter_FLP"] = function() {
                return (_silk_LPC_analysis_filter_FLP = Module["_silk_LPC_analysis_filter_FLP"] = Module["asm"]["silk_LPC_analysis_filter_FLP"]).apply(null, arguments)
            };
            var _silk_find_LTP_FLP = Module["_silk_find_LTP_FLP"] = function() {
                return (_silk_find_LTP_FLP = Module["_silk_find_LTP_FLP"] = Module["asm"]["silk_find_LTP_FLP"]).apply(null, arguments)
            };
            var _silk_scale_vector_FLP = Module["_silk_scale_vector_FLP"] = function() {
                return (_silk_scale_vector_FLP = Module["_silk_scale_vector_FLP"] = Module["asm"]["silk_scale_vector_FLP"]).apply(null, arguments)
            };
            var _silk_autocorrelation_FLP = Module["_silk_autocorrelation_FLP"] = function() {
                return (_silk_autocorrelation_FLP = Module["_silk_autocorrelation_FLP"] = Module["asm"]["silk_autocorrelation_FLP"]).apply(null, arguments)
            };
            var _silk_schur_FLP = Module["_silk_schur_FLP"] = function() {
                return (_silk_schur_FLP = Module["_silk_schur_FLP"] = Module["asm"]["silk_schur_FLP"]).apply(null, arguments)
            };
            var _silk_k2a_FLP = Module["_silk_k2a_FLP"] = function() {
                return (_silk_k2a_FLP = Module["_silk_k2a_FLP"] = Module["asm"]["silk_k2a_FLP"]).apply(null, arguments)
            };
            var _silk_bwexpander_FLP = Module["_silk_bwexpander_FLP"] = function() {
                return (_silk_bwexpander_FLP = Module["_silk_bwexpander_FLP"] = Module["asm"]["silk_bwexpander_FLP"]).apply(null, arguments)
            };
            var _silk_pitch_analysis_core_FLP = Module["_silk_pitch_analysis_core_FLP"] = function() {
                return (_silk_pitch_analysis_core_FLP = Module["_silk_pitch_analysis_core_FLP"] = Module["asm"]["silk_pitch_analysis_core_FLP"]).apply(null, arguments)
            };
            var _silk_quant_LTP_gains_FLP = Module["_silk_quant_LTP_gains_FLP"] = function() {
                return (_silk_quant_LTP_gains_FLP = Module["_silk_quant_LTP_gains_FLP"] = Module["asm"]["silk_quant_LTP_gains_FLP"]).apply(null, arguments)
            };
            var _silk_LTP_scale_ctrl_FLP = Module["_silk_LTP_scale_ctrl_FLP"] = function() {
                return (_silk_LTP_scale_ctrl_FLP = Module["_silk_LTP_scale_ctrl_FLP"] = Module["asm"]["silk_LTP_scale_ctrl_FLP"]).apply(null, arguments)
            };
            var _silk_LTP_analysis_filter_FLP = Module["_silk_LTP_analysis_filter_FLP"] = function() {
                return (_silk_LTP_analysis_filter_FLP = Module["_silk_LTP_analysis_filter_FLP"] = Module["asm"]["silk_LTP_analysis_filter_FLP"]).apply(null, arguments)
            };
            var _silk_scale_copy_vector_FLP = Module["_silk_scale_copy_vector_FLP"] = function() {
                return (_silk_scale_copy_vector_FLP = Module["_silk_scale_copy_vector_FLP"] = Module["asm"]["silk_scale_copy_vector_FLP"]).apply(null, arguments)
            };
            var _exp2 = Module["_exp2"] = function() {
                return (_exp2 = Module["_exp2"] = Module["asm"]["exp2"]).apply(null, arguments)
            };
            var _silk_process_NLSFs_FLP = Module["_silk_process_NLSFs_FLP"] = function() {
                return (_silk_process_NLSFs_FLP = Module["_silk_process_NLSFs_FLP"] = Module["asm"]["silk_process_NLSFs_FLP"]).apply(null, arguments)
            };
            var _silk_residual_energy_FLP = Module["_silk_residual_energy_FLP"] = function() {
                return (_silk_residual_energy_FLP = Module["_silk_residual_energy_FLP"] = Module["asm"]["silk_residual_energy_FLP"]).apply(null, arguments)
            };
            var _log10 = Module["_log10"] = function() {
                return (_log10 = Module["_log10"] = Module["asm"]["log10"]).apply(null, arguments)
            };
            var _silk_warped_autocorrelation_FLP = Module["_silk_warped_autocorrelation_FLP"] = function() {
                return (_silk_warped_autocorrelation_FLP = Module["_silk_warped_autocorrelation_FLP"] = Module["asm"]["silk_warped_autocorrelation_FLP"]).apply(null, arguments)
            };
            var _silk_regularize_correlations_FLP = Module["_silk_regularize_correlations_FLP"] = function() {
                return (_silk_regularize_correlations_FLP = Module["_silk_regularize_correlations_FLP"] = Module["asm"]["silk_regularize_correlations_FLP"]).apply(null, arguments)
            };
            var _silk_residual_energy_covar_FLP = Module["_silk_residual_energy_covar_FLP"] = function() {
                return (_silk_residual_energy_covar_FLP = Module["_silk_residual_energy_covar_FLP"] = Module["asm"]["silk_residual_energy_covar_FLP"]).apply(null, arguments)
            };
            var _silk_LPC_inverse_pred_gain_FLP = Module["_silk_LPC_inverse_pred_gain_FLP"] = function() {
                return (_silk_LPC_inverse_pred_gain_FLP = Module["_silk_LPC_inverse_pred_gain_FLP"] = Module["asm"]["silk_LPC_inverse_pred_gain_FLP"]).apply(null, arguments)
            };
            var _silk_insertion_sort_decreasing_FLP = Module["_silk_insertion_sort_decreasing_FLP"] = function() {
                return (_silk_insertion_sort_decreasing_FLP = Module["_silk_insertion_sort_decreasing_FLP"] = Module["asm"]["silk_insertion_sort_decreasing_FLP"]).apply(null, arguments)
            };
            var _opus_pcm_soft_clip = Module["_opus_pcm_soft_clip"] = function() {
                return (_opus_pcm_soft_clip = Module["_opus_pcm_soft_clip"] = Module["asm"]["opus_pcm_soft_clip"]).apply(null, arguments)
            };
            var _encode_size = Module["_encode_size"] = function() {
                return (_encode_size = Module["_encode_size"] = Module["asm"]["encode_size"]).apply(null, arguments)
            };
            var _opus_packet_get_samples_per_frame = Module["_opus_packet_get_samples_per_frame"] = function() {
                return (_opus_packet_get_samples_per_frame = Module["_opus_packet_get_samples_per_frame"] = Module["asm"]["opus_packet_get_samples_per_frame"]).apply(null, arguments)
            };
            var _opus_packet_parse_impl = Module["_opus_packet_parse_impl"] = function() {
                return (_opus_packet_parse_impl = Module["_opus_packet_parse_impl"] = Module["asm"]["opus_packet_parse_impl"]).apply(null, arguments)
            };
            var _opus_packet_parse = Module["_opus_packet_parse"] = function() {
                return (_opus_packet_parse = Module["_opus_packet_parse"] = Module["asm"]["opus_packet_parse"]).apply(null, arguments)
            };
            var _opus_decoder_get_size = Module["_opus_decoder_get_size"] = function() {
                return (_opus_decoder_get_size = Module["_opus_decoder_get_size"] = Module["asm"]["opus_decoder_get_size"]).apply(null, arguments)
            };
            var _opus_decoder_init = Module["_opus_decoder_init"] = function() {
                return (_opus_decoder_init = Module["_opus_decoder_init"] = Module["asm"]["opus_decoder_init"]).apply(null, arguments)
            };
            var _opus_decoder_create = Module["_opus_decoder_create"] = function() {
                return (_opus_decoder_create = Module["_opus_decoder_create"] = Module["asm"]["opus_decoder_create"]).apply(null, arguments)
            };
            var _malloc = Module["_malloc"] = function() {
                return (_malloc = Module["_malloc"] = Module["asm"]["malloc"]).apply(null, arguments)
            };
            var _free = Module["_free"] = function() {
                return (_free = Module["_free"] = Module["asm"]["free"]).apply(null, arguments)
            };
            var _opus_decode_native = Module["_opus_decode_native"] = function() {
                return (_opus_decode_native = Module["_opus_decode_native"] = Module["asm"]["opus_decode_native"]).apply(null, arguments)
            };
            var _opus_packet_get_bandwidth = Module["_opus_packet_get_bandwidth"] = function() {
                return (_opus_packet_get_bandwidth = Module["_opus_packet_get_bandwidth"] = Module["asm"]["opus_packet_get_bandwidth"]).apply(null, arguments)
            };
            var _opus_packet_get_nb_channels = Module["_opus_packet_get_nb_channels"] = function() {
                return (_opus_packet_get_nb_channels = Module["_opus_packet_get_nb_channels"] = Module["asm"]["opus_packet_get_nb_channels"]).apply(null, arguments)
            };
            var _opus_decode = Module["_opus_decode"] = function() {
                return (_opus_decode = Module["_opus_decode"] = Module["asm"]["opus_decode"]).apply(null, arguments)
            };
            var _opus_decoder_get_nb_samples = Module["_opus_decoder_get_nb_samples"] = function() {
                return (_opus_decoder_get_nb_samples = Module["_opus_decoder_get_nb_samples"] = Module["asm"]["opus_decoder_get_nb_samples"]).apply(null, arguments)
            };
            var _opus_decode_float = Module["_opus_decode_float"] = function() {
                return (_opus_decode_float = Module["_opus_decode_float"] = Module["asm"]["opus_decode_float"]).apply(null, arguments)
            };
            var _opus_decoder_ctl = Module["_opus_decoder_ctl"] = function() {
                return (_opus_decoder_ctl = Module["_opus_decoder_ctl"] = Module["asm"]["opus_decoder_ctl"]).apply(null, arguments)
            };
            var _opus_decoder_destroy = Module["_opus_decoder_destroy"] = function() {
                return (_opus_decoder_destroy = Module["_opus_decoder_destroy"] = Module["asm"]["opus_decoder_destroy"]).apply(null, arguments)
            };
            var _opus_packet_get_nb_frames = Module["_opus_packet_get_nb_frames"] = function() {
                return (_opus_packet_get_nb_frames = Module["_opus_packet_get_nb_frames"] = Module["asm"]["opus_packet_get_nb_frames"]).apply(null, arguments)
            };
            var _opus_packet_get_nb_samples = Module["_opus_packet_get_nb_samples"] = function() {
                return (_opus_packet_get_nb_samples = Module["_opus_packet_get_nb_samples"] = Module["asm"]["opus_packet_get_nb_samples"]).apply(null, arguments)
            };
            var _opus_encoder_get_size = Module["_opus_encoder_get_size"] = function() {
                return (_opus_encoder_get_size = Module["_opus_encoder_get_size"] = Module["asm"]["opus_encoder_get_size"]).apply(null, arguments)
            };
            var _opus_encoder_init = Module["_opus_encoder_init"] = function() {
                return (_opus_encoder_init = Module["_opus_encoder_init"] = Module["asm"]["opus_encoder_init"]).apply(null, arguments)
            };
            var _tonality_analysis_init = Module["_tonality_analysis_init"] = function() {
                return (_tonality_analysis_init = Module["_tonality_analysis_init"] = Module["asm"]["tonality_analysis_init"]).apply(null, arguments)
            };
            var _opus_encoder_create = Module["_opus_encoder_create"] = function() {
                return (_opus_encoder_create = Module["_opus_encoder_create"] = Module["asm"]["opus_encoder_create"]).apply(null, arguments)
            };
            var _downmix_float = Module["_downmix_float"] = function() {
                return (_downmix_float = Module["_downmix_float"] = Module["asm"]["downmix_float"]).apply(null, arguments)
            };
            var _downmix_int = Module["_downmix_int"] = function() {
                return (_downmix_int = Module["_downmix_int"] = Module["asm"]["downmix_int"]).apply(null, arguments)
            };
            var _frame_size_select = Module["_frame_size_select"] = function() {
                return (_frame_size_select = Module["_frame_size_select"] = Module["asm"]["frame_size_select"]).apply(null, arguments)
            };
            var _compute_stereo_width = Module["_compute_stereo_width"] = function() {
                return (_compute_stereo_width = Module["_compute_stereo_width"] = Module["asm"]["compute_stereo_width"]).apply(null, arguments)
            };
            var _is_digital_silence = Module["_is_digital_silence"] = function() {
                return (_is_digital_silence = Module["_is_digital_silence"] = Module["asm"]["is_digital_silence"]).apply(null, arguments)
            };
            var _opus_encode_native = Module["_opus_encode_native"] = function() {
                return (_opus_encode_native = Module["_opus_encode_native"] = Module["asm"]["opus_encode_native"]).apply(null, arguments)
            };
            var _run_analysis = Module["_run_analysis"] = function() {
                return (_run_analysis = Module["_run_analysis"] = Module["asm"]["run_analysis"]).apply(null, arguments)
            };
            var _tonality_analysis_reset = Module["_tonality_analysis_reset"] = function() {
                return (_tonality_analysis_reset = Module["_tonality_analysis_reset"] = Module["asm"]["tonality_analysis_reset"]).apply(null, arguments)
            };
            var _opus_packet_pad = Module["_opus_packet_pad"] = function() {
                return (_opus_packet_pad = Module["_opus_packet_pad"] = Module["asm"]["opus_packet_pad"]).apply(null, arguments)
            };
            var _opus_repacketizer_init = Module["_opus_repacketizer_init"] = function() {
                return (_opus_repacketizer_init = Module["_opus_repacketizer_init"] = Module["asm"]["opus_repacketizer_init"]).apply(null, arguments)
            };
            var _opus_repacketizer_cat = Module["_opus_repacketizer_cat"] = function() {
                return (_opus_repacketizer_cat = Module["_opus_repacketizer_cat"] = Module["asm"]["opus_repacketizer_cat"]).apply(null, arguments)
            };
            var _opus_repacketizer_out_range_impl = Module["_opus_repacketizer_out_range_impl"] = function() {
                return (_opus_repacketizer_out_range_impl = Module["_opus_repacketizer_out_range_impl"] = Module["asm"]["opus_repacketizer_out_range_impl"]).apply(null, arguments)
            };
            var _opus_encode = Module["_opus_encode"] = function() {
                return (_opus_encode = Module["_opus_encode"] = Module["asm"]["opus_encode"]).apply(null, arguments)
            };
            var _opus_encode_float = Module["_opus_encode_float"] = function() {
                return (_opus_encode_float = Module["_opus_encode_float"] = Module["asm"]["opus_encode_float"]).apply(null, arguments)
            };
            var _opus_encoder_ctl = Module["_opus_encoder_ctl"] = function() {
                return (_opus_encoder_ctl = Module["_opus_encoder_ctl"] = Module["asm"]["opus_encoder_ctl"]).apply(null, arguments)
            };
            var _opus_encoder_destroy = Module["_opus_encoder_destroy"] = function() {
                return (_opus_encoder_destroy = Module["_opus_encoder_destroy"] = Module["asm"]["opus_encoder_destroy"]).apply(null, arguments)
            };
            var _validate_layout = Module["_validate_layout"] = function() {
                return (_validate_layout = Module["_validate_layout"] = Module["asm"]["validate_layout"]).apply(null, arguments)
            };
            var _get_left_channel = Module["_get_left_channel"] = function() {
                return (_get_left_channel = Module["_get_left_channel"] = Module["asm"]["get_left_channel"]).apply(null, arguments)
            };
            var _get_right_channel = Module["_get_right_channel"] = function() {
                return (_get_right_channel = Module["_get_right_channel"] = Module["asm"]["get_right_channel"]).apply(null, arguments)
            };
            var _get_mono_channel = Module["_get_mono_channel"] = function() {
                return (_get_mono_channel = Module["_get_mono_channel"] = Module["asm"]["get_mono_channel"]).apply(null, arguments)
            };
            var _surround_analysis = Module["_surround_analysis"] = function() {
                return (_surround_analysis = Module["_surround_analysis"] = Module["asm"]["surround_analysis"]).apply(null, arguments)
            };
            var _opus_multistream_encoder_get_size = Module["_opus_multistream_encoder_get_size"] = function() {
                return (_opus_multistream_encoder_get_size = Module["_opus_multistream_encoder_get_size"] = Module["asm"]["opus_multistream_encoder_get_size"]).apply(null, arguments)
            };
            var _opus_multistream_surround_encoder_get_size = Module["_opus_multistream_surround_encoder_get_size"] = function() {
                return (_opus_multistream_surround_encoder_get_size = Module["_opus_multistream_surround_encoder_get_size"] = Module["asm"]["opus_multistream_surround_encoder_get_size"]).apply(null, arguments)
            };
            var _opus_multistream_encoder_init = Module["_opus_multistream_encoder_init"] = function() {
                return (_opus_multistream_encoder_init = Module["_opus_multistream_encoder_init"] = Module["asm"]["opus_multistream_encoder_init"]).apply(null, arguments)
            };
            var _opus_multistream_surround_encoder_init = Module["_opus_multistream_surround_encoder_init"] = function() {
                return (_opus_multistream_surround_encoder_init = Module["_opus_multistream_surround_encoder_init"] = Module["asm"]["opus_multistream_surround_encoder_init"]).apply(null, arguments)
            };
            var _opus_multistream_encoder_create = Module["_opus_multistream_encoder_create"] = function() {
                return (_opus_multistream_encoder_create = Module["_opus_multistream_encoder_create"] = Module["asm"]["opus_multistream_encoder_create"]).apply(null, arguments)
            };
            var _opus_multistream_surround_encoder_create = Module["_opus_multistream_surround_encoder_create"] = function() {
                return (_opus_multistream_surround_encoder_create = Module["_opus_multistream_surround_encoder_create"] = Module["asm"]["opus_multistream_surround_encoder_create"]).apply(null, arguments)
            };
            var _opus_multistream_encode_native = Module["_opus_multistream_encode_native"] = function() {
                return (_opus_multistream_encode_native = Module["_opus_multistream_encode_native"] = Module["asm"]["opus_multistream_encode_native"]).apply(null, arguments)
            };
            var _opus_repacketizer_get_nb_frames = Module["_opus_repacketizer_get_nb_frames"] = function() {
                return (_opus_repacketizer_get_nb_frames = Module["_opus_repacketizer_get_nb_frames"] = Module["asm"]["opus_repacketizer_get_nb_frames"]).apply(null, arguments)
            };
            var _opus_multistream_encode_float = Module["_opus_multistream_encode_float"] = function() {
                return (_opus_multistream_encode_float = Module["_opus_multistream_encode_float"] = Module["asm"]["opus_multistream_encode_float"]).apply(null, arguments)
            };
            var _opus_multistream_encode = Module["_opus_multistream_encode"] = function() {
                return (_opus_multistream_encode = Module["_opus_multistream_encode"] = Module["asm"]["opus_multistream_encode"]).apply(null, arguments)
            };
            var _opus_multistream_encoder_ctl_va_list = Module["_opus_multistream_encoder_ctl_va_list"] = function() {
                return (_opus_multistream_encoder_ctl_va_list = Module["_opus_multistream_encoder_ctl_va_list"] = Module["asm"]["opus_multistream_encoder_ctl_va_list"]).apply(null, arguments)
            };
            var _opus_multistream_encoder_ctl = Module["_opus_multistream_encoder_ctl"] = function() {
                return (_opus_multistream_encoder_ctl = Module["_opus_multistream_encoder_ctl"] = Module["asm"]["opus_multistream_encoder_ctl"]).apply(null, arguments)
            };
            var _opus_multistream_encoder_destroy = Module["_opus_multistream_encoder_destroy"] = function() {
                return (_opus_multistream_encoder_destroy = Module["_opus_multistream_encoder_destroy"] = Module["asm"]["opus_multistream_encoder_destroy"]).apply(null, arguments)
            };
            var _opus_multistream_decoder_get_size = Module["_opus_multistream_decoder_get_size"] = function() {
                return (_opus_multistream_decoder_get_size = Module["_opus_multistream_decoder_get_size"] = Module["asm"]["opus_multistream_decoder_get_size"]).apply(null, arguments)
            };
            var _opus_multistream_decoder_init = Module["_opus_multistream_decoder_init"] = function() {
                return (_opus_multistream_decoder_init = Module["_opus_multistream_decoder_init"] = Module["asm"]["opus_multistream_decoder_init"]).apply(null, arguments)
            };
            var _opus_multistream_decoder_create = Module["_opus_multistream_decoder_create"] = function() {
                return (_opus_multistream_decoder_create = Module["_opus_multistream_decoder_create"] = Module["asm"]["opus_multistream_decoder_create"]).apply(null, arguments)
            };
            var _opus_multistream_decode_native = Module["_opus_multistream_decode_native"] = function() {
                return (_opus_multistream_decode_native = Module["_opus_multistream_decode_native"] = Module["asm"]["opus_multistream_decode_native"]).apply(null, arguments)
            };
            var _opus_multistream_decoder_ctl = Module["_opus_multistream_decoder_ctl"] = function() {
                return (_opus_multistream_decoder_ctl = Module["_opus_multistream_decoder_ctl"] = Module["asm"]["opus_multistream_decoder_ctl"]).apply(null, arguments)
            };
            var _opus_multistream_decoder_ctl_va_list = Module["_opus_multistream_decoder_ctl_va_list"] = function() {
                return (_opus_multistream_decoder_ctl_va_list = Module["_opus_multistream_decoder_ctl_va_list"] = Module["asm"]["opus_multistream_decoder_ctl_va_list"]).apply(null, arguments)
            };
            var _opus_multistream_decode = Module["_opus_multistream_decode"] = function() {
                return (_opus_multistream_decode = Module["_opus_multistream_decode"] = Module["asm"]["opus_multistream_decode"]).apply(null, arguments)
            };
            var _opus_multistream_decode_float = Module["_opus_multistream_decode_float"] = function() {
                return (_opus_multistream_decode_float = Module["_opus_multistream_decode_float"] = Module["asm"]["opus_multistream_decode_float"]).apply(null, arguments)
            };
            var _opus_multistream_decoder_destroy = Module["_opus_multistream_decoder_destroy"] = function() {
                return (_opus_multistream_decoder_destroy = Module["_opus_multistream_decoder_destroy"] = Module["asm"]["opus_multistream_decoder_destroy"]).apply(null, arguments)
            };
            var _opus_repacketizer_get_size = Module["_opus_repacketizer_get_size"] = function() {
                return (_opus_repacketizer_get_size = Module["_opus_repacketizer_get_size"] = Module["asm"]["opus_repacketizer_get_size"]).apply(null, arguments)
            };
            var _opus_repacketizer_create = Module["_opus_repacketizer_create"] = function() {
                return (_opus_repacketizer_create = Module["_opus_repacketizer_create"] = Module["asm"]["opus_repacketizer_create"]).apply(null, arguments)
            };
            var _opus_repacketizer_destroy = Module["_opus_repacketizer_destroy"] = function() {
                return (_opus_repacketizer_destroy = Module["_opus_repacketizer_destroy"] = Module["asm"]["opus_repacketizer_destroy"]).apply(null, arguments)
            };
            var _opus_repacketizer_out_range = Module["_opus_repacketizer_out_range"] = function() {
                return (_opus_repacketizer_out_range = Module["_opus_repacketizer_out_range"] = Module["asm"]["opus_repacketizer_out_range"]).apply(null, arguments)
            };
            var _opus_repacketizer_out = Module["_opus_repacketizer_out"] = function() {
                return (_opus_repacketizer_out = Module["_opus_repacketizer_out"] = Module["asm"]["opus_repacketizer_out"]).apply(null, arguments)
            };
            var _opus_packet_unpad = Module["_opus_packet_unpad"] = function() {
                return (_opus_packet_unpad = Module["_opus_packet_unpad"] = Module["asm"]["opus_packet_unpad"]).apply(null, arguments)
            };
            var _opus_multistream_packet_pad = Module["_opus_multistream_packet_pad"] = function() {
                return (_opus_multistream_packet_pad = Module["_opus_multistream_packet_pad"] = Module["asm"]["opus_multistream_packet_pad"]).apply(null, arguments)
            };
            var _opus_multistream_packet_unpad = Module["_opus_multistream_packet_unpad"] = function() {
                return (_opus_multistream_packet_unpad = Module["_opus_multistream_packet_unpad"] = Module["asm"]["opus_multistream_packet_unpad"]).apply(null, arguments)
            };
            var _opus_projection_ambisonics_encoder_get_size = Module["_opus_projection_ambisonics_encoder_get_size"] = function() {
                return (_opus_projection_ambisonics_encoder_get_size = Module["_opus_projection_ambisonics_encoder_get_size"] = Module["asm"]["opus_projection_ambisonics_encoder_get_size"]).apply(null, arguments)
            };
            var _mapping_matrix_get_size = Module["_mapping_matrix_get_size"] = function() {
                return (_mapping_matrix_get_size = Module["_mapping_matrix_get_size"] = Module["asm"]["mapping_matrix_get_size"]).apply(null, arguments)
            };
            var _opus_projection_ambisonics_encoder_init = Module["_opus_projection_ambisonics_encoder_init"] = function() {
                return (_opus_projection_ambisonics_encoder_init = Module["_opus_projection_ambisonics_encoder_init"] = Module["asm"]["opus_projection_ambisonics_encoder_init"]).apply(null, arguments)
            };
            var _mapping_matrix_init = Module["_mapping_matrix_init"] = function() {
                return (_mapping_matrix_init = Module["_mapping_matrix_init"] = Module["asm"]["mapping_matrix_init"]).apply(null, arguments)
            };
            var _opus_projection_ambisonics_encoder_create = Module["_opus_projection_ambisonics_encoder_create"] = function() {
                return (_opus_projection_ambisonics_encoder_create = Module["_opus_projection_ambisonics_encoder_create"] = Module["asm"]["opus_projection_ambisonics_encoder_create"]).apply(null, arguments)
            };
            var _opus_projection_encode = Module["_opus_projection_encode"] = function() {
                return (_opus_projection_encode = Module["_opus_projection_encode"] = Module["asm"]["opus_projection_encode"]).apply(null, arguments)
            };
            var _mapping_matrix_multiply_channel_in_short = Module["_mapping_matrix_multiply_channel_in_short"] = function() {
                return (_mapping_matrix_multiply_channel_in_short = Module["_mapping_matrix_multiply_channel_in_short"] = Module["asm"]["mapping_matrix_multiply_channel_in_short"]).apply(null, arguments)
            };
            var _opus_projection_encode_float = Module["_opus_projection_encode_float"] = function() {
                return (_opus_projection_encode_float = Module["_opus_projection_encode_float"] = Module["asm"]["opus_projection_encode_float"]).apply(null, arguments)
            };
            var _mapping_matrix_multiply_channel_in_float = Module["_mapping_matrix_multiply_channel_in_float"] = function() {
                return (_mapping_matrix_multiply_channel_in_float = Module["_mapping_matrix_multiply_channel_in_float"] = Module["asm"]["mapping_matrix_multiply_channel_in_float"]).apply(null, arguments)
            };
            var _opus_projection_encoder_destroy = Module["_opus_projection_encoder_destroy"] = function() {
                return (_opus_projection_encoder_destroy = Module["_opus_projection_encoder_destroy"] = Module["asm"]["opus_projection_encoder_destroy"]).apply(null, arguments)
            };
            var _opus_projection_encoder_ctl = Module["_opus_projection_encoder_ctl"] = function() {
                return (_opus_projection_encoder_ctl = Module["_opus_projection_encoder_ctl"] = Module["asm"]["opus_projection_encoder_ctl"]).apply(null, arguments)
            };
            var _mapping_matrix_get_data = Module["_mapping_matrix_get_data"] = function() {
                return (_mapping_matrix_get_data = Module["_mapping_matrix_get_data"] = Module["asm"]["mapping_matrix_get_data"]).apply(null, arguments)
            };
            var _opus_projection_decoder_get_size = Module["_opus_projection_decoder_get_size"] = function() {
                return (_opus_projection_decoder_get_size = Module["_opus_projection_decoder_get_size"] = Module["asm"]["opus_projection_decoder_get_size"]).apply(null, arguments)
            };
            var _opus_projection_decoder_init = Module["_opus_projection_decoder_init"] = function() {
                return (_opus_projection_decoder_init = Module["_opus_projection_decoder_init"] = Module["asm"]["opus_projection_decoder_init"]).apply(null, arguments)
            };
            var _opus_projection_decoder_create = Module["_opus_projection_decoder_create"] = function() {
                return (_opus_projection_decoder_create = Module["_opus_projection_decoder_create"] = Module["asm"]["opus_projection_decoder_create"]).apply(null, arguments)
            };
            var _opus_projection_decode = Module["_opus_projection_decode"] = function() {
                return (_opus_projection_decode = Module["_opus_projection_decode"] = Module["asm"]["opus_projection_decode"]).apply(null, arguments)
            };
            var _mapping_matrix_multiply_channel_out_short = Module["_mapping_matrix_multiply_channel_out_short"] = function() {
                return (_mapping_matrix_multiply_channel_out_short = Module["_mapping_matrix_multiply_channel_out_short"] = Module["asm"]["mapping_matrix_multiply_channel_out_short"]).apply(null, arguments)
            };
            var _opus_projection_decode_float = Module["_opus_projection_decode_float"] = function() {
                return (_opus_projection_decode_float = Module["_opus_projection_decode_float"] = Module["asm"]["opus_projection_decode_float"]).apply(null, arguments)
            };
            var _mapping_matrix_multiply_channel_out_float = Module["_mapping_matrix_multiply_channel_out_float"] = function() {
                return (_mapping_matrix_multiply_channel_out_float = Module["_mapping_matrix_multiply_channel_out_float"] = Module["asm"]["mapping_matrix_multiply_channel_out_float"]).apply(null, arguments)
            };
            var _opus_projection_decoder_ctl = Module["_opus_projection_decoder_ctl"] = function() {
                return (_opus_projection_decoder_ctl = Module["_opus_projection_decoder_ctl"] = Module["asm"]["opus_projection_decoder_ctl"]).apply(null, arguments)
            };
            var _opus_projection_decoder_destroy = Module["_opus_projection_decoder_destroy"] = function() {
                return (_opus_projection_decoder_destroy = Module["_opus_projection_decoder_destroy"] = Module["asm"]["opus_projection_decoder_destroy"]).apply(null, arguments)
            };
            var _tonality_get_info = Module["_tonality_get_info"] = function() {
                return (_tonality_get_info = Module["_tonality_get_info"] = Module["asm"]["tonality_get_info"]).apply(null, arguments)
            };
            var _compute_dense = Module["_compute_dense"] = function() {
                return (_compute_dense = Module["_compute_dense"] = Module["asm"]["compute_dense"]).apply(null, arguments)
            };
            var _compute_gru = Module["_compute_gru"] = function() {
                return (_compute_gru = Module["_compute_gru"] = Module["asm"]["compute_gru"]).apply(null, arguments)
            };
            var _emscripten_GetProcAddress = Module["_emscripten_GetProcAddress"] = function() {
                return (_emscripten_GetProcAddress = Module["_emscripten_GetProcAddress"] = Module["asm"]["emscripten_GetProcAddress"]).apply(null, arguments)
            };
            var _strlen = Module["_strlen"] = function() {
                return (_strlen = Module["_strlen"] = Module["asm"]["strlen"]).apply(null, arguments)
            };
            var _strcpy = Module["_strcpy"] = function() {
                return (_strcpy = Module["_strcpy"] = Module["asm"]["strcpy"]).apply(null, arguments)
            };
            var _strstr = Module["_strstr"] = function() {
                return (_strstr = Module["_strstr"] = Module["asm"]["strstr"]).apply(null, arguments)
            };
            var _emscripten_webgl1_get_proc_address = Module["_emscripten_webgl1_get_proc_address"] = function() {
                return (_emscripten_webgl1_get_proc_address = Module["_emscripten_webgl1_get_proc_address"] = Module["asm"]["emscripten_webgl1_get_proc_address"]).apply(null, arguments)
            };
            var __webgl1_match_ext_proc_address_without_suffix = Module["__webgl1_match_ext_proc_address_without_suffix"] = function() {
                return (__webgl1_match_ext_proc_address_without_suffix = Module["__webgl1_match_ext_proc_address_without_suffix"] = Module["asm"]["_webgl1_match_ext_proc_address_without_suffix"]).apply(null, arguments)
            };
            var _emscripten_webgl_get_proc_address = Module["_emscripten_webgl_get_proc_address"] = function() {
                return (_emscripten_webgl_get_proc_address = Module["_emscripten_webgl_get_proc_address"] = Module["asm"]["emscripten_webgl_get_proc_address"]).apply(null, arguments)
            };
            var _strcmp = Module["_strcmp"] = function() {
                return (_strcmp = Module["_strcmp"] = Module["asm"]["strcmp"]).apply(null, arguments)
            };
            var _SDL_GL_GetProcAddress = Module["_SDL_GL_GetProcAddress"] = function() {
                return (_SDL_GL_GetProcAddress = Module["_SDL_GL_GetProcAddress"] = Module["asm"]["SDL_GL_GetProcAddress"]).apply(null, arguments)
            };
            var _eglGetProcAddress = Module["_eglGetProcAddress"] = function() {
                return (_eglGetProcAddress = Module["_eglGetProcAddress"] = Module["asm"]["eglGetProcAddress"]).apply(null, arguments)
            };
            var _glfwGetProcAddress = Module["_glfwGetProcAddress"] = function() {
                return (_glfwGetProcAddress = Module["_glfwGetProcAddress"] = Module["asm"]["glfwGetProcAddress"]).apply(null, arguments)
            };
            var _alcGetProcAddress = Module["_alcGetProcAddress"] = function() {
                return (_alcGetProcAddress = Module["_alcGetProcAddress"] = Module["asm"]["alcGetProcAddress"]).apply(null, arguments)
            };
            var _alGetProcAddress = Module["_alGetProcAddress"] = function() {
                return (_alGetProcAddress = Module["_alGetProcAddress"] = Module["asm"]["alGetProcAddress"]).apply(null, arguments)
            };
            var _emscripten_dom_vk_to_string = Module["_emscripten_dom_vk_to_string"] = function() {
                return (_emscripten_dom_vk_to_string = Module["_emscripten_dom_vk_to_string"] = Module["asm"]["emscripten_dom_vk_to_string"]).apply(null, arguments)
            };
            var _emscripten_compute_dom_pk_code = Module["_emscripten_compute_dom_pk_code"] = function() {
                return (_emscripten_compute_dom_pk_code = Module["_emscripten_compute_dom_pk_code"] = Module["asm"]["emscripten_compute_dom_pk_code"]).apply(null, arguments)
            };
            var _emscripten_dom_pk_code_to_string = Module["_emscripten_dom_pk_code_to_string"] = function() {
                return (_emscripten_dom_pk_code_to_string = Module["_emscripten_dom_pk_code_to_string"] = Module["asm"]["emscripten_dom_pk_code_to_string"]).apply(null, arguments)
            };
            var ___pthread_self = Module["___pthread_self"] = function() {
                return (___pthread_self = Module["___pthread_self"] = Module["asm"]["__pthread_self"]).apply(null, arguments)
            };
            var _pthread_self = Module["_pthread_self"] = function() {
                return (_pthread_self = Module["_pthread_self"] = Module["asm"]["pthread_self"]).apply(null, arguments)
            };
            var _thrd_current = Module["_thrd_current"] = function() {
                return (_thrd_current = Module["_thrd_current"] = Module["asm"]["thrd_current"]).apply(null, arguments)
            };
            var _thrd_create = Module["_thrd_create"] = function() {
                return (_thrd_create = Module["_thrd_create"] = Module["asm"]["thrd_create"]).apply(null, arguments)
            };
            var _thrd_exit = Module["_thrd_exit"] = function() {
                return (_thrd_exit = Module["_thrd_exit"] = Module["asm"]["thrd_exit"]).apply(null, arguments)
            };
            var _pthread_exit = Module["_pthread_exit"] = function() {
                return (_pthread_exit = Module["_pthread_exit"] = Module["asm"]["pthread_exit"]).apply(null, arguments)
            };
            var _thrd_join = Module["_thrd_join"] = function() {
                return (_thrd_join = Module["_thrd_join"] = Module["asm"]["thrd_join"]).apply(null, arguments)
            };
            var _thrd_sleep = Module["_thrd_sleep"] = function() {
                return (_thrd_sleep = Module["_thrd_sleep"] = Module["asm"]["thrd_sleep"]).apply(null, arguments)
            };
            var _nanosleep = Module["_nanosleep"] = function() {
                return (_nanosleep = Module["_nanosleep"] = Module["asm"]["nanosleep"]).apply(null, arguments)
            };
            var _thrd_yield = Module["_thrd_yield"] = function() {
                return (_thrd_yield = Module["_thrd_yield"] = Module["asm"]["thrd_yield"]).apply(null, arguments)
            };
            var _call_once = Module["_call_once"] = function() {
                return (_call_once = Module["_call_once"] = Module["asm"]["call_once"]).apply(null, arguments)
            };
            var ___pthread_once = Module["___pthread_once"] = function() {
                return (___pthread_once = Module["___pthread_once"] = Module["asm"]["__pthread_once"]).apply(null, arguments)
            };
            var _tss_create = Module["_tss_create"] = function() {
                return (_tss_create = Module["_tss_create"] = Module["asm"]["tss_create"]).apply(null, arguments)
            };
            var ___pthread_key_create = Module["___pthread_key_create"] = function() {
                return (___pthread_key_create = Module["___pthread_key_create"] = Module["asm"]["__pthread_key_create"]).apply(null, arguments)
            };
            var _tss_delete = Module["_tss_delete"] = function() {
                return (_tss_delete = Module["_tss_delete"] = Module["asm"]["tss_delete"]).apply(null, arguments)
            };
            var ___pthread_key_delete = Module["___pthread_key_delete"] = function() {
                return (___pthread_key_delete = Module["___pthread_key_delete"] = Module["asm"]["__pthread_key_delete"]).apply(null, arguments)
            };
            var _tss_set = Module["_tss_set"] = function() {
                return (_tss_set = Module["_tss_set"] = Module["asm"]["tss_set"]).apply(null, arguments)
            };
            var _emscripten_has_threading_support = Module["_emscripten_has_threading_support"] = function() {
                return (_emscripten_has_threading_support = Module["_emscripten_has_threading_support"] = Module["asm"]["emscripten_has_threading_support"]).apply(null, arguments)
            };
            var _emscripten_num_logical_cores = Module["_emscripten_num_logical_cores"] = function() {
                return (_emscripten_num_logical_cores = Module["_emscripten_num_logical_cores"] = Module["asm"]["emscripten_num_logical_cores"]).apply(null, arguments)
            };
            var _emscripten_force_num_logical_cores = Module["_emscripten_force_num_logical_cores"] = function() {
                return (_emscripten_force_num_logical_cores = Module["_emscripten_force_num_logical_cores"] = Module["asm"]["emscripten_force_num_logical_cores"]).apply(null, arguments)
            };
            var _emscripten_futex_wait = Module["_emscripten_futex_wait"] = function() {
                return (_emscripten_futex_wait = Module["_emscripten_futex_wait"] = Module["asm"]["emscripten_futex_wait"]).apply(null, arguments)
            };
            var _emscripten_futex_wake = Module["_emscripten_futex_wake"] = function() {
                return (_emscripten_futex_wake = Module["_emscripten_futex_wake"] = Module["asm"]["emscripten_futex_wake"]).apply(null, arguments)
            };
            var _emscripten_is_main_runtime_thread = Module["_emscripten_is_main_runtime_thread"] = function() {
                return (_emscripten_is_main_runtime_thread = Module["_emscripten_is_main_runtime_thread"] = Module["asm"]["emscripten_is_main_runtime_thread"]).apply(null, arguments)
            };
            var _emscripten_main_thread_process_queued_calls = Module["_emscripten_main_thread_process_queued_calls"] = function() {
                return (_emscripten_main_thread_process_queued_calls = Module["_emscripten_main_thread_process_queued_calls"] = Module["asm"]["emscripten_main_thread_process_queued_calls"]).apply(null, arguments)
            };
            var _emscripten_current_thread_process_queued_calls = Module["_emscripten_current_thread_process_queued_calls"] = function() {
                return (_emscripten_current_thread_process_queued_calls = Module["_emscripten_current_thread_process_queued_calls"] = Module["asm"]["emscripten_current_thread_process_queued_calls"]).apply(null, arguments)
            };
            var _pthread_mutex_init = Module["_pthread_mutex_init"] = function() {
                return (_pthread_mutex_init = Module["_pthread_mutex_init"] = Module["asm"]["pthread_mutex_init"]).apply(null, arguments)
            };
            var _pthread_mutex_lock = Module["_pthread_mutex_lock"] = function() {
                return (_pthread_mutex_lock = Module["_pthread_mutex_lock"] = Module["asm"]["pthread_mutex_lock"]).apply(null, arguments)
            };
            var _pthread_mutex_unlock = Module["_pthread_mutex_unlock"] = function() {
                return (_pthread_mutex_unlock = Module["_pthread_mutex_unlock"] = Module["asm"]["pthread_mutex_unlock"]).apply(null, arguments)
            };
            var _pthread_mutex_trylock = Module["_pthread_mutex_trylock"] = function() {
                return (_pthread_mutex_trylock = Module["_pthread_mutex_trylock"] = Module["asm"]["pthread_mutex_trylock"]).apply(null, arguments)
            };
            var _pthread_mutex_timedlock = Module["_pthread_mutex_timedlock"] = function() {
                return (_pthread_mutex_timedlock = Module["_pthread_mutex_timedlock"] = Module["asm"]["pthread_mutex_timedlock"]).apply(null, arguments)
            };
            var _pthread_mutex_destroy = Module["_pthread_mutex_destroy"] = function() {
                return (_pthread_mutex_destroy = Module["_pthread_mutex_destroy"] = Module["asm"]["pthread_mutex_destroy"]).apply(null, arguments)
            };
            var _pthread_mutex_consistent = Module["_pthread_mutex_consistent"] = function() {
                return (_pthread_mutex_consistent = Module["_pthread_mutex_consistent"] = Module["asm"]["pthread_mutex_consistent"]).apply(null, arguments)
            };
            var _pthread_barrier_init = Module["_pthread_barrier_init"] = function() {
                return (_pthread_barrier_init = Module["_pthread_barrier_init"] = Module["asm"]["pthread_barrier_init"]).apply(null, arguments)
            };
            var _pthread_barrier_destroy = Module["_pthread_barrier_destroy"] = function() {
                return (_pthread_barrier_destroy = Module["_pthread_barrier_destroy"] = Module["asm"]["pthread_barrier_destroy"]).apply(null, arguments)
            };
            var _pthread_barrier_wait = Module["_pthread_barrier_wait"] = function() {
                return (_pthread_barrier_wait = Module["_pthread_barrier_wait"] = Module["asm"]["pthread_barrier_wait"]).apply(null, arguments)
            };
            var _realloc = Module["_realloc"] = function() {
                return (_realloc = Module["_realloc"] = Module["asm"]["realloc"]).apply(null, arguments)
            };
            var _pthread_getspecific = Module["_pthread_getspecific"] = function() {
                return (_pthread_getspecific = Module["_pthread_getspecific"] = Module["asm"]["pthread_getspecific"]).apply(null, arguments)
            };
            var _pthread_setspecific = Module["_pthread_setspecific"] = function() {
                return (_pthread_setspecific = Module["_pthread_setspecific"] = Module["asm"]["pthread_setspecific"]).apply(null, arguments)
            };
            var _pthread_cond_wait = Module["_pthread_cond_wait"] = function() {
                return (_pthread_cond_wait = Module["_pthread_cond_wait"] = Module["asm"]["pthread_cond_wait"]).apply(null, arguments)
            };
            var _pthread_cond_signal = Module["_pthread_cond_signal"] = function() {
                return (_pthread_cond_signal = Module["_pthread_cond_signal"] = Module["asm"]["pthread_cond_signal"]).apply(null, arguments)
            };
            var _pthread_cond_broadcast = Module["_pthread_cond_broadcast"] = function() {
                return (_pthread_cond_broadcast = Module["_pthread_cond_broadcast"] = Module["asm"]["pthread_cond_broadcast"]).apply(null, arguments)
            };
            var _pthread_cond_init = Module["_pthread_cond_init"] = function() {
                return (_pthread_cond_init = Module["_pthread_cond_init"] = Module["asm"]["pthread_cond_init"]).apply(null, arguments)
            };
            var _pthread_cond_destroy = Module["_pthread_cond_destroy"] = function() {
                return (_pthread_cond_destroy = Module["_pthread_cond_destroy"] = Module["asm"]["pthread_cond_destroy"]).apply(null, arguments)
            };
            var _pthread_cond_timedwait = Module["_pthread_cond_timedwait"] = function() {
                return (_pthread_cond_timedwait = Module["_pthread_cond_timedwait"] = Module["asm"]["pthread_cond_timedwait"]).apply(null, arguments)
            };
            var _pthread_atfork = Module["_pthread_atfork"] = function() {
                return (_pthread_atfork = Module["_pthread_atfork"] = Module["asm"]["pthread_atfork"]).apply(null, arguments)
            };
            var _pthread_cancel = Module["_pthread_cancel"] = function() {
                return (_pthread_cancel = Module["_pthread_cancel"] = Module["asm"]["pthread_cancel"]).apply(null, arguments)
            };
            var _pthread_detach = Module["_pthread_detach"] = function() {
                return (_pthread_detach = Module["_pthread_detach"] = Module["asm"]["pthread_detach"]).apply(null, arguments)
            };
            var _emscripten_main_browser_thread_id = Module["_emscripten_main_browser_thread_id"] = function() {
                return (_emscripten_main_browser_thread_id = Module["_emscripten_main_browser_thread_id"] = Module["asm"]["emscripten_main_browser_thread_id"]).apply(null, arguments)
            };
            var _pthread_equal = Module["_pthread_equal"] = function() {
                return (_pthread_equal = Module["_pthread_equal"] = Module["asm"]["pthread_equal"]).apply(null, arguments)
            };
            var _pthread_mutexattr_init = Module["_pthread_mutexattr_init"] = function() {
                return (_pthread_mutexattr_init = Module["_pthread_mutexattr_init"] = Module["asm"]["pthread_mutexattr_init"]).apply(null, arguments)
            };
            var _pthread_mutexattr_setprotocol = Module["_pthread_mutexattr_setprotocol"] = function() {
                return (_pthread_mutexattr_setprotocol = Module["_pthread_mutexattr_setprotocol"] = Module["asm"]["pthread_mutexattr_setprotocol"]).apply(null, arguments)
            };
            var _pthread_mutexattr_settype = Module["_pthread_mutexattr_settype"] = function() {
                return (_pthread_mutexattr_settype = Module["_pthread_mutexattr_settype"] = Module["asm"]["pthread_mutexattr_settype"]).apply(null, arguments)
            };
            var _pthread_mutexattr_destroy = Module["_pthread_mutexattr_destroy"] = function() {
                return (_pthread_mutexattr_destroy = Module["_pthread_mutexattr_destroy"] = Module["asm"]["pthread_mutexattr_destroy"]).apply(null, arguments)
            };
            var _pthread_mutexattr_setpshared = Module["_pthread_mutexattr_setpshared"] = function() {
                return (_pthread_mutexattr_setpshared = Module["_pthread_mutexattr_setpshared"] = Module["asm"]["pthread_mutexattr_setpshared"]).apply(null, arguments)
            };
            var _pthread_condattr_init = Module["_pthread_condattr_init"] = function() {
                return (_pthread_condattr_init = Module["_pthread_condattr_init"] = Module["asm"]["pthread_condattr_init"]).apply(null, arguments)
            };
            var _pthread_condattr_destroy = Module["_pthread_condattr_destroy"] = function() {
                return (_pthread_condattr_destroy = Module["_pthread_condattr_destroy"] = Module["asm"]["pthread_condattr_destroy"]).apply(null, arguments)
            };
            var _pthread_condattr_setclock = Module["_pthread_condattr_setclock"] = function() {
                return (_pthread_condattr_setclock = Module["_pthread_condattr_setclock"] = Module["asm"]["pthread_condattr_setclock"]).apply(null, arguments)
            };
            var _pthread_condattr_setpshared = Module["_pthread_condattr_setpshared"] = function() {
                return (_pthread_condattr_setpshared = Module["_pthread_condattr_setpshared"] = Module["asm"]["pthread_condattr_setpshared"]).apply(null, arguments)
            };
            var _pthread_condattr_getclock = Module["_pthread_condattr_getclock"] = function() {
                return (_pthread_condattr_getclock = Module["_pthread_condattr_getclock"] = Module["asm"]["pthread_condattr_getclock"]).apply(null, arguments)
            };
            var _pthread_condattr_getpshared = Module["_pthread_condattr_getpshared"] = function() {
                return (_pthread_condattr_getpshared = Module["_pthread_condattr_getpshared"] = Module["asm"]["pthread_condattr_getpshared"]).apply(null, arguments)
            };
            var _pthread_attr_init = Module["_pthread_attr_init"] = function() {
                return (_pthread_attr_init = Module["_pthread_attr_init"] = Module["asm"]["pthread_attr_init"]).apply(null, arguments)
            };
            var _pthread_getattr_np = Module["_pthread_getattr_np"] = function() {
                return (_pthread_getattr_np = Module["_pthread_getattr_np"] = Module["asm"]["pthread_getattr_np"]).apply(null, arguments)
            };
            var _pthread_attr_destroy = Module["_pthread_attr_destroy"] = function() {
                return (_pthread_attr_destroy = Module["_pthread_attr_destroy"] = Module["asm"]["pthread_attr_destroy"]).apply(null, arguments)
            };
            var _pthread_attr_getdetachstate = Module["_pthread_attr_getdetachstate"] = function() {
                return (_pthread_attr_getdetachstate = Module["_pthread_attr_getdetachstate"] = Module["asm"]["pthread_attr_getdetachstate"]).apply(null, arguments)
            };
            var _pthread_attr_getstack = Module["_pthread_attr_getstack"] = function() {
                return (_pthread_attr_getstack = Module["_pthread_attr_getstack"] = Module["asm"]["pthread_attr_getstack"]).apply(null, arguments)
            };
            var _emscripten_stack_get_base = Module["_emscripten_stack_get_base"] = function() {
                return (_emscripten_stack_get_base = Module["_emscripten_stack_get_base"] = Module["asm"]["emscripten_stack_get_base"]).apply(null, arguments)
            };
            var _emscripten_stack_get_end = Module["_emscripten_stack_get_end"] = function() {
                return (_emscripten_stack_get_end = Module["_emscripten_stack_get_end"] = Module["asm"]["emscripten_stack_get_end"]).apply(null, arguments)
            };
            var _pthread_setcancelstate = Module["_pthread_setcancelstate"] = function() {
                return (_pthread_setcancelstate = Module["_pthread_setcancelstate"] = Module["asm"]["pthread_setcancelstate"]).apply(null, arguments)
            };
            var _pthread_setcanceltype = Module["_pthread_setcanceltype"] = function() {
                return (_pthread_setcanceltype = Module["_pthread_setcanceltype"] = Module["asm"]["pthread_setcanceltype"]).apply(null, arguments)
            };
            var _pthread_rwlock_init = Module["_pthread_rwlock_init"] = function() {
                return (_pthread_rwlock_init = Module["_pthread_rwlock_init"] = Module["asm"]["pthread_rwlock_init"]).apply(null, arguments)
            };
            var _pthread_rwlock_destroy = Module["_pthread_rwlock_destroy"] = function() {
                return (_pthread_rwlock_destroy = Module["_pthread_rwlock_destroy"] = Module["asm"]["pthread_rwlock_destroy"]).apply(null, arguments)
            };
            var _pthread_rwlock_rdlock = Module["_pthread_rwlock_rdlock"] = function() {
                return (_pthread_rwlock_rdlock = Module["_pthread_rwlock_rdlock"] = Module["asm"]["pthread_rwlock_rdlock"]).apply(null, arguments)
            };
            var _pthread_rwlock_tryrdlock = Module["_pthread_rwlock_tryrdlock"] = function() {
                return (_pthread_rwlock_tryrdlock = Module["_pthread_rwlock_tryrdlock"] = Module["asm"]["pthread_rwlock_tryrdlock"]).apply(null, arguments)
            };
            var _pthread_rwlock_timedrdlock = Module["_pthread_rwlock_timedrdlock"] = function() {
                return (_pthread_rwlock_timedrdlock = Module["_pthread_rwlock_timedrdlock"] = Module["asm"]["pthread_rwlock_timedrdlock"]).apply(null, arguments)
            };
            var _pthread_rwlock_wrlock = Module["_pthread_rwlock_wrlock"] = function() {
                return (_pthread_rwlock_wrlock = Module["_pthread_rwlock_wrlock"] = Module["asm"]["pthread_rwlock_wrlock"]).apply(null, arguments)
            };
            var _pthread_rwlock_trywrlock = Module["_pthread_rwlock_trywrlock"] = function() {
                return (_pthread_rwlock_trywrlock = Module["_pthread_rwlock_trywrlock"] = Module["asm"]["pthread_rwlock_trywrlock"]).apply(null, arguments)
            };
            var _pthread_rwlock_timedwrlock = Module["_pthread_rwlock_timedwrlock"] = function() {
                return (_pthread_rwlock_timedwrlock = Module["_pthread_rwlock_timedwrlock"] = Module["asm"]["pthread_rwlock_timedwrlock"]).apply(null, arguments)
            };
            var _pthread_rwlock_unlock = Module["_pthread_rwlock_unlock"] = function() {
                return (_pthread_rwlock_unlock = Module["_pthread_rwlock_unlock"] = Module["asm"]["pthread_rwlock_unlock"]).apply(null, arguments)
            };
            var _pthread_rwlockattr_init = Module["_pthread_rwlockattr_init"] = function() {
                return (_pthread_rwlockattr_init = Module["_pthread_rwlockattr_init"] = Module["asm"]["pthread_rwlockattr_init"]).apply(null, arguments)
            };
            var _pthread_rwlockattr_destroy = Module["_pthread_rwlockattr_destroy"] = function() {
                return (_pthread_rwlockattr_destroy = Module["_pthread_rwlockattr_destroy"] = Module["asm"]["pthread_rwlockattr_destroy"]).apply(null, arguments)
            };
            var _pthread_rwlockattr_setpshared = Module["_pthread_rwlockattr_setpshared"] = function() {
                return (_pthread_rwlockattr_setpshared = Module["_pthread_rwlockattr_setpshared"] = Module["asm"]["pthread_rwlockattr_setpshared"]).apply(null, arguments)
            };
            var _pthread_rwlockattr_getpshared = Module["_pthread_rwlockattr_getpshared"] = function() {
                return (_pthread_rwlockattr_getpshared = Module["_pthread_rwlockattr_getpshared"] = Module["asm"]["pthread_rwlockattr_getpshared"]).apply(null, arguments)
            };
            var _pthread_spin_init = Module["_pthread_spin_init"] = function() {
                return (_pthread_spin_init = Module["_pthread_spin_init"] = Module["asm"]["pthread_spin_init"]).apply(null, arguments)
            };
            var _pthread_spin_destroy = Module["_pthread_spin_destroy"] = function() {
                return (_pthread_spin_destroy = Module["_pthread_spin_destroy"] = Module["asm"]["pthread_spin_destroy"]).apply(null, arguments)
            };
            var _pthread_spin_lock = Module["_pthread_spin_lock"] = function() {
                return (_pthread_spin_lock = Module["_pthread_spin_lock"] = Module["asm"]["pthread_spin_lock"]).apply(null, arguments)
            };
            var _pthread_spin_trylock = Module["_pthread_spin_trylock"] = function() {
                return (_pthread_spin_trylock = Module["_pthread_spin_trylock"] = Module["asm"]["pthread_spin_trylock"]).apply(null, arguments)
            };
            var _pthread_spin_unlock = Module["_pthread_spin_unlock"] = function() {
                return (_pthread_spin_unlock = Module["_pthread_spin_unlock"] = Module["asm"]["pthread_spin_unlock"]).apply(null, arguments)
            };
            var _pthread_attr_setdetachstate = Module["_pthread_attr_setdetachstate"] = function() {
                return (_pthread_attr_setdetachstate = Module["_pthread_attr_setdetachstate"] = Module["asm"]["pthread_attr_setdetachstate"]).apply(null, arguments)
            };
            var _pthread_attr_setschedparam = Module["_pthread_attr_setschedparam"] = function() {
                return (_pthread_attr_setschedparam = Module["_pthread_attr_setschedparam"] = Module["asm"]["pthread_attr_setschedparam"]).apply(null, arguments)
            };
            var _pthread_attr_setstacksize = Module["_pthread_attr_setstacksize"] = function() {
                return (_pthread_attr_setstacksize = Module["_pthread_attr_setstacksize"] = Module["asm"]["pthread_attr_setstacksize"]).apply(null, arguments)
            };
            var _sem_init = Module["_sem_init"] = function() {
                return (_sem_init = Module["_sem_init"] = Module["asm"]["sem_init"]).apply(null, arguments)
            };
            var _sem_post = Module["_sem_post"] = function() {
                return (_sem_post = Module["_sem_post"] = Module["asm"]["sem_post"]).apply(null, arguments)
            };
            var _sem_wait = Module["_sem_wait"] = function() {
                return (_sem_wait = Module["_sem_wait"] = Module["asm"]["sem_wait"]).apply(null, arguments)
            };
            var _sem_trywait = Module["_sem_trywait"] = function() {
                return (_sem_trywait = Module["_sem_trywait"] = Module["asm"]["sem_trywait"]).apply(null, arguments)
            };
            var _sem_destroy = Module["_sem_destroy"] = function() {
                return (_sem_destroy = Module["_sem_destroy"] = Module["asm"]["sem_destroy"]).apply(null, arguments)
            };
            var ___wait = Module["___wait"] = function() {
                return (___wait = Module["___wait"] = Module["asm"]["__wait"]).apply(null, arguments)
            };
            var _pthread_key_delete = Module["_pthread_key_delete"] = function() {
                return (_pthread_key_delete = Module["_pthread_key_delete"] = Module["asm"]["pthread_key_delete"]).apply(null, arguments)
            };
            var _pthread_key_create = Module["_pthread_key_create"] = function() {
                return (_pthread_key_create = Module["_pthread_key_create"] = Module["asm"]["pthread_key_create"]).apply(null, arguments)
            };
            var _pthread_once = Module["_pthread_once"] = function() {
                return (_pthread_once = Module["_pthread_once"] = Module["asm"]["pthread_once"]).apply(null, arguments)
            };
            var _mkfifoat = Module["_mkfifoat"] = function() {
                return (_mkfifoat = Module["_mkfifoat"] = Module["asm"]["mkfifoat"]).apply(null, arguments)
            };
            var _mknodat = Module["_mknodat"] = function() {
                return (_mknodat = Module["_mknodat"] = Module["asm"]["mknodat"]).apply(null, arguments)
            };
            var _fstatat = Module["_fstatat"] = function() {
                return (_fstatat = Module["_fstatat"] = Module["asm"]["fstatat"]).apply(null, arguments)
            };
            var ___syscall_ret = Module["___syscall_ret"] = function() {
                return (___syscall_ret = Module["___syscall_ret"] = Module["asm"]["__syscall_ret"]).apply(null, arguments)
            };
            var _fstatat64 = Module["_fstatat64"] = function() {
                return (_fstatat64 = Module["_fstatat64"] = Module["asm"]["fstatat64"]).apply(null, arguments)
            };
            var _fstat = Module["_fstat"] = function() {
                return (_fstat = Module["_fstat"] = Module["asm"]["fstat"]).apply(null, arguments)
            };
            var ___wasi_fd_is_valid = Module["___wasi_fd_is_valid"] = function() {
                return (___wasi_fd_is_valid = Module["___wasi_fd_is_valid"] = Module["asm"]["__wasi_fd_is_valid"]).apply(null, arguments)
            };
            var ___procfdname = Module["___procfdname"] = function() {
                return (___procfdname = Module["___procfdname"] = Module["asm"]["__procfdname"]).apply(null, arguments)
            };
            var _fstat64 = Module["_fstat64"] = function() {
                return (_fstat64 = Module["_fstat64"] = Module["asm"]["fstat64"]).apply(null, arguments)
            };
            var _fchmod = Module["_fchmod"] = function() {
                return (_fchmod = Module["_fchmod"] = Module["asm"]["fchmod"]).apply(null, arguments)
            };
            var _umask = Module["_umask"] = function() {
                return (_umask = Module["_umask"] = Module["asm"]["umask"]).apply(null, arguments)
            };
            var _fchmodat = Module["_fchmodat"] = function() {
                return (_fchmodat = Module["_fchmodat"] = Module["asm"]["fchmodat"]).apply(null, arguments)
            };
            var _futimens = Module["_futimens"] = function() {
                return (_futimens = Module["_futimens"] = Module["asm"]["futimens"]).apply(null, arguments)
            };
            var _utimensat = Module["_utimensat"] = function() {
                return (_utimensat = Module["_utimensat"] = Module["asm"]["utimensat"]).apply(null, arguments)
            };
            var _chmod = Module["_chmod"] = function() {
                return (_chmod = Module["_chmod"] = Module["asm"]["chmod"]).apply(null, arguments)
            };
            var ___fxstat = Module["___fxstat"] = function() {
                return (___fxstat = Module["___fxstat"] = Module["asm"]["__fxstat"]).apply(null, arguments)
            };
            var ___fxstatat = Module["___fxstatat"] = function() {
                return (___fxstatat = Module["___fxstatat"] = Module["asm"]["__fxstatat"]).apply(null, arguments)
            };
            var ___lxstat = Module["___lxstat"] = function() {
                return (___lxstat = Module["___lxstat"] = Module["asm"]["__lxstat"]).apply(null, arguments)
            };
            var _lstat = Module["_lstat"] = function() {
                return (_lstat = Module["_lstat"] = Module["asm"]["lstat"]).apply(null, arguments)
            };
            var ___xstat = Module["___xstat"] = function() {
                return (___xstat = Module["___xstat"] = Module["asm"]["__xstat"]).apply(null, arguments)
            };
            var _stat = Module["_stat"] = function() {
                return (_stat = Module["_stat"] = Module["asm"]["stat"]).apply(null, arguments)
            };
            var ___xmknod = Module["___xmknod"] = function() {
                return (___xmknod = Module["___xmknod"] = Module["asm"]["__xmknod"]).apply(null, arguments)
            };
            var _mknod = Module["_mknod"] = function() {
                return (_mknod = Module["_mknod"] = Module["asm"]["mknod"]).apply(null, arguments)
            };
            var ___xmknodat = Module["___xmknodat"] = function() {
                return (___xmknodat = Module["___xmknodat"] = Module["asm"]["__xmknodat"]).apply(null, arguments)
            };
            var ___fxstat64 = Module["___fxstat64"] = function() {
                return (___fxstat64 = Module["___fxstat64"] = Module["asm"]["__fxstat64"]).apply(null, arguments)
            };
            var ___fxstatat64 = Module["___fxstatat64"] = function() {
                return (___fxstatat64 = Module["___fxstatat64"] = Module["asm"]["__fxstatat64"]).apply(null, arguments)
            };
            var ___lxstat64 = Module["___lxstat64"] = function() {
                return (___lxstat64 = Module["___lxstat64"] = Module["asm"]["__lxstat64"]).apply(null, arguments)
            };
            var ___xstat64 = Module["___xstat64"] = function() {
                return (___xstat64 = Module["___xstat64"] = Module["asm"]["__xstat64"]).apply(null, arguments)
            };
            var ___statfs = Module["___statfs"] = function() {
                return (___statfs = Module["___statfs"] = Module["asm"]["__statfs"]).apply(null, arguments)
            };
            var ___fstatfs = Module["___fstatfs"] = function() {
                return (___fstatfs = Module["___fstatfs"] = Module["asm"]["__fstatfs"]).apply(null, arguments)
            };
            var _statvfs = Module["_statvfs"] = function() {
                return (_statvfs = Module["_statvfs"] = Module["asm"]["statvfs"]).apply(null, arguments)
            };
            var _fstatvfs = Module["_fstatvfs"] = function() {
                return (_fstatvfs = Module["_fstatvfs"] = Module["asm"]["fstatvfs"]).apply(null, arguments)
            };
            var _statfs = Module["_statfs"] = function() {
                return (_statfs = Module["_statfs"] = Module["asm"]["statfs"]).apply(null, arguments)
            };
            var _fstatfs = Module["_fstatfs"] = function() {
                return (_fstatfs = Module["_fstatfs"] = Module["asm"]["fstatfs"]).apply(null, arguments)
            };
            var _statvfs64 = Module["_statvfs64"] = function() {
                return (_statvfs64 = Module["_statvfs64"] = Module["asm"]["statvfs64"]).apply(null, arguments)
            };
            var _statfs64 = Module["_statfs64"] = function() {
                return (_statfs64 = Module["_statfs64"] = Module["asm"]["statfs64"]).apply(null, arguments)
            };
            var _fstatvfs64 = Module["_fstatvfs64"] = function() {
                return (_fstatvfs64 = Module["_fstatvfs64"] = Module["asm"]["fstatvfs64"]).apply(null, arguments)
            };
            var _fstatfs64 = Module["_fstatfs64"] = function() {
                return (_fstatfs64 = Module["_fstatfs64"] = Module["asm"]["fstatfs64"]).apply(null, arguments)
            };
            var _lstat64 = Module["_lstat64"] = function() {
                return (_lstat64 = Module["_lstat64"] = Module["asm"]["lstat64"]).apply(null, arguments)
            };
            var _mkdirat = Module["_mkdirat"] = function() {
                return (_mkdirat = Module["_mkdirat"] = Module["asm"]["mkdirat"]).apply(null, arguments)
            };
            var ___futimesat = Module["___futimesat"] = function() {
                return (___futimesat = Module["___futimesat"] = Module["asm"]["__futimesat"]).apply(null, arguments)
            };
            var _futimesat = Module["_futimesat"] = function() {
                return (_futimesat = Module["_futimesat"] = Module["asm"]["futimesat"]).apply(null, arguments)
            };
            var _mkdir = Module["_mkdir"] = function() {
                return (_mkdir = Module["_mkdir"] = Module["asm"]["mkdir"]).apply(null, arguments)
            };
            var _stat64 = Module["_stat64"] = function() {
                return (_stat64 = Module["_stat64"] = Module["asm"]["stat64"]).apply(null, arguments)
            };
            var _lchmod = Module["_lchmod"] = function() {
                return (_lchmod = Module["_lchmod"] = Module["asm"]["lchmod"]).apply(null, arguments)
            };
            var _mkfifo = Module["_mkfifo"] = function() {
                return (_mkfifo = Module["_mkfifo"] = Module["asm"]["mkfifo"]).apply(null, arguments)
            };
            var _gethostid = Module["_gethostid"] = function() {
                return (_gethostid = Module["_gethostid"] = Module["asm"]["gethostid"]).apply(null, arguments)
            };
            var _ioctl = Module["_ioctl"] = function() {
                return (_ioctl = Module["_ioctl"] = Module["asm"]["ioctl"]).apply(null, arguments)
            };
            var _getpriority = Module["_getpriority"] = function() {
                return (_getpriority = Module["_getpriority"] = Module["asm"]["getpriority"]).apply(null, arguments)
            };
            var _getrlimit = Module["_getrlimit"] = function() {
                return (_getrlimit = Module["_getrlimit"] = Module["asm"]["getrlimit"]).apply(null, arguments)
            };
            var ___errno_location = Module["___errno_location"] = function() {
                return (___errno_location = Module["___errno_location"] = Module["asm"]["__errno_location"]).apply(null, arguments)
            };
            var _getrlimit64 = Module["_getrlimit64"] = function() {
                return (_getrlimit64 = Module["_getrlimit64"] = Module["asm"]["getrlimit64"]).apply(null, arguments)
            };
            var _a64l = Module["_a64l"] = function() {
                return (_a64l = Module["_a64l"] = Module["asm"]["a64l"]).apply(null, arguments)
            };
            var _strchr = Module["_strchr"] = function() {
                return (_strchr = Module["_strchr"] = Module["asm"]["strchr"]).apply(null, arguments)
            };
            var _l64a = Module["_l64a"] = function() {
                return (_l64a = Module["_l64a"] = Module["asm"]["l64a"]).apply(null, arguments)
            };
            var _ffs = Module["_ffs"] = function() {
                return (_ffs = Module["_ffs"] = Module["asm"]["ffs"]).apply(null, arguments)
            };
            var _get_current_dir_name = Module["_get_current_dir_name"] = function() {
                return (_get_current_dir_name = Module["_get_current_dir_name"] = Module["asm"]["get_current_dir_name"]).apply(null, arguments)
            };
            var _getenv = Module["_getenv"] = function() {
                return (_getenv = Module["_getenv"] = Module["asm"]["getenv"]).apply(null, arguments)
            };
            var _strdup = Module["_strdup"] = function() {
                return (_strdup = Module["_strdup"] = Module["asm"]["strdup"]).apply(null, arguments)
            };
            var _getcwd = Module["_getcwd"] = function() {
                return (_getcwd = Module["_getcwd"] = Module["asm"]["getcwd"]).apply(null, arguments)
            };
            var _ffsl = Module["_ffsl"] = function() {
                return (_ffsl = Module["_ffsl"] = Module["asm"]["ffsl"]).apply(null, arguments)
            };
            var ___getopt_msg = Module["___getopt_msg"] = function() {
                return (___getopt_msg = Module["___getopt_msg"] = Module["asm"]["__getopt_msg"]).apply(null, arguments)
            };
            var ___lctrans_cur = Module["___lctrans_cur"] = function() {
                return (___lctrans_cur = Module["___lctrans_cur"] = Module["asm"]["__lctrans_cur"]).apply(null, arguments)
            };
            var _flockfile = Module["_flockfile"] = function() {
                return (_flockfile = Module["_flockfile"] = Module["asm"]["flockfile"]).apply(null, arguments)
            };
            var _fputs = Module["_fputs"] = function() {
                return (_fputs = Module["_fputs"] = Module["asm"]["fputs"]).apply(null, arguments)
            };
            var _fwrite = Module["_fwrite"] = function() {
                return (_fwrite = Module["_fwrite"] = Module["asm"]["fwrite"]).apply(null, arguments)
            };
            var _putc = Module["_putc"] = function() {
                return (_putc = Module["_putc"] = Module["asm"]["putc"]).apply(null, arguments)
            };
            var _funlockfile = Module["_funlockfile"] = function() {
                return (_funlockfile = Module["_funlockfile"] = Module["asm"]["funlockfile"]).apply(null, arguments)
            };
            var _getopt = Module["_getopt"] = function() {
                return (_getopt = Module["_getopt"] = Module["asm"]["getopt"]).apply(null, arguments)
            };
            var _mbtowc = Module["_mbtowc"] = function() {
                return (_mbtowc = Module["_mbtowc"] = Module["asm"]["mbtowc"]).apply(null, arguments)
            };
            var ___posix_getopt = Module["___posix_getopt"] = function() {
                return (___posix_getopt = Module["___posix_getopt"] = Module["asm"]["__posix_getopt"]).apply(null, arguments)
            };
            var _setpriority = Module["_setpriority"] = function() {
                return (_setpriority = Module["_setpriority"] = Module["asm"]["setpriority"]).apply(null, arguments)
            };
            var _openpty = Module["_openpty"] = function() {
                return (_openpty = Module["_openpty"] = Module["asm"]["openpty"]).apply(null, arguments)
            };
            var _open = Module["_open"] = function() {
                return (_open = Module["_open"] = Module["asm"]["open"]).apply(null, arguments)
            };
            var _snprintf = Module["_snprintf"] = function() {
                return (_snprintf = Module["_snprintf"] = Module["asm"]["snprintf"]).apply(null, arguments)
            };
            var _tcsetattr = Module["_tcsetattr"] = function() {
                return (_tcsetattr = Module["_tcsetattr"] = Module["asm"]["tcsetattr"]).apply(null, arguments)
            };
            var _close = Module["_close"] = function() {
                return (_close = Module["_close"] = Module["asm"]["close"]).apply(null, arguments)
            };
            var _realpath = Module["_realpath"] = function() {
                return (_realpath = Module["_realpath"] = Module["asm"]["realpath"]).apply(null, arguments)
            };
            var _readlink = Module["_readlink"] = function() {
                return (_readlink = Module["_readlink"] = Module["asm"]["readlink"]).apply(null, arguments)
            };
            var _forkpty = Module["_forkpty"] = function() {
                return (_forkpty = Module["_forkpty"] = Module["asm"]["forkpty"]).apply(null, arguments)
            };
            var _pipe2 = Module["_pipe2"] = function() {
                return (_pipe2 = Module["_pipe2"] = Module["asm"]["pipe2"]).apply(null, arguments)
            };
            var _login_tty = Module["_login_tty"] = function() {
                return (_login_tty = Module["_login_tty"] = Module["asm"]["login_tty"]).apply(null, arguments)
            };
            var _read = Module["_read"] = function() {
                return (_read = Module["_read"] = Module["asm"]["read"]).apply(null, arguments)
            };
            var _waitpid = Module["_waitpid"] = function() {
                return (_waitpid = Module["_waitpid"] = Module["asm"]["waitpid"]).apply(null, arguments)
            };
            var _write = Module["_write"] = function() {
                return (_write = Module["_write"] = Module["asm"]["write"]).apply(null, arguments)
            };
            var _nftw = Module["_nftw"] = function() {
                return (_nftw = Module["_nftw"] = Module["asm"]["nftw"]).apply(null, arguments)
            };
            var _access = Module["_access"] = function() {
                return (_access = Module["_access"] = Module["asm"]["access"]).apply(null, arguments)
            };
            var _strrchr = Module["_strrchr"] = function() {
                return (_strrchr = Module["_strrchr"] = Module["asm"]["strrchr"]).apply(null, arguments)
            };
            var _opendir = Module["_opendir"] = function() {
                return (_opendir = Module["_opendir"] = Module["asm"]["opendir"]).apply(null, arguments)
            };
            var _readdir = Module["_readdir"] = function() {
                return (_readdir = Module["_readdir"] = Module["asm"]["readdir"]).apply(null, arguments)
            };
            var _closedir = Module["_closedir"] = function() {
                return (_closedir = Module["_closedir"] = Module["asm"]["closedir"]).apply(null, arguments)
            };
            var _nftw64 = Module["_nftw64"] = function() {
                return (_nftw64 = Module["_nftw64"] = Module["asm"]["nftw64"]).apply(null, arguments)
            };
            var _getdomainname = Module["_getdomainname"] = function() {
                return (_getdomainname = Module["_getdomainname"] = Module["asm"]["getdomainname"]).apply(null, arguments)
            };
            var _uname = Module["_uname"] = function() {
                return (_uname = Module["_uname"] = Module["asm"]["uname"]).apply(null, arguments)
            };
            var _issetugid = Module["_issetugid"] = function() {
                return (_issetugid = Module["_issetugid"] = Module["asm"]["issetugid"]).apply(null, arguments)
            };
            var _lockf = Module["_lockf"] = function() {
                return (_lockf = Module["_lockf"] = Module["asm"]["lockf"]).apply(null, arguments)
            };
            var _fcntl = Module["_fcntl"] = function() {
                return (_fcntl = Module["_fcntl"] = Module["asm"]["fcntl"]).apply(null, arguments)
            };
            var _getpid = Module["_getpid"] = function() {
                return (_getpid = Module["_getpid"] = Module["asm"]["getpid"]).apply(null, arguments)
            };
            var _lockf64 = Module["_lockf64"] = function() {
                return (_lockf64 = Module["_lockf64"] = Module["asm"]["lockf64"]).apply(null, arguments)
            };
            var _getauxval = Module["_getauxval"] = function() {
                return (_getauxval = Module["_getauxval"] = Module["asm"]["getauxval"]).apply(null, arguments)
            };
            var _getresuid = Module["_getresuid"] = function() {
                return (_getresuid = Module["_getresuid"] = Module["asm"]["getresuid"]).apply(null, arguments)
            };
            var ___setrlimit = Module["___setrlimit"] = function() {
                return (___setrlimit = Module["___setrlimit"] = Module["asm"]["__setrlimit"]).apply(null, arguments)
            };
            var _setrlimit = Module["_setrlimit"] = function() {
                return (_setrlimit = Module["_setrlimit"] = Module["asm"]["setrlimit"]).apply(null, arguments)
            };
            var ___synccall = Module["___synccall"] = function() {
                return (___synccall = Module["___synccall"] = Module["asm"]["__synccall"]).apply(null, arguments)
            };
            var _setrlimit64 = Module["_setrlimit64"] = function() {
                return (_setrlimit64 = Module["_setrlimit64"] = Module["asm"]["setrlimit64"]).apply(null, arguments)
            };
            var _setdomainname = Module["_setdomainname"] = function() {
                return (_setdomainname = Module["_setdomainname"] = Module["asm"]["setdomainname"]).apply(null, arguments)
            };
            var _getsubopt = Module["_getsubopt"] = function() {
                return (_getsubopt = Module["_getsubopt"] = Module["asm"]["getsubopt"]).apply(null, arguments)
            };
            var _strncmp = Module["_strncmp"] = function() {
                return (_strncmp = Module["_strncmp"] = Module["asm"]["strncmp"]).apply(null, arguments)
            };
            var _ffsll = Module["_ffsll"] = function() {
                return (_ffsll = Module["_ffsll"] = Module["asm"]["ffsll"]).apply(null, arguments)
            };
            var _getopt_long = Module["_getopt_long"] = function() {
                return (_getopt_long = Module["_getopt_long"] = Module["asm"]["getopt_long"]).apply(null, arguments)
            };
            var _getopt_long_only = Module["_getopt_long_only"] = function() {
                return (_getopt_long_only = Module["_getopt_long_only"] = Module["asm"]["getopt_long_only"]).apply(null, arguments)
            };
            var _ptsname = Module["_ptsname"] = function() {
                return (_ptsname = Module["_ptsname"] = Module["asm"]["ptsname"]).apply(null, arguments)
            };
            var ___ptsname_r = Module["___ptsname_r"] = function() {
                return (___ptsname_r = Module["___ptsname_r"] = Module["asm"]["__ptsname_r"]).apply(null, arguments)
            };
            var _getrusage = Module["_getrusage"] = function() {
                return (_getrusage = Module["_getrusage"] = Module["asm"]["getrusage"]).apply(null, arguments)
            };
            var _setlogmask = Module["_setlogmask"] = function() {
                return (_setlogmask = Module["_setlogmask"] = Module["asm"]["setlogmask"]).apply(null, arguments)
            };
            var ___lock = Module["___lock"] = function() {
                return (___lock = Module["___lock"] = Module["asm"]["__lock"]).apply(null, arguments)
            };
            var ___unlock = Module["___unlock"] = function() {
                return (___unlock = Module["___unlock"] = Module["asm"]["__unlock"]).apply(null, arguments)
            };
            var _closelog = Module["_closelog"] = function() {
                return (_closelog = Module["_closelog"] = Module["asm"]["closelog"]).apply(null, arguments)
            };
            var _openlog = Module["_openlog"] = function() {
                return (_openlog = Module["_openlog"] = Module["asm"]["openlog"]).apply(null, arguments)
            };
            var _strnlen = Module["_strnlen"] = function() {
                return (_strnlen = Module["_strnlen"] = Module["asm"]["strnlen"]).apply(null, arguments)
            };
            var ___vsyslog = Module["___vsyslog"] = function() {
                return (___vsyslog = Module["___vsyslog"] = Module["asm"]["__vsyslog"]).apply(null, arguments)
            };
            var _vsnprintf = Module["_vsnprintf"] = function() {
                return (_vsnprintf = Module["_vsnprintf"] = Module["asm"]["vsnprintf"]).apply(null, arguments)
            };
            var _send = Module["_send"] = function() {
                return (_send = Module["_send"] = Module["asm"]["send"]).apply(null, arguments)
            };
            var _connect = Module["_connect"] = function() {
                return (_connect = Module["_connect"] = Module["asm"]["connect"]).apply(null, arguments)
            };
            var _dprintf = Module["_dprintf"] = function() {
                return (_dprintf = Module["_dprintf"] = Module["asm"]["dprintf"]).apply(null, arguments)
            };
            var _syslog = Module["_syslog"] = function() {
                return (_syslog = Module["_syslog"] = Module["asm"]["syslog"]).apply(null, arguments)
            };
            var _socket = Module["_socket"] = function() {
                return (_socket = Module["_socket"] = Module["asm"]["socket"]).apply(null, arguments)
            };
            var _vsyslog = Module["_vsyslog"] = function() {
                return (_vsyslog = Module["_vsyslog"] = Module["asm"]["vsyslog"]).apply(null, arguments)
            };
            var _fmtmsg = Module["_fmtmsg"] = function() {
                return (_fmtmsg = Module["_fmtmsg"] = Module["asm"]["fmtmsg"]).apply(null, arguments)
            };
            var _getresgid = Module["_getresgid"] = function() {
                return (_getresgid = Module["_getresgid"] = Module["asm"]["getresgid"]).apply(null, arguments)
            };
            var _basename = Module["_basename"] = function() {
                return (_basename = Module["_basename"] = Module["asm"]["basename"]).apply(null, arguments)
            };
            var ___xpg_basename = Module["___xpg_basename"] = function() {
                return (___xpg_basename = Module["___xpg_basename"] = Module["asm"]["__xpg_basename"]).apply(null, arguments)
            };
            var _setmntent = Module["_setmntent"] = function() {
                return (_setmntent = Module["_setmntent"] = Module["asm"]["setmntent"]).apply(null, arguments)
            };
            var _fopen = Module["_fopen"] = function() {
                return (_fopen = Module["_fopen"] = Module["asm"]["fopen"]).apply(null, arguments)
            };
            var _endmntent = Module["_endmntent"] = function() {
                return (_endmntent = Module["_endmntent"] = Module["asm"]["endmntent"]).apply(null, arguments)
            };
            var _fclose = Module["_fclose"] = function() {
                return (_fclose = Module["_fclose"] = Module["asm"]["fclose"]).apply(null, arguments)
            };
            var _getmntent_r = Module["_getmntent_r"] = function() {
                return (_getmntent_r = Module["_getmntent_r"] = Module["asm"]["getmntent_r"]).apply(null, arguments)
            };
            var _fgets = Module["_fgets"] = function() {
                return (_fgets = Module["_fgets"] = Module["asm"]["fgets"]).apply(null, arguments)
            };
            var _feof = Module["_feof"] = function() {
                return (_feof = Module["_feof"] = Module["asm"]["feof"]).apply(null, arguments)
            };
            var _ferror = Module["_ferror"] = function() {
                return (_ferror = Module["_ferror"] = Module["asm"]["ferror"]).apply(null, arguments)
            };
            var _fscanf = Module["_fscanf"] = function() {
                return (_fscanf = Module["_fscanf"] = Module["asm"]["fscanf"]).apply(null, arguments)
            };
            var _sscanf = Module["_sscanf"] = function() {
                return (_sscanf = Module["_sscanf"] = Module["asm"]["sscanf"]).apply(null, arguments)
            };
            var _getmntent = Module["_getmntent"] = function() {
                return (_getmntent = Module["_getmntent"] = Module["asm"]["getmntent"]).apply(null, arguments)
            };
            var _addmntent = Module["_addmntent"] = function() {
                return (_addmntent = Module["_addmntent"] = Module["asm"]["addmntent"]).apply(null, arguments)
            };
            var _fseek = Module["_fseek"] = function() {
                return (_fseek = Module["_fseek"] = Module["asm"]["fseek"]).apply(null, arguments)
            };
            var _fprintf = Module["_fprintf"] = function() {
                return (_fprintf = Module["_fprintf"] = Module["asm"]["fprintf"]).apply(null, arguments)
            };
            var _hasmntopt = Module["_hasmntopt"] = function() {
                return (_hasmntopt = Module["_hasmntopt"] = Module["asm"]["hasmntopt"]).apply(null, arguments)
            };
            var _posix_openpt = Module["_posix_openpt"] = function() {
                return (_posix_openpt = Module["_posix_openpt"] = Module["asm"]["posix_openpt"]).apply(null, arguments)
            };
            var _grantpt = Module["_grantpt"] = function() {
                return (_grantpt = Module["_grantpt"] = Module["asm"]["grantpt"]).apply(null, arguments)
            };
            var _unlockpt = Module["_unlockpt"] = function() {
                return (_unlockpt = Module["_unlockpt"] = Module["asm"]["unlockpt"]).apply(null, arguments)
            };
            var _ptsname_r = Module["_ptsname_r"] = function() {
                return (_ptsname_r = Module["_ptsname_r"] = Module["asm"]["ptsname_r"]).apply(null, arguments)
            };
            var _setsid = Module["_setsid"] = function() {
                return (_setsid = Module["_setsid"] = Module["asm"]["setsid"]).apply(null, arguments)
            };
            var _dup2 = Module["_dup2"] = function() {
                return (_dup2 = Module["_dup2"] = Module["asm"]["dup2"]).apply(null, arguments)
            };
            var _dirname = Module["_dirname"] = function() {
                return (_dirname = Module["_dirname"] = Module["asm"]["dirname"]).apply(null, arguments)
            };
            var _calloc = Module["_calloc"] = function() {
                return (_calloc = Module["_calloc"] = Module["asm"]["calloc"]).apply(null, arguments)
            };
            var _readdir_r = Module["_readdir_r"] = function() {
                return (_readdir_r = Module["_readdir_r"] = Module["asm"]["readdir_r"]).apply(null, arguments)
            };
            var _readdir64_r = Module["_readdir64_r"] = function() {
                return (_readdir64_r = Module["_readdir64_r"] = Module["asm"]["readdir64_r"]).apply(null, arguments)
            };
            var _dirfd = Module["_dirfd"] = function() {
                return (_dirfd = Module["_dirfd"] = Module["asm"]["dirfd"]).apply(null, arguments)
            };
            var _rewinddir = Module["_rewinddir"] = function() {
                return (_rewinddir = Module["_rewinddir"] = Module["asm"]["rewinddir"]).apply(null, arguments)
            };
            var _lseek = Module["_lseek"] = function() {
                return (_lseek = Module["_lseek"] = Module["asm"]["lseek"]).apply(null, arguments)
            };
            var ___getdents = Module["___getdents"] = function() {
                return (___getdents = Module["___getdents"] = Module["asm"]["__getdents"]).apply(null, arguments)
            };
            var _getdents = Module["_getdents"] = function() {
                return (_getdents = Module["_getdents"] = Module["asm"]["getdents"]).apply(null, arguments)
            };
            var _getdents64 = Module["_getdents64"] = function() {
                return (_getdents64 = Module["_getdents64"] = Module["asm"]["getdents64"]).apply(null, arguments)
            };
            var _versionsort = Module["_versionsort"] = function() {
                return (_versionsort = Module["_versionsort"] = Module["asm"]["versionsort"]).apply(null, arguments)
            };
            var _strverscmp = Module["_strverscmp"] = function() {
                return (_strverscmp = Module["_strverscmp"] = Module["asm"]["strverscmp"]).apply(null, arguments)
            };
            var _versionsort64 = Module["_versionsort64"] = function() {
                return (_versionsort64 = Module["_versionsort64"] = Module["asm"]["versionsort64"]).apply(null, arguments)
            };
            var _scandir = Module["_scandir"] = function() {
                return (_scandir = Module["_scandir"] = Module["asm"]["scandir"]).apply(null, arguments)
            };
            var _qsort = Module["_qsort"] = function() {
                return (_qsort = Module["_qsort"] = Module["asm"]["qsort"]).apply(null, arguments)
            };
            var _scandir64 = Module["_scandir64"] = function() {
                return (_scandir64 = Module["_scandir64"] = Module["asm"]["scandir64"]).apply(null, arguments)
            };
            var _fdopendir = Module["_fdopendir"] = function() {
                return (_fdopendir = Module["_fdopendir"] = Module["asm"]["fdopendir"]).apply(null, arguments)
            };
            var _telldir = Module["_telldir"] = function() {
                return (_telldir = Module["_telldir"] = Module["asm"]["telldir"]).apply(null, arguments)
            };
            var _readdir64 = Module["_readdir64"] = function() {
                return (_readdir64 = Module["_readdir64"] = Module["asm"]["readdir64"]).apply(null, arguments)
            };
            var _seekdir = Module["_seekdir"] = function() {
                return (_seekdir = Module["_seekdir"] = Module["asm"]["seekdir"]).apply(null, arguments)
            };
            var _alphasort = Module["_alphasort"] = function() {
                return (_alphasort = Module["_alphasort"] = Module["asm"]["alphasort"]).apply(null, arguments)
            };
            var _strcoll = Module["_strcoll"] = function() {
                return (_strcoll = Module["_strcoll"] = Module["asm"]["strcoll"]).apply(null, arguments)
            };
            var _alphasort64 = Module["_alphasort64"] = function() {
                return (_alphasort64 = Module["_alphasort64"] = Module["asm"]["alphasort64"]).apply(null, arguments)
            };
            var ___crypt_blowfish = Module["___crypt_blowfish"] = function() {
                return (___crypt_blowfish = Module["___crypt_blowfish"] = Module["asm"]["__crypt_blowfish"]).apply(null, arguments)
            };
            var _memcmp = Module["_memcmp"] = function() {
                return (_memcmp = Module["_memcmp"] = Module["asm"]["memcmp"]).apply(null, arguments)
            };
            var ___crypt_sha256 = Module["___crypt_sha256"] = function() {
                return (___crypt_sha256 = Module["___crypt_sha256"] = Module["asm"]["__crypt_sha256"]).apply(null, arguments)
            };
            var _isdigit = Module["_isdigit"] = function() {
                return (_isdigit = Module["_isdigit"] = Module["asm"]["isdigit"]).apply(null, arguments)
            };
            var _strtoul = Module["_strtoul"] = function() {
                return (_strtoul = Module["_strtoul"] = Module["asm"]["strtoul"]).apply(null, arguments)
            };
            var _sprintf = Module["_sprintf"] = function() {
                return (_sprintf = Module["_sprintf"] = Module["asm"]["sprintf"]).apply(null, arguments)
            };
            var _crypt = Module["_crypt"] = function() {
                return (_crypt = Module["_crypt"] = Module["asm"]["crypt"]).apply(null, arguments)
            };
            var ___crypt_r = Module["___crypt_r"] = function() {
                return (___crypt_r = Module["___crypt_r"] = Module["asm"]["__crypt_r"]).apply(null, arguments)
            };
            var ___crypt_md5 = Module["___crypt_md5"] = function() {
                return (___crypt_md5 = Module["___crypt_md5"] = Module["asm"]["__crypt_md5"]).apply(null, arguments)
            };
            var _setkey = Module["_setkey"] = function() {
                return (_setkey = Module["_setkey"] = Module["asm"]["setkey"]).apply(null, arguments)
            };
            var ___des_setkey = Module["___des_setkey"] = function() {
                return (___des_setkey = Module["___des_setkey"] = Module["asm"]["__des_setkey"]).apply(null, arguments)
            };
            var _encrypt = Module["_encrypt"] = function() {
                return (_encrypt = Module["_encrypt"] = Module["asm"]["encrypt"]).apply(null, arguments)
            };
            var ___do_des = Module["___do_des"] = function() {
                return (___do_des = Module["___do_des"] = Module["asm"]["__do_des"]).apply(null, arguments)
            };
            var ___crypt_des = Module["___crypt_des"] = function() {
                return (___crypt_des = Module["___crypt_des"] = Module["asm"]["__crypt_des"]).apply(null, arguments)
            };
            var ___crypt_sha512 = Module["___crypt_sha512"] = function() {
                return (___crypt_sha512 = Module["___crypt_sha512"] = Module["asm"]["__crypt_sha512"]).apply(null, arguments)
            };
            var _crypt_r = Module["_crypt_r"] = function() {
                return (_crypt_r = Module["_crypt_r"] = Module["asm"]["crypt_r"]).apply(null, arguments)
            };
            var _strfmon_l = Module["_strfmon_l"] = function() {
                return (_strfmon_l = Module["_strfmon_l"] = Module["asm"]["strfmon_l"]).apply(null, arguments)
            };
            var _strfmon = Module["_strfmon"] = function() {
                return (_strfmon = Module["_strfmon"] = Module["asm"]["strfmon"]).apply(null, arguments)
            };
            var ___lctrans_impl = Module["___lctrans_impl"] = function() {
                return (___lctrans_impl = Module["___lctrans_impl"] = Module["asm"]["__lctrans_impl"]).apply(null, arguments)
            };
            var ___mo_lookup = Module["___mo_lookup"] = function() {
                return (___mo_lookup = Module["___mo_lookup"] = Module["asm"]["__mo_lookup"]).apply(null, arguments)
            };
            var ___get_locale = Module["___get_locale"] = function() {
                return (___get_locale = Module["___get_locale"] = Module["asm"]["__get_locale"]).apply(null, arguments)
            };
            var ___wcscoll_l = Module["___wcscoll_l"] = function() {
                return (___wcscoll_l = Module["___wcscoll_l"] = Module["asm"]["__wcscoll_l"]).apply(null, arguments)
            };
            var _wcscmp = Module["_wcscmp"] = function() {
                return (_wcscmp = Module["_wcscmp"] = Module["asm"]["wcscmp"]).apply(null, arguments)
            };
            var _wcscoll = Module["_wcscoll"] = function() {
                return (_wcscoll = Module["_wcscoll"] = Module["asm"]["wcscoll"]).apply(null, arguments)
            };
            var _wcscoll_l = Module["_wcscoll_l"] = function() {
                return (_wcscoll_l = Module["_wcscoll_l"] = Module["asm"]["wcscoll_l"]).apply(null, arguments)
            };
            var ___strcoll_l = Module["___strcoll_l"] = function() {
                return (___strcoll_l = Module["___strcoll_l"] = Module["asm"]["__strcoll_l"]).apply(null, arguments)
            };
            var _strcoll_l = Module["_strcoll_l"] = function() {
                return (_strcoll_l = Module["_strcoll_l"] = Module["asm"]["strcoll_l"]).apply(null, arguments)
            };
            var _iconv_open = Module["_iconv_open"] = function() {
                return (_iconv_open = Module["_iconv_open"] = Module["asm"]["iconv_open"]).apply(null, arguments)
            };
            var _iconv_close = Module["_iconv_close"] = function() {
                return (_iconv_close = Module["_iconv_close"] = Module["asm"]["iconv_close"]).apply(null, arguments)
            };
            var _iconv = Module["_iconv"] = function() {
                return (_iconv = Module["_iconv"] = Module["asm"]["iconv"]).apply(null, arguments)
            };
            var _mbrtowc = Module["_mbrtowc"] = function() {
                return (_mbrtowc = Module["_mbrtowc"] = Module["asm"]["mbrtowc"]).apply(null, arguments)
            };
            var _wctomb = Module["_wctomb"] = function() {
                return (_wctomb = Module["_wctomb"] = Module["asm"]["wctomb"]).apply(null, arguments)
            };
            var _setlocale = Module["_setlocale"] = function() {
                return (_setlocale = Module["_setlocale"] = Module["asm"]["setlocale"]).apply(null, arguments)
            };
            var ___strchrnul = Module["___strchrnul"] = function() {
                return (___strchrnul = Module["___strchrnul"] = Module["asm"]["__strchrnul"]).apply(null, arguments)
            };
            var _freelocale = Module["_freelocale"] = function() {
                return (_freelocale = Module["_freelocale"] = Module["asm"]["freelocale"]).apply(null, arguments)
            };
            var ___loc_is_allocated = Module["___loc_is_allocated"] = function() {
                return (___loc_is_allocated = Module["___loc_is_allocated"] = Module["asm"]["__loc_is_allocated"]).apply(null, arguments)
            };
            var ___freelocale = Module["___freelocale"] = function() {
                return (___freelocale = Module["___freelocale"] = Module["asm"]["__freelocale"]).apply(null, arguments)
            };
            var ___uselocale = Module["___uselocale"] = function() {
                return (___uselocale = Module["___uselocale"] = Module["asm"]["__uselocale"]).apply(null, arguments)
            };
            var _uselocale = Module["_uselocale"] = function() {
                return (_uselocale = Module["_uselocale"] = Module["asm"]["uselocale"]).apply(null, arguments)
            };
            var _bindtextdomain = Module["_bindtextdomain"] = function() {
                return (_bindtextdomain = Module["_bindtextdomain"] = Module["asm"]["bindtextdomain"]).apply(null, arguments)
            };
            var _dcngettext = Module["_dcngettext"] = function() {
                return (_dcngettext = Module["_dcngettext"] = Module["asm"]["dcngettext"]).apply(null, arguments)
            };
            var ___gettextdomain = Module["___gettextdomain"] = function() {
                return (___gettextdomain = Module["___gettextdomain"] = Module["asm"]["__gettextdomain"]).apply(null, arguments)
            };
            var ___munmap = Module["___munmap"] = function() {
                return (___munmap = Module["___munmap"] = Module["asm"]["__munmap"]).apply(null, arguments)
            };
            var _isspace = Module["_isspace"] = function() {
                return (_isspace = Module["_isspace"] = Module["asm"]["isspace"]).apply(null, arguments)
            };
            var ___pleval = Module["___pleval"] = function() {
                return (___pleval = Module["___pleval"] = Module["asm"]["__pleval"]).apply(null, arguments)
            };
            var _dcgettext = Module["_dcgettext"] = function() {
                return (_dcgettext = Module["_dcgettext"] = Module["asm"]["dcgettext"]).apply(null, arguments)
            };
            var _dngettext = Module["_dngettext"] = function() {
                return (_dngettext = Module["_dngettext"] = Module["asm"]["dngettext"]).apply(null, arguments)
            };
            var _dgettext = Module["_dgettext"] = function() {
                return (_dgettext = Module["_dgettext"] = Module["asm"]["dgettext"]).apply(null, arguments)
            };
            var _localeconv = Module["_localeconv"] = function() {
                return (_localeconv = Module["_localeconv"] = Module["asm"]["localeconv"]).apply(null, arguments)
            };
            var _catgets = Module["_catgets"] = function() {
                return (_catgets = Module["_catgets"] = Module["asm"]["catgets"]).apply(null, arguments)
            };
            var _bind_textdomain_codeset = Module["_bind_textdomain_codeset"] = function() {
                return (_bind_textdomain_codeset = Module["_bind_textdomain_codeset"] = Module["asm"]["bind_textdomain_codeset"]).apply(null, arguments)
            };
            var _strcasecmp = Module["_strcasecmp"] = function() {
                return (_strcasecmp = Module["_strcasecmp"] = Module["asm"]["strcasecmp"]).apply(null, arguments)
            };
            var _catclose = Module["_catclose"] = function() {
                return (_catclose = Module["_catclose"] = Module["asm"]["catclose"]).apply(null, arguments)
            };
            var ___wcsxfrm_l = Module["___wcsxfrm_l"] = function() {
                return (___wcsxfrm_l = Module["___wcsxfrm_l"] = Module["asm"]["__wcsxfrm_l"]).apply(null, arguments)
            };
            var _wcslen = Module["_wcslen"] = function() {
                return (_wcslen = Module["_wcslen"] = Module["asm"]["wcslen"]).apply(null, arguments)
            };
            var _wmemcpy = Module["_wmemcpy"] = function() {
                return (_wmemcpy = Module["_wmemcpy"] = Module["asm"]["wmemcpy"]).apply(null, arguments)
            };
            var _wcsxfrm = Module["_wcsxfrm"] = function() {
                return (_wcsxfrm = Module["_wcsxfrm"] = Module["asm"]["wcsxfrm"]).apply(null, arguments)
            };
            var _wcsxfrm_l = Module["_wcsxfrm_l"] = function() {
                return (_wcsxfrm_l = Module["_wcsxfrm_l"] = Module["asm"]["wcsxfrm_l"]).apply(null, arguments)
            };
            var ___lctrans = Module["___lctrans"] = function() {
                return (___lctrans = Module["___lctrans"] = Module["asm"]["__lctrans"]).apply(null, arguments)
            };
            var ___newlocale = Module["___newlocale"] = function() {
                return (___newlocale = Module["___newlocale"] = Module["asm"]["__newlocale"]).apply(null, arguments)
            };
            var _newlocale = Module["_newlocale"] = function() {
                return (_newlocale = Module["_newlocale"] = Module["asm"]["newlocale"]).apply(null, arguments)
            };
            var ___nl_langinfo_l = Module["___nl_langinfo_l"] = function() {
                return (___nl_langinfo_l = Module["___nl_langinfo_l"] = Module["asm"]["__nl_langinfo_l"]).apply(null, arguments)
            };
            var ___nl_langinfo = Module["___nl_langinfo"] = function() {
                return (___nl_langinfo = Module["___nl_langinfo"] = Module["asm"]["__nl_langinfo"]).apply(null, arguments)
            };
            var _nl_langinfo = Module["_nl_langinfo"] = function() {
                return (_nl_langinfo = Module["_nl_langinfo"] = Module["asm"]["nl_langinfo"]).apply(null, arguments)
            };
            var _nl_langinfo_l = Module["_nl_langinfo_l"] = function() {
                return (_nl_langinfo_l = Module["_nl_langinfo_l"] = Module["asm"]["nl_langinfo_l"]).apply(null, arguments)
            };
            var ___duplocale = Module["___duplocale"] = function() {
                return (___duplocale = Module["___duplocale"] = Module["asm"]["__duplocale"]).apply(null, arguments)
            };
            var _duplocale = Module["_duplocale"] = function() {
                return (_duplocale = Module["_duplocale"] = Module["asm"]["duplocale"]).apply(null, arguments)
            };
            var _catopen = Module["_catopen"] = function() {
                return (_catopen = Module["_catopen"] = Module["asm"]["catopen"]).apply(null, arguments)
            };
            var ___strxfrm_l = Module["___strxfrm_l"] = function() {
                return (___strxfrm_l = Module["___strxfrm_l"] = Module["asm"]["__strxfrm_l"]).apply(null, arguments)
            };
            var _strxfrm = Module["_strxfrm"] = function() {
                return (_strxfrm = Module["_strxfrm"] = Module["asm"]["strxfrm"]).apply(null, arguments)
            };
            var _strxfrm_l = Module["_strxfrm_l"] = function() {
                return (_strxfrm_l = Module["_strxfrm_l"] = Module["asm"]["strxfrm_l"]).apply(null, arguments)
            };
            var _textdomain = Module["_textdomain"] = function() {
                return (_textdomain = Module["_textdomain"] = Module["asm"]["textdomain"]).apply(null, arguments)
            };
            var _gettext = Module["_gettext"] = function() {
                return (_gettext = Module["_gettext"] = Module["asm"]["gettext"]).apply(null, arguments)
            };
            var _ngettext = Module["_ngettext"] = function() {
                return (_ngettext = Module["_ngettext"] = Module["asm"]["ngettext"]).apply(null, arguments)
            };
            var ___rand48_step = Module["___rand48_step"] = function() {
                return (___rand48_step = Module["___rand48_step"] = Module["asm"]["__rand48_step"]).apply(null, arguments)
            };
            var _rand_r = Module["_rand_r"] = function() {
                return (_rand_r = Module["_rand_r"] = Module["asm"]["rand_r"]).apply(null, arguments)
            };
            var _lcong48 = Module["_lcong48"] = function() {
                return (_lcong48 = Module["_lcong48"] = Module["asm"]["lcong48"]).apply(null, arguments)
            };
            var _srandom = Module["_srandom"] = function() {
                return (_srandom = Module["_srandom"] = Module["asm"]["srandom"]).apply(null, arguments)
            };
            var _initstate = Module["_initstate"] = function() {
                return (_initstate = Module["_initstate"] = Module["asm"]["initstate"]).apply(null, arguments)
            };
            var _setstate = Module["_setstate"] = function() {
                return (_setstate = Module["_setstate"] = Module["asm"]["setstate"]).apply(null, arguments)
            };
            var _random = Module["_random"] = function() {
                return (_random = Module["_random"] = Module["asm"]["random"]).apply(null, arguments)
            };
            var _srand48 = Module["_srand48"] = function() {
                return (_srand48 = Module["_srand48"] = Module["asm"]["srand48"]).apply(null, arguments)
            };
            var _seed48 = Module["_seed48"] = function() {
                return (_seed48 = Module["_seed48"] = Module["asm"]["seed48"]).apply(null, arguments)
            };
            var _erand48 = Module["_erand48"] = function() {
                return (_erand48 = Module["_erand48"] = Module["asm"]["erand48"]).apply(null, arguments)
            };
            var _drand48 = Module["_drand48"] = function() {
                return (_drand48 = Module["_drand48"] = Module["asm"]["drand48"]).apply(null, arguments)
            };
            var _nrand48 = Module["_nrand48"] = function() {
                return (_nrand48 = Module["_nrand48"] = Module["asm"]["nrand48"]).apply(null, arguments)
            };
            var _lrand48 = Module["_lrand48"] = function() {
                return (_lrand48 = Module["_lrand48"] = Module["asm"]["lrand48"]).apply(null, arguments)
            };
            var _jrand48 = Module["_jrand48"] = function() {
                return (_jrand48 = Module["_jrand48"] = Module["asm"]["jrand48"]).apply(null, arguments)
            };
            var _mrand48 = Module["_mrand48"] = function() {
                return (_mrand48 = Module["_mrand48"] = Module["asm"]["mrand48"]).apply(null, arguments)
            };
            var _srand = Module["_srand"] = function() {
                return (_srand = Module["_srand"] = Module["asm"]["srand"]).apply(null, arguments)
            };
            var _rand = Module["_rand"] = function() {
                return (_rand = Module["_rand"] = Module["asm"]["rand"]).apply(null, arguments)
            };
            var _mlock = Module["_mlock"] = function() {
                return (_mlock = Module["_mlock"] = Module["asm"]["mlock"]).apply(null, arguments)
            };
            var ___madvise = Module["___madvise"] = function() {
                return (___madvise = Module["___madvise"] = Module["asm"]["__madvise"]).apply(null, arguments)
            };
            var _madvise = Module["_madvise"] = function() {
                return (_madvise = Module["_madvise"] = Module["asm"]["madvise"]).apply(null, arguments)
            };
            var ___mremap = Module["___mremap"] = function() {
                return (___mremap = Module["___mremap"] = Module["asm"]["__mremap"]).apply(null, arguments)
            };
            var ___vm_wait = Module["___vm_wait"] = function() {
                return (___vm_wait = Module["___vm_wait"] = Module["asm"]["__vm_wait"]).apply(null, arguments)
            };
            var _mremap = Module["_mremap"] = function() {
                return (_mremap = Module["_mremap"] = Module["asm"]["mremap"]).apply(null, arguments)
            };
            var _posix_madvise = Module["_posix_madvise"] = function() {
                return (_posix_madvise = Module["_posix_madvise"] = Module["asm"]["posix_madvise"]).apply(null, arguments)
            };
            var _munlock = Module["_munlock"] = function() {
                return (_munlock = Module["_munlock"] = Module["asm"]["munlock"]).apply(null, arguments)
            };
            var ___mmap = Module["___mmap"] = function() {
                return (___mmap = Module["___mmap"] = Module["asm"]["__mmap"]).apply(null, arguments)
            };
            var _mmap = Module["_mmap"] = function() {
                return (_mmap = Module["_mmap"] = Module["asm"]["mmap"]).apply(null, arguments)
            };
            var _mmap64 = Module["_mmap64"] = function() {
                return (_mmap64 = Module["_mmap64"] = Module["asm"]["mmap64"]).apply(null, arguments)
            };
            var _msync = Module["_msync"] = function() {
                return (_msync = Module["_msync"] = Module["asm"]["msync"]).apply(null, arguments)
            };
            var ___shm_mapname = Module["___shm_mapname"] = function() {
                return (___shm_mapname = Module["___shm_mapname"] = Module["asm"]["__shm_mapname"]).apply(null, arguments)
            };
            var _shm_open = Module["_shm_open"] = function() {
                return (_shm_open = Module["_shm_open"] = Module["asm"]["shm_open"]).apply(null, arguments)
            };
            var _shm_unlink = Module["_shm_unlink"] = function() {
                return (_shm_unlink = Module["_shm_unlink"] = Module["asm"]["shm_unlink"]).apply(null, arguments)
            };
            var _unlink = Module["_unlink"] = function() {
                return (_unlink = Module["_unlink"] = Module["asm"]["unlink"]).apply(null, arguments)
            };
            var ___mprotect = Module["___mprotect"] = function() {
                return (___mprotect = Module["___mprotect"] = Module["asm"]["__mprotect"]).apply(null, arguments)
            };
            var _mprotect = Module["_mprotect"] = function() {
                return (_mprotect = Module["_mprotect"] = Module["asm"]["mprotect"]).apply(null, arguments)
            };
            var _munlockall = Module["_munlockall"] = function() {
                return (_munlockall = Module["_munlockall"] = Module["asm"]["munlockall"]).apply(null, arguments)
            };
            var _munmap = Module["_munmap"] = function() {
                return (_munmap = Module["_munmap"] = Module["asm"]["munmap"]).apply(null, arguments)
            };
            var _mlockall = Module["_mlockall"] = function() {
                return (_mlockall = Module["_mlockall"] = Module["asm"]["mlockall"]).apply(null, arguments)
            };
            var _mincore = Module["_mincore"] = function() {
                return (_mincore = Module["_mincore"] = Module["asm"]["mincore"]).apply(null, arguments)
            };
            var _lgammaf = Module["_lgammaf"] = function() {
                return (_lgammaf = Module["_lgammaf"] = Module["asm"]["lgammaf"]).apply(null, arguments)
            };
            var ___lgammaf_r = Module["___lgammaf_r"] = function() {
                return (___lgammaf_r = Module["___lgammaf_r"] = Module["asm"]["__lgammaf_r"]).apply(null, arguments)
            };
            var _atan2 = Module["_atan2"] = function() {
                return (_atan2 = Module["_atan2"] = Module["asm"]["atan2"]).apply(null, arguments)
            };
            var _atan = Module["_atan"] = function() {
                return (_atan = Module["_atan"] = Module["asm"]["atan"]).apply(null, arguments)
            };
            var _fabs = Module["_fabs"] = function() {
                return (_fabs = Module["_fabs"] = Module["asm"]["fabs"]).apply(null, arguments)
            };
            var _scalbn = Module["_scalbn"] = function() {
                return (_scalbn = Module["_scalbn"] = Module["asm"]["scalbn"]).apply(null, arguments)
            };
            var _remquol = Module["_remquol"] = function() {
                return (_remquol = Module["_remquol"] = Module["asm"]["remquol"]).apply(null, arguments)
            };
            var ___eqtf2 = Module["___eqtf2"] = function() {
                return (___eqtf2 = Module["___eqtf2"] = Module["asm"]["__eqtf2"]).apply(null, arguments)
            };
            var ___fpclassifyl = Module["___fpclassifyl"] = function() {
                return (___fpclassifyl = Module["___fpclassifyl"] = Module["asm"]["__fpclassifyl"]).apply(null, arguments)
            };
            var ___multf3 = Module["___multf3"] = function() {
                return (___multf3 = Module["___multf3"] = Module["asm"]["__multf3"]).apply(null, arguments)
            };
            var ___divtf3 = Module["___divtf3"] = function() {
                return (___divtf3 = Module["___divtf3"] = Module["asm"]["__divtf3"]).apply(null, arguments)
            };
            var ___addtf3 = Module["___addtf3"] = function() {
                return (___addtf3 = Module["___addtf3"] = Module["asm"]["__addtf3"]).apply(null, arguments)
            };
            var ___gttf2 = Module["___gttf2"] = function() {
                return (___gttf2 = Module["___gttf2"] = Module["asm"]["__gttf2"]).apply(null, arguments)
            };
            var ___netf2 = Module["___netf2"] = function() {
                return (___netf2 = Module["___netf2"] = Module["asm"]["__netf2"]).apply(null, arguments)
            };
            var ___subtf3 = Module["___subtf3"] = function() {
                return (___subtf3 = Module["___subtf3"] = Module["asm"]["__subtf3"]).apply(null, arguments)
            };
            var _modfl = Module["_modfl"] = function() {
                return (_modfl = Module["_modfl"] = Module["asm"]["modfl"]).apply(null, arguments)
            };
            var _tgammaf = Module["_tgammaf"] = function() {
                return (_tgammaf = Module["_tgammaf"] = Module["asm"]["tgammaf"]).apply(null, arguments)
            };
            var _tgamma = Module["_tgamma"] = function() {
                return (_tgamma = Module["_tgamma"] = Module["asm"]["tgamma"]).apply(null, arguments)
            };
            var _nan = Module["_nan"] = function() {
                return (_nan = Module["_nan"] = Module["asm"]["nan"]).apply(null, arguments)
            };
            var _nearbyintl = Module["_nearbyintl"] = function() {
                return (_nearbyintl = Module["_nearbyintl"] = Module["asm"]["nearbyintl"]).apply(null, arguments)
            };
            var _rintl = Module["_rintl"] = function() {
                return (_rintl = Module["_rintl"] = Module["asm"]["rintl"]).apply(null, arguments)
            };
            var _ilogbf = Module["_ilogbf"] = function() {
                return (_ilogbf = Module["_ilogbf"] = Module["asm"]["ilogbf"]).apply(null, arguments)
            };
            var ___lgammal_r = Module["___lgammal_r"] = function() {
                return (___lgammal_r = Module["___lgammal_r"] = Module["asm"]["__lgammal_r"]).apply(null, arguments)
            };
            var ___trunctfdf2 = Module["___trunctfdf2"] = function() {
                return (___trunctfdf2 = Module["___trunctfdf2"] = Module["asm"]["__trunctfdf2"]).apply(null, arguments)
            };
            var ___lgamma_r = Module["___lgamma_r"] = function() {
                return (___lgamma_r = Module["___lgamma_r"] = Module["asm"]["__lgamma_r"]).apply(null, arguments)
            };
            var ___extenddftf2 = Module["___extenddftf2"] = function() {
                return (___extenddftf2 = Module["___extenddftf2"] = Module["asm"]["__extenddftf2"]).apply(null, arguments)
            };
            var _lgammal = Module["_lgammal"] = function() {
                return (_lgammal = Module["_lgammal"] = Module["asm"]["lgammal"]).apply(null, arguments)
            };
            var _lgammal_r = Module["_lgammal_r"] = function() {
                return (_lgammal_r = Module["_lgammal_r"] = Module["asm"]["lgammal_r"]).apply(null, arguments)
            };
            var ___tandf = Module["___tandf"] = function() {
                return (___tandf = Module["___tandf"] = Module["asm"]["__tandf"]).apply(null, arguments)
            };
            var _scalb = Module["_scalb"] = function() {
                return (_scalb = Module["_scalb"] = Module["asm"]["scalb"]).apply(null, arguments)
            };
            var _rint = Module["_rint"] = function() {
                return (_rint = Module["_rint"] = Module["asm"]["rint"]).apply(null, arguments)
            };
            var _remainder = Module["_remainder"] = function() {
                return (_remainder = Module["_remainder"] = Module["asm"]["remainder"]).apply(null, arguments)
            };
            var _remquo = Module["_remquo"] = function() {
                return (_remquo = Module["_remquo"] = Module["asm"]["remquo"]).apply(null, arguments)
            };
            var _drem = Module["_drem"] = function() {
                return (_drem = Module["_drem"] = Module["asm"]["drem"]).apply(null, arguments)
            };
            var _logbl = Module["_logbl"] = function() {
                return (_logbl = Module["_logbl"] = Module["asm"]["logbl"]).apply(null, arguments)
            };
            var _ilogbl = Module["_ilogbl"] = function() {
                return (_ilogbl = Module["_ilogbl"] = Module["asm"]["ilogbl"]).apply(null, arguments)
            };
            var ___floatsitf = Module["___floatsitf"] = function() {
                return (___floatsitf = Module["___floatsitf"] = Module["asm"]["__floatsitf"]).apply(null, arguments)
            };
            var _sqrtl = Module["_sqrtl"] = function() {
                return (_sqrtl = Module["_sqrtl"] = Module["asm"]["sqrtl"]).apply(null, arguments)
            };
            var _sqrt = Module["_sqrt"] = function() {
                return (_sqrt = Module["_sqrt"] = Module["asm"]["sqrt"]).apply(null, arguments)
            };
            var ___invtrigl_R = Module["___invtrigl_R"] = function() {
                return (___invtrigl_R = Module["___invtrigl_R"] = Module["asm"]["__invtrigl_R"]).apply(null, arguments)
            };
            var _fabsf = Module["_fabsf"] = function() {
                return (_fabsf = Module["_fabsf"] = Module["asm"]["fabsf"]).apply(null, arguments)
            };
            var _sincosl = Module["_sincosl"] = function() {
                return (_sincosl = Module["_sincosl"] = Module["asm"]["sincosl"]).apply(null, arguments)
            };
            var ___lttf2 = Module["___lttf2"] = function() {
                return (___lttf2 = Module["___lttf2"] = Module["asm"]["__lttf2"]).apply(null, arguments)
            };
            var ___sinl = Module["___sinl"] = function() {
                return (___sinl = Module["___sinl"] = Module["asm"]["__sinl"]).apply(null, arguments)
            };
            var ___cosl = Module["___cosl"] = function() {
                return (___cosl = Module["___cosl"] = Module["asm"]["__cosl"]).apply(null, arguments)
            };
            var ___rem_pio2l = Module["___rem_pio2l"] = function() {
                return (___rem_pio2l = Module["___rem_pio2l"] = Module["asm"]["__rem_pio2l"]).apply(null, arguments)
            };
            var _log10l = Module["_log10l"] = function() {
                return (_log10l = Module["_log10l"] = Module["asm"]["log10l"]).apply(null, arguments)
            };
            var _logb = Module["_logb"] = function() {
                return (_logb = Module["_logb"] = Module["asm"]["logb"]).apply(null, arguments)
            };
            var _ilogb = Module["_ilogb"] = function() {
                return (_ilogb = Module["_ilogb"] = Module["asm"]["ilogb"]).apply(null, arguments)
            };
            var _frexpf = Module["_frexpf"] = function() {
                return (_frexpf = Module["_frexpf"] = Module["asm"]["frexpf"]).apply(null, arguments)
            };
            var _powl = Module["_powl"] = function() {
                return (_powl = Module["_powl"] = Module["asm"]["powl"]).apply(null, arguments)
            };
            var _pow = Module["_pow"] = function() {
                return (_pow = Module["_pow"] = Module["asm"]["pow"]).apply(null, arguments)
            };
            var ___fpclassifyf = Module["___fpclassifyf"] = function() {
                return (___fpclassifyf = Module["___fpclassifyf"] = Module["asm"]["__fpclassifyf"]).apply(null, arguments)
            };
            var _finitef = Module["_finitef"] = function() {
                return (_finitef = Module["_finitef"] = Module["asm"]["finitef"]).apply(null, arguments)
            };
            var _fabsl = Module["_fabsl"] = function() {
                return (_fabsl = Module["_fabsl"] = Module["asm"]["fabsl"]).apply(null, arguments)
            };
            var _trunc = Module["_trunc"] = function() {
                return (_trunc = Module["_trunc"] = Module["asm"]["trunc"]).apply(null, arguments)
            };
            var _nextafterf = Module["_nextafterf"] = function() {
                return (_nextafterf = Module["_nextafterf"] = Module["asm"]["nextafterf"]).apply(null, arguments)
            };
            var _cbrtl = Module["_cbrtl"] = function() {
                return (_cbrtl = Module["_cbrtl"] = Module["asm"]["cbrtl"]).apply(null, arguments)
            };
            var ___trunctfsf2 = Module["___trunctfsf2"] = function() {
                return (___trunctfsf2 = Module["___trunctfsf2"] = Module["asm"]["__trunctfsf2"]).apply(null, arguments)
            };
            var _remainderf = Module["_remainderf"] = function() {
                return (_remainderf = Module["_remainderf"] = Module["asm"]["remainderf"]).apply(null, arguments)
            };
            var _remquof = Module["_remquof"] = function() {
                return (_remquof = Module["_remquof"] = Module["asm"]["remquof"]).apply(null, arguments)
            };
            var _dremf = Module["_dremf"] = function() {
                return (_dremf = Module["_dremf"] = Module["asm"]["dremf"]).apply(null, arguments)
            };
            var ___expo2f = Module["___expo2f"] = function() {
                return (___expo2f = Module["___expo2f"] = Module["asm"]["__expo2f"]).apply(null, arguments)
            };
            var _expf = Module["_expf"] = function() {
                return (_expf = Module["_expf"] = Module["asm"]["expf"]).apply(null, arguments)
            };
            var ___fpclassify = Module["___fpclassify"] = function() {
                return (___fpclassify = Module["___fpclassify"] = Module["asm"]["__fpclassify"]).apply(null, arguments)
            };
            var _atan2f = Module["_atan2f"] = function() {
                return (_atan2f = Module["_atan2f"] = Module["asm"]["atan2f"]).apply(null, arguments)
            };
            var _atanf = Module["_atanf"] = function() {
                return (_atanf = Module["_atanf"] = Module["asm"]["atanf"]).apply(null, arguments)
            };
            var _j1 = Module["_j1"] = function() {
                return (_j1 = Module["_j1"] = Module["asm"]["j1"]).apply(null, arguments)
            };
            var _sin = Module["_sin"] = function() {
                return (_sin = Module["_sin"] = Module["asm"]["sin"]).apply(null, arguments)
            };
            var _y1 = Module["_y1"] = function() {
                return (_y1 = Module["_y1"] = Module["asm"]["y1"]).apply(null, arguments)
            };
            var _ldexp = Module["_ldexp"] = function() {
                return (_ldexp = Module["_ldexp"] = Module["asm"]["ldexp"]).apply(null, arguments)
            };
            var _nexttowardl = Module["_nexttowardl"] = function() {
                return (_nexttowardl = Module["_nexttowardl"] = Module["asm"]["nexttowardl"]).apply(null, arguments)
            };
            var _nextafterl = Module["_nextafterl"] = function() {
                return (_nextafterl = Module["_nextafterl"] = Module["asm"]["nextafterl"]).apply(null, arguments)
            };
            var _acosf = Module["_acosf"] = function() {
                return (_acosf = Module["_acosf"] = Module["asm"]["acosf"]).apply(null, arguments)
            };
            var _sqrtf = Module["_sqrtf"] = function() {
                return (_sqrtf = Module["_sqrtf"] = Module["asm"]["sqrtf"]).apply(null, arguments)
            };
            var _asin = Module["_asin"] = function() {
                return (_asin = Module["_asin"] = Module["asm"]["asin"]).apply(null, arguments)
            };
            var _scalbnf = Module["_scalbnf"] = function() {
                return (_scalbnf = Module["_scalbnf"] = Module["asm"]["scalbnf"]).apply(null, arguments)
            };
            var _log1pl = Module["_log1pl"] = function() {
                return (_log1pl = Module["_log1pl"] = Module["asm"]["log1pl"]).apply(null, arguments)
            };
            var _log1p = Module["_log1p"] = function() {
                return (_log1p = Module["_log1p"] = Module["asm"]["log1p"]).apply(null, arguments)
            };
            var _frexpl = Module["_frexpl"] = function() {
                return (_frexpl = Module["_frexpl"] = Module["asm"]["frexpl"]).apply(null, arguments)
            };
            var _sinl = Module["_sinl"] = function() {
                return (_sinl = Module["_sinl"] = Module["asm"]["sinl"]).apply(null, arguments)
            };
            var _logl = Module["_logl"] = function() {
                return (_logl = Module["_logl"] = Module["asm"]["logl"]).apply(null, arguments)
            };
            var _nearbyint = Module["_nearbyint"] = function() {
                return (_nearbyint = Module["_nearbyint"] = Module["asm"]["nearbyint"]).apply(null, arguments)
            };
            var _acos = Module["_acos"] = function() {
                return (_acos = Module["_acos"] = Module["asm"]["acos"]).apply(null, arguments)
            };
            var _rintf = Module["_rintf"] = function() {
                return (_rintf = Module["_rintf"] = Module["asm"]["rintf"]).apply(null, arguments)
            };
            var _llroundf = Module["_llroundf"] = function() {
                return (_llroundf = Module["_llroundf"] = Module["asm"]["llroundf"]).apply(null, arguments)
            };
            var _roundf = Module["_roundf"] = function() {
                return (_roundf = Module["_roundf"] = Module["asm"]["roundf"]).apply(null, arguments)
            };
            var _modf = Module["_modf"] = function() {
                return (_modf = Module["_modf"] = Module["asm"]["modf"]).apply(null, arguments)
            };
            var _lrint = Module["_lrint"] = function() {
                return (_lrint = Module["_lrint"] = Module["asm"]["lrint"]).apply(null, arguments)
            };
            var _sinhf = Module["_sinhf"] = function() {
                return (_sinhf = Module["_sinhf"] = Module["asm"]["sinhf"]).apply(null, arguments)
            };
            var _expm1f = Module["_expm1f"] = function() {
                return (_expm1f = Module["_expm1f"] = Module["asm"]["expm1f"]).apply(null, arguments)
            };
            var _acoshl = Module["_acoshl"] = function() {
                return (_acoshl = Module["_acoshl"] = Module["asm"]["acoshl"]).apply(null, arguments)
            };
            var _acosh = Module["_acosh"] = function() {
                return (_acosh = Module["_acosh"] = Module["asm"]["acosh"]).apply(null, arguments)
            };
            var _scalblnl = Module["_scalblnl"] = function() {
                return (_scalblnl = Module["_scalblnl"] = Module["asm"]["scalblnl"]).apply(null, arguments)
            };
            var _scalbnl = Module["_scalbnl"] = function() {
                return (_scalbnl = Module["_scalbnl"] = Module["asm"]["scalbnl"]).apply(null, arguments)
            };
            var ___tanl = Module["___tanl"] = function() {
                return (___tanl = Module["___tanl"] = Module["asm"]["__tanl"]).apply(null, arguments)
            };
            var ___getf2 = Module["___getf2"] = function() {
                return (___getf2 = Module["___getf2"] = Module["asm"]["__getf2"]).apply(null, arguments)
            };
            var _lround = Module["_lround"] = function() {
                return (_lround = Module["_lround"] = Module["asm"]["lround"]).apply(null, arguments)
            };
            var _round = Module["_round"] = function() {
                return (_round = Module["_round"] = Module["asm"]["round"]).apply(null, arguments)
            };
            var _scalblnf = Module["_scalblnf"] = function() {
                return (_scalblnf = Module["_scalblnf"] = Module["asm"]["scalblnf"]).apply(null, arguments)
            };
            var _atanh = Module["_atanh"] = function() {
                return (_atanh = Module["_atanh"] = Module["asm"]["atanh"]).apply(null, arguments)
            };
            var _llround = Module["_llround"] = function() {
                return (_llround = Module["_llround"] = Module["asm"]["llround"]).apply(null, arguments)
            };
            var _hypotf = Module["_hypotf"] = function() {
                return (_hypotf = Module["_hypotf"] = Module["asm"]["hypotf"]).apply(null, arguments)
            };
            var _significandf = Module["_significandf"] = function() {
                return (_significandf = Module["_significandf"] = Module["asm"]["significandf"]).apply(null, arguments)
            };
            var _cosh = Module["_cosh"] = function() {
                return (_cosh = Module["_cosh"] = Module["asm"]["cosh"]).apply(null, arguments)
            };
            var _expm1 = Module["_expm1"] = function() {
                return (_expm1 = Module["_expm1"] = Module["asm"]["expm1"]).apply(null, arguments)
            };
            var ___expo2 = Module["___expo2"] = function() {
                return (___expo2 = Module["___expo2"] = Module["asm"]["__expo2"]).apply(null, arguments)
            };
            var ___tan = Module["___tan"] = function() {
                return (___tan = Module["___tan"] = Module["asm"]["__tan"]).apply(null, arguments)
            };
            var _truncf = Module["_truncf"] = function() {
                return (_truncf = Module["_truncf"] = Module["asm"]["truncf"]).apply(null, arguments)
            };
            var ___fixtfdi = Module["___fixtfdi"] = function() {
                return (___fixtfdi = Module["___fixtfdi"] = Module["asm"]["__fixtfdi"]).apply(null, arguments)
            };
            var ___fixtfsi = Module["___fixtfsi"] = function() {
                return (___fixtfsi = Module["___fixtfsi"] = Module["asm"]["__fixtfsi"]).apply(null, arguments)
            };
            var ___rem_pio2_large = Module["___rem_pio2_large"] = function() {
                return (___rem_pio2_large = Module["___rem_pio2_large"] = Module["asm"]["__rem_pio2_large"]).apply(null, arguments)
            };
            var _llrintf = Module["_llrintf"] = function() {
                return (_llrintf = Module["_llrintf"] = Module["asm"]["llrintf"]).apply(null, arguments)
            };
            var _asinhf = Module["_asinhf"] = function() {
                return (_asinhf = Module["_asinhf"] = Module["asm"]["asinhf"]).apply(null, arguments)
            };
            var _logf = Module["_logf"] = function() {
                return (_logf = Module["_logf"] = Module["asm"]["logf"]).apply(null, arguments)
            };
            var _log1pf = Module["_log1pf"] = function() {
                return (_log1pf = Module["_log1pf"] = Module["asm"]["log1pf"]).apply(null, arguments)
            };
            var _ceil = Module["_ceil"] = function() {
                return (_ceil = Module["_ceil"] = Module["asm"]["ceil"]).apply(null, arguments)
            };
            var _ldexpf = Module["_ldexpf"] = function() {
                return (_ldexpf = Module["_ldexpf"] = Module["asm"]["ldexpf"]).apply(null, arguments)
            };
            var _atanhl = Module["_atanhl"] = function() {
                return (_atanhl = Module["_atanhl"] = Module["asm"]["atanhl"]).apply(null, arguments)
            };
            var _frexp = Module["_frexp"] = function() {
                return (_frexp = Module["_frexp"] = Module["asm"]["frexp"]).apply(null, arguments)
            };
            var _tanl = Module["_tanl"] = function() {
                return (_tanl = Module["_tanl"] = Module["asm"]["tanl"]).apply(null, arguments)
            };
            var _tanhl = Module["_tanhl"] = function() {
                return (_tanhl = Module["_tanhl"] = Module["asm"]["tanhl"]).apply(null, arguments)
            };
            var _tanh = Module["_tanh"] = function() {
                return (_tanh = Module["_tanh"] = Module["asm"]["tanh"]).apply(null, arguments)
            };
            var _coshl = Module["_coshl"] = function() {
                return (_coshl = Module["_coshl"] = Module["asm"]["coshl"]).apply(null, arguments)
            };
            var ___cosdf = Module["___cosdf"] = function() {
                return (___cosdf = Module["___cosdf"] = Module["asm"]["__cosdf"]).apply(null, arguments)
            };
            var _fmal = Module["_fmal"] = function() {
                return (_fmal = Module["_fmal"] = Module["asm"]["fmal"]).apply(null, arguments)
            };
            var _fegetround = Module["_fegetround"] = function() {
                return (_fegetround = Module["_fegetround"] = Module["asm"]["fegetround"]).apply(null, arguments)
            };
            var _copysignl = Module["_copysignl"] = function() {
                return (_copysignl = Module["_copysignl"] = Module["asm"]["copysignl"]).apply(null, arguments)
            };
            var _fesetround = Module["_fesetround"] = function() {
                return (_fesetround = Module["_fesetround"] = Module["asm"]["fesetround"]).apply(null, arguments)
            };
            var _truncl = Module["_truncl"] = function() {
                return (_truncl = Module["_truncl"] = Module["asm"]["truncl"]).apply(null, arguments)
            };
            var _log2l = Module["_log2l"] = function() {
                return (_log2l = Module["_log2l"] = Module["asm"]["log2l"]).apply(null, arguments)
            };
            var _log2 = Module["_log2"] = function() {
                return (_log2 = Module["_log2"] = Module["asm"]["log2"]).apply(null, arguments)
            };
            var _significand = Module["_significand"] = function() {
                return (_significand = Module["_significand"] = Module["asm"]["significand"]).apply(null, arguments)
            };
            var _asinl = Module["_asinl"] = function() {
                return (_asinl = Module["_asinl"] = Module["asm"]["asinl"]).apply(null, arguments)
            };
            var _floor = Module["_floor"] = function() {
                return (_floor = Module["_floor"] = Module["asm"]["floor"]).apply(null, arguments)
            };
            var _finite = Module["_finite"] = function() {
                return (_finite = Module["_finite"] = Module["asm"]["finite"]).apply(null, arguments)
            };
            var _j0f = Module["_j0f"] = function() {
                return (_j0f = Module["_j0f"] = Module["asm"]["j0f"]).apply(null, arguments)
            };
            var _sinf = Module["_sinf"] = function() {
                return (_sinf = Module["_sinf"] = Module["asm"]["sinf"]).apply(null, arguments)
            };
            var _cosf = Module["_cosf"] = function() {
                return (_cosf = Module["_cosf"] = Module["asm"]["cosf"]).apply(null, arguments)
            };
            var _y0f = Module["_y0f"] = function() {
                return (_y0f = Module["_y0f"] = Module["asm"]["y0f"]).apply(null, arguments)
            };
            var _fmaf = Module["_fmaf"] = function() {
                return (_fmaf = Module["_fmaf"] = Module["asm"]["fmaf"]).apply(null, arguments)
            };
            var _remainderl = Module["_remainderl"] = function() {
                return (_remainderl = Module["_remainderl"] = Module["asm"]["remainderl"]).apply(null, arguments)
            };
            var _cbrt = Module["_cbrt"] = function() {
                return (_cbrt = Module["_cbrt"] = Module["asm"]["cbrt"]).apply(null, arguments)
            };
            var _logbf = Module["_logbf"] = function() {
                return (_logbf = Module["_logbf"] = Module["asm"]["logbf"]).apply(null, arguments)
            };
            var _sincos = Module["_sincos"] = function() {
                return (_sincos = Module["_sincos"] = Module["asm"]["sincos"]).apply(null, arguments)
            };
            var ___sin = Module["___sin"] = function() {
                return (___sin = Module["___sin"] = Module["asm"]["__sin"]).apply(null, arguments)
            };
            var ___cos = Module["___cos"] = function() {
                return (___cos = Module["___cos"] = Module["asm"]["__cos"]).apply(null, arguments)
            };
            var ___rem_pio2 = Module["___rem_pio2"] = function() {
                return (___rem_pio2 = Module["___rem_pio2"] = Module["asm"]["__rem_pio2"]).apply(null, arguments)
            };
            var _jn = Module["_jn"] = function() {
                return (_jn = Module["_jn"] = Module["asm"]["jn"]).apply(null, arguments)
            };
            var _j0 = Module["_j0"] = function() {
                return (_j0 = Module["_j0"] = Module["asm"]["j0"]).apply(null, arguments)
            };
            var _yn = Module["_yn"] = function() {
                return (_yn = Module["_yn"] = Module["asm"]["yn"]).apply(null, arguments)
            };
            var _y0 = Module["_y0"] = function() {
                return (_y0 = Module["_y0"] = Module["asm"]["y0"]).apply(null, arguments)
            };
            var _exp10l = Module["_exp10l"] = function() {
                return (_exp10l = Module["_exp10l"] = Module["asm"]["exp10l"]).apply(null, arguments)
            };
            var _exp2l = Module["_exp2l"] = function() {
                return (_exp2l = Module["_exp2l"] = Module["asm"]["exp2l"]).apply(null, arguments)
            };
            var _pow10l = Module["_pow10l"] = function() {
                return (_pow10l = Module["_pow10l"] = Module["asm"]["pow10l"]).apply(null, arguments)
            };
            var _ceill = Module["_ceill"] = function() {
                return (_ceill = Module["_ceill"] = Module["asm"]["ceill"]).apply(null, arguments)
            };
            var _jnf = Module["_jnf"] = function() {
                return (_jnf = Module["_jnf"] = Module["asm"]["jnf"]).apply(null, arguments)
            };
            var _j1f = Module["_j1f"] = function() {
                return (_j1f = Module["_j1f"] = Module["asm"]["j1f"]).apply(null, arguments)
            };
            var _ynf = Module["_ynf"] = function() {
                return (_ynf = Module["_ynf"] = Module["asm"]["ynf"]).apply(null, arguments)
            };
            var _y1f = Module["_y1f"] = function() {
                return (_y1f = Module["_y1f"] = Module["asm"]["y1f"]).apply(null, arguments)
            };
            var _hypotl = Module["_hypotl"] = function() {
                return (_hypotl = Module["_hypotl"] = Module["asm"]["hypotl"]).apply(null, arguments)
            };
            var _powf = Module["_powf"] = function() {
                return (_powf = Module["_powf"] = Module["asm"]["powf"]).apply(null, arguments)
            };
            var _tanhf = Module["_tanhf"] = function() {
                return (_tanhf = Module["_tanhf"] = Module["asm"]["tanhf"]).apply(null, arguments)
            };
            var ___sindf = Module["___sindf"] = function() {
                return (___sindf = Module["___sindf"] = Module["asm"]["__sindf"]).apply(null, arguments)
            };
            var ___rem_pio2f = Module["___rem_pio2f"] = function() {
                return (___rem_pio2f = Module["___rem_pio2f"] = Module["asm"]["__rem_pio2f"]).apply(null, arguments)
            };
            var _lroundl = Module["_lroundl"] = function() {
                return (_lroundl = Module["_lroundl"] = Module["asm"]["lroundl"]).apply(null, arguments)
            };
            var _roundl = Module["_roundl"] = function() {
                return (_roundl = Module["_roundl"] = Module["asm"]["roundl"]).apply(null, arguments)
            };
            var _fma = Module["_fma"] = function() {
                return (_fma = Module["_fma"] = Module["asm"]["fma"]).apply(null, arguments)
            };
            var _nextafter = Module["_nextafter"] = function() {
                return (_nextafter = Module["_nextafter"] = Module["asm"]["nextafter"]).apply(null, arguments)
            };
            var _copysign = Module["_copysign"] = function() {
                return (_copysign = Module["_copysign"] = Module["asm"]["copysign"]).apply(null, arguments)
            };
            var _lgamma = Module["_lgamma"] = function() {
                return (_lgamma = Module["_lgamma"] = Module["asm"]["lgamma"]).apply(null, arguments)
            };
            var _acoshf = Module["_acoshf"] = function() {
                return (_acoshf = Module["_acoshf"] = Module["asm"]["acoshf"]).apply(null, arguments)
            };
            var _asinhl = Module["_asinhl"] = function() {
                return (_asinhl = Module["_asinhl"] = Module["asm"]["asinhl"]).apply(null, arguments)
            };
            var _asinh = Module["_asinh"] = function() {
                return (_asinh = Module["_asinh"] = Module["asm"]["asinh"]).apply(null, arguments)
            };
            var _modff = Module["_modff"] = function() {
                return (_modff = Module["_modff"] = Module["asm"]["modff"]).apply(null, arguments)
            };
            var _llroundl = Module["_llroundl"] = function() {
                return (_llroundl = Module["_llroundl"] = Module["asm"]["llroundl"]).apply(null, arguments)
            };
            var _copysignf = Module["_copysignf"] = function() {
                return (_copysignf = Module["_copysignf"] = Module["asm"]["copysignf"]).apply(null, arguments)
            };
            var _atanhf = Module["_atanhf"] = function() {
                return (_atanhf = Module["_atanhf"] = Module["asm"]["atanhf"]).apply(null, arguments)
            };
            var _erfl = Module["_erfl"] = function() {
                return (_erfl = Module["_erfl"] = Module["asm"]["erfl"]).apply(null, arguments)
            };
            var _erf = Module["_erf"] = function() {
                return (_erf = Module["_erf"] = Module["asm"]["erf"]).apply(null, arguments)
            };
            var _erfcl = Module["_erfcl"] = function() {
                return (_erfcl = Module["_erfcl"] = Module["asm"]["erfcl"]).apply(null, arguments)
            };
            var _erfc = Module["_erfc"] = function() {
                return (_erfc = Module["_erfc"] = Module["asm"]["erfc"]).apply(null, arguments)
            };
            var _hypot = Module["_hypot"] = function() {
                return (_hypot = Module["_hypot"] = Module["asm"]["hypot"]).apply(null, arguments)
            };
            var _ldexpl = Module["_ldexpl"] = function() {
                return (_ldexpl = Module["_ldexpl"] = Module["asm"]["ldexpl"]).apply(null, arguments)
            };
            var _atan2l = Module["_atan2l"] = function() {
                return (_atan2l = Module["_atan2l"] = Module["asm"]["atan2l"]).apply(null, arguments)
            };
            var _atanl = Module["_atanl"] = function() {
                return (_atanl = Module["_atanl"] = Module["asm"]["atanl"]).apply(null, arguments)
            };
            var _floorf = Module["_floorf"] = function() {
                return (_floorf = Module["_floorf"] = Module["asm"]["floorf"]).apply(null, arguments)
            };
            var _nanl = Module["_nanl"] = function() {
                return (_nanl = Module["_nanl"] = Module["asm"]["nanl"]).apply(null, arguments)
            };
            var _fdim = Module["_fdim"] = function() {
                return (_fdim = Module["_fdim"] = Module["asm"]["fdim"]).apply(null, arguments)
            };
            var ___polevll = Module["___polevll"] = function() {
                return (___polevll = Module["___polevll"] = Module["asm"]["__polevll"]).apply(null, arguments)
            };
            var ___p1evll = Module["___p1evll"] = function() {
                return (___p1evll = Module["___p1evll"] = Module["asm"]["__p1evll"]).apply(null, arguments)
            };
            var _lgammaf_r = Module["_lgammaf_r"] = function() {
                return (_lgammaf_r = Module["_lgammaf_r"] = Module["asm"]["lgammaf_r"]).apply(null, arguments)
            };
            var _cbrtf = Module["_cbrtf"] = function() {
                return (_cbrtf = Module["_cbrtf"] = Module["asm"]["cbrtf"]).apply(null, arguments)
            };
            var _tan = Module["_tan"] = function() {
                return (_tan = Module["_tan"] = Module["asm"]["tan"]).apply(null, arguments)
            };
            var _tgammal = Module["_tgammal"] = function() {
                return (_tgammal = Module["_tgammal"] = Module["asm"]["tgammal"]).apply(null, arguments)
            };
            var _fdiml = Module["_fdiml"] = function() {
                return (_fdiml = Module["_fdiml"] = Module["asm"]["fdiml"]).apply(null, arguments)
            };
            var _coshf = Module["_coshf"] = function() {
                return (_coshf = Module["_coshf"] = Module["asm"]["coshf"]).apply(null, arguments)
            };
            var _acosl = Module["_acosl"] = function() {
                return (_acosl = Module["_acosl"] = Module["asm"]["acosl"]).apply(null, arguments)
            };
            var _sinhl = Module["_sinhl"] = function() {
                return (_sinhl = Module["_sinhl"] = Module["asm"]["sinhl"]).apply(null, arguments)
            };
            var _sinh = Module["_sinh"] = function() {
                return (_sinh = Module["_sinh"] = Module["asm"]["sinh"]).apply(null, arguments)
            };
            var _lrintl = Module["_lrintl"] = function() {
                return (_lrintl = Module["_lrintl"] = Module["asm"]["lrintl"]).apply(null, arguments)
            };
            var _lgamma_r = Module["_lgamma_r"] = function() {
                return (_lgamma_r = Module["_lgamma_r"] = Module["asm"]["lgamma_r"]).apply(null, arguments)
            };
            var _llrintl = Module["_llrintl"] = function() {
                return (_llrintl = Module["_llrintl"] = Module["asm"]["llrintl"]).apply(null, arguments)
            };
            var _expm1l = Module["_expm1l"] = function() {
                return (_expm1l = Module["_expm1l"] = Module["asm"]["expm1l"]).apply(null, arguments)
            };
            var _lroundf = Module["_lroundf"] = function() {
                return (_lroundf = Module["_lroundf"] = Module["asm"]["lroundf"]).apply(null, arguments)
            };
            var _floorl = Module["_floorl"] = function() {
                return (_floorl = Module["_floorl"] = Module["asm"]["floorl"]).apply(null, arguments)
            };
            var _tanf = Module["_tanf"] = function() {
                return (_tanf = Module["_tanf"] = Module["asm"]["tanf"]).apply(null, arguments)
            };
            var _expl = Module["_expl"] = function() {
                return (_expl = Module["_expl"] = Module["asm"]["expl"]).apply(null, arguments)
            };
            var _scalbln = Module["_scalbln"] = function() {
                return (_scalbln = Module["_scalbln"] = Module["asm"]["scalbln"]).apply(null, arguments)
            };
            var _nanf = Module["_nanf"] = function() {
                return (_nanf = Module["_nanf"] = Module["asm"]["nanf"]).apply(null, arguments)
            };
            var _asinf = Module["_asinf"] = function() {
                return (_asinf = Module["_asinf"] = Module["asm"]["asinf"]).apply(null, arguments)
            };
            var _cosl = Module["_cosl"] = function() {
                return (_cosl = Module["_cosl"] = Module["asm"]["cosl"]).apply(null, arguments)
            };
            var _nexttowardf = Module["_nexttowardf"] = function() {
                return (_nexttowardf = Module["_nexttowardf"] = Module["asm"]["nexttowardf"]).apply(null, arguments)
            };
            var ___extendsftf2 = Module["___extendsftf2"] = function() {
                return (___extendsftf2 = Module["___extendsftf2"] = Module["asm"]["__extendsftf2"]).apply(null, arguments)
            };
            var ___signbitl = Module["___signbitl"] = function() {
                return (___signbitl = Module["___signbitl"] = Module["asm"]["__signbitl"]).apply(null, arguments)
            };
            var _fdimf = Module["_fdimf"] = function() {
                return (_fdimf = Module["_fdimf"] = Module["asm"]["fdimf"]).apply(null, arguments)
            };
            var _nearbyintf = Module["_nearbyintf"] = function() {
                return (_nearbyintf = Module["_nearbyintf"] = Module["asm"]["nearbyintf"]).apply(null, arguments)
            };
            var ___letf2 = Module["___letf2"] = function() {
                return (___letf2 = Module["___letf2"] = Module["asm"]["__letf2"]).apply(null, arguments)
            };
            var _ceilf = Module["_ceilf"] = function() {
                return (_ceilf = Module["_ceilf"] = Module["asm"]["ceilf"]).apply(null, arguments)
            };
            var _llrint = Module["_llrint"] = function() {
                return (_llrint = Module["_llrint"] = Module["asm"]["llrint"]).apply(null, arguments)
            };
            var _sincosf = Module["_sincosf"] = function() {
                return (_sincosf = Module["_sincosf"] = Module["asm"]["sincosf"]).apply(null, arguments)
            };
            var _nexttoward = Module["_nexttoward"] = function() {
                return (_nexttoward = Module["_nexttoward"] = Module["asm"]["nexttoward"]).apply(null, arguments)
            };
            var _scalbf = Module["_scalbf"] = function() {
                return (_scalbf = Module["_scalbf"] = Module["asm"]["scalbf"]).apply(null, arguments)
            };
            var _erff = Module["_erff"] = function() {
                return (_erff = Module["_erff"] = Module["asm"]["erff"]).apply(null, arguments)
            };
            var _erfcf = Module["_erfcf"] = function() {
                return (_erfcf = Module["_erfcf"] = Module["asm"]["erfcf"]).apply(null, arguments)
            };
            var ___stdio_seek = Module["___stdio_seek"] = function() {
                return (___stdio_seek = Module["___stdio_seek"] = Module["asm"]["__stdio_seek"]).apply(null, arguments)
            };
            var ___wasi_syscall_ret = Module["___wasi_syscall_ret"] = function() {
                return (___wasi_syscall_ret = Module["___wasi_syscall_ret"] = Module["asm"]["__wasi_syscall_ret"]).apply(null, arguments)
            };
            var _perror = Module["_perror"] = function() {
                return (_perror = Module["_perror"] = Module["asm"]["perror"]).apply(null, arguments)
            };
            var _strerror = Module["_strerror"] = function() {
                return (_strerror = Module["_strerror"] = Module["asm"]["strerror"]).apply(null, arguments)
            };
            var ___lockfile = Module["___lockfile"] = function() {
                return (___lockfile = Module["___lockfile"] = Module["asm"]["__lockfile"]).apply(null, arguments)
            };
            var _fputc = Module["_fputc"] = function() {
                return (_fputc = Module["_fputc"] = Module["asm"]["fputc"]).apply(null, arguments)
            };
            var ___unlockfile = Module["___unlockfile"] = function() {
                return (___unlockfile = Module["___unlockfile"] = Module["asm"]["__unlockfile"]).apply(null, arguments)
            };
            var _tempnam = Module["_tempnam"] = function() {
                return (_tempnam = Module["_tempnam"] = Module["asm"]["tempnam"]).apply(null, arguments)
            };
            var ___randname = Module["___randname"] = function() {
                return (___randname = Module["___randname"] = Module["asm"]["__randname"]).apply(null, arguments)
            };
            var _getline = Module["_getline"] = function() {
                return (_getline = Module["_getline"] = Module["asm"]["getline"]).apply(null, arguments)
            };
            var _getdelim = Module["_getdelim"] = function() {
                return (_getdelim = Module["_getdelim"] = Module["asm"]["getdelim"]).apply(null, arguments)
            };
            var _putchar = Module["_putchar"] = function() {
                return (_putchar = Module["_putchar"] = Module["asm"]["putchar"]).apply(null, arguments)
            };
            var _rename = Module["_rename"] = function() {
                return (_rename = Module["_rename"] = Module["asm"]["rename"]).apply(null, arguments)
            };
            var _tmpnam = Module["_tmpnam"] = function() {
                return (_tmpnam = Module["_tmpnam"] = Module["asm"]["tmpnam"]).apply(null, arguments)
            };
            var _vsscanf = Module["_vsscanf"] = function() {
                return (_vsscanf = Module["_vsscanf"] = Module["asm"]["vsscanf"]).apply(null, arguments)
            };
            var _vfscanf = Module["_vfscanf"] = function() {
                return (_vfscanf = Module["_vfscanf"] = Module["asm"]["vfscanf"]).apply(null, arguments)
            };
            var ___string_read = Module["___string_read"] = function() {
                return (___string_read = Module["___string_read"] = Module["asm"]["__string_read"]).apply(null, arguments)
            };
            var ___isoc99_vsscanf = Module["___isoc99_vsscanf"] = function() {
                return (___isoc99_vsscanf = Module["___isoc99_vsscanf"] = Module["asm"]["__isoc99_vsscanf"]).apply(null, arguments)
            };
            var ___fmodeflags = Module["___fmodeflags"] = function() {
                return (___fmodeflags = Module["___fmodeflags"] = Module["asm"]["__fmodeflags"]).apply(null, arguments)
            };
            var _clearerr = Module["_clearerr"] = function() {
                return (_clearerr = Module["_clearerr"] = Module["asm"]["clearerr"]).apply(null, arguments)
            };
            var _clearerr_unlocked = Module["_clearerr_unlocked"] = function() {
                return (_clearerr_unlocked = Module["_clearerr_unlocked"] = Module["asm"]["clearerr_unlocked"]).apply(null, arguments)
            };
            var _ungetwc = Module["_ungetwc"] = function() {
                return (_ungetwc = Module["_ungetwc"] = Module["asm"]["ungetwc"]).apply(null, arguments)
            };
            var _fwide = Module["_fwide"] = function() {
                return (_fwide = Module["_fwide"] = Module["asm"]["fwide"]).apply(null, arguments)
            };
            var ___toread = Module["___toread"] = function() {
                return (___toread = Module["___toread"] = Module["asm"]["__toread"]).apply(null, arguments)
            };
            var _wcrtomb = Module["_wcrtomb"] = function() {
                return (_wcrtomb = Module["_wcrtomb"] = Module["asm"]["wcrtomb"]).apply(null, arguments)
            };
            var _wprintf = Module["_wprintf"] = function() {
                return (_wprintf = Module["_wprintf"] = Module["asm"]["wprintf"]).apply(null, arguments)
            };
            var _vwprintf = Module["_vwprintf"] = function() {
                return (_vwprintf = Module["_vwprintf"] = Module["asm"]["vwprintf"]).apply(null, arguments)
            };
            var _fread = Module["_fread"] = function() {
                return (_fread = Module["_fread"] = Module["asm"]["fread"]).apply(null, arguments)
            };
            var _fread_unlocked = Module["_fread_unlocked"] = function() {
                return (_fread_unlocked = Module["_fread_unlocked"] = Module["asm"]["fread_unlocked"]).apply(null, arguments)
            };
            var _vasprintf = Module["_vasprintf"] = function() {
                return (_vasprintf = Module["_vasprintf"] = Module["asm"]["vasprintf"]).apply(null, arguments)
            };
            var _fmemopen = Module["_fmemopen"] = function() {
                return (_fmemopen = Module["_fmemopen"] = Module["asm"]["fmemopen"]).apply(null, arguments)
            };
            var ___ofl_add = Module["___ofl_add"] = function() {
                return (___ofl_add = Module["___ofl_add"] = Module["asm"]["__ofl_add"]).apply(null, arguments)
            };
            var _ftrylockfile = Module["_ftrylockfile"] = function() {
                return (_ftrylockfile = Module["_ftrylockfile"] = Module["asm"]["ftrylockfile"]).apply(null, arguments)
            };
            var _ungetc = Module["_ungetc"] = function() {
                return (_ungetc = Module["_ungetc"] = Module["asm"]["ungetc"]).apply(null, arguments)
            };
            var _swprintf = Module["_swprintf"] = function() {
                return (_swprintf = Module["_swprintf"] = Module["asm"]["swprintf"]).apply(null, arguments)
            };
            var _vswprintf = Module["_vswprintf"] = function() {
                return (_vswprintf = Module["_vswprintf"] = Module["asm"]["vswprintf"]).apply(null, arguments)
            };
            var _fgetln = Module["_fgetln"] = function() {
                return (_fgetln = Module["_fgetln"] = Module["asm"]["fgetln"]).apply(null, arguments)
            };
            var ___uflow = Module["___uflow"] = function() {
                return (___uflow = Module["___uflow"] = Module["asm"]["__uflow"]).apply(null, arguments)
            };
            var _memchr = Module["_memchr"] = function() {
                return (_memchr = Module["_memchr"] = Module["asm"]["memchr"]).apply(null, arguments)
            };
            var _vswscanf = Module["_vswscanf"] = function() {
                return (_vswscanf = Module["_vswscanf"] = Module["asm"]["vswscanf"]).apply(null, arguments)
            };
            var _vfwscanf = Module["_vfwscanf"] = function() {
                return (_vfwscanf = Module["_vfwscanf"] = Module["asm"]["vfwscanf"]).apply(null, arguments)
            };
            var _wcsrtombs = Module["_wcsrtombs"] = function() {
                return (_wcsrtombs = Module["_wcsrtombs"] = Module["asm"]["wcsrtombs"]).apply(null, arguments)
            };
            var ___isoc99_vswscanf = Module["___isoc99_vswscanf"] = function() {
                return (___isoc99_vswscanf = Module["___isoc99_vswscanf"] = Module["asm"]["__isoc99_vswscanf"]).apply(null, arguments)
            };
            var ___fgetwc_unlocked = Module["___fgetwc_unlocked"] = function() {
                return (___fgetwc_unlocked = Module["___fgetwc_unlocked"] = Module["asm"]["__fgetwc_unlocked"]).apply(null, arguments)
            };
            var _mbsinit = Module["_mbsinit"] = function() {
                return (_mbsinit = Module["_mbsinit"] = Module["asm"]["mbsinit"]).apply(null, arguments)
            };
            var _fgetwc = Module["_fgetwc"] = function() {
                return (_fgetwc = Module["_fgetwc"] = Module["asm"]["fgetwc"]).apply(null, arguments)
            };
            var _fgetwc_unlocked = Module["_fgetwc_unlocked"] = function() {
                return (_fgetwc_unlocked = Module["_fgetwc_unlocked"] = Module["asm"]["fgetwc_unlocked"]).apply(null, arguments)
            };
            var _getwc_unlocked = Module["_getwc_unlocked"] = function() {
                return (_getwc_unlocked = Module["_getwc_unlocked"] = Module["asm"]["getwc_unlocked"]).apply(null, arguments)
            };
            var _getchar_unlocked = Module["_getchar_unlocked"] = function() {
                return (_getchar_unlocked = Module["_getchar_unlocked"] = Module["asm"]["getchar_unlocked"]).apply(null, arguments)
            };
            var _vfwprintf = Module["_vfwprintf"] = function() {
                return (_vfwprintf = Module["_vfwprintf"] = Module["asm"]["vfwprintf"]).apply(null, arguments)
            };
            var _getwc = Module["_getwc"] = function() {
                return (_getwc = Module["_getwc"] = Module["asm"]["getwc"]).apply(null, arguments)
            };
            var _rewind = Module["_rewind"] = function() {
                return (_rewind = Module["_rewind"] = Module["asm"]["rewind"]).apply(null, arguments)
            };
            var ___fseeko_unlocked = Module["___fseeko_unlocked"] = function() {
                return (___fseeko_unlocked = Module["___fseeko_unlocked"] = Module["asm"]["__fseeko_unlocked"]).apply(null, arguments)
            };
            var ___getdelim = Module["___getdelim"] = function() {
                return (___getdelim = Module["___getdelim"] = Module["asm"]["__getdelim"]).apply(null, arguments)
            };
            var ___stdio_close = Module["___stdio_close"] = function() {
                return (___stdio_close = Module["___stdio_close"] = Module["asm"]["__stdio_close"]).apply(null, arguments)
            };
            var ___aio_close = Module["___aio_close"] = function() {
                return (___aio_close = Module["___aio_close"] = Module["asm"]["__aio_close"]).apply(null, arguments)
            };
            var _setbuf = Module["_setbuf"] = function() {
                return (_setbuf = Module["_setbuf"] = Module["asm"]["setbuf"]).apply(null, arguments)
            };
            var _setvbuf = Module["_setvbuf"] = function() {
                return (_setvbuf = Module["_setvbuf"] = Module["asm"]["setvbuf"]).apply(null, arguments)
            };
            var ___overflow = Module["___overflow"] = function() {
                return (___overflow = Module["___overflow"] = Module["asm"]["__overflow"]).apply(null, arguments)
            };
            var _ferror_unlocked = Module["_ferror_unlocked"] = function() {
                return (_ferror_unlocked = Module["_ferror_unlocked"] = Module["asm"]["ferror_unlocked"]).apply(null, arguments)
            };
            var __IO_ferror_unlocked = Module["__IO_ferror_unlocked"] = function() {
                return (__IO_ferror_unlocked = Module["__IO_ferror_unlocked"] = Module["asm"]["_IO_ferror_unlocked"]).apply(null, arguments)
            };
            var __IO_putc = Module["__IO_putc"] = function() {
                return (__IO_putc = Module["__IO_putc"] = Module["asm"]["_IO_putc"]).apply(null, arguments)
            };
            var _vfprintf = Module["_vfprintf"] = function() {
                return (_vfprintf = Module["_vfprintf"] = Module["asm"]["vfprintf"]).apply(null, arguments)
            };
            var _vfiprintf = Module["_vfiprintf"] = function() {
                return (_vfiprintf = Module["_vfiprintf"] = Module["asm"]["vfiprintf"]).apply(null, arguments)
            };
            var ___small_fprintf = Module["___small_fprintf"] = function() {
                return (___small_fprintf = Module["___small_fprintf"] = Module["asm"]["__small_fprintf"]).apply(null, arguments)
            };
            var ___small_vfprintf = Module["___small_vfprintf"] = function() {
                return (___small_vfprintf = Module["___small_vfprintf"] = Module["asm"]["__small_vfprintf"]).apply(null, arguments)
            };
            var _fgetc = Module["_fgetc"] = function() {
                return (_fgetc = Module["_fgetc"] = Module["asm"]["fgetc"]).apply(null, arguments)
            };
            var _getchar = Module["_getchar"] = function() {
                return (_getchar = Module["_getchar"] = Module["asm"]["getchar"]).apply(null, arguments)
            };
            var _fflush = Module["_fflush"] = function() {
                return (_fflush = Module["_fflush"] = Module["asm"]["fflush"]).apply(null, arguments)
            };
            var ___ofl_lock = Module["___ofl_lock"] = function() {
                return (___ofl_lock = Module["___ofl_lock"] = Module["asm"]["__ofl_lock"]).apply(null, arguments)
            };
            var ___ofl_unlock = Module["___ofl_unlock"] = function() {
                return (___ofl_unlock = Module["___ofl_unlock"] = Module["asm"]["__ofl_unlock"]).apply(null, arguments)
            };
            var _fflush_unlocked = Module["_fflush_unlocked"] = function() {
                return (_fflush_unlocked = Module["_fflush_unlocked"] = Module["asm"]["fflush_unlocked"]).apply(null, arguments)
            };
            var _wscanf = Module["_wscanf"] = function() {
                return (_wscanf = Module["_wscanf"] = Module["asm"]["wscanf"]).apply(null, arguments)
            };
            var _vwscanf = Module["_vwscanf"] = function() {
                return (_vwscanf = Module["_vwscanf"] = Module["asm"]["vwscanf"]).apply(null, arguments)
            };
            var ___isoc99_wscanf = Module["___isoc99_wscanf"] = function() {
                return (___isoc99_wscanf = Module["___isoc99_wscanf"] = Module["asm"]["__isoc99_wscanf"]).apply(null, arguments)
            };
            var ___unlist_locked_file = Module["___unlist_locked_file"] = function() {
                return (___unlist_locked_file = Module["___unlist_locked_file"] = Module["asm"]["__unlist_locked_file"]).apply(null, arguments)
            };
            var ___shlim = Module["___shlim"] = function() {
                return (___shlim = Module["___shlim"] = Module["asm"]["__shlim"]).apply(null, arguments)
            };
            var ___shgetc = Module["___shgetc"] = function() {
                return (___shgetc = Module["___shgetc"] = Module["asm"]["__shgetc"]).apply(null, arguments)
            };
            var ___floatscan = Module["___floatscan"] = function() {
                return (___floatscan = Module["___floatscan"] = Module["asm"]["__floatscan"]).apply(null, arguments)
            };
            var ___intscan = Module["___intscan"] = function() {
                return (___intscan = Module["___intscan"] = Module["asm"]["__intscan"]).apply(null, arguments)
            };
            var ___isoc99_vfscanf = Module["___isoc99_vfscanf"] = function() {
                return (___isoc99_vfscanf = Module["___isoc99_vfscanf"] = Module["asm"]["__isoc99_vfscanf"]).apply(null, arguments)
            };
            var _gets = Module["_gets"] = function() {
                return (_gets = Module["_gets"] = Module["asm"]["gets"]).apply(null, arguments)
            };
            var _fwprintf = Module["_fwprintf"] = function() {
                return (_fwprintf = Module["_fwprintf"] = Module["asm"]["fwprintf"]).apply(null, arguments)
            };
            var _fgets_unlocked = Module["_fgets_unlocked"] = function() {
                return (_fgets_unlocked = Module["_fgets_unlocked"] = Module["asm"]["fgets_unlocked"]).apply(null, arguments)
            };
            var _setbuffer = Module["_setbuffer"] = function() {
                return (_setbuffer = Module["_setbuffer"] = Module["asm"]["setbuffer"]).apply(null, arguments)
            };
            var _vprintf = Module["_vprintf"] = function() {
                return (_vprintf = Module["_vprintf"] = Module["asm"]["vprintf"]).apply(null, arguments)
            };
            var ___fclose_ca = Module["___fclose_ca"] = function() {
                return (___fclose_ca = Module["___fclose_ca"] = Module["asm"]["__fclose_ca"]).apply(null, arguments)
            };
            var __flushlbf = Module["__flushlbf"] = function() {
                return (__flushlbf = Module["__flushlbf"] = Module["asm"]["_flushlbf"]).apply(null, arguments)
            };
            var ___fsetlocking = Module["___fsetlocking"] = function() {
                return (___fsetlocking = Module["___fsetlocking"] = Module["asm"]["__fsetlocking"]).apply(null, arguments)
            };
            var ___fwriting = Module["___fwriting"] = function() {
                return (___fwriting = Module["___fwriting"] = Module["asm"]["__fwriting"]).apply(null, arguments)
            };
            var ___freading = Module["___freading"] = function() {
                return (___freading = Module["___freading"] = Module["asm"]["__freading"]).apply(null, arguments)
            };
            var ___freadable = Module["___freadable"] = function() {
                return (___freadable = Module["___freadable"] = Module["asm"]["__freadable"]).apply(null, arguments)
            };
            var ___fwritable = Module["___fwritable"] = function() {
                return (___fwritable = Module["___fwritable"] = Module["asm"]["__fwritable"]).apply(null, arguments)
            };
            var ___flbf = Module["___flbf"] = function() {
                return (___flbf = Module["___flbf"] = Module["asm"]["__flbf"]).apply(null, arguments)
            };
            var ___fbufsize = Module["___fbufsize"] = function() {
                return (___fbufsize = Module["___fbufsize"] = Module["asm"]["__fbufsize"]).apply(null, arguments)
            };
            var ___fpending = Module["___fpending"] = function() {
                return (___fpending = Module["___fpending"] = Module["asm"]["__fpending"]).apply(null, arguments)
            };
            var ___fpurge = Module["___fpurge"] = function() {
                return (___fpurge = Module["___fpurge"] = Module["asm"]["__fpurge"]).apply(null, arguments)
            };
            var _fpurge = Module["_fpurge"] = function() {
                return (_fpurge = Module["_fpurge"] = Module["asm"]["fpurge"]).apply(null, arguments)
            };
            var _vscanf = Module["_vscanf"] = function() {
                return (_vscanf = Module["_vscanf"] = Module["asm"]["vscanf"]).apply(null, arguments)
            };
            var ___isoc99_vscanf = Module["___isoc99_vscanf"] = function() {
                return (___isoc99_vscanf = Module["___isoc99_vscanf"] = Module["asm"]["__isoc99_vscanf"]).apply(null, arguments)
            };
            var _getwchar = Module["_getwchar"] = function() {
                return (_getwchar = Module["_getwchar"] = Module["asm"]["getwchar"]).apply(null, arguments)
            };
            var _getwchar_unlocked = Module["_getwchar_unlocked"] = function() {
                return (_getwchar_unlocked = Module["_getwchar_unlocked"] = Module["asm"]["getwchar_unlocked"]).apply(null, arguments)
            };
            var _freopen = Module["_freopen"] = function() {
                return (_freopen = Module["_freopen"] = Module["asm"]["freopen"]).apply(null, arguments)
            };
            var ___dup3 = Module["___dup3"] = function() {
                return (___dup3 = Module["___dup3"] = Module["asm"]["__dup3"]).apply(null, arguments)
            };
            var _freopen64 = Module["_freopen64"] = function() {
                return (_freopen64 = Module["_freopen64"] = Module["asm"]["freopen64"]).apply(null, arguments)
            };
            var ___freadahead = Module["___freadahead"] = function() {
                return (___freadahead = Module["___freadahead"] = Module["asm"]["__freadahead"]).apply(null, arguments)
            };
            var ___freadptr = Module["___freadptr"] = function() {
                return (___freadptr = Module["___freadptr"] = Module["asm"]["__freadptr"]).apply(null, arguments)
            };
            var ___freadptrinc = Module["___freadptrinc"] = function() {
                return (___freadptrinc = Module["___freadptrinc"] = Module["asm"]["__freadptrinc"]).apply(null, arguments)
            };
            var ___fseterr = Module["___fseterr"] = function() {
                return (___fseterr = Module["___fseterr"] = Module["asm"]["__fseterr"]).apply(null, arguments)
            };
            var _getc = Module["_getc"] = function() {
                return (_getc = Module["_getc"] = Module["asm"]["getc"]).apply(null, arguments)
            };
            var __IO_getc = Module["__IO_getc"] = function() {
                return (__IO_getc = Module["__IO_getc"] = Module["asm"]["_IO_getc"]).apply(null, arguments)
            };
            var ___fputwc_unlocked = Module["___fputwc_unlocked"] = function() {
                return (___fputwc_unlocked = Module["___fputwc_unlocked"] = Module["asm"]["__fputwc_unlocked"]).apply(null, arguments)
            };
            var ___fwritex = Module["___fwritex"] = function() {
                return (___fwritex = Module["___fwritex"] = Module["asm"]["__fwritex"]).apply(null, arguments)
            };
            var _fputwc = Module["_fputwc"] = function() {
                return (_fputwc = Module["_fputwc"] = Module["asm"]["fputwc"]).apply(null, arguments)
            };
            var _fputwc_unlocked = Module["_fputwc_unlocked"] = function() {
                return (_fputwc_unlocked = Module["_fputwc_unlocked"] = Module["asm"]["fputwc_unlocked"]).apply(null, arguments)
            };
            var _putwc_unlocked = Module["_putwc_unlocked"] = function() {
                return (_putwc_unlocked = Module["_putwc_unlocked"] = Module["asm"]["putwc_unlocked"]).apply(null, arguments)
            };
            var _feof_unlocked = Module["_feof_unlocked"] = function() {
                return (_feof_unlocked = Module["_feof_unlocked"] = Module["asm"]["feof_unlocked"]).apply(null, arguments)
            };
            var __IO_feof_unlocked = Module["__IO_feof_unlocked"] = function() {
                return (__IO_feof_unlocked = Module["__IO_feof_unlocked"] = Module["asm"]["_IO_feof_unlocked"]).apply(null, arguments)
            };
            var _fgetpos = Module["_fgetpos"] = function() {
                return (_fgetpos = Module["_fgetpos"] = Module["asm"]["fgetpos"]).apply(null, arguments)
            };
            var ___ftello = Module["___ftello"] = function() {
                return (___ftello = Module["___ftello"] = Module["asm"]["__ftello"]).apply(null, arguments)
            };
            var _fgetpos64 = Module["_fgetpos64"] = function() {
                return (_fgetpos64 = Module["_fgetpos64"] = Module["asm"]["fgetpos64"]).apply(null, arguments)
            };
            var _putw = Module["_putw"] = function() {
                return (_putw = Module["_putw"] = Module["asm"]["putw"]).apply(null, arguments)
            };
            var _fsetpos = Module["_fsetpos"] = function() {
                return (_fsetpos = Module["_fsetpos"] = Module["asm"]["fsetpos"]).apply(null, arguments)
            };
            var ___fseeko = Module["___fseeko"] = function() {
                return (___fseeko = Module["___fseeko"] = Module["asm"]["__fseeko"]).apply(null, arguments)
            };
            var _fsetpos64 = Module["_fsetpos64"] = function() {
                return (_fsetpos64 = Module["_fsetpos64"] = Module["asm"]["fsetpos64"]).apply(null, arguments)
            };
            var ___isoc99_vwscanf = Module["___isoc99_vwscanf"] = function() {
                return (___isoc99_vwscanf = Module["___isoc99_vwscanf"] = Module["asm"]["__isoc99_vwscanf"]).apply(null, arguments)
            };
            var _fileno = Module["_fileno"] = function() {
                return (_fileno = Module["_fileno"] = Module["asm"]["fileno"]).apply(null, arguments)
            };
            var _fileno_unlocked = Module["_fileno_unlocked"] = function() {
                return (_fileno_unlocked = Module["_fileno_unlocked"] = Module["asm"]["fileno_unlocked"]).apply(null, arguments)
            };
            var _setlinebuf = Module["_setlinebuf"] = function() {
                return (_setlinebuf = Module["_setlinebuf"] = Module["asm"]["setlinebuf"]).apply(null, arguments)
            };
            var _asprintf = Module["_asprintf"] = function() {
                return (_asprintf = Module["_asprintf"] = Module["asm"]["asprintf"]).apply(null, arguments)
            };
            var _getc_unlocked = Module["_getc_unlocked"] = function() {
                return (_getc_unlocked = Module["_getc_unlocked"] = Module["asm"]["getc_unlocked"]).apply(null, arguments)
            };
            var _fgetc_unlocked = Module["_fgetc_unlocked"] = function() {
                return (_fgetc_unlocked = Module["_fgetc_unlocked"] = Module["asm"]["fgetc_unlocked"]).apply(null, arguments)
            };
            var __IO_getc_unlocked = Module["__IO_getc_unlocked"] = function() {
                return (__IO_getc_unlocked = Module["__IO_getc_unlocked"] = Module["asm"]["_IO_getc_unlocked"]).apply(null, arguments)
            };
            var _open_wmemstream = Module["_open_wmemstream"] = function() {
                return (_open_wmemstream = Module["_open_wmemstream"] = Module["asm"]["open_wmemstream"]).apply(null, arguments)
            };
            var _mbsnrtowcs = Module["_mbsnrtowcs"] = function() {
                return (_mbsnrtowcs = Module["_mbsnrtowcs"] = Module["asm"]["mbsnrtowcs"]).apply(null, arguments)
            };
            var ___toread_needs_stdio_exit = Module["___toread_needs_stdio_exit"] = function() {
                return (___toread_needs_stdio_exit = Module["___toread_needs_stdio_exit"] = Module["asm"]["__toread_needs_stdio_exit"]).apply(null, arguments)
            };
            var ___stdio_exit_needed = Module["___stdio_exit_needed"] = function() {
                return (___stdio_exit_needed = Module["___stdio_exit_needed"] = Module["asm"]["__stdio_exit_needed"]).apply(null, arguments)
            };
            var _pclose = Module["_pclose"] = function() {
                return (_pclose = Module["_pclose"] = Module["asm"]["pclose"]).apply(null, arguments)
            };
            var _swscanf = Module["_swscanf"] = function() {
                return (_swscanf = Module["_swscanf"] = Module["asm"]["swscanf"]).apply(null, arguments)
            };
            var ___isoc99_swscanf = Module["___isoc99_swscanf"] = function() {
                return (___isoc99_swscanf = Module["___isoc99_swscanf"] = Module["asm"]["__isoc99_swscanf"]).apply(null, arguments)
            };
            var _fputws = Module["_fputws"] = function() {
                return (_fputws = Module["_fputws"] = Module["asm"]["fputws"]).apply(null, arguments)
            };
            var _fputws_unlocked = Module["_fputws_unlocked"] = function() {
                return (_fputws_unlocked = Module["_fputws_unlocked"] = Module["asm"]["fputws_unlocked"]).apply(null, arguments)
            };
            var _vsniprintf = Module["_vsniprintf"] = function() {
                return (_vsniprintf = Module["_vsniprintf"] = Module["asm"]["vsniprintf"]).apply(null, arguments)
            };
            var ___small_vsnprintf = Module["___small_vsnprintf"] = function() {
                return (___small_vsnprintf = Module["___small_vsnprintf"] = Module["asm"]["__small_vsnprintf"]).apply(null, arguments)
            };
            var ___stdio_read = Module["___stdio_read"] = function() {
                return (___stdio_read = Module["___stdio_read"] = Module["asm"]["__stdio_read"]).apply(null, arguments)
            };
            var ___stdio_exit = Module["___stdio_exit"] = function() {
                return (___stdio_exit = Module["___stdio_exit"] = Module["asm"]["__stdio_exit"]).apply(null, arguments)
            };
            var ___stdio_write = Module["___stdio_write"] = function() {
                return (___stdio_write = Module["___stdio_write"] = Module["asm"]["__stdio_write"]).apply(null, arguments)
            };
            var ___fopen_rb_ca = Module["___fopen_rb_ca"] = function() {
                return (___fopen_rb_ca = Module["___fopen_rb_ca"] = Module["asm"]["__fopen_rb_ca"]).apply(null, arguments)
            };
            var _iswspace = Module["_iswspace"] = function() {
                return (_iswspace = Module["_iswspace"] = Module["asm"]["iswspace"]).apply(null, arguments)
            };
            var _iswdigit = Module["_iswdigit"] = function() {
                return (_iswdigit = Module["_iswdigit"] = Module["asm"]["iswdigit"]).apply(null, arguments)
            };
            var ___isoc99_vfwscanf = Module["___isoc99_vfwscanf"] = function() {
                return (___isoc99_vfwscanf = Module["___isoc99_vfwscanf"] = Module["asm"]["__isoc99_vfwscanf"]).apply(null, arguments)
            };
            var _vdprintf = Module["_vdprintf"] = function() {
                return (_vdprintf = Module["_vdprintf"] = Module["asm"]["vdprintf"]).apply(null, arguments)
            };
            var _putchar_unlocked = Module["_putchar_unlocked"] = function() {
                return (_putchar_unlocked = Module["_putchar_unlocked"] = Module["asm"]["putchar_unlocked"]).apply(null, arguments)
            };
            var _putwchar = Module["_putwchar"] = function() {
                return (_putwchar = Module["_putwchar"] = Module["asm"]["putwchar"]).apply(null, arguments)
            };
            var _putwchar_unlocked = Module["_putwchar_unlocked"] = function() {
                return (_putwchar_unlocked = Module["_putwchar_unlocked"] = Module["asm"]["putwchar_unlocked"]).apply(null, arguments)
            };
            var _putc_unlocked = Module["_putc_unlocked"] = function() {
                return (_putc_unlocked = Module["_putc_unlocked"] = Module["asm"]["putc_unlocked"]).apply(null, arguments)
            };
            var _fputc_unlocked = Module["_fputc_unlocked"] = function() {
                return (_fputc_unlocked = Module["_fputc_unlocked"] = Module["asm"]["fputc_unlocked"]).apply(null, arguments)
            };
            var __IO_putc_unlocked = Module["__IO_putc_unlocked"] = function() {
                return (__IO_putc_unlocked = Module["__IO_putc_unlocked"] = Module["asm"]["_IO_putc_unlocked"]).apply(null, arguments)
            };
            var ___fdopen = Module["___fdopen"] = function() {
                return (___fdopen = Module["___fdopen"] = Module["asm"]["__fdopen"]).apply(null, arguments)
            };
            var _fopen64 = Module["_fopen64"] = function() {
                return (_fopen64 = Module["_fopen64"] = Module["asm"]["fopen64"]).apply(null, arguments)
            };
            var _wcsspn = Module["_wcsspn"] = function() {
                return (_wcsspn = Module["_wcsspn"] = Module["asm"]["wcsspn"]).apply(null, arguments)
            };
            var _btowc = Module["_btowc"] = function() {
                return (_btowc = Module["_btowc"] = Module["asm"]["btowc"]).apply(null, arguments)
            };
            var _wmemchr = Module["_wmemchr"] = function() {
                return (_wmemchr = Module["_wmemchr"] = Module["asm"]["wmemchr"]).apply(null, arguments)
            };
            var _tmpfile = Module["_tmpfile"] = function() {
                return (_tmpfile = Module["_tmpfile"] = Module["asm"]["tmpfile"]).apply(null, arguments)
            };
            var _tmpfile64 = Module["_tmpfile64"] = function() {
                return (_tmpfile64 = Module["_tmpfile64"] = Module["asm"]["tmpfile64"]).apply(null, arguments)
            };
            var _vsprintf = Module["_vsprintf"] = function() {
                return (_vsprintf = Module["_vsprintf"] = Module["asm"]["vsprintf"]).apply(null, arguments)
            };
            var _vsiprintf = Module["_vsiprintf"] = function() {
                return (_vsiprintf = Module["_vsiprintf"] = Module["asm"]["vsiprintf"]).apply(null, arguments)
            };
            var ___small_vsprintf = Module["___small_vsprintf"] = function() {
                return (___small_vsprintf = Module["___small_vsprintf"] = Module["asm"]["__small_vsprintf"]).apply(null, arguments)
            };
            var _fwscanf = Module["_fwscanf"] = function() {
                return (_fwscanf = Module["_fwscanf"] = Module["asm"]["fwscanf"]).apply(null, arguments)
            };
            var ___isoc99_fwscanf = Module["___isoc99_fwscanf"] = function() {
                return (___isoc99_fwscanf = Module["___isoc99_fwscanf"] = Module["asm"]["__isoc99_fwscanf"]).apply(null, arguments)
            };
            var _open_memstream = Module["_open_memstream"] = function() {
                return (_open_memstream = Module["_open_memstream"] = Module["asm"]["open_memstream"]).apply(null, arguments)
            };
            var ___isoc99_sscanf = Module["___isoc99_sscanf"] = function() {
                return (___isoc99_sscanf = Module["___isoc99_sscanf"] = Module["asm"]["__isoc99_sscanf"]).apply(null, arguments)
            };
            var ___do_orphaned_stdio_locks = Module["___do_orphaned_stdio_locks"] = function() {
                return (___do_orphaned_stdio_locks = Module["___do_orphaned_stdio_locks"] = Module["asm"]["__do_orphaned_stdio_locks"]).apply(null, arguments)
            };
            var _scanf = Module["_scanf"] = function() {
                return (_scanf = Module["_scanf"] = Module["asm"]["scanf"]).apply(null, arguments)
            };
            var ___isoc99_scanf = Module["___isoc99_scanf"] = function() {
                return (___isoc99_scanf = Module["___isoc99_scanf"] = Module["asm"]["__isoc99_scanf"]).apply(null, arguments)
            };
            var _fseeko = Module["_fseeko"] = function() {
                return (_fseeko = Module["_fseeko"] = Module["asm"]["fseeko"]).apply(null, arguments)
            };
            var _fseeko64 = Module["_fseeko64"] = function() {
                return (_fseeko64 = Module["_fseeko64"] = Module["asm"]["fseeko64"]).apply(null, arguments)
            };
            var ___stdout_write = Module["___stdout_write"] = function() {
                return (___stdout_write = Module["___stdout_write"] = Module["asm"]["__stdout_write"]).apply(null, arguments)
            };
            var ___isoc99_fscanf = Module["___isoc99_fscanf"] = function() {
                return (___isoc99_fscanf = Module["___isoc99_fscanf"] = Module["asm"]["__isoc99_fscanf"]).apply(null, arguments)
            };
            var _fdopen = Module["_fdopen"] = function() {
                return (_fdopen = Module["_fdopen"] = Module["asm"]["fdopen"]).apply(null, arguments)
            };
            var _siprintf = Module["_siprintf"] = function() {
                return (_siprintf = Module["_siprintf"] = Module["asm"]["siprintf"]).apply(null, arguments)
            };
            var ___small_sprintf = Module["___small_sprintf"] = function() {
                return (___small_sprintf = Module["___small_sprintf"] = Module["asm"]["__small_sprintf"]).apply(null, arguments)
            };
            var ___vfprintf_internal = Module["___vfprintf_internal"] = function() {
                return (___vfprintf_internal = Module["___vfprintf_internal"] = Module["asm"]["__vfprintf_internal"]).apply(null, arguments)
            };
            var _remove = Module["_remove"] = function() {
                return (_remove = Module["_remove"] = Module["asm"]["remove"]).apply(null, arguments)
            };
            var _fgetws = Module["_fgetws"] = function() {
                return (_fgetws = Module["_fgetws"] = Module["asm"]["fgetws"]).apply(null, arguments)
            };
            var _fgetws_unlocked = Module["_fgetws_unlocked"] = function() {
                return (_fgetws_unlocked = Module["_fgetws_unlocked"] = Module["asm"]["fgetws_unlocked"]).apply(null, arguments)
            };
            var _putwc = Module["_putwc"] = function() {
                return (_putwc = Module["_putwc"] = Module["asm"]["putwc"]).apply(null, arguments)
            };
            var _getw = Module["_getw"] = function() {
                return (_getw = Module["_getw"] = Module["asm"]["getw"]).apply(null, arguments)
            };
            var ___ftello_unlocked = Module["___ftello_unlocked"] = function() {
                return (___ftello_unlocked = Module["___ftello_unlocked"] = Module["asm"]["__ftello_unlocked"]).apply(null, arguments)
            };
            var _ftell = Module["_ftell"] = function() {
                return (_ftell = Module["_ftell"] = Module["asm"]["ftell"]).apply(null, arguments)
            };
            var _ftello = Module["_ftello"] = function() {
                return (_ftello = Module["_ftello"] = Module["asm"]["ftello"]).apply(null, arguments)
            };
            var _ftello64 = Module["_ftello64"] = function() {
                return (_ftello64 = Module["_ftello64"] = Module["asm"]["ftello64"]).apply(null, arguments)
            };
            var _fnmatch = Module["_fnmatch"] = function() {
                return (_fnmatch = Module["_fnmatch"] = Module["asm"]["fnmatch"]).apply(null, arguments)
            };
            var _towupper = Module["_towupper"] = function() {
                return (_towupper = Module["_towupper"] = Module["asm"]["towupper"]).apply(null, arguments)
            };
            var _towlower = Module["_towlower"] = function() {
                return (_towlower = Module["_towlower"] = Module["asm"]["towlower"]).apply(null, arguments)
            };
            var _wctype = Module["_wctype"] = function() {
                return (_wctype = Module["_wctype"] = Module["asm"]["wctype"]).apply(null, arguments)
            };
            var _iswctype = Module["_iswctype"] = function() {
                return (_iswctype = Module["_iswctype"] = Module["asm"]["iswctype"]).apply(null, arguments)
            };
            var ___tre_mem_new_impl = Module["___tre_mem_new_impl"] = function() {
                return (___tre_mem_new_impl = Module["___tre_mem_new_impl"] = Module["asm"]["__tre_mem_new_impl"]).apply(null, arguments)
            };
            var ___tre_mem_destroy = Module["___tre_mem_destroy"] = function() {
                return (___tre_mem_destroy = Module["___tre_mem_destroy"] = Module["asm"]["__tre_mem_destroy"]).apply(null, arguments)
            };
            var ___tre_mem_alloc_impl = Module["___tre_mem_alloc_impl"] = function() {
                return (___tre_mem_alloc_impl = Module["___tre_mem_alloc_impl"] = Module["asm"]["__tre_mem_alloc_impl"]).apply(null, arguments)
            };
            var _regexec = Module["_regexec"] = function() {
                return (_regexec = Module["_regexec"] = Module["asm"]["regexec"]).apply(null, arguments)
            };
            var _iswalnum = Module["_iswalnum"] = function() {
                return (_iswalnum = Module["_iswalnum"] = Module["asm"]["iswalnum"]).apply(null, arguments)
            };
            var _regcomp = Module["_regcomp"] = function() {
                return (_regcomp = Module["_regcomp"] = Module["asm"]["regcomp"]).apply(null, arguments)
            };
            var _regfree = Module["_regfree"] = function() {
                return (_regfree = Module["_regfree"] = Module["asm"]["regfree"]).apply(null, arguments)
            };
            var _iswupper = Module["_iswupper"] = function() {
                return (_iswupper = Module["_iswupper"] = Module["asm"]["iswupper"]).apply(null, arguments)
            };
            var _iswlower = Module["_iswlower"] = function() {
                return (_iswlower = Module["_iswlower"] = Module["asm"]["iswlower"]).apply(null, arguments)
            };
            var _glob = Module["_glob"] = function() {
                return (_glob = Module["_glob"] = Module["asm"]["glob"]).apply(null, arguments)
            };
            var _strcat = Module["_strcat"] = function() {
                return (_strcat = Module["_strcat"] = Module["asm"]["strcat"]).apply(null, arguments)
            };
            var _globfree = Module["_globfree"] = function() {
                return (_globfree = Module["_globfree"] = Module["asm"]["globfree"]).apply(null, arguments)
            };
            var _glob64 = Module["_glob64"] = function() {
                return (_glob64 = Module["_glob64"] = Module["asm"]["glob64"]).apply(null, arguments)
            };
            var _globfree64 = Module["_globfree64"] = function() {
                return (_globfree64 = Module["_globfree64"] = Module["asm"]["globfree64"]).apply(null, arguments)
            };
            var _regerror = Module["_regerror"] = function() {
                return (_regerror = Module["_regerror"] = Module["asm"]["regerror"]).apply(null, arguments)
            };
            var _wcsncpy = Module["_wcsncpy"] = function() {
                return (_wcsncpy = Module["_wcsncpy"] = Module["asm"]["wcsncpy"]).apply(null, arguments)
            };
            var _wmemset = Module["_wmemset"] = function() {
                return (_wmemset = Module["_wmemset"] = Module["asm"]["wmemset"]).apply(null, arguments)
            };
            var _bzero = Module["_bzero"] = function() {
                return (_bzero = Module["_bzero"] = Module["asm"]["bzero"]).apply(null, arguments)
            };
            var _strcasestr = Module["_strcasestr"] = function() {
                return (_strcasestr = Module["_strcasestr"] = Module["asm"]["strcasestr"]).apply(null, arguments)
            };
            var _strncasecmp = Module["_strncasecmp"] = function() {
                return (_strncasecmp = Module["_strncasecmp"] = Module["asm"]["strncasecmp"]).apply(null, arguments)
            };
            var _wcscat = Module["_wcscat"] = function() {
                return (_wcscat = Module["_wcscat"] = Module["asm"]["wcscat"]).apply(null, arguments)
            };
            var _wcscpy = Module["_wcscpy"] = function() {
                return (_wcscpy = Module["_wcscpy"] = Module["asm"]["wcscpy"]).apply(null, arguments)
            };
            var _wcpncpy = Module["_wcpncpy"] = function() {
                return (_wcpncpy = Module["_wcpncpy"] = Module["asm"]["wcpncpy"]).apply(null, arguments)
            };
            var _wcsnlen = Module["_wcsnlen"] = function() {
                return (_wcsnlen = Module["_wcsnlen"] = Module["asm"]["wcsnlen"]).apply(null, arguments)
            };
            var _index = Module["_index"] = function() {
                return (_index = Module["_index"] = Module["asm"]["index"]).apply(null, arguments)
            };
            var _strndup = Module["_strndup"] = function() {
                return (_strndup = Module["_strndup"] = Module["asm"]["strndup"]).apply(null, arguments)
            };
            var _tolower = Module["_tolower"] = function() {
                return (_tolower = Module["_tolower"] = Module["asm"]["tolower"]).apply(null, arguments)
            };
            var ___strncasecmp_l = Module["___strncasecmp_l"] = function() {
                return (___strncasecmp_l = Module["___strncasecmp_l"] = Module["asm"]["__strncasecmp_l"]).apply(null, arguments)
            };
            var _strncasecmp_l = Module["_strncasecmp_l"] = function() {
                return (_strncasecmp_l = Module["_strncasecmp_l"] = Module["asm"]["strncasecmp_l"]).apply(null, arguments)
            };
            var _strerror_r = Module["_strerror_r"] = function() {
                return (_strerror_r = Module["_strerror_r"] = Module["asm"]["strerror_r"]).apply(null, arguments)
            };
            var ___xpg_strerror_r = Module["___xpg_strerror_r"] = function() {
                return (___xpg_strerror_r = Module["___xpg_strerror_r"] = Module["asm"]["__xpg_strerror_r"]).apply(null, arguments)
            };
            var _strtok = Module["_strtok"] = function() {
                return (_strtok = Module["_strtok"] = Module["asm"]["strtok"]).apply(null, arguments)
            };
            var _strspn = Module["_strspn"] = function() {
                return (_strspn = Module["_strspn"] = Module["asm"]["strspn"]).apply(null, arguments)
            };
            var _strcspn = Module["_strcspn"] = function() {
                return (_strcspn = Module["_strcspn"] = Module["asm"]["strcspn"]).apply(null, arguments)
            };
            var ___strcasecmp_l = Module["___strcasecmp_l"] = function() {
                return (___strcasecmp_l = Module["___strcasecmp_l"] = Module["asm"]["__strcasecmp_l"]).apply(null, arguments)
            };
            var _strcasecmp_l = Module["_strcasecmp_l"] = function() {
                return (_strcasecmp_l = Module["_strcasecmp_l"] = Module["asm"]["strcasecmp_l"]).apply(null, arguments)
            };
            var _wcswcs = Module["_wcswcs"] = function() {
                return (_wcswcs = Module["_wcswcs"] = Module["asm"]["wcswcs"]).apply(null, arguments)
            };
            var _wcsstr = Module["_wcsstr"] = function() {
                return (_wcsstr = Module["_wcsstr"] = Module["asm"]["wcsstr"]).apply(null, arguments)
            };
            var _strsignal = Module["_strsignal"] = function() {
                return (_strsignal = Module["_strsignal"] = Module["asm"]["strsignal"]).apply(null, arguments)
            };
            var _swab = Module["_swab"] = function() {
                return (_swab = Module["_swab"] = Module["asm"]["swab"]).apply(null, arguments)
            };
            var _wcschr = Module["_wcschr"] = function() {
                return (_wcschr = Module["_wcschr"] = Module["asm"]["wcschr"]).apply(null, arguments)
            };
            var _wmemcmp = Module["_wmemcmp"] = function() {
                return (_wmemcmp = Module["_wmemcmp"] = Module["asm"]["wmemcmp"]).apply(null, arguments)
            };
            var _strlcat = Module["_strlcat"] = function() {
                return (_strlcat = Module["_strlcat"] = Module["asm"]["strlcat"]).apply(null, arguments)
            };
            var _strlcpy = Module["_strlcpy"] = function() {
                return (_strlcpy = Module["_strlcpy"] = Module["asm"]["strlcpy"]).apply(null, arguments)
            };
            var _wcsrchr = Module["_wcsrchr"] = function() {
                return (_wcsrchr = Module["_wcsrchr"] = Module["asm"]["wcsrchr"]).apply(null, arguments)
            };
            var ___memrchr = Module["___memrchr"] = function() {
                return (___memrchr = Module["___memrchr"] = Module["asm"]["__memrchr"]).apply(null, arguments)
            };
            var _memrchr = Module["_memrchr"] = function() {
                return (_memrchr = Module["_memrchr"] = Module["asm"]["memrchr"]).apply(null, arguments)
            };
            var _wcsncmp = Module["_wcsncmp"] = function() {
                return (_wcsncmp = Module["_wcsncmp"] = Module["asm"]["wcsncmp"]).apply(null, arguments)
            };
            var ___stpncpy = Module["___stpncpy"] = function() {
                return (___stpncpy = Module["___stpncpy"] = Module["asm"]["__stpncpy"]).apply(null, arguments)
            };
            var _stpncpy = Module["_stpncpy"] = function() {
                return (_stpncpy = Module["_stpncpy"] = Module["asm"]["stpncpy"]).apply(null, arguments)
            };
            var _wcpcpy = Module["_wcpcpy"] = function() {
                return (_wcpcpy = Module["_wcpcpy"] = Module["asm"]["wcpcpy"]).apply(null, arguments)
            };
            var _wcscspn = Module["_wcscspn"] = function() {
                return (_wcscspn = Module["_wcscspn"] = Module["asm"]["wcscspn"]).apply(null, arguments)
            };
            var _memmem = Module["_memmem"] = function() {
                return (_memmem = Module["_memmem"] = Module["asm"]["memmem"]).apply(null, arguments)
            };
            var _bcmp = Module["_bcmp"] = function() {
                return (_bcmp = Module["_bcmp"] = Module["asm"]["bcmp"]).apply(null, arguments)
            };
            var _strsep = Module["_strsep"] = function() {
                return (_strsep = Module["_strsep"] = Module["asm"]["strsep"]).apply(null, arguments)
            };
            var _wcsncasecmp = Module["_wcsncasecmp"] = function() {
                return (_wcsncasecmp = Module["_wcsncasecmp"] = Module["asm"]["wcsncasecmp"]).apply(null, arguments)
            };
            var _bcopy = Module["_bcopy"] = function() {
                return (_bcopy = Module["_bcopy"] = Module["asm"]["bcopy"]).apply(null, arguments)
            };
            var _mempcpy = Module["_mempcpy"] = function() {
                return (_mempcpy = Module["_mempcpy"] = Module["asm"]["mempcpy"]).apply(null, arguments)
            };
            var _wmemmove = Module["_wmemmove"] = function() {
                return (_wmemmove = Module["_wmemmove"] = Module["asm"]["wmemmove"]).apply(null, arguments)
            };
            var _rindex = Module["_rindex"] = function() {
                return (_rindex = Module["_rindex"] = Module["asm"]["rindex"]).apply(null, arguments)
            };
            var _wcsdup = Module["_wcsdup"] = function() {
                return (_wcsdup = Module["_wcsdup"] = Module["asm"]["wcsdup"]).apply(null, arguments)
            };
            var ___stpcpy = Module["___stpcpy"] = function() {
                return (___stpcpy = Module["___stpcpy"] = Module["asm"]["__stpcpy"]).apply(null, arguments)
            };
            var _wcscasecmp = Module["_wcscasecmp"] = function() {
                return (_wcscasecmp = Module["_wcscasecmp"] = Module["asm"]["wcscasecmp"]).apply(null, arguments)
            };
            var _strncat = Module["_strncat"] = function() {
                return (_strncat = Module["_strncat"] = Module["asm"]["strncat"]).apply(null, arguments)
            };
            var _strncpy = Module["_strncpy"] = function() {
                return (_strncpy = Module["_strncpy"] = Module["asm"]["strncpy"]).apply(null, arguments)
            };
            var _wcscasecmp_l = Module["_wcscasecmp_l"] = function() {
                return (_wcscasecmp_l = Module["_wcscasecmp_l"] = Module["asm"]["wcscasecmp_l"]).apply(null, arguments)
            };
            var _strpbrk = Module["_strpbrk"] = function() {
                return (_strpbrk = Module["_strpbrk"] = Module["asm"]["strpbrk"]).apply(null, arguments)
            };
            var _memccpy = Module["_memccpy"] = function() {
                return (_memccpy = Module["_memccpy"] = Module["asm"]["memccpy"]).apply(null, arguments)
            };
            var _strtok_r = Module["_strtok_r"] = function() {
                return (_strtok_r = Module["_strtok_r"] = Module["asm"]["strtok_r"]).apply(null, arguments)
            };
            var ___strdup = Module["___strdup"] = function() {
                return (___strdup = Module["___strdup"] = Module["asm"]["__strdup"]).apply(null, arguments)
            };
            var _strchrnul = Module["_strchrnul"] = function() {
                return (_strchrnul = Module["_strchrnul"] = Module["asm"]["strchrnul"]).apply(null, arguments)
            };
            var _stpcpy = Module["_stpcpy"] = function() {
                return (_stpcpy = Module["_stpcpy"] = Module["asm"]["stpcpy"]).apply(null, arguments)
            };
            var _wcsncat = Module["_wcsncat"] = function() {
                return (_wcsncat = Module["_wcsncat"] = Module["asm"]["wcsncat"]).apply(null, arguments)
            };
            var _wcspbrk = Module["_wcspbrk"] = function() {
                return (_wcspbrk = Module["_wcspbrk"] = Module["asm"]["wcspbrk"]).apply(null, arguments)
            };
            var _wcsncasecmp_l = Module["_wcsncasecmp_l"] = function() {
                return (_wcsncasecmp_l = Module["_wcsncasecmp_l"] = Module["asm"]["wcsncasecmp_l"]).apply(null, arguments)
            };
            var _wcstok = Module["_wcstok"] = function() {
                return (_wcstok = Module["_wcstok"] = Module["asm"]["wcstok"]).apply(null, arguments)
            };
            var _posix_fallocate = Module["_posix_fallocate"] = function() {
                return (_posix_fallocate = Module["_posix_fallocate"] = Module["asm"]["posix_fallocate"]).apply(null, arguments)
            };
            var _posix_fallocate64 = Module["_posix_fallocate64"] = function() {
                return (_posix_fallocate64 = Module["_posix_fallocate64"] = Module["asm"]["posix_fallocate64"]).apply(null, arguments)
            };
            var _openat = Module["_openat"] = function() {
                return (_openat = Module["_openat"] = Module["asm"]["openat"]).apply(null, arguments)
            };
            var _openat64 = Module["_openat64"] = function() {
                return (_openat64 = Module["_openat64"] = Module["asm"]["openat64"]).apply(null, arguments)
            };
            var _open64 = Module["_open64"] = function() {
                return (_open64 = Module["_open64"] = Module["asm"]["open64"]).apply(null, arguments)
            };
            var _creat = Module["_creat"] = function() {
                return (_creat = Module["_creat"] = Module["asm"]["creat"]).apply(null, arguments)
            };
            var _creat64 = Module["_creat64"] = function() {
                return (_creat64 = Module["_creat64"] = Module["asm"]["creat64"]).apply(null, arguments)
            };
            var _posix_fadvise = Module["_posix_fadvise"] = function() {
                return (_posix_fadvise = Module["_posix_fadvise"] = Module["asm"]["posix_fadvise"]).apply(null, arguments)
            };
            var _posix_fadvise64 = Module["_posix_fadvise64"] = function() {
                return (_posix_fadvise64 = Module["_posix_fadvise64"] = Module["asm"]["posix_fadvise64"]).apply(null, arguments)
            };
            var ___iswlower_l = Module["___iswlower_l"] = function() {
                return (___iswlower_l = Module["___iswlower_l"] = Module["asm"]["__iswlower_l"]).apply(null, arguments)
            };
            var _iswlower_l = Module["_iswlower_l"] = function() {
                return (_iswlower_l = Module["_iswlower_l"] = Module["asm"]["iswlower_l"]).apply(null, arguments)
            };
            var ___isdigit_l = Module["___isdigit_l"] = function() {
                return (___isdigit_l = Module["___isdigit_l"] = Module["asm"]["__isdigit_l"]).apply(null, arguments)
            };
            var _isdigit_l = Module["_isdigit_l"] = function() {
                return (_isdigit_l = Module["_isdigit_l"] = Module["asm"]["isdigit_l"]).apply(null, arguments)
            };
            var _iswprint = Module["_iswprint"] = function() {
                return (_iswprint = Module["_iswprint"] = Module["asm"]["iswprint"]).apply(null, arguments)
            };
            var ___iswprint_l = Module["___iswprint_l"] = function() {
                return (___iswprint_l = Module["___iswprint_l"] = Module["asm"]["__iswprint_l"]).apply(null, arguments)
            };
            var _iswprint_l = Module["_iswprint_l"] = function() {
                return (_iswprint_l = Module["_iswprint_l"] = Module["asm"]["iswprint_l"]).apply(null, arguments)
            };
            var _iswblank = Module["_iswblank"] = function() {
                return (_iswblank = Module["_iswblank"] = Module["asm"]["iswblank"]).apply(null, arguments)
            };
            var _isblank = Module["_isblank"] = function() {
                return (_isblank = Module["_isblank"] = Module["asm"]["isblank"]).apply(null, arguments)
            };
            var ___iswblank_l = Module["___iswblank_l"] = function() {
                return (___iswblank_l = Module["___iswblank_l"] = Module["asm"]["__iswblank_l"]).apply(null, arguments)
            };
            var _iswblank_l = Module["_iswblank_l"] = function() {
                return (_iswblank_l = Module["_iswblank_l"] = Module["asm"]["iswblank_l"]).apply(null, arguments)
            };
            var _iswgraph = Module["_iswgraph"] = function() {
                return (_iswgraph = Module["_iswgraph"] = Module["asm"]["iswgraph"]).apply(null, arguments)
            };
            var ___iswgraph_l = Module["___iswgraph_l"] = function() {
                return (___iswgraph_l = Module["___iswgraph_l"] = Module["asm"]["__iswgraph_l"]).apply(null, arguments)
            };
            var _iswgraph_l = Module["_iswgraph_l"] = function() {
                return (_iswgraph_l = Module["_iswgraph_l"] = Module["asm"]["iswgraph_l"]).apply(null, arguments)
            };
            var ___ctype_b_loc = Module["___ctype_b_loc"] = function() {
                return (___ctype_b_loc = Module["___ctype_b_loc"] = Module["asm"]["__ctype_b_loc"]).apply(null, arguments)
            };
            var ___ctype_toupper_loc = Module["___ctype_toupper_loc"] = function() {
                return (___ctype_toupper_loc = Module["___ctype_toupper_loc"] = Module["asm"]["__ctype_toupper_loc"]).apply(null, arguments)
            };
            var _isalpha = Module["_isalpha"] = function() {
                return (_isalpha = Module["_isalpha"] = Module["asm"]["isalpha"]).apply(null, arguments)
            };
            var ___isalpha_l = Module["___isalpha_l"] = function() {
                return (___isalpha_l = Module["___isalpha_l"] = Module["asm"]["__isalpha_l"]).apply(null, arguments)
            };
            var _isalpha_l = Module["_isalpha_l"] = function() {
                return (_isalpha_l = Module["_isalpha_l"] = Module["asm"]["isalpha_l"]).apply(null, arguments)
            };
            var _toupper = Module["_toupper"] = function() {
                return (_toupper = Module["_toupper"] = Module["asm"]["toupper"]).apply(null, arguments)
            };
            var _islower = Module["_islower"] = function() {
                return (_islower = Module["_islower"] = Module["asm"]["islower"]).apply(null, arguments)
            };
            var ___toupper_l = Module["___toupper_l"] = function() {
                return (___toupper_l = Module["___toupper_l"] = Module["asm"]["__toupper_l"]).apply(null, arguments)
            };
            var _toupper_l = Module["_toupper_l"] = function() {
                return (_toupper_l = Module["_toupper_l"] = Module["asm"]["toupper_l"]).apply(null, arguments)
            };
            var _iswpunct = Module["_iswpunct"] = function() {
                return (_iswpunct = Module["_iswpunct"] = Module["asm"]["iswpunct"]).apply(null, arguments)
            };
            var ___iswpunct_l = Module["___iswpunct_l"] = function() {
                return (___iswpunct_l = Module["___iswpunct_l"] = Module["asm"]["__iswpunct_l"]).apply(null, arguments)
            };
            var _iswpunct_l = Module["_iswpunct_l"] = function() {
                return (_iswpunct_l = Module["_iswpunct_l"] = Module["asm"]["iswpunct_l"]).apply(null, arguments)
            };
            var ___isspace_l = Module["___isspace_l"] = function() {
                return (___isspace_l = Module["___isspace_l"] = Module["asm"]["__isspace_l"]).apply(null, arguments)
            };
            var _isspace_l = Module["_isspace_l"] = function() {
                return (_isspace_l = Module["_isspace_l"] = Module["asm"]["isspace_l"]).apply(null, arguments)
            };
            var _isxdigit = Module["_isxdigit"] = function() {
                return (_isxdigit = Module["_isxdigit"] = Module["asm"]["isxdigit"]).apply(null, arguments)
            };
            var ___isxdigit_l = Module["___isxdigit_l"] = function() {
                return (___isxdigit_l = Module["___isxdigit_l"] = Module["asm"]["__isxdigit_l"]).apply(null, arguments)
            };
            var _isxdigit_l = Module["_isxdigit_l"] = function() {
                return (_isxdigit_l = Module["_isxdigit_l"] = Module["asm"]["isxdigit_l"]).apply(null, arguments)
            };
            var _iscntrl = Module["_iscntrl"] = function() {
                return (_iscntrl = Module["_iscntrl"] = Module["asm"]["iscntrl"]).apply(null, arguments)
            };
            var ___iscntrl_l = Module["___iscntrl_l"] = function() {
                return (___iscntrl_l = Module["___iscntrl_l"] = Module["asm"]["__iscntrl_l"]).apply(null, arguments)
            };
            var _iscntrl_l = Module["_iscntrl_l"] = function() {
                return (_iscntrl_l = Module["_iscntrl_l"] = Module["asm"]["iscntrl_l"]).apply(null, arguments)
            };
            var _ispunct = Module["_ispunct"] = function() {
                return (_ispunct = Module["_ispunct"] = Module["asm"]["ispunct"]).apply(null, arguments)
            };
            var _isgraph = Module["_isgraph"] = function() {
                return (_isgraph = Module["_isgraph"] = Module["asm"]["isgraph"]).apply(null, arguments)
            };
            var _isalnum = Module["_isalnum"] = function() {
                return (_isalnum = Module["_isalnum"] = Module["asm"]["isalnum"]).apply(null, arguments)
            };
            var ___ispunct_l = Module["___ispunct_l"] = function() {
                return (___ispunct_l = Module["___ispunct_l"] = Module["asm"]["__ispunct_l"]).apply(null, arguments)
            };
            var _ispunct_l = Module["_ispunct_l"] = function() {
                return (_ispunct_l = Module["_ispunct_l"] = Module["asm"]["ispunct_l"]).apply(null, arguments)
            };
            var ___iswdigit_l = Module["___iswdigit_l"] = function() {
                return (___iswdigit_l = Module["___iswdigit_l"] = Module["asm"]["__iswdigit_l"]).apply(null, arguments)
            };
            var _iswdigit_l = Module["_iswdigit_l"] = function() {
                return (_iswdigit_l = Module["_iswdigit_l"] = Module["asm"]["iswdigit_l"]).apply(null, arguments)
            };
            var _isupper = Module["_isupper"] = function() {
                return (_isupper = Module["_isupper"] = Module["asm"]["isupper"]).apply(null, arguments)
            };
            var ___isupper_l = Module["___isupper_l"] = function() {
                return (___isupper_l = Module["___isupper_l"] = Module["asm"]["__isupper_l"]).apply(null, arguments)
            };
            var _isupper_l = Module["_isupper_l"] = function() {
                return (_isupper_l = Module["_isupper_l"] = Module["asm"]["isupper_l"]).apply(null, arguments)
            };
            var _iswxdigit = Module["_iswxdigit"] = function() {
                return (_iswxdigit = Module["_iswxdigit"] = Module["asm"]["iswxdigit"]).apply(null, arguments)
            };
            var ___iswxdigit_l = Module["___iswxdigit_l"] = function() {
                return (___iswxdigit_l = Module["___iswxdigit_l"] = Module["asm"]["__iswxdigit_l"]).apply(null, arguments)
            };
            var _iswxdigit_l = Module["_iswxdigit_l"] = function() {
                return (_iswxdigit_l = Module["_iswxdigit_l"] = Module["asm"]["iswxdigit_l"]).apply(null, arguments)
            };
            var ___isblank_l = Module["___isblank_l"] = function() {
                return (___isblank_l = Module["___isblank_l"] = Module["asm"]["__isblank_l"]).apply(null, arguments)
            };
            var _isblank_l = Module["_isblank_l"] = function() {
                return (_isblank_l = Module["_isblank_l"] = Module["asm"]["isblank_l"]).apply(null, arguments)
            };
            var ___iswupper_l = Module["___iswupper_l"] = function() {
                return (___iswupper_l = Module["___iswupper_l"] = Module["asm"]["__iswupper_l"]).apply(null, arguments)
            };
            var _iswupper_l = Module["_iswupper_l"] = function() {
                return (_iswupper_l = Module["_iswupper_l"] = Module["asm"]["iswupper_l"]).apply(null, arguments)
            };
            var ___tolower_l = Module["___tolower_l"] = function() {
                return (___tolower_l = Module["___tolower_l"] = Module["asm"]["__tolower_l"]).apply(null, arguments)
            };
            var _tolower_l = Module["_tolower_l"] = function() {
                return (_tolower_l = Module["_tolower_l"] = Module["asm"]["tolower_l"]).apply(null, arguments)
            };
            var _wcwidth = Module["_wcwidth"] = function() {
                return (_wcwidth = Module["_wcwidth"] = Module["asm"]["wcwidth"]).apply(null, arguments)
            };
            var _iswcntrl = Module["_iswcntrl"] = function() {
                return (_iswcntrl = Module["_iswcntrl"] = Module["asm"]["iswcntrl"]).apply(null, arguments)
            };
            var ___iswcntrl_l = Module["___iswcntrl_l"] = function() {
                return (___iswcntrl_l = Module["___iswcntrl_l"] = Module["asm"]["__iswcntrl_l"]).apply(null, arguments)
            };
            var _iswcntrl_l = Module["_iswcntrl_l"] = function() {
                return (_iswcntrl_l = Module["_iswcntrl_l"] = Module["asm"]["iswcntrl_l"]).apply(null, arguments)
            };
            var _wctrans = Module["_wctrans"] = function() {
                return (_wctrans = Module["_wctrans"] = Module["asm"]["wctrans"]).apply(null, arguments)
            };
            var _towctrans = Module["_towctrans"] = function() {
                return (_towctrans = Module["_towctrans"] = Module["asm"]["towctrans"]).apply(null, arguments)
            };
            var ___wctrans_l = Module["___wctrans_l"] = function() {
                return (___wctrans_l = Module["___wctrans_l"] = Module["asm"]["__wctrans_l"]).apply(null, arguments)
            };
            var ___towctrans_l = Module["___towctrans_l"] = function() {
                return (___towctrans_l = Module["___towctrans_l"] = Module["asm"]["__towctrans_l"]).apply(null, arguments)
            };
            var _wctrans_l = Module["_wctrans_l"] = function() {
                return (_wctrans_l = Module["_wctrans_l"] = Module["asm"]["wctrans_l"]).apply(null, arguments)
            };
            var _towctrans_l = Module["_towctrans_l"] = function() {
                return (_towctrans_l = Module["_towctrans_l"] = Module["asm"]["towctrans_l"]).apply(null, arguments)
            };
            var _isprint = Module["_isprint"] = function() {
                return (_isprint = Module["_isprint"] = Module["asm"]["isprint"]).apply(null, arguments)
            };
            var ___isprint_l = Module["___isprint_l"] = function() {
                return (___isprint_l = Module["___isprint_l"] = Module["asm"]["__isprint_l"]).apply(null, arguments)
            };
            var _isprint_l = Module["_isprint_l"] = function() {
                return (_isprint_l = Module["_isprint_l"] = Module["asm"]["isprint_l"]).apply(null, arguments)
            };
            var ___ctype_tolower_loc = Module["___ctype_tolower_loc"] = function() {
                return (___ctype_tolower_loc = Module["___ctype_tolower_loc"] = Module["asm"]["__ctype_tolower_loc"]).apply(null, arguments)
            };
            var ___isgraph_l = Module["___isgraph_l"] = function() {
                return (___isgraph_l = Module["___isgraph_l"] = Module["asm"]["__isgraph_l"]).apply(null, arguments)
            };
            var _isgraph_l = Module["_isgraph_l"] = function() {
                return (_isgraph_l = Module["_isgraph_l"] = Module["asm"]["isgraph_l"]).apply(null, arguments)
            };
            var _toascii = Module["_toascii"] = function() {
                return (_toascii = Module["_toascii"] = Module["asm"]["toascii"]).apply(null, arguments)
            };
            var ___iswspace_l = Module["___iswspace_l"] = function() {
                return (___iswspace_l = Module["___iswspace_l"] = Module["asm"]["__iswspace_l"]).apply(null, arguments)
            };
            var _iswspace_l = Module["_iswspace_l"] = function() {
                return (_iswspace_l = Module["_iswspace_l"] = Module["asm"]["iswspace_l"]).apply(null, arguments)
            };
            var _iswalpha = Module["_iswalpha"] = function() {
                return (_iswalpha = Module["_iswalpha"] = Module["asm"]["iswalpha"]).apply(null, arguments)
            };
            var ___iswalpha_l = Module["___iswalpha_l"] = function() {
                return (___iswalpha_l = Module["___iswalpha_l"] = Module["asm"]["__iswalpha_l"]).apply(null, arguments)
            };
            var _iswalpha_l = Module["_iswalpha_l"] = function() {
                return (_iswalpha_l = Module["_iswalpha_l"] = Module["asm"]["iswalpha_l"]).apply(null, arguments)
            };
            var ___towupper_l = Module["___towupper_l"] = function() {
                return (___towupper_l = Module["___towupper_l"] = Module["asm"]["__towupper_l"]).apply(null, arguments)
            };
            var ___towlower_l = Module["___towlower_l"] = function() {
                return (___towlower_l = Module["___towlower_l"] = Module["asm"]["__towlower_l"]).apply(null, arguments)
            };
            var _towupper_l = Module["_towupper_l"] = function() {
                return (_towupper_l = Module["_towupper_l"] = Module["asm"]["towupper_l"]).apply(null, arguments)
            };
            var _towlower_l = Module["_towlower_l"] = function() {
                return (_towlower_l = Module["_towlower_l"] = Module["asm"]["towlower_l"]).apply(null, arguments)
            };
            var ___iswctype_l = Module["___iswctype_l"] = function() {
                return (___iswctype_l = Module["___iswctype_l"] = Module["asm"]["__iswctype_l"]).apply(null, arguments)
            };
            var ___wctype_l = Module["___wctype_l"] = function() {
                return (___wctype_l = Module["___wctype_l"] = Module["asm"]["__wctype_l"]).apply(null, arguments)
            };
            var _iswctype_l = Module["_iswctype_l"] = function() {
                return (_iswctype_l = Module["_iswctype_l"] = Module["asm"]["iswctype_l"]).apply(null, arguments)
            };
            var _wctype_l = Module["_wctype_l"] = function() {
                return (_wctype_l = Module["_wctype_l"] = Module["asm"]["wctype_l"]).apply(null, arguments)
            };
            var _wcswidth = Module["_wcswidth"] = function() {
                return (_wcswidth = Module["_wcswidth"] = Module["asm"]["wcswidth"]).apply(null, arguments)
            };
            var _isascii = Module["_isascii"] = function() {
                return (_isascii = Module["_isascii"] = Module["asm"]["isascii"]).apply(null, arguments)
            };
            var ___ctype_get_mb_cur_max = Module["___ctype_get_mb_cur_max"] = function() {
                return (___ctype_get_mb_cur_max = Module["___ctype_get_mb_cur_max"] = Module["asm"]["__ctype_get_mb_cur_max"]).apply(null, arguments)
            };
            var ___iswalnum_l = Module["___iswalnum_l"] = function() {
                return (___iswalnum_l = Module["___iswalnum_l"] = Module["asm"]["__iswalnum_l"]).apply(null, arguments)
            };
            var _iswalnum_l = Module["_iswalnum_l"] = function() {
                return (_iswalnum_l = Module["_iswalnum_l"] = Module["asm"]["iswalnum_l"]).apply(null, arguments)
            };
            var ___islower_l = Module["___islower_l"] = function() {
                return (___islower_l = Module["___islower_l"] = Module["asm"]["__islower_l"]).apply(null, arguments)
            };
            var _islower_l = Module["_islower_l"] = function() {
                return (_islower_l = Module["_islower_l"] = Module["asm"]["islower_l"]).apply(null, arguments)
            };
            var ___isalnum_l = Module["___isalnum_l"] = function() {
                return (___isalnum_l = Module["___isalnum_l"] = Module["asm"]["__isalnum_l"]).apply(null, arguments)
            };
            var _isalnum_l = Module["_isalnum_l"] = function() {
                return (_isalnum_l = Module["_isalnum_l"] = Module["asm"]["isalnum_l"]).apply(null, arguments)
            };
            var _mbrtoc32 = Module["_mbrtoc32"] = function() {
                return (_mbrtoc32 = Module["_mbrtoc32"] = Module["asm"]["mbrtoc32"]).apply(null, arguments)
            };
            var _c32rtomb = Module["_c32rtomb"] = function() {
                return (_c32rtomb = Module["_c32rtomb"] = Module["asm"]["c32rtomb"]).apply(null, arguments)
            };
            var _wcsnrtombs = Module["_wcsnrtombs"] = function() {
                return (_wcsnrtombs = Module["_wcsnrtombs"] = Module["asm"]["wcsnrtombs"]).apply(null, arguments)
            };
            var _c16rtomb = Module["_c16rtomb"] = function() {
                return (_c16rtomb = Module["_c16rtomb"] = Module["asm"]["c16rtomb"]).apply(null, arguments)
            };
            var _mbstowcs = Module["_mbstowcs"] = function() {
                return (_mbstowcs = Module["_mbstowcs"] = Module["asm"]["mbstowcs"]).apply(null, arguments)
            };
            var _mbsrtowcs = Module["_mbsrtowcs"] = function() {
                return (_mbsrtowcs = Module["_mbsrtowcs"] = Module["asm"]["mbsrtowcs"]).apply(null, arguments)
            };
            var _wctob = Module["_wctob"] = function() {
                return (_wctob = Module["_wctob"] = Module["asm"]["wctob"]).apply(null, arguments)
            };
            var _wcstombs = Module["_wcstombs"] = function() {
                return (_wcstombs = Module["_wcstombs"] = Module["asm"]["wcstombs"]).apply(null, arguments)
            };
            var _mbrlen = Module["_mbrlen"] = function() {
                return (_mbrlen = Module["_mbrlen"] = Module["asm"]["mbrlen"]).apply(null, arguments)
            };
            var _mbrtoc16 = Module["_mbrtoc16"] = function() {
                return (_mbrtoc16 = Module["_mbrtoc16"] = Module["asm"]["mbrtoc16"]).apply(null, arguments)
            };
            var _mblen = Module["_mblen"] = function() {
                return (_mblen = Module["_mblen"] = Module["asm"]["mblen"]).apply(null, arguments)
            };
            var _mktemp = Module["_mktemp"] = function() {
                return (_mktemp = Module["_mktemp"] = Module["asm"]["mktemp"]).apply(null, arguments)
            };
            var _mkostemp = Module["_mkostemp"] = function() {
                return (_mkostemp = Module["_mkostemp"] = Module["asm"]["mkostemp"]).apply(null, arguments)
            };
            var ___mkostemps = Module["___mkostemps"] = function() {
                return (___mkostemps = Module["___mkostemps"] = Module["asm"]["__mkostemps"]).apply(null, arguments)
            };
            var _mkostemp64 = Module["_mkostemp64"] = function() {
                return (_mkostemp64 = Module["_mkostemp64"] = Module["asm"]["mkostemp64"]).apply(null, arguments)
            };
            var _mkdtemp = Module["_mkdtemp"] = function() {
                return (_mkdtemp = Module["_mkdtemp"] = Module["asm"]["mkdtemp"]).apply(null, arguments)
            };
            var _mkstemps = Module["_mkstemps"] = function() {
                return (_mkstemps = Module["_mkstemps"] = Module["asm"]["mkstemps"]).apply(null, arguments)
            };
            var _mkstemps64 = Module["_mkstemps64"] = function() {
                return (_mkstemps64 = Module["_mkstemps64"] = Module["asm"]["mkstemps64"]).apply(null, arguments)
            };
            var _mkstemp = Module["_mkstemp"] = function() {
                return (_mkstemp = Module["_mkstemp"] = Module["asm"]["mkstemp"]).apply(null, arguments)
            };
            var _mkstemp64 = Module["_mkstemp64"] = function() {
                return (_mkstemp64 = Module["_mkstemp64"] = Module["asm"]["mkstemp64"]).apply(null, arguments)
            };
            var _mkostemps = Module["_mkostemps"] = function() {
                return (_mkostemps = Module["_mkostemps"] = Module["asm"]["mkostemps"]).apply(null, arguments)
            };
            var _mkostemps64 = Module["_mkostemps64"] = function() {
                return (_mkostemps64 = Module["_mkostemps64"] = Module["asm"]["mkostemps64"]).apply(null, arguments)
            };
            var ___strerror_l = Module["___strerror_l"] = function() {
                return (___strerror_l = Module["___strerror_l"] = Module["asm"]["__strerror_l"]).apply(null, arguments)
            };
            var _strerror_l = Module["_strerror_l"] = function() {
                return (_strerror_l = Module["_strerror_l"] = Module["asm"]["strerror_l"]).apply(null, arguments)
            };
            var _cfmakeraw = Module["_cfmakeraw"] = function() {
                return (_cfmakeraw = Module["_cfmakeraw"] = Module["asm"]["cfmakeraw"]).apply(null, arguments)
            };
            var _cfsetospeed = Module["_cfsetospeed"] = function() {
                return (_cfsetospeed = Module["_cfsetospeed"] = Module["asm"]["cfsetospeed"]).apply(null, arguments)
            };
            var _cfsetispeed = Module["_cfsetispeed"] = function() {
                return (_cfsetispeed = Module["_cfsetispeed"] = Module["asm"]["cfsetispeed"]).apply(null, arguments)
            };
            var _cfsetspeed = Module["_cfsetspeed"] = function() {
                return (_cfsetspeed = Module["_cfsetspeed"] = Module["asm"]["cfsetspeed"]).apply(null, arguments)
            };
            var _tcflow = Module["_tcflow"] = function() {
                return (_tcflow = Module["_tcflow"] = Module["asm"]["tcflow"]).apply(null, arguments)
            };
            var _cfgetospeed = Module["_cfgetospeed"] = function() {
                return (_cfgetospeed = Module["_cfgetospeed"] = Module["asm"]["cfgetospeed"]).apply(null, arguments)
            };
            var _cfgetispeed = Module["_cfgetispeed"] = function() {
                return (_cfgetispeed = Module["_cfgetispeed"] = Module["asm"]["cfgetispeed"]).apply(null, arguments)
            };
            var _tcsendbreak = Module["_tcsendbreak"] = function() {
                return (_tcsendbreak = Module["_tcsendbreak"] = Module["asm"]["tcsendbreak"]).apply(null, arguments)
            };
            var _tcflush = Module["_tcflush"] = function() {
                return (_tcflush = Module["_tcflush"] = Module["asm"]["tcflush"]).apply(null, arguments)
            };
            var _tcdrain = Module["_tcdrain"] = function() {
                return (_tcdrain = Module["_tcdrain"] = Module["asm"]["tcdrain"]).apply(null, arguments)
            };
            var _tcgetsid = Module["_tcgetsid"] = function() {
                return (_tcgetsid = Module["_tcgetsid"] = Module["asm"]["tcgetsid"]).apply(null, arguments)
            };
            var _tcgetattr = Module["_tcgetattr"] = function() {
                return (_tcgetattr = Module["_tcgetattr"] = Module["asm"]["tcgetattr"]).apply(null, arguments)
            };
            var _fchownat = Module["_fchownat"] = function() {
                return (_fchownat = Module["_fchownat"] = Module["asm"]["fchownat"]).apply(null, arguments)
            };
            var _lseek64 = Module["_lseek64"] = function() {
                return (_lseek64 = Module["_lseek64"] = Module["asm"]["lseek64"]).apply(null, arguments)
            };
            var _truncate = Module["_truncate"] = function() {
                return (_truncate = Module["_truncate"] = Module["asm"]["truncate"]).apply(null, arguments)
            };
            var _truncate64 = Module["_truncate64"] = function() {
                return (_truncate64 = Module["_truncate64"] = Module["asm"]["truncate64"]).apply(null, arguments)
            };
            var _sleep = Module["_sleep"] = function() {
                return (_sleep = Module["_sleep"] = Module["asm"]["sleep"]).apply(null, arguments)
            };
            var _symlink = Module["_symlink"] = function() {
                return (_symlink = Module["_symlink"] = Module["asm"]["symlink"]).apply(null, arguments)
            };
            var _dup3 = Module["_dup3"] = function() {
                return (_dup3 = Module["_dup3"] = Module["asm"]["dup3"]).apply(null, arguments)
            };
            var _setgid = Module["_setgid"] = function() {
                return (_setgid = Module["_setgid"] = Module["asm"]["setgid"]).apply(null, arguments)
            };
            var ___setxid = Module["___setxid"] = function() {
                return (___setxid = Module["___setxid"] = Module["asm"]["__setxid"]).apply(null, arguments)
            };
            var _rmdir = Module["_rmdir"] = function() {
                return (_rmdir = Module["_rmdir"] = Module["asm"]["rmdir"]).apply(null, arguments)
            };
            var _lchown = Module["_lchown"] = function() {
                return (_lchown = Module["_lchown"] = Module["asm"]["lchown"]).apply(null, arguments)
            };
            var _fsync = Module["_fsync"] = function() {
                return (_fsync = Module["_fsync"] = Module["asm"]["fsync"]).apply(null, arguments)
            };
            var _pwrite = Module["_pwrite"] = function() {
                return (_pwrite = Module["_pwrite"] = Module["asm"]["pwrite"]).apply(null, arguments)
            };
            var _pwrite64 = Module["_pwrite64"] = function() {
                return (_pwrite64 = Module["_pwrite64"] = Module["asm"]["pwrite64"]).apply(null, arguments)
            };
            var _fdatasync = Module["_fdatasync"] = function() {
                return (_fdatasync = Module["_fdatasync"] = Module["asm"]["fdatasync"]).apply(null, arguments)
            };
            var _pipe = Module["_pipe"] = function() {
                return (_pipe = Module["_pipe"] = Module["asm"]["pipe"]).apply(null, arguments)
            };
            var _setuid = Module["_setuid"] = function() {
                return (_setuid = Module["_setuid"] = Module["asm"]["setuid"]).apply(null, arguments)
            };
            var _readlinkat = Module["_readlinkat"] = function() {
                return (_readlinkat = Module["_readlinkat"] = Module["asm"]["readlinkat"]).apply(null, arguments)
            };
            var _getlogin = Module["_getlogin"] = function() {
                return (_getlogin = Module["_getlogin"] = Module["asm"]["getlogin"]).apply(null, arguments)
            };
            var _writev = Module["_writev"] = function() {
                return (_writev = Module["_writev"] = Module["asm"]["writev"]).apply(null, arguments)
            };
            var _getegid = Module["_getegid"] = function() {
                return (_getegid = Module["_getegid"] = Module["asm"]["getegid"]).apply(null, arguments)
            };
            var _getppid = Module["_getppid"] = function() {
                return (_getppid = Module["_getppid"] = Module["asm"]["getppid"]).apply(null, arguments)
            };
            var _setegid = Module["_setegid"] = function() {
                return (_setegid = Module["_setegid"] = Module["asm"]["setegid"]).apply(null, arguments)
            };
            var _pread = Module["_pread"] = function() {
                return (_pread = Module["_pread"] = Module["asm"]["pread"]).apply(null, arguments)
            };
            var _pread64 = Module["_pread64"] = function() {
                return (_pread64 = Module["_pread64"] = Module["asm"]["pread64"]).apply(null, arguments)
            };
            var _getuid = Module["_getuid"] = function() {
                return (_getuid = Module["_getuid"] = Module["asm"]["getuid"]).apply(null, arguments)
            };
            var _geteuid = Module["_geteuid"] = function() {
                return (_geteuid = Module["_geteuid"] = Module["asm"]["geteuid"]).apply(null, arguments)
            };
            var _readv = Module["_readv"] = function() {
                return (_readv = Module["_readv"] = Module["asm"]["readv"]).apply(null, arguments)
            };
            var _chown = Module["_chown"] = function() {
                return (_chown = Module["_chown"] = Module["asm"]["chown"]).apply(null, arguments)
            };
            var _setregid = Module["_setregid"] = function() {
                return (_setregid = Module["_setregid"] = Module["asm"]["setregid"]).apply(null, arguments)
            };
            var _symlinkat = Module["_symlinkat"] = function() {
                return (_symlinkat = Module["_symlinkat"] = Module["asm"]["symlinkat"]).apply(null, arguments)
            };
            var _ualarm = Module["_ualarm"] = function() {
                return (_ualarm = Module["_ualarm"] = Module["asm"]["ualarm"]).apply(null, arguments)
            };
            var _tcsetpgrp = Module["_tcsetpgrp"] = function() {
                return (_tcsetpgrp = Module["_tcsetpgrp"] = Module["asm"]["tcsetpgrp"]).apply(null, arguments)
            };
            var _getpgid = Module["_getpgid"] = function() {
                return (_getpgid = Module["_getpgid"] = Module["asm"]["getpgid"]).apply(null, arguments)
            };
            var _ttyname = Module["_ttyname"] = function() {
                return (_ttyname = Module["_ttyname"] = Module["asm"]["ttyname"]).apply(null, arguments)
            };
            var _ttyname_r = Module["_ttyname_r"] = function() {
                return (_ttyname_r = Module["_ttyname_r"] = Module["asm"]["ttyname_r"]).apply(null, arguments)
            };
            var _gethostname = Module["_gethostname"] = function() {
                return (_gethostname = Module["_gethostname"] = Module["asm"]["gethostname"]).apply(null, arguments)
            };
            var _dup = Module["_dup"] = function() {
                return (_dup = Module["_dup"] = Module["asm"]["dup"]).apply(null, arguments)
            };
            var _sync = Module["_sync"] = function() {
                return (_sync = Module["_sync"] = Module["asm"]["sync"]).apply(null, arguments)
            };
            var _tcgetpgrp = Module["_tcgetpgrp"] = function() {
                return (_tcgetpgrp = Module["_tcgetpgrp"] = Module["asm"]["tcgetpgrp"]).apply(null, arguments)
            };
            var _getgid = Module["_getgid"] = function() {
                return (_getgid = Module["_getgid"] = Module["asm"]["getgid"]).apply(null, arguments)
            };
            var _getlogin_r = Module["_getlogin_r"] = function() {
                return (_getlogin_r = Module["_getlogin_r"] = Module["asm"]["getlogin_r"]).apply(null, arguments)
            };
            var _pause = Module["_pause"] = function() {
                return (_pause = Module["_pause"] = Module["asm"]["pause"]).apply(null, arguments)
            };
            var _chdir = Module["_chdir"] = function() {
                return (_chdir = Module["_chdir"] = Module["asm"]["chdir"]).apply(null, arguments)
            };
            var _unlinkat = Module["_unlinkat"] = function() {
                return (_unlinkat = Module["_unlinkat"] = Module["asm"]["unlinkat"]).apply(null, arguments)
            };
            var _getgroups = Module["_getgroups"] = function() {
                return (_getgroups = Module["_getgroups"] = Module["asm"]["getgroups"]).apply(null, arguments)
            };
            var _fchown = Module["_fchown"] = function() {
                return (_fchown = Module["_fchown"] = Module["asm"]["fchown"]).apply(null, arguments)
            };
            var _pwritev = Module["_pwritev"] = function() {
                return (_pwritev = Module["_pwritev"] = Module["asm"]["pwritev"]).apply(null, arguments)
            };
            var _pwritev64 = Module["_pwritev64"] = function() {
                return (_pwritev64 = Module["_pwritev64"] = Module["asm"]["pwritev64"]).apply(null, arguments)
            };
            var _preadv = Module["_preadv"] = function() {
                return (_preadv = Module["_preadv"] = Module["asm"]["preadv"]).apply(null, arguments)
            };
            var _preadv64 = Module["_preadv64"] = function() {
                return (_preadv64 = Module["_preadv64"] = Module["asm"]["preadv64"]).apply(null, arguments)
            };
            var _usleep = Module["_usleep"] = function() {
                return (_usleep = Module["_usleep"] = Module["asm"]["usleep"]).apply(null, arguments)
            };
            var _fchdir = Module["_fchdir"] = function() {
                return (_fchdir = Module["_fchdir"] = Module["asm"]["fchdir"]).apply(null, arguments)
            };
            var _linkat = Module["_linkat"] = function() {
                return (_linkat = Module["_linkat"] = Module["asm"]["linkat"]).apply(null, arguments)
            };
            var _ctermid = Module["_ctermid"] = function() {
                return (_ctermid = Module["_ctermid"] = Module["asm"]["ctermid"]).apply(null, arguments)
            };
            var _setresgid = Module["_setresgid"] = function() {
                return (_setresgid = Module["_setresgid"] = Module["asm"]["setresgid"]).apply(null, arguments)
            };
            var _ftruncate = Module["_ftruncate"] = function() {
                return (_ftruncate = Module["_ftruncate"] = Module["asm"]["ftruncate"]).apply(null, arguments)
            };
            var _ftruncate64 = Module["_ftruncate64"] = function() {
                return (_ftruncate64 = Module["_ftruncate64"] = Module["asm"]["ftruncate64"]).apply(null, arguments)
            };
            var _isatty = Module["_isatty"] = function() {
                return (_isatty = Module["_isatty"] = Module["asm"]["isatty"]).apply(null, arguments)
            };
            var _acct = Module["_acct"] = function() {
                return (_acct = Module["_acct"] = Module["asm"]["acct"]).apply(null, arguments)
            };
            var _setpgid = Module["_setpgid"] = function() {
                return (_setpgid = Module["_setpgid"] = Module["asm"]["setpgid"]).apply(null, arguments)
            };
            var _renameat = Module["_renameat"] = function() {
                return (_renameat = Module["_renameat"] = Module["asm"]["renameat"]).apply(null, arguments)
            };
            var _setreuid = Module["_setreuid"] = function() {
                return (_setreuid = Module["_setreuid"] = Module["asm"]["setreuid"]).apply(null, arguments)
            };
            var _nice = Module["_nice"] = function() {
                return (_nice = Module["_nice"] = Module["asm"]["nice"]).apply(null, arguments)
            };
            var _posix_close = Module["_posix_close"] = function() {
                return (_posix_close = Module["_posix_close"] = Module["asm"]["posix_close"]).apply(null, arguments)
            };
            var _link = Module["_link"] = function() {
                return (_link = Module["_link"] = Module["asm"]["link"]).apply(null, arguments)
            };
            var _setresuid = Module["_setresuid"] = function() {
                return (_setresuid = Module["_setresuid"] = Module["asm"]["setresuid"]).apply(null, arguments)
            };
            var _setpgrp = Module["_setpgrp"] = function() {
                return (_setpgrp = Module["_setpgrp"] = Module["asm"]["setpgrp"]).apply(null, arguments)
            };
            var _getsid = Module["_getsid"] = function() {
                return (_getsid = Module["_getsid"] = Module["asm"]["getsid"]).apply(null, arguments)
            };
            var _seteuid = Module["_seteuid"] = function() {
                return (_seteuid = Module["_seteuid"] = Module["asm"]["seteuid"]).apply(null, arguments)
            };
            var _getpgrp = Module["_getpgrp"] = function() {
                return (_getpgrp = Module["_getpgrp"] = Module["asm"]["getpgrp"]).apply(null, arguments)
            };
            var _fpathconf = Module["_fpathconf"] = function() {
                return (_fpathconf = Module["_fpathconf"] = Module["asm"]["fpathconf"]).apply(null, arguments)
            };
            var _confstr = Module["_confstr"] = function() {
                return (_confstr = Module["_confstr"] = Module["asm"]["confstr"]).apply(null, arguments)
            };
            var _sysconf = Module["_sysconf"] = function() {
                return (_sysconf = Module["_sysconf"] = Module["asm"]["sysconf"]).apply(null, arguments)
            };
            var _get_nprocs_conf = Module["_get_nprocs_conf"] = function() {
                return (_get_nprocs_conf = Module["_get_nprocs_conf"] = Module["asm"]["get_nprocs_conf"]).apply(null, arguments)
            };
            var _get_nprocs = Module["_get_nprocs"] = function() {
                return (_get_nprocs = Module["_get_nprocs"] = Module["asm"]["get_nprocs"]).apply(null, arguments)
            };
            var _get_phys_pages = Module["_get_phys_pages"] = function() {
                return (_get_phys_pages = Module["_get_phys_pages"] = Module["asm"]["get_phys_pages"]).apply(null, arguments)
            };
            var _get_avphys_pages = Module["_get_avphys_pages"] = function() {
                return (_get_avphys_pages = Module["_get_avphys_pages"] = Module["asm"]["get_avphys_pages"]).apply(null, arguments)
            };
            var _pathconf = Module["_pathconf"] = function() {
                return (_pathconf = Module["_pathconf"] = Module["asm"]["pathconf"]).apply(null, arguments)
            };
            var ___floatunsitf = Module["___floatunsitf"] = function() {
                return (___floatunsitf = Module["___floatunsitf"] = Module["asm"]["__floatunsitf"]).apply(null, arguments)
            };
            var _fmodl = Module["_fmodl"] = function() {
                return (_fmodl = Module["_fmodl"] = Module["asm"]["fmodl"]).apply(null, arguments)
            };
            var ___libc_get_version = Module["___libc_get_version"] = function() {
                return (___libc_get_version = Module["___libc_get_version"] = Module["asm"]["__libc_get_version"]).apply(null, arguments)
            };
            var ___multi3 = Module["___multi3"] = function() {
                return (___multi3 = Module["___multi3"] = Module["asm"]["__multi3"]).apply(null, arguments)
            };
            var ___res_state = Module["___res_state"] = function() {
                return (___res_state = Module["___res_state"] = Module["asm"]["__res_state"]).apply(null, arguments)
            };
            var _if_indextoname = Module["_if_indextoname"] = function() {
                return (_if_indextoname = Module["_if_indextoname"] = Module["asm"]["if_indextoname"]).apply(null, arguments)
            };
            var _getservbyport = Module["_getservbyport"] = function() {
                return (_getservbyport = Module["_getservbyport"] = Module["asm"]["getservbyport"]).apply(null, arguments)
            };
            var _getservbyport_r = Module["_getservbyport_r"] = function() {
                return (_getservbyport_r = Module["_getservbyport_r"] = Module["asm"]["getservbyport_r"]).apply(null, arguments)
            };
            var ___lookup_name = Module["___lookup_name"] = function() {
                return (___lookup_name = Module["___lookup_name"] = Module["asm"]["__lookup_name"]).apply(null, arguments)
            };
            var _getsockname = Module["_getsockname"] = function() {
                return (_getsockname = Module["_getsockname"] = Module["asm"]["getsockname"]).apply(null, arguments)
            };
            var ___lookup_ipliteral = Module["___lookup_ipliteral"] = function() {
                return (___lookup_ipliteral = Module["___lookup_ipliteral"] = Module["asm"]["__lookup_ipliteral"]).apply(null, arguments)
            };
            var ___get_resolv_conf = Module["___get_resolv_conf"] = function() {
                return (___get_resolv_conf = Module["___get_resolv_conf"] = Module["asm"]["__get_resolv_conf"]).apply(null, arguments)
            };
            var ___res_mkquery = Module["___res_mkquery"] = function() {
                return (___res_mkquery = Module["___res_mkquery"] = Module["asm"]["__res_mkquery"]).apply(null, arguments)
            };
            var ___res_msend_rc = Module["___res_msend_rc"] = function() {
                return (___res_msend_rc = Module["___res_msend_rc"] = Module["asm"]["__res_msend_rc"]).apply(null, arguments)
            };
            var ___dns_parse = Module["___dns_parse"] = function() {
                return (___dns_parse = Module["___dns_parse"] = Module["asm"]["__dns_parse"]).apply(null, arguments)
            };
            var ___dn_expand = Module["___dn_expand"] = function() {
                return (___dn_expand = Module["___dn_expand"] = Module["asm"]["__dn_expand"]).apply(null, arguments)
            };
            var ___dn_comp = Module["___dn_comp"] = function() {
                return (___dn_comp = Module["___dn_comp"] = Module["asm"]["__dn_comp"]).apply(null, arguments)
            };
            var _dn_comp = Module["_dn_comp"] = function() {
                return (_dn_comp = Module["_dn_comp"] = Module["asm"]["dn_comp"]).apply(null, arguments)
            };
            var _recvmmsg = Module["_recvmmsg"] = function() {
                return (_recvmmsg = Module["_recvmmsg"] = Module["asm"]["recvmmsg"]).apply(null, arguments)
            };
            var _ntohl = Module["_ntohl"] = function() {
                return (_ntohl = Module["_ntohl"] = Module["asm"]["ntohl"]).apply(null, arguments)
            };
            var _ns_get16 = Module["_ns_get16"] = function() {
                return (_ns_get16 = Module["_ns_get16"] = Module["asm"]["ns_get16"]).apply(null, arguments)
            };
            var _ns_get32 = Module["_ns_get32"] = function() {
                return (_ns_get32 = Module["_ns_get32"] = Module["asm"]["ns_get32"]).apply(null, arguments)
            };
            var _ns_put16 = Module["_ns_put16"] = function() {
                return (_ns_put16 = Module["_ns_put16"] = Module["asm"]["ns_put16"]).apply(null, arguments)
            };
            var _ns_put32 = Module["_ns_put32"] = function() {
                return (_ns_put32 = Module["_ns_put32"] = Module["asm"]["ns_put32"]).apply(null, arguments)
            };
            var _ns_skiprr = Module["_ns_skiprr"] = function() {
                return (_ns_skiprr = Module["_ns_skiprr"] = Module["asm"]["ns_skiprr"]).apply(null, arguments)
            };
            var _dn_skipname = Module["_dn_skipname"] = function() {
                return (_dn_skipname = Module["_dn_skipname"] = Module["asm"]["dn_skipname"]).apply(null, arguments)
            };
            var _ns_initparse = Module["_ns_initparse"] = function() {
                return (_ns_initparse = Module["_ns_initparse"] = Module["asm"]["ns_initparse"]).apply(null, arguments)
            };
            var _ns_name_uncompress = Module["_ns_name_uncompress"] = function() {
                return (_ns_name_uncompress = Module["_ns_name_uncompress"] = Module["asm"]["ns_name_uncompress"]).apply(null, arguments)
            };
            var _dn_expand = Module["_dn_expand"] = function() {
                return (_dn_expand = Module["_dn_expand"] = Module["asm"]["dn_expand"]).apply(null, arguments)
            };
            var _ns_parserr = Module["_ns_parserr"] = function() {
                return (_ns_parserr = Module["_ns_parserr"] = Module["asm"]["ns_parserr"]).apply(null, arguments)
            };
            var ___res_send = Module["___res_send"] = function() {
                return (___res_send = Module["___res_send"] = Module["asm"]["__res_send"]).apply(null, arguments)
            };
            var ___res_msend = Module["___res_msend"] = function() {
                return (___res_msend = Module["___res_msend"] = Module["asm"]["__res_msend"]).apply(null, arguments)
            };
            var _res_send = Module["_res_send"] = function() {
                return (_res_send = Module["_res_send"] = Module["asm"]["res_send"]).apply(null, arguments)
            };
            var _inet_addr = Module["_inet_addr"] = function() {
                return (_inet_addr = Module["_inet_addr"] = Module["asm"]["inet_addr"]).apply(null, arguments)
            };
            var ___inet_aton = Module["___inet_aton"] = function() {
                return (___inet_aton = Module["___inet_aton"] = Module["asm"]["__inet_aton"]).apply(null, arguments)
            };
            var _if_nametoindex = Module["_if_nametoindex"] = function() {
                return (_if_nametoindex = Module["_if_nametoindex"] = Module["asm"]["if_nametoindex"]).apply(null, arguments)
            };
            var _freeifaddrs = Module["_freeifaddrs"] = function() {
                return (_freeifaddrs = Module["_freeifaddrs"] = Module["asm"]["freeifaddrs"]).apply(null, arguments)
            };
            var _getifaddrs = Module["_getifaddrs"] = function() {
                return (_getifaddrs = Module["_getifaddrs"] = Module["asm"]["getifaddrs"]).apply(null, arguments)
            };
            var ___rtnetlink_enumerate = Module["___rtnetlink_enumerate"] = function() {
                return (___rtnetlink_enumerate = Module["___rtnetlink_enumerate"] = Module["asm"]["__rtnetlink_enumerate"]).apply(null, arguments)
            };
            var _res_mkquery = Module["_res_mkquery"] = function() {
                return (_res_mkquery = Module["_res_mkquery"] = Module["asm"]["res_mkquery"]).apply(null, arguments)
            };
            var _sockatmark = Module["_sockatmark"] = function() {
                return (_sockatmark = Module["_sockatmark"] = Module["asm"]["sockatmark"]).apply(null, arguments)
            };
            var _if_freenameindex = Module["_if_freenameindex"] = function() {
                return (_if_freenameindex = Module["_if_freenameindex"] = Module["asm"]["if_freenameindex"]).apply(null, arguments)
            };
            var _htons = Module["_htons"] = function() {
                return (_htons = Module["_htons"] = Module["asm"]["htons"]).apply(null, arguments)
            };
            var _bind = Module["_bind"] = function() {
                return (_bind = Module["_bind"] = Module["asm"]["bind"]).apply(null, arguments)
            };
            var _setsockopt = Module["_setsockopt"] = function() {
                return (_setsockopt = Module["_setsockopt"] = Module["asm"]["setsockopt"]).apply(null, arguments)
            };
            var _sendto = Module["_sendto"] = function() {
                return (_sendto = Module["_sendto"] = Module["asm"]["sendto"]).apply(null, arguments)
            };
            var _poll = Module["_poll"] = function() {
                return (_poll = Module["_poll"] = Module["asm"]["poll"]).apply(null, arguments)
            };
            var _recvfrom = Module["_recvfrom"] = function() {
                return (_recvfrom = Module["_recvfrom"] = Module["asm"]["recvfrom"]).apply(null, arguments)
            };
            var _inet_ntoa = Module["_inet_ntoa"] = function() {
                return (_inet_ntoa = Module["_inet_ntoa"] = Module["asm"]["inet_ntoa"]).apply(null, arguments)
            };
            var _inet_pton = Module["_inet_pton"] = function() {
                return (_inet_pton = Module["_inet_pton"] = Module["asm"]["inet_pton"]).apply(null, arguments)
            };
            var _htonl = Module["_htonl"] = function() {
                return (_htonl = Module["_htonl"] = Module["asm"]["htonl"]).apply(null, arguments)
            };
            var _sethostent = Module["_sethostent"] = function() {
                return (_sethostent = Module["_sethostent"] = Module["asm"]["sethostent"]).apply(null, arguments)
            };
            var _gethostent = Module["_gethostent"] = function() {
                return (_gethostent = Module["_gethostent"] = Module["asm"]["gethostent"]).apply(null, arguments)
            };
            var _endhostent = Module["_endhostent"] = function() {
                return (_endhostent = Module["_endhostent"] = Module["asm"]["endhostent"]).apply(null, arguments)
            };
            var _setnetent = Module["_setnetent"] = function() {
                return (_setnetent = Module["_setnetent"] = Module["asm"]["setnetent"]).apply(null, arguments)
            };
            var _getnetent = Module["_getnetent"] = function() {
                return (_getnetent = Module["_getnetent"] = Module["asm"]["getnetent"]).apply(null, arguments)
            };
            var _endnetent = Module["_endnetent"] = function() {
                return (_endnetent = Module["_endnetent"] = Module["asm"]["endnetent"]).apply(null, arguments)
            };
            var _ntohs = Module["_ntohs"] = function() {
                return (_ntohs = Module["_ntohs"] = Module["asm"]["ntohs"]).apply(null, arguments)
            };
            var _recv = Module["_recv"] = function() {
                return (_recv = Module["_recv"] = Module["asm"]["recv"]).apply(null, arguments)
            };
            var _hstrerror = Module["_hstrerror"] = function() {
                return (_hstrerror = Module["_hstrerror"] = Module["asm"]["hstrerror"]).apply(null, arguments)
            };
            var _strtoull = Module["_strtoull"] = function() {
                return (_strtoull = Module["_strtoull"] = Module["asm"]["strtoull"]).apply(null, arguments)
            };
            var _if_nameindex = Module["_if_nameindex"] = function() {
                return (_if_nameindex = Module["_if_nameindex"] = Module["asm"]["if_nameindex"]).apply(null, arguments)
            };
            var _res_init = Module["_res_init"] = function() {
                return (_res_init = Module["_res_init"] = Module["asm"]["res_init"]).apply(null, arguments)
            };
            var _inet_network = Module["_inet_network"] = function() {
                return (_inet_network = Module["_inet_network"] = Module["asm"]["inet_network"]).apply(null, arguments)
            };
            var _inet_makeaddr = Module["_inet_makeaddr"] = function() {
                return (_inet_makeaddr = Module["_inet_makeaddr"] = Module["asm"]["inet_makeaddr"]).apply(null, arguments)
            };
            var _inet_lnaof = Module["_inet_lnaof"] = function() {
                return (_inet_lnaof = Module["_inet_lnaof"] = Module["asm"]["inet_lnaof"]).apply(null, arguments)
            };
            var _inet_netof = Module["_inet_netof"] = function() {
                return (_inet_netof = Module["_inet_netof"] = Module["asm"]["inet_netof"]).apply(null, arguments)
            };
            var _getservbyname = Module["_getservbyname"] = function() {
                return (_getservbyname = Module["_getservbyname"] = Module["asm"]["getservbyname"]).apply(null, arguments)
            };
            var _getservbyname_r = Module["_getservbyname_r"] = function() {
                return (_getservbyname_r = Module["_getservbyname_r"] = Module["asm"]["getservbyname_r"]).apply(null, arguments)
            };
            var _endservent = Module["_endservent"] = function() {
                return (_endservent = Module["_endservent"] = Module["asm"]["endservent"]).apply(null, arguments)
            };
            var _setservent = Module["_setservent"] = function() {
                return (_setservent = Module["_setservent"] = Module["asm"]["setservent"]).apply(null, arguments)
            };
            var _getservent = Module["_getservent"] = function() {
                return (_getservent = Module["_getservent"] = Module["asm"]["getservent"]).apply(null, arguments)
            };
            var _getnetbyaddr = Module["_getnetbyaddr"] = function() {
                return (_getnetbyaddr = Module["_getnetbyaddr"] = Module["asm"]["getnetbyaddr"]).apply(null, arguments)
            };
            var _getnetbyname = Module["_getnetbyname"] = function() {
                return (_getnetbyname = Module["_getnetbyname"] = Module["asm"]["getnetbyname"]).apply(null, arguments)
            };
            var _herror = Module["_herror"] = function() {
                return (_herror = Module["_herror"] = Module["asm"]["herror"]).apply(null, arguments)
            };
            var ___h_errno_location = Module["___h_errno_location"] = function() {
                return (___h_errno_location = Module["___h_errno_location"] = Module["asm"]["__h_errno_location"]).apply(null, arguments)
            };
            var _sendmmsg = Module["_sendmmsg"] = function() {
                return (_sendmmsg = Module["_sendmmsg"] = Module["asm"]["sendmmsg"]).apply(null, arguments)
            };
            var _inet_ntop = Module["_inet_ntop"] = function() {
                return (_inet_ntop = Module["_inet_ntop"] = Module["asm"]["inet_ntop"]).apply(null, arguments)
            };
            var _inet_aton = Module["_inet_aton"] = function() {
                return (_inet_aton = Module["_inet_aton"] = Module["asm"]["inet_aton"]).apply(null, arguments)
            };
            var _accept4 = Module["_accept4"] = function() {
                return (_accept4 = Module["_accept4"] = Module["asm"]["accept4"]).apply(null, arguments)
            };
            var _accept = Module["_accept"] = function() {
                return (_accept = Module["_accept"] = Module["asm"]["accept"]).apply(null, arguments)
            };
            var _ether_aton_r = Module["_ether_aton_r"] = function() {
                return (_ether_aton_r = Module["_ether_aton_r"] = Module["asm"]["ether_aton_r"]).apply(null, arguments)
            };
            var _ether_aton = Module["_ether_aton"] = function() {
                return (_ether_aton = Module["_ether_aton"] = Module["asm"]["ether_aton"]).apply(null, arguments)
            };
            var _ether_ntoa_r = Module["_ether_ntoa_r"] = function() {
                return (_ether_ntoa_r = Module["_ether_ntoa_r"] = Module["asm"]["ether_ntoa_r"]).apply(null, arguments)
            };
            var _ether_ntoa = Module["_ether_ntoa"] = function() {
                return (_ether_ntoa = Module["_ether_ntoa"] = Module["asm"]["ether_ntoa"]).apply(null, arguments)
            };
            var _ether_line = Module["_ether_line"] = function() {
                return (_ether_line = Module["_ether_line"] = Module["asm"]["ether_line"]).apply(null, arguments)
            };
            var _ether_ntohost = Module["_ether_ntohost"] = function() {
                return (_ether_ntohost = Module["_ether_ntohost"] = Module["asm"]["ether_ntohost"]).apply(null, arguments)
            };
            var _ether_hostton = Module["_ether_hostton"] = function() {
                return (_ether_hostton = Module["_ether_hostton"] = Module["asm"]["ether_hostton"]).apply(null, arguments)
            };
            var ___lookup_serv = Module["___lookup_serv"] = function() {
                return (___lookup_serv = Module["___lookup_serv"] = Module["asm"]["__lookup_serv"]).apply(null, arguments)
            };
            var _csqrtf = Module["_csqrtf"] = function() {
                return (_csqrtf = Module["_csqrtf"] = Module["asm"]["csqrtf"]).apply(null, arguments)
            };
            var _conjf = Module["_conjf"] = function() {
                return (_conjf = Module["_conjf"] = Module["asm"]["conjf"]).apply(null, arguments)
            };
            var _ctanl = Module["_ctanl"] = function() {
                return (_ctanl = Module["_ctanl"] = Module["asm"]["ctanl"]).apply(null, arguments)
            };
            var _ctanhl = Module["_ctanhl"] = function() {
                return (_ctanhl = Module["_ctanhl"] = Module["asm"]["ctanhl"]).apply(null, arguments)
            };
            var _cpow = Module["_cpow"] = function() {
                return (_cpow = Module["_cpow"] = Module["asm"]["cpow"]).apply(null, arguments)
            };
            var _clog = Module["_clog"] = function() {
                return (_clog = Module["_clog"] = Module["asm"]["clog"]).apply(null, arguments)
            };
            var ___muldc3 = Module["___muldc3"] = function() {
                return (___muldc3 = Module["___muldc3"] = Module["asm"]["__muldc3"]).apply(null, arguments)
            };
            var _cexp = Module["_cexp"] = function() {
                return (_cexp = Module["_cexp"] = Module["asm"]["cexp"]).apply(null, arguments)
            };
            var _cpowl = Module["_cpowl"] = function() {
                return (_cpowl = Module["_cpowl"] = Module["asm"]["cpowl"]).apply(null, arguments)
            };
            var _clogl = Module["_clogl"] = function() {
                return (_clogl = Module["_clogl"] = Module["asm"]["clogl"]).apply(null, arguments)
            };
            var ___unordtf2 = Module["___unordtf2"] = function() {
                return (___unordtf2 = Module["___unordtf2"] = Module["asm"]["__unordtf2"]).apply(null, arguments)
            };
            var ___multc3 = Module["___multc3"] = function() {
                return (___multc3 = Module["___multc3"] = Module["asm"]["__multc3"]).apply(null, arguments)
            };
            var _cexpl = Module["_cexpl"] = function() {
                return (_cexpl = Module["_cexpl"] = Module["asm"]["cexpl"]).apply(null, arguments)
            };
            var _csinhl = Module["_csinhl"] = function() {
                return (_csinhl = Module["_csinhl"] = Module["asm"]["csinhl"]).apply(null, arguments)
            };
            var _csinh = Module["_csinh"] = function() {
                return (_csinh = Module["_csinh"] = Module["asm"]["csinh"]).apply(null, arguments)
            };
            var _csin = Module["_csin"] = function() {
                return (_csin = Module["_csin"] = Module["asm"]["csin"]).apply(null, arguments)
            };
            var _ccos = Module["_ccos"] = function() {
                return (_ccos = Module["_ccos"] = Module["asm"]["ccos"]).apply(null, arguments)
            };
            var _ccosh = Module["_ccosh"] = function() {
                return (_ccosh = Module["_ccosh"] = Module["asm"]["ccosh"]).apply(null, arguments)
            };
            var _clogf = Module["_clogf"] = function() {
                return (_clogf = Module["_clogf"] = Module["asm"]["clogf"]).apply(null, arguments)
            };
            var _cabsf = Module["_cabsf"] = function() {
                return (_cabsf = Module["_cabsf"] = Module["asm"]["cabsf"]).apply(null, arguments)
            };
            var _cargf = Module["_cargf"] = function() {
                return (_cargf = Module["_cargf"] = Module["asm"]["cargf"]).apply(null, arguments)
            };
            var _casinl = Module["_casinl"] = function() {
                return (_casinl = Module["_casinl"] = Module["asm"]["casinl"]).apply(null, arguments)
            };
            var _csqrtl = Module["_csqrtl"] = function() {
                return (_csqrtl = Module["_csqrtl"] = Module["asm"]["csqrtl"]).apply(null, arguments)
            };
            var _cexpf = Module["_cexpf"] = function() {
                return (_cexpf = Module["_cexpf"] = Module["asm"]["cexpf"]).apply(null, arguments)
            };
            var ___ldexp_cexpf = Module["___ldexp_cexpf"] = function() {
                return (___ldexp_cexpf = Module["___ldexp_cexpf"] = Module["asm"]["__ldexp_cexpf"]).apply(null, arguments)
            };
            var _cacosf = Module["_cacosf"] = function() {
                return (_cacosf = Module["_cacosf"] = Module["asm"]["cacosf"]).apply(null, arguments)
            };
            var _casinf = Module["_casinf"] = function() {
                return (_casinf = Module["_casinf"] = Module["asm"]["casinf"]).apply(null, arguments)
            };
            var _ctanhf = Module["_ctanhf"] = function() {
                return (_ctanhf = Module["_ctanhf"] = Module["asm"]["ctanhf"]).apply(null, arguments)
            };
            var _cabsl = Module["_cabsl"] = function() {
                return (_cabsl = Module["_cabsl"] = Module["asm"]["cabsl"]).apply(null, arguments)
            };
            var _cargl = Module["_cargl"] = function() {
                return (_cargl = Module["_cargl"] = Module["asm"]["cargl"]).apply(null, arguments)
            };
            var _cacoshl = Module["_cacoshl"] = function() {
                return (_cacoshl = Module["_cacoshl"] = Module["asm"]["cacoshl"]).apply(null, arguments)
            };
            var _cacosl = Module["_cacosl"] = function() {
                return (_cacosl = Module["_cacosl"] = Module["asm"]["cacosl"]).apply(null, arguments)
            };
            var _ctanh = Module["_ctanh"] = function() {
                return (_ctanh = Module["_ctanh"] = Module["asm"]["ctanh"]).apply(null, arguments)
            };
            var _casinhf = Module["_casinhf"] = function() {
                return (_casinhf = Module["_casinhf"] = Module["asm"]["casinhf"]).apply(null, arguments)
            };
            var _ctanf = Module["_ctanf"] = function() {
                return (_ctanf = Module["_ctanf"] = Module["asm"]["ctanf"]).apply(null, arguments)
            };
            var _catanl = Module["_catanl"] = function() {
                return (_catanl = Module["_catanl"] = Module["asm"]["catanl"]).apply(null, arguments)
            };
            var ___ldexp_cexp = Module["___ldexp_cexp"] = function() {
                return (___ldexp_cexp = Module["___ldexp_cexp"] = Module["asm"]["__ldexp_cexp"]).apply(null, arguments)
            };
            var _ctan = Module["_ctan"] = function() {
                return (_ctan = Module["_ctan"] = Module["asm"]["ctan"]).apply(null, arguments)
            };
            var _ccosl = Module["_ccosl"] = function() {
                return (_ccosl = Module["_ccosl"] = Module["asm"]["ccosl"]).apply(null, arguments)
            };
            var _ccoshl = Module["_ccoshl"] = function() {
                return (_ccoshl = Module["_ccoshl"] = Module["asm"]["ccoshl"]).apply(null, arguments)
            };
            var _creal = Module["_creal"] = function() {
                return (_creal = Module["_creal"] = Module["asm"]["creal"]).apply(null, arguments)
            };
            var _catanhl = Module["_catanhl"] = function() {
                return (_catanhl = Module["_catanhl"] = Module["asm"]["catanhl"]).apply(null, arguments)
            };
            var _cacosh = Module["_cacosh"] = function() {
                return (_cacosh = Module["_cacosh"] = Module["asm"]["cacosh"]).apply(null, arguments)
            };
            var _cacos = Module["_cacos"] = function() {
                return (_cacos = Module["_cacos"] = Module["asm"]["cacos"]).apply(null, arguments)
            };
            var _cimag = Module["_cimag"] = function() {
                return (_cimag = Module["_cimag"] = Module["asm"]["cimag"]).apply(null, arguments)
            };
            var _catanh = Module["_catanh"] = function() {
                return (_catanh = Module["_catanh"] = Module["asm"]["catanh"]).apply(null, arguments)
            };
            var _catan = Module["_catan"] = function() {
                return (_catan = Module["_catan"] = Module["asm"]["catan"]).apply(null, arguments)
            };
            var _casinhl = Module["_casinhl"] = function() {
                return (_casinhl = Module["_casinhl"] = Module["asm"]["casinhl"]).apply(null, arguments)
            };
            var _cprojl = Module["_cprojl"] = function() {
                return (_cprojl = Module["_cprojl"] = Module["asm"]["cprojl"]).apply(null, arguments)
            };
            var _csinhf = Module["_csinhf"] = function() {
                return (_csinhf = Module["_csinhf"] = Module["asm"]["csinhf"]).apply(null, arguments)
            };
            var _cabs = Module["_cabs"] = function() {
                return (_cabs = Module["_cabs"] = Module["asm"]["cabs"]).apply(null, arguments)
            };
            var _carg = Module["_carg"] = function() {
                return (_carg = Module["_carg"] = Module["asm"]["carg"]).apply(null, arguments)
            };
            var _csinf = Module["_csinf"] = function() {
                return (_csinf = Module["_csinf"] = Module["asm"]["csinf"]).apply(null, arguments)
            };
            var _casinh = Module["_casinh"] = function() {
                return (_casinh = Module["_casinh"] = Module["asm"]["casinh"]).apply(null, arguments)
            };
            var _casin = Module["_casin"] = function() {
                return (_casin = Module["_casin"] = Module["asm"]["casin"]).apply(null, arguments)
            };
            var _catanhf = Module["_catanhf"] = function() {
                return (_catanhf = Module["_catanhf"] = Module["asm"]["catanhf"]).apply(null, arguments)
            };
            var _catanf = Module["_catanf"] = function() {
                return (_catanf = Module["_catanf"] = Module["asm"]["catanf"]).apply(null, arguments)
            };
            var _cproj = Module["_cproj"] = function() {
                return (_cproj = Module["_cproj"] = Module["asm"]["cproj"]).apply(null, arguments)
            };
            var _csinl = Module["_csinl"] = function() {
                return (_csinl = Module["_csinl"] = Module["asm"]["csinl"]).apply(null, arguments)
            };
            var _cimagl = Module["_cimagl"] = function() {
                return (_cimagl = Module["_cimagl"] = Module["asm"]["cimagl"]).apply(null, arguments)
            };
            var _cimagf = Module["_cimagf"] = function() {
                return (_cimagf = Module["_cimagf"] = Module["asm"]["cimagf"]).apply(null, arguments)
            };
            var _conjl = Module["_conjl"] = function() {
                return (_conjl = Module["_conjl"] = Module["asm"]["conjl"]).apply(null, arguments)
            };
            var _ccoshf = Module["_ccoshf"] = function() {
                return (_ccoshf = Module["_ccoshf"] = Module["asm"]["ccoshf"]).apply(null, arguments)
            };
            var _ccosf = Module["_ccosf"] = function() {
                return (_ccosf = Module["_ccosf"] = Module["asm"]["ccosf"]).apply(null, arguments)
            };
            var _cacoshf = Module["_cacoshf"] = function() {
                return (_cacoshf = Module["_cacoshf"] = Module["asm"]["cacoshf"]).apply(null, arguments)
            };
            var _crealf = Module["_crealf"] = function() {
                return (_crealf = Module["_crealf"] = Module["asm"]["crealf"]).apply(null, arguments)
            };
            var _csqrt = Module["_csqrt"] = function() {
                return (_csqrt = Module["_csqrt"] = Module["asm"]["csqrt"]).apply(null, arguments)
            };
            var _cpowf = Module["_cpowf"] = function() {
                return (_cpowf = Module["_cpowf"] = Module["asm"]["cpowf"]).apply(null, arguments)
            };
            var ___mulsc3 = Module["___mulsc3"] = function() {
                return (___mulsc3 = Module["___mulsc3"] = Module["asm"]["__mulsc3"]).apply(null, arguments)
            };
            var _cprojf = Module["_cprojf"] = function() {
                return (_cprojf = Module["_cprojf"] = Module["asm"]["cprojf"]).apply(null, arguments)
            };
            var _creall = Module["_creall"] = function() {
                return (_creall = Module["_creall"] = Module["asm"]["creall"]).apply(null, arguments)
            };
            var _conj = Module["_conj"] = function() {
                return (_conj = Module["_conj"] = Module["asm"]["conj"]).apply(null, arguments)
            };
            var _fegetexceptflag = Module["_fegetexceptflag"] = function() {
                return (_fegetexceptflag = Module["_fegetexceptflag"] = Module["asm"]["fegetexceptflag"]).apply(null, arguments)
            };
            var _fetestexcept = Module["_fetestexcept"] = function() {
                return (_fetestexcept = Module["_fetestexcept"] = Module["asm"]["fetestexcept"]).apply(null, arguments)
            };
            var _fesetexceptflag = Module["_fesetexceptflag"] = function() {
                return (_fesetexceptflag = Module["_fesetexceptflag"] = Module["asm"]["fesetexceptflag"]).apply(null, arguments)
            };
            var _feclearexcept = Module["_feclearexcept"] = function() {
                return (_feclearexcept = Module["_feclearexcept"] = Module["asm"]["feclearexcept"]).apply(null, arguments)
            };
            var _feraiseexcept = Module["_feraiseexcept"] = function() {
                return (_feraiseexcept = Module["_feraiseexcept"] = Module["asm"]["feraiseexcept"]).apply(null, arguments)
            };
            var ___fesetround = Module["___fesetround"] = function() {
                return (___fesetround = Module["___fesetround"] = Module["asm"]["__fesetround"]).apply(null, arguments)
            };
            var _fegetenv = Module["_fegetenv"] = function() {
                return (_fegetenv = Module["_fegetenv"] = Module["asm"]["fegetenv"]).apply(null, arguments)
            };
            var _fesetenv = Module["_fesetenv"] = function() {
                return (_fesetenv = Module["_fesetenv"] = Module["asm"]["fesetenv"]).apply(null, arguments)
            };
            var _feholdexcept = Module["_feholdexcept"] = function() {
                return (_feholdexcept = Module["_feholdexcept"] = Module["asm"]["feholdexcept"]).apply(null, arguments)
            };
            var ___flt_rounds = Module["___flt_rounds"] = function() {
                return (___flt_rounds = Module["___flt_rounds"] = Module["asm"]["__flt_rounds"]).apply(null, arguments)
            };
            var _feupdateenv = Module["_feupdateenv"] = function() {
                return (_feupdateenv = Module["_feupdateenv"] = Module["asm"]["feupdateenv"]).apply(null, arguments)
            };
            var _posix_spawnattr_setpgroup = Module["_posix_spawnattr_setpgroup"] = function() {
                return (_posix_spawnattr_setpgroup = Module["_posix_spawnattr_setpgroup"] = Module["asm"]["posix_spawnattr_setpgroup"]).apply(null, arguments)
            };
            var _wait = Module["_wait"] = function() {
                return (_wait = Module["_wait"] = Module["asm"]["wait"]).apply(null, arguments)
            };
            var ___execvpe = Module["___execvpe"] = function() {
                return (___execvpe = Module["___execvpe"] = Module["asm"]["__execvpe"]).apply(null, arguments)
            };
            var _execvp = Module["_execvp"] = function() {
                return (_execvp = Module["_execvp"] = Module["asm"]["execvp"]).apply(null, arguments)
            };
            var _execvpe = Module["_execvpe"] = function() {
                return (_execvpe = Module["_execvpe"] = Module["asm"]["execvpe"]).apply(null, arguments)
            };
            var _posix_spawnattr_destroy = Module["_posix_spawnattr_destroy"] = function() {
                return (_posix_spawnattr_destroy = Module["_posix_spawnattr_destroy"] = Module["asm"]["posix_spawnattr_destroy"]).apply(null, arguments)
            };
            var _posix_spawnattr_getflags = Module["_posix_spawnattr_getflags"] = function() {
                return (_posix_spawnattr_getflags = Module["_posix_spawnattr_getflags"] = Module["asm"]["posix_spawnattr_getflags"]).apply(null, arguments)
            };
            var _execv = Module["_execv"] = function() {
                return (_execv = Module["_execv"] = Module["asm"]["execv"]).apply(null, arguments)
            };
            var _posix_spawnattr_getpgroup = Module["_posix_spawnattr_getpgroup"] = function() {
                return (_posix_spawnattr_getpgroup = Module["_posix_spawnattr_getpgroup"] = Module["asm"]["posix_spawnattr_getpgroup"]).apply(null, arguments)
            };
            var _execl = Module["_execl"] = function() {
                return (_execl = Module["_execl"] = Module["asm"]["execl"]).apply(null, arguments)
            };
            var _posix_spawn_file_actions_adddup2 = Module["_posix_spawn_file_actions_adddup2"] = function() {
                return (_posix_spawn_file_actions_adddup2 = Module["_posix_spawn_file_actions_adddup2"] = Module["asm"]["posix_spawn_file_actions_adddup2"]).apply(null, arguments)
            };
            var _posix_spawnattr_setsigmask = Module["_posix_spawnattr_setsigmask"] = function() {
                return (_posix_spawnattr_setsigmask = Module["_posix_spawnattr_setsigmask"] = Module["asm"]["posix_spawnattr_setsigmask"]).apply(null, arguments)
            };
            var _execlp = Module["_execlp"] = function() {
                return (_execlp = Module["_execlp"] = Module["asm"]["execlp"]).apply(null, arguments)
            };
            var _posix_spawnattr_init = Module["_posix_spawnattr_init"] = function() {
                return (_posix_spawnattr_init = Module["_posix_spawnattr_init"] = Module["asm"]["posix_spawnattr_init"]).apply(null, arguments)
            };
            var _posix_spawn_file_actions_init = Module["_posix_spawn_file_actions_init"] = function() {
                return (_posix_spawn_file_actions_init = Module["_posix_spawn_file_actions_init"] = Module["asm"]["posix_spawn_file_actions_init"]).apply(null, arguments)
            };
            var _posix_spawn_file_actions_addopen = Module["_posix_spawn_file_actions_addopen"] = function() {
                return (_posix_spawn_file_actions_addopen = Module["_posix_spawn_file_actions_addopen"] = Module["asm"]["posix_spawn_file_actions_addopen"]).apply(null, arguments)
            };
            var _posix_spawnattr_setflags = Module["_posix_spawnattr_setflags"] = function() {
                return (_posix_spawnattr_setflags = Module["_posix_spawnattr_setflags"] = Module["asm"]["posix_spawnattr_setflags"]).apply(null, arguments)
            };
            var _posix_spawnattr_getsigdefault = Module["_posix_spawnattr_getsigdefault"] = function() {
                return (_posix_spawnattr_getsigdefault = Module["_posix_spawnattr_getsigdefault"] = Module["asm"]["posix_spawnattr_getsigdefault"]).apply(null, arguments)
            };
            var _posix_spawn_file_actions_destroy = Module["_posix_spawn_file_actions_destroy"] = function() {
                return (_posix_spawn_file_actions_destroy = Module["_posix_spawn_file_actions_destroy"] = Module["asm"]["posix_spawn_file_actions_destroy"]).apply(null, arguments)
            };
            var _posix_spawnattr_getschedparam = Module["_posix_spawnattr_getschedparam"] = function() {
                return (_posix_spawnattr_getschedparam = Module["_posix_spawnattr_getschedparam"] = Module["asm"]["posix_spawnattr_getschedparam"]).apply(null, arguments)
            };
            var _posix_spawnattr_setschedparam = Module["_posix_spawnattr_setschedparam"] = function() {
                return (_posix_spawnattr_setschedparam = Module["_posix_spawnattr_setschedparam"] = Module["asm"]["posix_spawnattr_setschedparam"]).apply(null, arguments)
            };
            var _posix_spawnattr_getschedpolicy = Module["_posix_spawnattr_getschedpolicy"] = function() {
                return (_posix_spawnattr_getschedpolicy = Module["_posix_spawnattr_getschedpolicy"] = Module["asm"]["posix_spawnattr_getschedpolicy"]).apply(null, arguments)
            };
            var _posix_spawnattr_setschedpolicy = Module["_posix_spawnattr_setschedpolicy"] = function() {
                return (_posix_spawnattr_setschedpolicy = Module["_posix_spawnattr_setschedpolicy"] = Module["asm"]["posix_spawnattr_setschedpolicy"]).apply(null, arguments)
            };
            var _posix_spawnattr_getsigmask = Module["_posix_spawnattr_getsigmask"] = function() {
                return (_posix_spawnattr_getsigmask = Module["_posix_spawnattr_getsigmask"] = Module["asm"]["posix_spawnattr_getsigmask"]).apply(null, arguments)
            };
            var _execle = Module["_execle"] = function() {
                return (_execle = Module["_execle"] = Module["asm"]["execle"]).apply(null, arguments)
            };
            var _posix_spawnattr_setsigdefault = Module["_posix_spawnattr_setsigdefault"] = function() {
                return (_posix_spawnattr_setsigdefault = Module["_posix_spawnattr_setsigdefault"] = Module["asm"]["posix_spawnattr_setsigdefault"]).apply(null, arguments)
            };
            var _posix_spawn_file_actions_addclose = Module["_posix_spawn_file_actions_addclose"] = function() {
                return (_posix_spawn_file_actions_addclose = Module["_posix_spawn_file_actions_addclose"] = Module["asm"]["posix_spawn_file_actions_addclose"]).apply(null, arguments)
            };
            var _fexecve = Module["_fexecve"] = function() {
                return (_fexecve = Module["_fexecve"] = Module["asm"]["fexecve"]).apply(null, arguments)
            };
            var _select = Module["_select"] = function() {
                return (_select = Module["_select"] = Module["asm"]["select"]).apply(null, arguments)
            };
            var _pselect = Module["_pselect"] = function() {
                return (_pselect = Module["_pselect"] = Module["asm"]["pselect"]).apply(null, arguments)
            };
            var _bsearch = Module["_bsearch"] = function() {
                return (_bsearch = Module["_bsearch"] = Module["asm"]["bsearch"]).apply(null, arguments)
            };
            var _llabs = Module["_llabs"] = function() {
                return (_llabs = Module["_llabs"] = Module["asm"]["llabs"]).apply(null, arguments)
            };
            var _strtof = Module["_strtof"] = function() {
                return (_strtof = Module["_strtof"] = Module["asm"]["strtof"]).apply(null, arguments)
            };
            var _strtod = Module["_strtod"] = function() {
                return (_strtod = Module["_strtod"] = Module["asm"]["strtod"]).apply(null, arguments)
            };
            var _strtold = Module["_strtold"] = function() {
                return (_strtold = Module["_strtold"] = Module["asm"]["strtold"]).apply(null, arguments)
            };
            var _strtof_l = Module["_strtof_l"] = function() {
                return (_strtof_l = Module["_strtof_l"] = Module["asm"]["strtof_l"]).apply(null, arguments)
            };
            var _strtod_l = Module["_strtod_l"] = function() {
                return (_strtod_l = Module["_strtod_l"] = Module["asm"]["strtod_l"]).apply(null, arguments)
            };
            var _strtold_l = Module["_strtold_l"] = function() {
                return (_strtold_l = Module["_strtold_l"] = Module["asm"]["strtold_l"]).apply(null, arguments)
            };
            var _abs = Module["_abs"] = function() {
                return (_abs = Module["_abs"] = Module["asm"]["abs"]).apply(null, arguments)
            };
            var _imaxabs = Module["_imaxabs"] = function() {
                return (_imaxabs = Module["_imaxabs"] = Module["asm"]["imaxabs"]).apply(null, arguments)
            };
            var _atol = Module["_atol"] = function() {
                return (_atol = Module["_atol"] = Module["asm"]["atol"]).apply(null, arguments)
            };
            var _fcvt = Module["_fcvt"] = function() {
                return (_fcvt = Module["_fcvt"] = Module["asm"]["fcvt"]).apply(null, arguments)
            };
            var _ecvt = Module["_ecvt"] = function() {
                return (_ecvt = Module["_ecvt"] = Module["asm"]["ecvt"]).apply(null, arguments)
            };
            var _wcstof = Module["_wcstof"] = function() {
                return (_wcstof = Module["_wcstof"] = Module["asm"]["wcstof"]).apply(null, arguments)
            };
            var _wcstod = Module["_wcstod"] = function() {
                return (_wcstod = Module["_wcstod"] = Module["asm"]["wcstod"]).apply(null, arguments)
            };
            var _wcstold = Module["_wcstold"] = function() {
                return (_wcstold = Module["_wcstold"] = Module["asm"]["wcstold"]).apply(null, arguments)
            };
            var _div = Module["_div"] = function() {
                return (_div = Module["_div"] = Module["asm"]["div"]).apply(null, arguments)
            };
            var _atoll = Module["_atoll"] = function() {
                return (_atoll = Module["_atoll"] = Module["asm"]["atoll"]).apply(null, arguments)
            };
            var _labs = Module["_labs"] = function() {
                return (_labs = Module["_labs"] = Module["asm"]["labs"]).apply(null, arguments)
            };
            var _atof = Module["_atof"] = function() {
                return (_atof = Module["_atof"] = Module["asm"]["atof"]).apply(null, arguments)
            };
            var _lldiv = Module["_lldiv"] = function() {
                return (_lldiv = Module["_lldiv"] = Module["asm"]["lldiv"]).apply(null, arguments)
            };
            var _gcvt = Module["_gcvt"] = function() {
                return (_gcvt = Module["_gcvt"] = Module["asm"]["gcvt"]).apply(null, arguments)
            };
            var _ldiv = Module["_ldiv"] = function() {
                return (_ldiv = Module["_ldiv"] = Module["asm"]["ldiv"]).apply(null, arguments)
            };
            var _atoi = Module["_atoi"] = function() {
                return (_atoi = Module["_atoi"] = Module["asm"]["atoi"]).apply(null, arguments)
            };
            var _wcstoull = Module["_wcstoull"] = function() {
                return (_wcstoull = Module["_wcstoull"] = Module["asm"]["wcstoull"]).apply(null, arguments)
            };
            var _wcstoll = Module["_wcstoll"] = function() {
                return (_wcstoll = Module["_wcstoll"] = Module["asm"]["wcstoll"]).apply(null, arguments)
            };
            var _wcstoul = Module["_wcstoul"] = function() {
                return (_wcstoul = Module["_wcstoul"] = Module["asm"]["wcstoul"]).apply(null, arguments)
            };
            var _wcstol = Module["_wcstol"] = function() {
                return (_wcstol = Module["_wcstol"] = Module["asm"]["wcstol"]).apply(null, arguments)
            };
            var _wcstoimax = Module["_wcstoimax"] = function() {
                return (_wcstoimax = Module["_wcstoimax"] = Module["asm"]["wcstoimax"]).apply(null, arguments)
            };
            var _wcstoumax = Module["_wcstoumax"] = function() {
                return (_wcstoumax = Module["_wcstoumax"] = Module["asm"]["wcstoumax"]).apply(null, arguments)
            };
            var _imaxdiv = Module["_imaxdiv"] = function() {
                return (_imaxdiv = Module["_imaxdiv"] = Module["asm"]["imaxdiv"]).apply(null, arguments)
            };
            var _strtoll = Module["_strtoll"] = function() {
                return (_strtoll = Module["_strtoll"] = Module["asm"]["strtoll"]).apply(null, arguments)
            };
            var _strtol = Module["_strtol"] = function() {
                return (_strtol = Module["_strtol"] = Module["asm"]["strtol"]).apply(null, arguments)
            };
            var _strtoimax = Module["_strtoimax"] = function() {
                return (_strtoimax = Module["_strtoimax"] = Module["asm"]["strtoimax"]).apply(null, arguments)
            };
            var _strtoumax = Module["_strtoumax"] = function() {
                return (_strtoumax = Module["_strtoumax"] = Module["asm"]["strtoumax"]).apply(null, arguments)
            };
            var ___strtol_internal = Module["___strtol_internal"] = function() {
                return (___strtol_internal = Module["___strtol_internal"] = Module["asm"]["__strtol_internal"]).apply(null, arguments)
            };
            var ___strtoul_internal = Module["___strtoul_internal"] = function() {
                return (___strtoul_internal = Module["___strtoul_internal"] = Module["asm"]["__strtoul_internal"]).apply(null, arguments)
            };
            var ___strtoll_internal = Module["___strtoll_internal"] = function() {
                return (___strtoll_internal = Module["___strtoll_internal"] = Module["asm"]["__strtoll_internal"]).apply(null, arguments)
            };
            var ___strtoull_internal = Module["___strtoull_internal"] = function() {
                return (___strtoull_internal = Module["___strtoull_internal"] = Module["asm"]["__strtoull_internal"]).apply(null, arguments)
            };
            var ___strtoimax_internal = Module["___strtoimax_internal"] = function() {
                return (___strtoimax_internal = Module["___strtoimax_internal"] = Module["asm"]["__strtoimax_internal"]).apply(null, arguments)
            };
            var ___strtoumax_internal = Module["___strtoumax_internal"] = function() {
                return (___strtoumax_internal = Module["___strtoumax_internal"] = Module["asm"]["__strtoumax_internal"]).apply(null, arguments)
            };
            var _clock_settime = Module["_clock_settime"] = function() {
                return (_clock_settime = Module["_clock_settime"] = Module["asm"]["clock_settime"]).apply(null, arguments)
            };
            var _asctime_r = Module["_asctime_r"] = function() {
                return (_asctime_r = Module["_asctime_r"] = Module["asm"]["asctime_r"]).apply(null, arguments)
            };
            var _asctime = Module["_asctime"] = function() {
                return (_asctime = Module["_asctime"] = Module["asm"]["asctime"]).apply(null, arguments)
            };
            var _ctime = Module["_ctime"] = function() {
                return (_ctime = Module["_ctime"] = Module["asm"]["ctime"]).apply(null, arguments)
            };
            var _localtime = Module["_localtime"] = function() {
                return (_localtime = Module["_localtime"] = Module["asm"]["localtime"]).apply(null, arguments)
            };
            var _gmtime = Module["_gmtime"] = function() {
                return (_gmtime = Module["_gmtime"] = Module["asm"]["gmtime"]).apply(null, arguments)
            };
            var _getpagesize = Module["_getpagesize"] = function() {
                return (_getpagesize = Module["_getpagesize"] = Module["asm"]["getpagesize"]).apply(null, arguments)
            };
            var _vwarn = Module["_vwarn"] = function() {
                return (_vwarn = Module["_vwarn"] = Module["asm"]["vwarn"]).apply(null, arguments)
            };
            var _vwarnx = Module["_vwarnx"] = function() {
                return (_vwarnx = Module["_vwarnx"] = Module["asm"]["vwarnx"]).apply(null, arguments)
            };
            var _verr = Module["_verr"] = function() {
                return (_verr = Module["_verr"] = Module["asm"]["verr"]).apply(null, arguments)
            };
            var _verrx = Module["_verrx"] = function() {
                return (_verrx = Module["_verrx"] = Module["asm"]["verrx"]).apply(null, arguments)
            };
            var _warn = Module["_warn"] = function() {
                return (_warn = Module["_warn"] = Module["asm"]["warn"]).apply(null, arguments)
            };
            var _warnx = Module["_warnx"] = function() {
                return (_warnx = Module["_warnx"] = Module["asm"]["warnx"]).apply(null, arguments)
            };
            var _err = Module["_err"] = function() {
                return (_err = Module["_err"] = Module["asm"]["err"]).apply(null, arguments)
            };
            var _errx = Module["_errx"] = function() {
                return (_errx = Module["_errx"] = Module["asm"]["errx"]).apply(null, arguments)
            };
            var ___emscripten_environ_constructor = Module["___emscripten_environ_constructor"] = function() {
                return (___emscripten_environ_constructor = Module["___emscripten_environ_constructor"] = Module["asm"]["__emscripten_environ_constructor"]).apply(null, arguments)
            };
            var ___putenv = Module["___putenv"] = function() {
                return (___putenv = Module["___putenv"] = Module["asm"]["__putenv"]).apply(null, arguments)
            };
            var _unsetenv = Module["_unsetenv"] = function() {
                return (_unsetenv = Module["_unsetenv"] = Module["asm"]["unsetenv"]).apply(null, arguments)
            };
            var _putenv = Module["_putenv"] = function() {
                return (_putenv = Module["_putenv"] = Module["asm"]["putenv"]).apply(null, arguments)
            };
            var _setenv = Module["_setenv"] = function() {
                return (_setenv = Module["_setenv"] = Module["asm"]["setenv"]).apply(null, arguments)
            };
            var _sched_yield = Module["_sched_yield"] = function() {
                return (_sched_yield = Module["_sched_yield"] = Module["asm"]["sched_yield"]).apply(null, arguments)
            };
            var __get_tzname = Module["__get_tzname"] = function() {
                return (__get_tzname = Module["__get_tzname"] = Module["asm"]["_get_tzname"]).apply(null, arguments)
            };
            var __get_daylight = Module["__get_daylight"] = function() {
                return (__get_daylight = Module["__get_daylight"] = Module["asm"]["_get_daylight"]).apply(null, arguments)
            };
            var __get_timezone = Module["__get_timezone"] = function() {
                return (__get_timezone = Module["__get_timezone"] = Module["asm"]["_get_timezone"]).apply(null, arguments)
            };
            var ___emscripten_pthread_data_constructor = Module["___emscripten_pthread_data_constructor"] = function() {
                return (___emscripten_pthread_data_constructor = Module["___emscripten_pthread_data_constructor"] = Module["asm"]["__emscripten_pthread_data_constructor"]).apply(null, arguments)
            };
            var _emscripten_get_heap_size = Module["_emscripten_get_heap_size"] = function() {
                return (_emscripten_get_heap_size = Module["_emscripten_get_heap_size"] = Module["asm"]["emscripten_get_heap_size"]).apply(null, arguments)
            };
            var _emscripten_atomic_exchange_u8 = Module["_emscripten_atomic_exchange_u8"] = function() {
                return (_emscripten_atomic_exchange_u8 = Module["_emscripten_atomic_exchange_u8"] = Module["asm"]["emscripten_atomic_exchange_u8"]).apply(null, arguments)
            };
            var _emscripten_atomic_exchange_u16 = Module["_emscripten_atomic_exchange_u16"] = function() {
                return (_emscripten_atomic_exchange_u16 = Module["_emscripten_atomic_exchange_u16"] = Module["asm"]["emscripten_atomic_exchange_u16"]).apply(null, arguments)
            };
            var _emscripten_atomic_exchange_u32 = Module["_emscripten_atomic_exchange_u32"] = function() {
                return (_emscripten_atomic_exchange_u32 = Module["_emscripten_atomic_exchange_u32"] = Module["asm"]["emscripten_atomic_exchange_u32"]).apply(null, arguments)
            };
            var _emscripten_atomic_exchange_u64 = Module["_emscripten_atomic_exchange_u64"] = function() {
                return (_emscripten_atomic_exchange_u64 = Module["_emscripten_atomic_exchange_u64"] = Module["asm"]["emscripten_atomic_exchange_u64"]).apply(null, arguments)
            };
            var _emscripten_atomic_cas_u8 = Module["_emscripten_atomic_cas_u8"] = function() {
                return (_emscripten_atomic_cas_u8 = Module["_emscripten_atomic_cas_u8"] = Module["asm"]["emscripten_atomic_cas_u8"]).apply(null, arguments)
            };
            var _emscripten_atomic_cas_u16 = Module["_emscripten_atomic_cas_u16"] = function() {
                return (_emscripten_atomic_cas_u16 = Module["_emscripten_atomic_cas_u16"] = Module["asm"]["emscripten_atomic_cas_u16"]).apply(null, arguments)
            };
            var _emscripten_atomic_cas_u32 = Module["_emscripten_atomic_cas_u32"] = function() {
                return (_emscripten_atomic_cas_u32 = Module["_emscripten_atomic_cas_u32"] = Module["asm"]["emscripten_atomic_cas_u32"]).apply(null, arguments)
            };
            var _emscripten_atomic_cas_u64 = Module["_emscripten_atomic_cas_u64"] = function() {
                return (_emscripten_atomic_cas_u64 = Module["_emscripten_atomic_cas_u64"] = Module["asm"]["emscripten_atomic_cas_u64"]).apply(null, arguments)
            };
            var _emscripten_atomic_load_u8 = Module["_emscripten_atomic_load_u8"] = function() {
                return (_emscripten_atomic_load_u8 = Module["_emscripten_atomic_load_u8"] = Module["asm"]["emscripten_atomic_load_u8"]).apply(null, arguments)
            };
            var _emscripten_atomic_load_u16 = Module["_emscripten_atomic_load_u16"] = function() {
                return (_emscripten_atomic_load_u16 = Module["_emscripten_atomic_load_u16"] = Module["asm"]["emscripten_atomic_load_u16"]).apply(null, arguments)
            };
            var _emscripten_atomic_load_u32 = Module["_emscripten_atomic_load_u32"] = function() {
                return (_emscripten_atomic_load_u32 = Module["_emscripten_atomic_load_u32"] = Module["asm"]["emscripten_atomic_load_u32"]).apply(null, arguments)
            };
            var _emscripten_atomic_load_f32 = Module["_emscripten_atomic_load_f32"] = function() {
                return (_emscripten_atomic_load_f32 = Module["_emscripten_atomic_load_f32"] = Module["asm"]["emscripten_atomic_load_f32"]).apply(null, arguments)
            };
            var _emscripten_atomic_load_u64 = Module["_emscripten_atomic_load_u64"] = function() {
                return (_emscripten_atomic_load_u64 = Module["_emscripten_atomic_load_u64"] = Module["asm"]["emscripten_atomic_load_u64"]).apply(null, arguments)
            };
            var _emscripten_atomic_load_f64 = Module["_emscripten_atomic_load_f64"] = function() {
                return (_emscripten_atomic_load_f64 = Module["_emscripten_atomic_load_f64"] = Module["asm"]["emscripten_atomic_load_f64"]).apply(null, arguments)
            };
            var _emscripten_atomic_store_u8 = Module["_emscripten_atomic_store_u8"] = function() {
                return (_emscripten_atomic_store_u8 = Module["_emscripten_atomic_store_u8"] = Module["asm"]["emscripten_atomic_store_u8"]).apply(null, arguments)
            };
            var _emscripten_atomic_store_u16 = Module["_emscripten_atomic_store_u16"] = function() {
                return (_emscripten_atomic_store_u16 = Module["_emscripten_atomic_store_u16"] = Module["asm"]["emscripten_atomic_store_u16"]).apply(null, arguments)
            };
            var _emscripten_atomic_store_u32 = Module["_emscripten_atomic_store_u32"] = function() {
                return (_emscripten_atomic_store_u32 = Module["_emscripten_atomic_store_u32"] = Module["asm"]["emscripten_atomic_store_u32"]).apply(null, arguments)
            };
            var _emscripten_atomic_store_f32 = Module["_emscripten_atomic_store_f32"] = function() {
                return (_emscripten_atomic_store_f32 = Module["_emscripten_atomic_store_f32"] = Module["asm"]["emscripten_atomic_store_f32"]).apply(null, arguments)
            };
            var _emscripten_atomic_store_u64 = Module["_emscripten_atomic_store_u64"] = function() {
                return (_emscripten_atomic_store_u64 = Module["_emscripten_atomic_store_u64"] = Module["asm"]["emscripten_atomic_store_u64"]).apply(null, arguments)
            };
            var _emscripten_atomic_store_f64 = Module["_emscripten_atomic_store_f64"] = function() {
                return (_emscripten_atomic_store_f64 = Module["_emscripten_atomic_store_f64"] = Module["asm"]["emscripten_atomic_store_f64"]).apply(null, arguments)
            };
            var _emscripten_atomic_fence = Module["_emscripten_atomic_fence"] = function() {
                return (_emscripten_atomic_fence = Module["_emscripten_atomic_fence"] = Module["asm"]["emscripten_atomic_fence"]).apply(null, arguments)
            };
            var _emscripten_atomic_or_u8 = Module["_emscripten_atomic_or_u8"] = function() {
                return (_emscripten_atomic_or_u8 = Module["_emscripten_atomic_or_u8"] = Module["asm"]["emscripten_atomic_or_u8"]).apply(null, arguments)
            };
            var _emscripten_atomic_add_u8 = Module["_emscripten_atomic_add_u8"] = function() {
                return (_emscripten_atomic_add_u8 = Module["_emscripten_atomic_add_u8"] = Module["asm"]["emscripten_atomic_add_u8"]).apply(null, arguments)
            };
            var _emscripten_atomic_add_u16 = Module["_emscripten_atomic_add_u16"] = function() {
                return (_emscripten_atomic_add_u16 = Module["_emscripten_atomic_add_u16"] = Module["asm"]["emscripten_atomic_add_u16"]).apply(null, arguments)
            };
            var _emscripten_atomic_add_u32 = Module["_emscripten_atomic_add_u32"] = function() {
                return (_emscripten_atomic_add_u32 = Module["_emscripten_atomic_add_u32"] = Module["asm"]["emscripten_atomic_add_u32"]).apply(null, arguments)
            };
            var _emscripten_atomic_add_u64 = Module["_emscripten_atomic_add_u64"] = function() {
                return (_emscripten_atomic_add_u64 = Module["_emscripten_atomic_add_u64"] = Module["asm"]["emscripten_atomic_add_u64"]).apply(null, arguments)
            };
            var _emscripten_atomic_sub_u8 = Module["_emscripten_atomic_sub_u8"] = function() {
                return (_emscripten_atomic_sub_u8 = Module["_emscripten_atomic_sub_u8"] = Module["asm"]["emscripten_atomic_sub_u8"]).apply(null, arguments)
            };
            var _emscripten_atomic_sub_u16 = Module["_emscripten_atomic_sub_u16"] = function() {
                return (_emscripten_atomic_sub_u16 = Module["_emscripten_atomic_sub_u16"] = Module["asm"]["emscripten_atomic_sub_u16"]).apply(null, arguments)
            };
            var _emscripten_atomic_sub_u32 = Module["_emscripten_atomic_sub_u32"] = function() {
                return (_emscripten_atomic_sub_u32 = Module["_emscripten_atomic_sub_u32"] = Module["asm"]["emscripten_atomic_sub_u32"]).apply(null, arguments)
            };
            var _emscripten_atomic_sub_u64 = Module["_emscripten_atomic_sub_u64"] = function() {
                return (_emscripten_atomic_sub_u64 = Module["_emscripten_atomic_sub_u64"] = Module["asm"]["emscripten_atomic_sub_u64"]).apply(null, arguments)
            };
            var _emscripten_atomic_and_u8 = Module["_emscripten_atomic_and_u8"] = function() {
                return (_emscripten_atomic_and_u8 = Module["_emscripten_atomic_and_u8"] = Module["asm"]["emscripten_atomic_and_u8"]).apply(null, arguments)
            };
            var _emscripten_atomic_and_u16 = Module["_emscripten_atomic_and_u16"] = function() {
                return (_emscripten_atomic_and_u16 = Module["_emscripten_atomic_and_u16"] = Module["asm"]["emscripten_atomic_and_u16"]).apply(null, arguments)
            };
            var _emscripten_atomic_and_u32 = Module["_emscripten_atomic_and_u32"] = function() {
                return (_emscripten_atomic_and_u32 = Module["_emscripten_atomic_and_u32"] = Module["asm"]["emscripten_atomic_and_u32"]).apply(null, arguments)
            };
            var _emscripten_atomic_and_u64 = Module["_emscripten_atomic_and_u64"] = function() {
                return (_emscripten_atomic_and_u64 = Module["_emscripten_atomic_and_u64"] = Module["asm"]["emscripten_atomic_and_u64"]).apply(null, arguments)
            };
            var _emscripten_atomic_or_u16 = Module["_emscripten_atomic_or_u16"] = function() {
                return (_emscripten_atomic_or_u16 = Module["_emscripten_atomic_or_u16"] = Module["asm"]["emscripten_atomic_or_u16"]).apply(null, arguments)
            };
            var _emscripten_atomic_or_u32 = Module["_emscripten_atomic_or_u32"] = function() {
                return (_emscripten_atomic_or_u32 = Module["_emscripten_atomic_or_u32"] = Module["asm"]["emscripten_atomic_or_u32"]).apply(null, arguments)
            };
            var _emscripten_atomic_or_u64 = Module["_emscripten_atomic_or_u64"] = function() {
                return (_emscripten_atomic_or_u64 = Module["_emscripten_atomic_or_u64"] = Module["asm"]["emscripten_atomic_or_u64"]).apply(null, arguments)
            };
            var _emscripten_atomic_xor_u8 = Module["_emscripten_atomic_xor_u8"] = function() {
                return (_emscripten_atomic_xor_u8 = Module["_emscripten_atomic_xor_u8"] = Module["asm"]["emscripten_atomic_xor_u8"]).apply(null, arguments)
            };
            var _emscripten_atomic_xor_u16 = Module["_emscripten_atomic_xor_u16"] = function() {
                return (_emscripten_atomic_xor_u16 = Module["_emscripten_atomic_xor_u16"] = Module["asm"]["emscripten_atomic_xor_u16"]).apply(null, arguments)
            };
            var _emscripten_atomic_xor_u32 = Module["_emscripten_atomic_xor_u32"] = function() {
                return (_emscripten_atomic_xor_u32 = Module["_emscripten_atomic_xor_u32"] = Module["asm"]["emscripten_atomic_xor_u32"]).apply(null, arguments)
            };
            var _emscripten_atomic_xor_u64 = Module["_emscripten_atomic_xor_u64"] = function() {
                return (_emscripten_atomic_xor_u64 = Module["_emscripten_atomic_xor_u64"] = Module["asm"]["emscripten_atomic_xor_u64"]).apply(null, arguments)
            };
            var _strupr = Module["_strupr"] = function() {
                return (_strupr = Module["_strupr"] = Module["asm"]["strupr"]).apply(null, arguments)
            };
            var _strtoull_l = Module["_strtoull_l"] = function() {
                return (_strtoull_l = Module["_strtoull_l"] = Module["asm"]["strtoull_l"]).apply(null, arguments)
            };
            var _strtoll_l = Module["_strtoll_l"] = function() {
                return (_strtoll_l = Module["_strtoll_l"] = Module["asm"]["strtoll_l"]).apply(null, arguments)
            };
            var _strtoul_l = Module["_strtoul_l"] = function() {
                return (_strtoul_l = Module["_strtoul_l"] = Module["asm"]["strtoul_l"]).apply(null, arguments)
            };
            var _strtol_l = Module["_strtol_l"] = function() {
                return (_strtol_l = Module["_strtol_l"] = Module["asm"]["strtol_l"]).apply(null, arguments)
            };
            var _strlwr = Module["_strlwr"] = function() {
                return (_strlwr = Module["_strlwr"] = Module["asm"]["strlwr"]).apply(null, arguments)
            };
            var _aligned_alloc = Module["_aligned_alloc"] = function() {
                return (_aligned_alloc = Module["_aligned_alloc"] = Module["asm"]["aligned_alloc"]).apply(null, arguments)
            };
            var _posix_memalign = Module["_posix_memalign"] = function() {
                return (_posix_memalign = Module["_posix_memalign"] = Module["asm"]["posix_memalign"]).apply(null, arguments)
            };
            var ___divmodsi4 = Module["___divmodsi4"] = function() {
                return (___divmodsi4 = Module["___divmodsi4"] = Module["asm"]["__divmodsi4"]).apply(null, arguments)
            };
            var ___divsi3 = Module["___divsi3"] = function() {
                return (___divsi3 = Module["___divsi3"] = Module["asm"]["__divsi3"]).apply(null, arguments)
            };
            var ___addvdi3 = Module["___addvdi3"] = function() {
                return (___addvdi3 = Module["___addvdi3"] = Module["asm"]["__addvdi3"]).apply(null, arguments)
            };
            var ___compilerrt_abort_impl = Module["___compilerrt_abort_impl"] = function() {
                return (___compilerrt_abort_impl = Module["___compilerrt_abort_impl"] = Module["asm"]["__compilerrt_abort_impl"]).apply(null, arguments)
            };
            var ___umodti3 = Module["___umodti3"] = function() {
                return (___umodti3 = Module["___umodti3"] = Module["asm"]["__umodti3"]).apply(null, arguments)
            };
            var ___udivmodti4 = Module["___udivmodti4"] = function() {
                return (___udivmodti4 = Module["___udivmodti4"] = Module["asm"]["__udivmodti4"]).apply(null, arguments)
            };
            var ___floatdixf = Module["___floatdixf"] = function() {
                return (___floatdixf = Module["___floatdixf"] = Module["asm"]["__floatdixf"]).apply(null, arguments)
            };
            var ___negsf2 = Module["___negsf2"] = function() {
                return (___negsf2 = Module["___negsf2"] = Module["asm"]["__negsf2"]).apply(null, arguments)
            };
            var ___floatdisf = Module["___floatdisf"] = function() {
                return (___floatdisf = Module["___floatdisf"] = Module["asm"]["__floatdisf"]).apply(null, arguments)
            };
            var ___ashlti3 = Module["___ashlti3"] = function() {
                return (___ashlti3 = Module["___ashlti3"] = Module["asm"]["__ashlti3"]).apply(null, arguments)
            };
            var ___paritydi2 = Module["___paritydi2"] = function() {
                return (___paritydi2 = Module["___paritydi2"] = Module["asm"]["__paritydi2"]).apply(null, arguments)
            };
            var ___paritysi2 = Module["___paritysi2"] = function() {
                return (___paritysi2 = Module["___paritysi2"] = Module["asm"]["__paritysi2"]).apply(null, arguments)
            };
            var ___mulosi4 = Module["___mulosi4"] = function() {
                return (___mulosi4 = Module["___mulosi4"] = Module["asm"]["__mulosi4"]).apply(null, arguments)
            };
            var ___fixunsxfti = Module["___fixunsxfti"] = function() {
                return (___fixunsxfti = Module["___fixunsxfti"] = Module["asm"]["__fixunsxfti"]).apply(null, arguments)
            };
            var ___lshrti3 = Module["___lshrti3"] = function() {
                return (___lshrti3 = Module["___lshrti3"] = Module["asm"]["__lshrti3"]).apply(null, arguments)
            };
            var ___fixunssfdi = Module["___fixunssfdi"] = function() {
                return (___fixunssfdi = Module["___fixunssfdi"] = Module["asm"]["__fixunssfdi"]).apply(null, arguments)
            };
            var ___floatuntitf = Module["___floatuntitf"] = function() {
                return (___floatuntitf = Module["___floatuntitf"] = Module["asm"]["__floatuntitf"]).apply(null, arguments)
            };
            var ___clzti2 = Module["___clzti2"] = function() {
                return (___clzti2 = Module["___clzti2"] = Module["asm"]["__clzti2"]).apply(null, arguments)
            };
            var ___udivti3 = Module["___udivti3"] = function() {
                return (___udivti3 = Module["___udivti3"] = Module["asm"]["__udivti3"]).apply(null, arguments)
            };
            var ___ctzti2 = Module["___ctzti2"] = function() {
                return (___ctzti2 = Module["___ctzti2"] = Module["asm"]["__ctzti2"]).apply(null, arguments)
            };
            var ___ctzsi2 = Module["___ctzsi2"] = function() {
                return (___ctzsi2 = Module["___ctzsi2"] = Module["asm"]["__ctzsi2"]).apply(null, arguments)
            };
            var ___muloti4 = Module["___muloti4"] = function() {
                return (___muloti4 = Module["___muloti4"] = Module["asm"]["__muloti4"]).apply(null, arguments)
            };
            var ___fixtfti = Module["___fixtfti"] = function() {
                return (___fixtfti = Module["___fixtfti"] = Module["asm"]["__fixtfti"]).apply(null, arguments)
            };
            var ___ffssi2 = Module["___ffssi2"] = function() {
                return (___ffssi2 = Module["___ffssi2"] = Module["asm"]["__ffssi2"]).apply(null, arguments)
            };
            var ___floatuntisf = Module["___floatuntisf"] = function() {
                return (___floatuntisf = Module["___floatuntisf"] = Module["asm"]["__floatuntisf"]).apply(null, arguments)
            };
            var ___floatuntixf = Module["___floatuntixf"] = function() {
                return (___floatuntixf = Module["___floatuntixf"] = Module["asm"]["__floatuntixf"]).apply(null, arguments)
            };
            var ___addvsi3 = Module["___addvsi3"] = function() {
                return (___addvsi3 = Module["___addvsi3"] = Module["asm"]["__addvsi3"]).apply(null, arguments)
            };
            var ___subdf3 = Module["___subdf3"] = function() {
                return (___subdf3 = Module["___subdf3"] = Module["asm"]["__subdf3"]).apply(null, arguments)
            };
            var ___adddf3 = Module["___adddf3"] = function() {
                return (___adddf3 = Module["___adddf3"] = Module["asm"]["__adddf3"]).apply(null, arguments)
            };
            var ___modsi3 = Module["___modsi3"] = function() {
                return (___modsi3 = Module["___modsi3"] = Module["asm"]["__modsi3"]).apply(null, arguments)
            };
            var ___fixxfti = Module["___fixxfti"] = function() {
                return (___fixxfti = Module["___fixxfti"] = Module["asm"]["__fixxfti"]).apply(null, arguments)
            };
            var ___floattixf = Module["___floattixf"] = function() {
                return (___floattixf = Module["___floattixf"] = Module["asm"]["__floattixf"]).apply(null, arguments)
            };
            var ___udivdi3 = Module["___udivdi3"] = function() {
                return (___udivdi3 = Module["___udivdi3"] = Module["asm"]["__udivdi3"]).apply(null, arguments)
            };
            var ___udivmoddi4 = Module["___udivmoddi4"] = function() {
                return (___udivmoddi4 = Module["___udivmoddi4"] = Module["asm"]["__udivmoddi4"]).apply(null, arguments)
            };
            var ___floatundidf = Module["___floatundidf"] = function() {
                return (___floatundidf = Module["___floatundidf"] = Module["asm"]["__floatundidf"]).apply(null, arguments)
            };
            var ___fe_getround = Module["___fe_getround"] = function() {
                return (___fe_getround = Module["___fe_getround"] = Module["asm"]["__fe_getround"]).apply(null, arguments)
            };
            var ___fe_raise_inexact = Module["___fe_raise_inexact"] = function() {
                return (___fe_raise_inexact = Module["___fe_raise_inexact"] = Module["asm"]["__fe_raise_inexact"]).apply(null, arguments)
            };
            var ___mulvti3 = Module["___mulvti3"] = function() {
                return (___mulvti3 = Module["___mulvti3"] = Module["asm"]["__mulvti3"]).apply(null, arguments)
            };
            var ___divsf3 = Module["___divsf3"] = function() {
                return (___divsf3 = Module["___divsf3"] = Module["asm"]["__divsf3"]).apply(null, arguments)
            };
            var ___popcountsi2 = Module["___popcountsi2"] = function() {
                return (___popcountsi2 = Module["___popcountsi2"] = Module["asm"]["__popcountsi2"]).apply(null, arguments)
            };
            var ___subvdi3 = Module["___subvdi3"] = function() {
                return (___subvdi3 = Module["___subvdi3"] = Module["asm"]["__subvdi3"]).apply(null, arguments)
            };
            var ___negdf2 = Module["___negdf2"] = function() {
                return (___negdf2 = Module["___negdf2"] = Module["asm"]["__negdf2"]).apply(null, arguments)
            };
            var ___floattitf = Module["___floattitf"] = function() {
                return (___floattitf = Module["___floattitf"] = Module["asm"]["__floattitf"]).apply(null, arguments)
            };
            var ___extendhfsf2 = Module["___extendhfsf2"] = function() {
                return (___extendhfsf2 = Module["___extendhfsf2"] = Module["asm"]["__extendhfsf2"]).apply(null, arguments)
            };
            var ___gnu_h2f_ieee = Module["___gnu_h2f_ieee"] = function() {
                return (___gnu_h2f_ieee = Module["___gnu_h2f_ieee"] = Module["asm"]["__gnu_h2f_ieee"]).apply(null, arguments)
            };
            var ___atomic_load = Module["___atomic_load"] = function() {
                return (___atomic_load = Module["___atomic_load"] = Module["asm"]["__atomic_load"]).apply(null, arguments)
            };
            var ___atomic_store = Module["___atomic_store"] = function() {
                return (___atomic_store = Module["___atomic_store"] = Module["asm"]["__atomic_store"]).apply(null, arguments)
            };
            var ___atomic_compare_exchange = Module["___atomic_compare_exchange"] = function() {
                return (___atomic_compare_exchange = Module["___atomic_compare_exchange"] = Module["asm"]["__atomic_compare_exchange"]).apply(null, arguments)
            };
            var ___atomic_exchange = Module["___atomic_exchange"] = function() {
                return (___atomic_exchange = Module["___atomic_exchange"] = Module["asm"]["__atomic_exchange"]).apply(null, arguments)
            };
            var ___atomic_load_1 = Module["___atomic_load_1"] = function() {
                return (___atomic_load_1 = Module["___atomic_load_1"] = Module["asm"]["__atomic_load_1"]).apply(null, arguments)
            };
            var ___atomic_load_2 = Module["___atomic_load_2"] = function() {
                return (___atomic_load_2 = Module["___atomic_load_2"] = Module["asm"]["__atomic_load_2"]).apply(null, arguments)
            };
            var ___atomic_load_4 = Module["___atomic_load_4"] = function() {
                return (___atomic_load_4 = Module["___atomic_load_4"] = Module["asm"]["__atomic_load_4"]).apply(null, arguments)
            };
            var ___atomic_load_8 = Module["___atomic_load_8"] = function() {
                return (___atomic_load_8 = Module["___atomic_load_8"] = Module["asm"]["__atomic_load_8"]).apply(null, arguments)
            };
            var ___atomic_load_16 = Module["___atomic_load_16"] = function() {
                return (___atomic_load_16 = Module["___atomic_load_16"] = Module["asm"]["__atomic_load_16"]).apply(null, arguments)
            };
            var ___atomic_store_1 = Module["___atomic_store_1"] = function() {
                return (___atomic_store_1 = Module["___atomic_store_1"] = Module["asm"]["__atomic_store_1"]).apply(null, arguments)
            };
            var ___atomic_store_2 = Module["___atomic_store_2"] = function() {
                return (___atomic_store_2 = Module["___atomic_store_2"] = Module["asm"]["__atomic_store_2"]).apply(null, arguments)
            };
            var ___atomic_store_4 = Module["___atomic_store_4"] = function() {
                return (___atomic_store_4 = Module["___atomic_store_4"] = Module["asm"]["__atomic_store_4"]).apply(null, arguments)
            };
            var ___atomic_store_8 = Module["___atomic_store_8"] = function() {
                return (___atomic_store_8 = Module["___atomic_store_8"] = Module["asm"]["__atomic_store_8"]).apply(null, arguments)
            };
            var ___atomic_store_16 = Module["___atomic_store_16"] = function() {
                return (___atomic_store_16 = Module["___atomic_store_16"] = Module["asm"]["__atomic_store_16"]).apply(null, arguments)
            };
            var ___atomic_exchange_1 = Module["___atomic_exchange_1"] = function() {
                return (___atomic_exchange_1 = Module["___atomic_exchange_1"] = Module["asm"]["__atomic_exchange_1"]).apply(null, arguments)
            };
            var ___atomic_exchange_2 = Module["___atomic_exchange_2"] = function() {
                return (___atomic_exchange_2 = Module["___atomic_exchange_2"] = Module["asm"]["__atomic_exchange_2"]).apply(null, arguments)
            };
            var ___atomic_exchange_4 = Module["___atomic_exchange_4"] = function() {
                return (___atomic_exchange_4 = Module["___atomic_exchange_4"] = Module["asm"]["__atomic_exchange_4"]).apply(null, arguments)
            };
            var ___atomic_exchange_8 = Module["___atomic_exchange_8"] = function() {
                return (___atomic_exchange_8 = Module["___atomic_exchange_8"] = Module["asm"]["__atomic_exchange_8"]).apply(null, arguments)
            };
            var ___atomic_exchange_16 = Module["___atomic_exchange_16"] = function() {
                return (___atomic_exchange_16 = Module["___atomic_exchange_16"] = Module["asm"]["__atomic_exchange_16"]).apply(null, arguments)
            };
            var ___atomic_compare_exchange_1 = Module["___atomic_compare_exchange_1"] = function() {
                return (___atomic_compare_exchange_1 = Module["___atomic_compare_exchange_1"] = Module["asm"]["__atomic_compare_exchange_1"]).apply(null, arguments)
            };
            var ___atomic_compare_exchange_2 = Module["___atomic_compare_exchange_2"] = function() {
                return (___atomic_compare_exchange_2 = Module["___atomic_compare_exchange_2"] = Module["asm"]["__atomic_compare_exchange_2"]).apply(null, arguments)
            };
            var ___atomic_compare_exchange_4 = Module["___atomic_compare_exchange_4"] = function() {
                return (___atomic_compare_exchange_4 = Module["___atomic_compare_exchange_4"] = Module["asm"]["__atomic_compare_exchange_4"]).apply(null, arguments)
            };
            var ___atomic_compare_exchange_8 = Module["___atomic_compare_exchange_8"] = function() {
                return (___atomic_compare_exchange_8 = Module["___atomic_compare_exchange_8"] = Module["asm"]["__atomic_compare_exchange_8"]).apply(null, arguments)
            };
            var ___atomic_compare_exchange_16 = Module["___atomic_compare_exchange_16"] = function() {
                return (___atomic_compare_exchange_16 = Module["___atomic_compare_exchange_16"] = Module["asm"]["__atomic_compare_exchange_16"]).apply(null, arguments)
            };
            var ___atomic_fetch_add_1 = Module["___atomic_fetch_add_1"] = function() {
                return (___atomic_fetch_add_1 = Module["___atomic_fetch_add_1"] = Module["asm"]["__atomic_fetch_add_1"]).apply(null, arguments)
            };
            var ___atomic_fetch_add_2 = Module["___atomic_fetch_add_2"] = function() {
                return (___atomic_fetch_add_2 = Module["___atomic_fetch_add_2"] = Module["asm"]["__atomic_fetch_add_2"]).apply(null, arguments)
            };
            var ___atomic_fetch_add_4 = Module["___atomic_fetch_add_4"] = function() {
                return (___atomic_fetch_add_4 = Module["___atomic_fetch_add_4"] = Module["asm"]["__atomic_fetch_add_4"]).apply(null, arguments)
            };
            var ___atomic_fetch_add_8 = Module["___atomic_fetch_add_8"] = function() {
                return (___atomic_fetch_add_8 = Module["___atomic_fetch_add_8"] = Module["asm"]["__atomic_fetch_add_8"]).apply(null, arguments)
            };
            var ___atomic_fetch_add_16 = Module["___atomic_fetch_add_16"] = function() {
                return (___atomic_fetch_add_16 = Module["___atomic_fetch_add_16"] = Module["asm"]["__atomic_fetch_add_16"]).apply(null, arguments)
            };
            var ___atomic_fetch_sub_1 = Module["___atomic_fetch_sub_1"] = function() {
                return (___atomic_fetch_sub_1 = Module["___atomic_fetch_sub_1"] = Module["asm"]["__atomic_fetch_sub_1"]).apply(null, arguments)
            };
            var ___atomic_fetch_sub_2 = Module["___atomic_fetch_sub_2"] = function() {
                return (___atomic_fetch_sub_2 = Module["___atomic_fetch_sub_2"] = Module["asm"]["__atomic_fetch_sub_2"]).apply(null, arguments)
            };
            var ___atomic_fetch_sub_4 = Module["___atomic_fetch_sub_4"] = function() {
                return (___atomic_fetch_sub_4 = Module["___atomic_fetch_sub_4"] = Module["asm"]["__atomic_fetch_sub_4"]).apply(null, arguments)
            };
            var ___atomic_fetch_sub_8 = Module["___atomic_fetch_sub_8"] = function() {
                return (___atomic_fetch_sub_8 = Module["___atomic_fetch_sub_8"] = Module["asm"]["__atomic_fetch_sub_8"]).apply(null, arguments)
            };
            var ___atomic_fetch_sub_16 = Module["___atomic_fetch_sub_16"] = function() {
                return (___atomic_fetch_sub_16 = Module["___atomic_fetch_sub_16"] = Module["asm"]["__atomic_fetch_sub_16"]).apply(null, arguments)
            };
            var ___atomic_fetch_and_1 = Module["___atomic_fetch_and_1"] = function() {
                return (___atomic_fetch_and_1 = Module["___atomic_fetch_and_1"] = Module["asm"]["__atomic_fetch_and_1"]).apply(null, arguments)
            };
            var ___atomic_fetch_and_2 = Module["___atomic_fetch_and_2"] = function() {
                return (___atomic_fetch_and_2 = Module["___atomic_fetch_and_2"] = Module["asm"]["__atomic_fetch_and_2"]).apply(null, arguments)
            };
            var ___atomic_fetch_and_4 = Module["___atomic_fetch_and_4"] = function() {
                return (___atomic_fetch_and_4 = Module["___atomic_fetch_and_4"] = Module["asm"]["__atomic_fetch_and_4"]).apply(null, arguments)
            };
            var ___atomic_fetch_and_8 = Module["___atomic_fetch_and_8"] = function() {
                return (___atomic_fetch_and_8 = Module["___atomic_fetch_and_8"] = Module["asm"]["__atomic_fetch_and_8"]).apply(null, arguments)
            };
            var ___atomic_fetch_and_16 = Module["___atomic_fetch_and_16"] = function() {
                return (___atomic_fetch_and_16 = Module["___atomic_fetch_and_16"] = Module["asm"]["__atomic_fetch_and_16"]).apply(null, arguments)
            };
            var ___atomic_fetch_or_1 = Module["___atomic_fetch_or_1"] = function() {
                return (___atomic_fetch_or_1 = Module["___atomic_fetch_or_1"] = Module["asm"]["__atomic_fetch_or_1"]).apply(null, arguments)
            };
            var ___atomic_fetch_or_2 = Module["___atomic_fetch_or_2"] = function() {
                return (___atomic_fetch_or_2 = Module["___atomic_fetch_or_2"] = Module["asm"]["__atomic_fetch_or_2"]).apply(null, arguments)
            };
            var ___atomic_fetch_or_4 = Module["___atomic_fetch_or_4"] = function() {
                return (___atomic_fetch_or_4 = Module["___atomic_fetch_or_4"] = Module["asm"]["__atomic_fetch_or_4"]).apply(null, arguments)
            };
            var ___atomic_fetch_or_8 = Module["___atomic_fetch_or_8"] = function() {
                return (___atomic_fetch_or_8 = Module["___atomic_fetch_or_8"] = Module["asm"]["__atomic_fetch_or_8"]).apply(null, arguments)
            };
            var ___atomic_fetch_or_16 = Module["___atomic_fetch_or_16"] = function() {
                return (___atomic_fetch_or_16 = Module["___atomic_fetch_or_16"] = Module["asm"]["__atomic_fetch_or_16"]).apply(null, arguments)
            };
            var ___atomic_fetch_xor_1 = Module["___atomic_fetch_xor_1"] = function() {
                return (___atomic_fetch_xor_1 = Module["___atomic_fetch_xor_1"] = Module["asm"]["__atomic_fetch_xor_1"]).apply(null, arguments)
            };
            var ___atomic_fetch_xor_2 = Module["___atomic_fetch_xor_2"] = function() {
                return (___atomic_fetch_xor_2 = Module["___atomic_fetch_xor_2"] = Module["asm"]["__atomic_fetch_xor_2"]).apply(null, arguments)
            };
            var ___atomic_fetch_xor_4 = Module["___atomic_fetch_xor_4"] = function() {
                return (___atomic_fetch_xor_4 = Module["___atomic_fetch_xor_4"] = Module["asm"]["__atomic_fetch_xor_4"]).apply(null, arguments)
            };
            var ___atomic_fetch_xor_8 = Module["___atomic_fetch_xor_8"] = function() {
                return (___atomic_fetch_xor_8 = Module["___atomic_fetch_xor_8"] = Module["asm"]["__atomic_fetch_xor_8"]).apply(null, arguments)
            };
            var ___atomic_fetch_xor_16 = Module["___atomic_fetch_xor_16"] = function() {
                return (___atomic_fetch_xor_16 = Module["___atomic_fetch_xor_16"] = Module["asm"]["__atomic_fetch_xor_16"]).apply(null, arguments)
            };
            var ___fixsfdi = Module["___fixsfdi"] = function() {
                return (___fixsfdi = Module["___fixsfdi"] = Module["asm"]["__fixsfdi"]).apply(null, arguments)
            };
            var ___floatundixf = Module["___floatundixf"] = function() {
                return (___floatundixf = Module["___floatundixf"] = Module["asm"]["__floatundixf"]).apply(null, arguments)
            };
            var ___floatditf = Module["___floatditf"] = function() {
                return (___floatditf = Module["___floatditf"] = Module["asm"]["__floatditf"]).apply(null, arguments)
            };
            var ___floatsidf = Module["___floatsidf"] = function() {
                return (___floatsidf = Module["___floatsidf"] = Module["asm"]["__floatsidf"]).apply(null, arguments)
            };
            var ___mulxc3 = Module["___mulxc3"] = function() {
                return (___mulxc3 = Module["___mulxc3"] = Module["asm"]["__mulxc3"]).apply(null, arguments)
            };
            var ___divdc3 = Module["___divdc3"] = function() {
                return (___divdc3 = Module["___divdc3"] = Module["asm"]["__divdc3"]).apply(null, arguments)
            };
            var _fmax = Module["_fmax"] = function() {
                return (_fmax = Module["_fmax"] = Module["asm"]["fmax"]).apply(null, arguments)
            };
            var ___fixunssfti = Module["___fixunssfti"] = function() {
                return (___fixunssfti = Module["___fixunssfti"] = Module["asm"]["__fixunssfti"]).apply(null, arguments)
            };
            var ___fixunsdfdi = Module["___fixunsdfdi"] = function() {
                return (___fixunsdfdi = Module["___fixunsdfdi"] = Module["asm"]["__fixunsdfdi"]).apply(null, arguments)
            };
            var ___fixdfti = Module["___fixdfti"] = function() {
                return (___fixdfti = Module["___fixdfti"] = Module["asm"]["__fixdfti"]).apply(null, arguments)
            };
            var ___fixunstfsi = Module["___fixunstfsi"] = function() {
                return (___fixunstfsi = Module["___fixunstfsi"] = Module["asm"]["__fixunstfsi"]).apply(null, arguments)
            };
            var ___floatsisf = Module["___floatsisf"] = function() {
                return (___floatsisf = Module["___floatsisf"] = Module["asm"]["__floatsisf"]).apply(null, arguments)
            };
            var _atomic_flag_clear_explicit = Module["_atomic_flag_clear_explicit"] = function() {
                return (_atomic_flag_clear_explicit = Module["_atomic_flag_clear_explicit"] = Module["asm"]["atomic_flag_clear_explicit"]).apply(null, arguments)
            };
            var ___floatdidf = Module["___floatdidf"] = function() {
                return (___floatdidf = Module["___floatdidf"] = Module["asm"]["__floatdidf"]).apply(null, arguments)
            };
            var ___ledf2 = Module["___ledf2"] = function() {
                return (___ledf2 = Module["___ledf2"] = Module["asm"]["__ledf2"]).apply(null, arguments)
            };
            var ___gedf2 = Module["___gedf2"] = function() {
                return (___gedf2 = Module["___gedf2"] = Module["asm"]["__gedf2"]).apply(null, arguments)
            };
            var ___unorddf2 = Module["___unorddf2"] = function() {
                return (___unorddf2 = Module["___unorddf2"] = Module["asm"]["__unorddf2"]).apply(null, arguments)
            };
            var ___eqdf2 = Module["___eqdf2"] = function() {
                return (___eqdf2 = Module["___eqdf2"] = Module["asm"]["__eqdf2"]).apply(null, arguments)
            };
            var ___ltdf2 = Module["___ltdf2"] = function() {
                return (___ltdf2 = Module["___ltdf2"] = Module["asm"]["__ltdf2"]).apply(null, arguments)
            };
            var ___nedf2 = Module["___nedf2"] = function() {
                return (___nedf2 = Module["___nedf2"] = Module["asm"]["__nedf2"]).apply(null, arguments)
            };
            var ___gtdf2 = Module["___gtdf2"] = function() {
                return (___gtdf2 = Module["___gtdf2"] = Module["asm"]["__gtdf2"]).apply(null, arguments)
            };
            var ___fixunsdfsi = Module["___fixunsdfsi"] = function() {
                return (___fixunsdfsi = Module["___fixunsdfsi"] = Module["asm"]["__fixunsdfsi"]).apply(null, arguments)
            };
            var ___addsf3 = Module["___addsf3"] = function() {
                return (___addsf3 = Module["___addsf3"] = Module["asm"]["__addsf3"]).apply(null, arguments)
            };
            var ___absvti2 = Module["___absvti2"] = function() {
                return (___absvti2 = Module["___absvti2"] = Module["asm"]["__absvti2"]).apply(null, arguments)
            };
            var ___negdi2 = Module["___negdi2"] = function() {
                return (___negdi2 = Module["___negdi2"] = Module["asm"]["__negdi2"]).apply(null, arguments)
            };
            var ___parityti2 = Module["___parityti2"] = function() {
                return (___parityti2 = Module["___parityti2"] = Module["asm"]["__parityti2"]).apply(null, arguments)
            };
            var ___divsc3 = Module["___divsc3"] = function() {
                return (___divsc3 = Module["___divsc3"] = Module["asm"]["__divsc3"]).apply(null, arguments)
            };
            var _fmaxf = Module["_fmaxf"] = function() {
                return (_fmaxf = Module["_fmaxf"] = Module["asm"]["fmaxf"]).apply(null, arguments)
            };
            var ___powidf2 = Module["___powidf2"] = function() {
                return (___powidf2 = Module["___powidf2"] = Module["asm"]["__powidf2"]).apply(null, arguments)
            };
            var ___fixunsxfsi = Module["___fixunsxfsi"] = function() {
                return (___fixunsxfsi = Module["___fixunsxfsi"] = Module["asm"]["__fixunsxfsi"]).apply(null, arguments)
            };
            var ___truncsfhf2 = Module["___truncsfhf2"] = function() {
                return (___truncsfhf2 = Module["___truncsfhf2"] = Module["asm"]["__truncsfhf2"]).apply(null, arguments)
            };
            var ___gnu_f2h_ieee = Module["___gnu_f2h_ieee"] = function() {
                return (___gnu_f2h_ieee = Module["___gnu_f2h_ieee"] = Module["asm"]["__gnu_f2h_ieee"]).apply(null, arguments)
            };
            var ___subsf3 = Module["___subsf3"] = function() {
                return (___subsf3 = Module["___subsf3"] = Module["asm"]["__subsf3"]).apply(null, arguments)
            };
            var ___udivmodsi4 = Module["___udivmodsi4"] = function() {
                return (___udivmodsi4 = Module["___udivmodsi4"] = Module["asm"]["__udivmodsi4"]).apply(null, arguments)
            };
            var ___udivsi3 = Module["___udivsi3"] = function() {
                return (___udivsi3 = Module["___udivsi3"] = Module["asm"]["__udivsi3"]).apply(null, arguments)
            };
            var ___fixdfdi = Module["___fixdfdi"] = function() {
                return (___fixdfdi = Module["___fixdfdi"] = Module["asm"]["__fixdfdi"]).apply(null, arguments)
            };
            var ___floatuntidf = Module["___floatuntidf"] = function() {
                return (___floatuntidf = Module["___floatuntidf"] = Module["asm"]["__floatuntidf"]).apply(null, arguments)
            };
            var ___cmpdi2 = Module["___cmpdi2"] = function() {
                return (___cmpdi2 = Module["___cmpdi2"] = Module["asm"]["__cmpdi2"]).apply(null, arguments)
            };
            var ___eprintf = Module["___eprintf"] = function() {
                return (___eprintf = Module["___eprintf"] = Module["asm"]["__eprintf"]).apply(null, arguments)
            };
            var ___divti3 = Module["___divti3"] = function() {
                return (___divti3 = Module["___divti3"] = Module["asm"]["__divti3"]).apply(null, arguments)
            };
            var ___powisf2 = Module["___powisf2"] = function() {
                return (___powisf2 = Module["___powisf2"] = Module["asm"]["__powisf2"]).apply(null, arguments)
            };
            var ___floatunsidf = Module["___floatunsidf"] = function() {
                return (___floatunsidf = Module["___floatunsidf"] = Module["asm"]["__floatunsidf"]).apply(null, arguments)
            };
            var ___emutls_get_address = Module["___emutls_get_address"] = function() {
                return (___emutls_get_address = Module["___emutls_get_address"] = Module["asm"]["__emutls_get_address"]).apply(null, arguments)
            };
            var ___fixsfsi = Module["___fixsfsi"] = function() {
                return (___fixsfsi = Module["___fixsfsi"] = Module["asm"]["__fixsfsi"]).apply(null, arguments)
            };
            var ___absvdi2 = Module["___absvdi2"] = function() {
                return (___absvdi2 = Module["___absvdi2"] = Module["asm"]["__absvdi2"]).apply(null, arguments)
            };
            var ___umoddi3 = Module["___umoddi3"] = function() {
                return (___umoddi3 = Module["___umoddi3"] = Module["asm"]["__umoddi3"]).apply(null, arguments)
            };
            var ___floatundisf = Module["___floatundisf"] = function() {
                return (___floatundisf = Module["___floatundisf"] = Module["asm"]["__floatundisf"]).apply(null, arguments)
            };
            var ___bswapsi2 = Module["___bswapsi2"] = function() {
                return (___bswapsi2 = Module["___bswapsi2"] = Module["asm"]["__bswapsi2"]).apply(null, arguments)
            };
            var ___negvti2 = Module["___negvti2"] = function() {
                return (___negvti2 = Module["___negvti2"] = Module["asm"]["__negvti2"]).apply(null, arguments)
            };
            var _atomic_flag_clear = Module["_atomic_flag_clear"] = function() {
                return (_atomic_flag_clear = Module["_atomic_flag_clear"] = Module["asm"]["atomic_flag_clear"]).apply(null, arguments)
            };
            var ___fixunstfdi = Module["___fixunstfdi"] = function() {
                return (___fixunstfdi = Module["___fixunstfdi"] = Module["asm"]["__fixunstfdi"]).apply(null, arguments)
            };
            var ___negti2 = Module["___negti2"] = function() {
                return (___negti2 = Module["___negti2"] = Module["asm"]["__negti2"]).apply(null, arguments)
            };
            var ___fixunssfsi = Module["___fixunssfsi"] = function() {
                return (___fixunssfsi = Module["___fixunssfsi"] = Module["asm"]["__fixunssfsi"]).apply(null, arguments)
            };
            var ___ucmpdi2 = Module["___ucmpdi2"] = function() {
                return (___ucmpdi2 = Module["___ucmpdi2"] = Module["asm"]["__ucmpdi2"]).apply(null, arguments)
            };
            var ___ffsti2 = Module["___ffsti2"] = function() {
                return (___ffsti2 = Module["___ffsti2"] = Module["asm"]["__ffsti2"]).apply(null, arguments)
            };
            var ___divtc3 = Module["___divtc3"] = function() {
                return (___divtc3 = Module["___divtc3"] = Module["asm"]["__divtc3"]).apply(null, arguments)
            };
            var _fmaxl = Module["_fmaxl"] = function() {
                return (_fmaxl = Module["_fmaxl"] = Module["asm"]["fmaxl"]).apply(null, arguments)
            };
            var ___moddi3 = Module["___moddi3"] = function() {
                return (___moddi3 = Module["___moddi3"] = Module["asm"]["__moddi3"]).apply(null, arguments)
            };
            var ___popcountti2 = Module["___popcountti2"] = function() {
                return (___popcountti2 = Module["___popcountti2"] = Module["asm"]["__popcountti2"]).apply(null, arguments)
            };
            var ___mulodi4 = Module["___mulodi4"] = function() {
                return (___mulodi4 = Module["___mulodi4"] = Module["asm"]["__mulodi4"]).apply(null, arguments)
            };
            var ___dtoi64 = Module["___dtoi64"] = function() {
                return (___dtoi64 = Module["___dtoi64"] = Module["asm"]["__dtoi64"]).apply(null, arguments)
            };
            var ___stoi64 = Module["___stoi64"] = function() {
                return (___stoi64 = Module["___stoi64"] = Module["asm"]["__stoi64"]).apply(null, arguments)
            };
            var ___dtou64 = Module["___dtou64"] = function() {
                return (___dtou64 = Module["___dtou64"] = Module["asm"]["__dtou64"]).apply(null, arguments)
            };
            var ___stou64 = Module["___stou64"] = function() {
                return (___stou64 = Module["___stou64"] = Module["asm"]["__stou64"]).apply(null, arguments)
            };
            var ___i64tod = Module["___i64tod"] = function() {
                return (___i64tod = Module["___i64tod"] = Module["asm"]["__i64tod"]).apply(null, arguments)
            };
            var ___i64tos = Module["___i64tos"] = function() {
                return (___i64tos = Module["___i64tos"] = Module["asm"]["__i64tos"]).apply(null, arguments)
            };
            var ___u64tod = Module["___u64tod"] = function() {
                return (___u64tod = Module["___u64tod"] = Module["asm"]["__u64tod"]).apply(null, arguments)
            };
            var ___u64tos = Module["___u64tos"] = function() {
                return (___u64tos = Module["___u64tos"] = Module["asm"]["__u64tos"]).apply(null, arguments)
            };
            var ___addvti3 = Module["___addvti3"] = function() {
                return (___addvti3 = Module["___addvti3"] = Module["asm"]["__addvti3"]).apply(null, arguments)
            };
            var ___divdf3 = Module["___divdf3"] = function() {
                return (___divdf3 = Module["___divdf3"] = Module["asm"]["__divdf3"]).apply(null, arguments)
            };
            var ___fixunstfti = Module["___fixunstfti"] = function() {
                return (___fixunstfti = Module["___fixunstfti"] = Module["asm"]["__fixunstfti"]).apply(null, arguments)
            };
            var ___lshrdi3 = Module["___lshrdi3"] = function() {
                return (___lshrdi3 = Module["___lshrdi3"] = Module["asm"]["__lshrdi3"]).apply(null, arguments)
            };
            var ___subvsi3 = Module["___subvsi3"] = function() {
                return (___subvsi3 = Module["___subvsi3"] = Module["asm"]["__subvsi3"]).apply(null, arguments)
            };
            var ___divmoddi4 = Module["___divmoddi4"] = function() {
                return (___divmoddi4 = Module["___divmoddi4"] = Module["asm"]["__divmoddi4"]).apply(null, arguments)
            };
            var ___divdi3 = Module["___divdi3"] = function() {
                return (___divdi3 = Module["___divdi3"] = Module["asm"]["__divdi3"]).apply(null, arguments)
            };
            var ___divxc3 = Module["___divxc3"] = function() {
                return (___divxc3 = Module["___divxc3"] = Module["asm"]["__divxc3"]).apply(null, arguments)
            };
            var ___muldi3 = Module["___muldi3"] = function() {
                return (___muldi3 = Module["___muldi3"] = Module["asm"]["__muldi3"]).apply(null, arguments)
            };
            var _atomic_signal_fence = Module["_atomic_signal_fence"] = function() {
                return (_atomic_signal_fence = Module["_atomic_signal_fence"] = Module["asm"]["atomic_signal_fence"]).apply(null, arguments)
            };
            var ___ashldi3 = Module["___ashldi3"] = function() {
                return (___ashldi3 = Module["___ashldi3"] = Module["asm"]["__ashldi3"]).apply(null, arguments)
            };
            var ___clear_cache = Module["___clear_cache"] = function() {
                return (___clear_cache = Module["___clear_cache"] = Module["asm"]["__clear_cache"]).apply(null, arguments)
            };
            var ___absvsi2 = Module["___absvsi2"] = function() {
                return (___absvsi2 = Module["___absvsi2"] = Module["asm"]["__absvsi2"]).apply(null, arguments)
            };
            var ___modti3 = Module["___modti3"] = function() {
                return (___modti3 = Module["___modti3"] = Module["asm"]["__modti3"]).apply(null, arguments)
            };
            var _atomic_flag_test_and_set_explicit = Module["_atomic_flag_test_and_set_explicit"] = function() {
                return (_atomic_flag_test_and_set_explicit = Module["_atomic_flag_test_and_set_explicit"] = Module["asm"]["atomic_flag_test_and_set_explicit"]).apply(null, arguments)
            };
            var ___powitf2 = Module["___powitf2"] = function() {
                return (___powitf2 = Module["___powitf2"] = Module["asm"]["__powitf2"]).apply(null, arguments)
            };
            var ___mulsf3 = Module["___mulsf3"] = function() {
                return (___mulsf3 = Module["___mulsf3"] = Module["asm"]["__mulsf3"]).apply(null, arguments)
            };
            var ___fixdfsi = Module["___fixdfsi"] = function() {
                return (___fixdfsi = Module["___fixdfsi"] = Module["asm"]["__fixdfsi"]).apply(null, arguments)
            };
            var ___truncdfsf2 = Module["___truncdfsf2"] = function() {
                return (___truncdfsf2 = Module["___truncdfsf2"] = Module["asm"]["__truncdfsf2"]).apply(null, arguments)
            };
            var ___clzsi2 = Module["___clzsi2"] = function() {
                return (___clzsi2 = Module["___clzsi2"] = Module["asm"]["__clzsi2"]).apply(null, arguments)
            };
            var ___ffsdi2 = Module["___ffsdi2"] = function() {
                return (___ffsdi2 = Module["___ffsdi2"] = Module["asm"]["__ffsdi2"]).apply(null, arguments)
            };
            var ___floatunsisf = Module["___floatunsisf"] = function() {
                return (___floatunsisf = Module["___floatunsisf"] = Module["asm"]["__floatunsisf"]).apply(null, arguments)
            };
            var ___ashrti3 = Module["___ashrti3"] = function() {
                return (___ashrti3 = Module["___ashrti3"] = Module["asm"]["__ashrti3"]).apply(null, arguments)
            };
            var ___clzdi2 = Module["___clzdi2"] = function() {
                return (___clzdi2 = Module["___clzdi2"] = Module["asm"]["__clzdi2"]).apply(null, arguments)
            };
            var ___subvti3 = Module["___subvti3"] = function() {
                return (___subvti3 = Module["___subvti3"] = Module["asm"]["__subvti3"]).apply(null, arguments)
            };
            var ___lesf2 = Module["___lesf2"] = function() {
                return (___lesf2 = Module["___lesf2"] = Module["asm"]["__lesf2"]).apply(null, arguments)
            };
            var ___gesf2 = Module["___gesf2"] = function() {
                return (___gesf2 = Module["___gesf2"] = Module["asm"]["__gesf2"]).apply(null, arguments)
            };
            var ___unordsf2 = Module["___unordsf2"] = function() {
                return (___unordsf2 = Module["___unordsf2"] = Module["asm"]["__unordsf2"]).apply(null, arguments)
            };
            var ___eqsf2 = Module["___eqsf2"] = function() {
                return (___eqsf2 = Module["___eqsf2"] = Module["asm"]["__eqsf2"]).apply(null, arguments)
            };
            var ___ltsf2 = Module["___ltsf2"] = function() {
                return (___ltsf2 = Module["___ltsf2"] = Module["asm"]["__ltsf2"]).apply(null, arguments)
            };
            var ___nesf2 = Module["___nesf2"] = function() {
                return (___nesf2 = Module["___nesf2"] = Module["asm"]["__nesf2"]).apply(null, arguments)
            };
            var ___gtsf2 = Module["___gtsf2"] = function() {
                return (___gtsf2 = Module["___gtsf2"] = Module["asm"]["__gtsf2"]).apply(null, arguments)
            };
            var _atomic_flag_test_and_set = Module["_atomic_flag_test_and_set"] = function() {
                return (_atomic_flag_test_and_set = Module["_atomic_flag_test_and_set"] = Module["asm"]["atomic_flag_test_and_set"]).apply(null, arguments)
            };
            var ___negvsi2 = Module["___negvsi2"] = function() {
                return (___negvsi2 = Module["___negvsi2"] = Module["asm"]["__negvsi2"]).apply(null, arguments)
            };
            var ___bswapdi2 = Module["___bswapdi2"] = function() {
                return (___bswapdi2 = Module["___bswapdi2"] = Module["asm"]["__bswapdi2"]).apply(null, arguments)
            };
            var ___cmpti2 = Module["___cmpti2"] = function() {
                return (___cmpti2 = Module["___cmpti2"] = Module["asm"]["__cmpti2"]).apply(null, arguments)
            };
            var _atomic_thread_fence = Module["_atomic_thread_fence"] = function() {
                return (_atomic_thread_fence = Module["_atomic_thread_fence"] = Module["asm"]["atomic_thread_fence"]).apply(null, arguments)
            };
            var ___ucmpti2 = Module["___ucmpti2"] = function() {
                return (___ucmpti2 = Module["___ucmpti2"] = Module["asm"]["__ucmpti2"]).apply(null, arguments)
            };
            var ___fixunsdfti = Module["___fixunsdfti"] = function() {
                return (___fixunsdfti = Module["___fixunsdfti"] = Module["asm"]["__fixunsdfti"]).apply(null, arguments)
            };
            var ___enable_execute_stack = Module["___enable_execute_stack"] = function() {
                return (___enable_execute_stack = Module["___enable_execute_stack"] = Module["asm"]["__enable_execute_stack"]).apply(null, arguments)
            };
            var ___fixxfdi = Module["___fixxfdi"] = function() {
                return (___fixxfdi = Module["___fixxfdi"] = Module["asm"]["__fixxfdi"]).apply(null, arguments)
            };
            var ___negvdi2 = Module["___negvdi2"] = function() {
                return (___negvdi2 = Module["___negvdi2"] = Module["asm"]["__negvdi2"]).apply(null, arguments)
            };
            var ___floattidf = Module["___floattidf"] = function() {
                return (___floattidf = Module["___floattidf"] = Module["asm"]["__floattidf"]).apply(null, arguments)
            };
            var ___muldf3 = Module["___muldf3"] = function() {
                return (___muldf3 = Module["___muldf3"] = Module["asm"]["__muldf3"]).apply(null, arguments)
            };
            var ___mulvsi3 = Module["___mulvsi3"] = function() {
                return (___mulvsi3 = Module["___mulvsi3"] = Module["asm"]["__mulvsi3"]).apply(null, arguments)
            };
            var ___mulvdi3 = Module["___mulvdi3"] = function() {
                return (___mulvdi3 = Module["___mulvdi3"] = Module["asm"]["__mulvdi3"]).apply(null, arguments)
            };
            var ___powixf2 = Module["___powixf2"] = function() {
                return (___powixf2 = Module["___powixf2"] = Module["asm"]["__powixf2"]).apply(null, arguments)
            };
            var ___fixsfti = Module["___fixsfti"] = function() {
                return (___fixsfti = Module["___fixsfti"] = Module["asm"]["__fixsfti"]).apply(null, arguments)
            };
            var ___fixunsxfdi = Module["___fixunsxfdi"] = function() {
                return (___fixunsxfdi = Module["___fixunsxfdi"] = Module["asm"]["__fixunsxfdi"]).apply(null, arguments)
            };
            var ___popcountdi2 = Module["___popcountdi2"] = function() {
                return (___popcountdi2 = Module["___popcountdi2"] = Module["asm"]["__popcountdi2"]).apply(null, arguments)
            };
            var ___ctzdi2 = Module["___ctzdi2"] = function() {
                return (___ctzdi2 = Module["___ctzdi2"] = Module["asm"]["__ctzdi2"]).apply(null, arguments)
            };
            var ___ashrdi3 = Module["___ashrdi3"] = function() {
                return (___ashrdi3 = Module["___ashrdi3"] = Module["asm"]["__ashrdi3"]).apply(null, arguments)
            };
            var ___extendsfdf2 = Module["___extendsfdf2"] = function() {
                return (___extendsfdf2 = Module["___extendsfdf2"] = Module["asm"]["__extendsfdf2"]).apply(null, arguments)
            };
            var ___truncdfhf2 = Module["___truncdfhf2"] = function() {
                return (___truncdfhf2 = Module["___truncdfhf2"] = Module["asm"]["__truncdfhf2"]).apply(null, arguments)
            };
            var ___floatunditf = Module["___floatunditf"] = function() {
                return (___floatunditf = Module["___floatunditf"] = Module["asm"]["__floatunditf"]).apply(null, arguments)
            };
            var ___umodsi3 = Module["___umodsi3"] = function() {
                return (___umodsi3 = Module["___umodsi3"] = Module["asm"]["__umodsi3"]).apply(null, arguments)
            };
            var ___floattisf = Module["___floattisf"] = function() {
                return (___floattisf = Module["___floattisf"] = Module["asm"]["__floattisf"]).apply(null, arguments)
            };
            var stackSave = Module["stackSave"] = function() {
                return (stackSave = Module["stackSave"] = Module["asm"]["stackSave"]).apply(null, arguments)
            };
            var stackRestore = Module["stackRestore"] = function() {
                return (stackRestore = Module["stackRestore"] = Module["asm"]["stackRestore"]).apply(null, arguments)
            };
            var stackAlloc = Module["stackAlloc"] = function() {
                return (stackAlloc = Module["stackAlloc"] = Module["asm"]["stackAlloc"]).apply(null, arguments)
            };
            var _emscripten_stack_get_current = Module["_emscripten_stack_get_current"] = function() {
                return (_emscripten_stack_get_current = Module["_emscripten_stack_get_current"] = Module["asm"]["emscripten_stack_get_current"]).apply(null, arguments)
            };
            var _emscripten_stack_init = Module["_emscripten_stack_init"] = function() {
                return (_emscripten_stack_init = Module["_emscripten_stack_init"] = Module["asm"]["emscripten_stack_init"]).apply(null, arguments)
            };
            var _emscripten_stack_set_limits = Module["_emscripten_stack_set_limits"] = function() {
                return (_emscripten_stack_set_limits = Module["_emscripten_stack_set_limits"] = Module["asm"]["emscripten_stack_set_limits"]).apply(null, arguments)
            };
            var _emscripten_stack_get_free = Module["_emscripten_stack_get_free"] = function() {
                return (_emscripten_stack_get_free = Module["_emscripten_stack_get_free"] = Module["asm"]["emscripten_stack_get_free"]).apply(null, arguments)
            };
            var _saveSetjmp = Module["_saveSetjmp"] = function() {
                return (_saveSetjmp = Module["_saveSetjmp"] = Module["asm"]["saveSetjmp"]).apply(null, arguments)
            };
            var _testSetjmp = Module["_testSetjmp"] = function() {
                return (_testSetjmp = Module["_testSetjmp"] = Module["asm"]["testSetjmp"]).apply(null, arguments)
            };
            var _setThrew = Module["_setThrew"] = function() {
                return (_setThrew = Module["_setThrew"] = Module["asm"]["setThrew"]).apply(null, arguments)
            };
            var __ZNSt3__219__shared_mutex_baseC2Ev = Module["__ZNSt3__219__shared_mutex_baseC2Ev"] = function() {
                return (__ZNSt3__219__shared_mutex_baseC2Ev = Module["__ZNSt3__219__shared_mutex_baseC2Ev"] = Module["asm"]["_ZNSt3__219__shared_mutex_baseC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__25mutexC2Ev = Module["__ZNSt3__25mutexC2Ev"] = function() {
                return (__ZNSt3__25mutexC2Ev = Module["__ZNSt3__25mutexC2Ev"] = Module["asm"]["_ZNSt3__25mutexC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__218condition_variableC2Ev = Module["__ZNSt3__218condition_variableC2Ev"] = function() {
                return (__ZNSt3__218condition_variableC2Ev = Module["__ZNSt3__218condition_variableC2Ev"] = Module["asm"]["_ZNSt3__218condition_variableC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__219__shared_mutex_base4lockEv = Module["__ZNSt3__219__shared_mutex_base4lockEv"] = function() {
                return (__ZNSt3__219__shared_mutex_base4lockEv = Module["__ZNSt3__219__shared_mutex_base4lockEv"] = Module["asm"]["_ZNSt3__219__shared_mutex_base4lockEv"]).apply(null, arguments)
            };
            var __ZNSt3__211unique_lockINS_5mutexEEC2ERS1_ = Module["__ZNSt3__211unique_lockINS_5mutexEEC2ERS1_"] = function() {
                return (__ZNSt3__211unique_lockINS_5mutexEEC2ERS1_ = Module["__ZNSt3__211unique_lockINS_5mutexEEC2ERS1_"] = Module["asm"]["_ZNSt3__211unique_lockINS_5mutexEEC2ERS1_"]).apply(null, arguments)
            };
            var __ZNSt3__218condition_variable4waitERNS_11unique_lockINS_5mutexEEE = Module["__ZNSt3__218condition_variable4waitERNS_11unique_lockINS_5mutexEEE"] = function() {
                return (__ZNSt3__218condition_variable4waitERNS_11unique_lockINS_5mutexEEE = Module["__ZNSt3__218condition_variable4waitERNS_11unique_lockINS_5mutexEEE"] = Module["asm"]["_ZNSt3__218condition_variable4waitERNS_11unique_lockINS_5mutexEEE"]).apply(null, arguments)
            };
            var __ZNSt3__211unique_lockINS_5mutexEED2Ev = Module["__ZNSt3__211unique_lockINS_5mutexEED2Ev"] = function() {
                return (__ZNSt3__211unique_lockINS_5mutexEED2Ev = Module["__ZNSt3__211unique_lockINS_5mutexEED2Ev"] = Module["asm"]["_ZNSt3__211unique_lockINS_5mutexEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29addressofINS_5mutexEEEPT_RS2_ = Module["__ZNSt3__29addressofINS_5mutexEEEPT_RS2_"] = function() {
                return (__ZNSt3__29addressofINS_5mutexEEEPT_RS2_ = Module["__ZNSt3__29addressofINS_5mutexEEEPT_RS2_"] = Module["asm"]["_ZNSt3__29addressofINS_5mutexEEEPT_RS2_"]).apply(null, arguments)
            };
            var __ZNSt3__25mutex4lockEv = Module["__ZNSt3__25mutex4lockEv"] = function() {
                return (__ZNSt3__25mutex4lockEv = Module["__ZNSt3__25mutex4lockEv"] = Module["asm"]["_ZNSt3__25mutex4lockEv"]).apply(null, arguments)
            };
            var __ZNSt3__25mutex6unlockEv = Module["__ZNSt3__25mutex6unlockEv"] = function() {
                return (__ZNSt3__25mutex6unlockEv = Module["__ZNSt3__25mutex6unlockEv"] = Module["asm"]["_ZNSt3__25mutex6unlockEv"]).apply(null, arguments)
            };
            var __ZNSt3__219__shared_mutex_base8try_lockEv = Module["__ZNSt3__219__shared_mutex_base8try_lockEv"] = function() {
                return (__ZNSt3__219__shared_mutex_base8try_lockEv = Module["__ZNSt3__219__shared_mutex_base8try_lockEv"] = Module["asm"]["_ZNSt3__219__shared_mutex_base8try_lockEv"]).apply(null, arguments)
            };
            var __ZNSt3__219__shared_mutex_base6unlockEv = Module["__ZNSt3__219__shared_mutex_base6unlockEv"] = function() {
                return (__ZNSt3__219__shared_mutex_base6unlockEv = Module["__ZNSt3__219__shared_mutex_base6unlockEv"] = Module["asm"]["_ZNSt3__219__shared_mutex_base6unlockEv"]).apply(null, arguments)
            };
            var __ZNSt3__210lock_guardINS_5mutexEEC2ERS1_ = Module["__ZNSt3__210lock_guardINS_5mutexEEC2ERS1_"] = function() {
                return (__ZNSt3__210lock_guardINS_5mutexEEC2ERS1_ = Module["__ZNSt3__210lock_guardINS_5mutexEEC2ERS1_"] = Module["asm"]["_ZNSt3__210lock_guardINS_5mutexEEC2ERS1_"]).apply(null, arguments)
            };
            var __ZNSt3__218condition_variable10notify_allEv = Module["__ZNSt3__218condition_variable10notify_allEv"] = function() {
                return (__ZNSt3__218condition_variable10notify_allEv = Module["__ZNSt3__218condition_variable10notify_allEv"] = Module["asm"]["_ZNSt3__218condition_variable10notify_allEv"]).apply(null, arguments)
            };
            var __ZNSt3__210lock_guardINS_5mutexEED2Ev = Module["__ZNSt3__210lock_guardINS_5mutexEED2Ev"] = function() {
                return (__ZNSt3__210lock_guardINS_5mutexEED2Ev = Module["__ZNSt3__210lock_guardINS_5mutexEED2Ev"] = Module["asm"]["_ZNSt3__210lock_guardINS_5mutexEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__219__shared_mutex_base11lock_sharedEv = Module["__ZNSt3__219__shared_mutex_base11lock_sharedEv"] = function() {
                return (__ZNSt3__219__shared_mutex_base11lock_sharedEv = Module["__ZNSt3__219__shared_mutex_base11lock_sharedEv"] = Module["asm"]["_ZNSt3__219__shared_mutex_base11lock_sharedEv"]).apply(null, arguments)
            };
            var __ZNSt3__219__shared_mutex_base15try_lock_sharedEv = Module["__ZNSt3__219__shared_mutex_base15try_lock_sharedEv"] = function() {
                return (__ZNSt3__219__shared_mutex_base15try_lock_sharedEv = Module["__ZNSt3__219__shared_mutex_base15try_lock_sharedEv"] = Module["asm"]["_ZNSt3__219__shared_mutex_base15try_lock_sharedEv"]).apply(null, arguments)
            };
            var __ZNSt3__219__shared_mutex_base13unlock_sharedEv = Module["__ZNSt3__219__shared_mutex_base13unlock_sharedEv"] = function() {
                return (__ZNSt3__219__shared_mutex_base13unlock_sharedEv = Module["__ZNSt3__219__shared_mutex_base13unlock_sharedEv"] = Module["asm"]["_ZNSt3__219__shared_mutex_base13unlock_sharedEv"]).apply(null, arguments)
            };
            var __ZNSt3__218condition_variable10notify_oneEv = Module["__ZNSt3__218condition_variable10notify_oneEv"] = function() {
                return (__ZNSt3__218condition_variable10notify_oneEv = Module["__ZNSt3__218condition_variable10notify_oneEv"] = Module["asm"]["_ZNSt3__218condition_variable10notify_oneEv"]).apply(null, arguments)
            };
            var __ZNSt3__218shared_timed_mutexC2Ev = Module["__ZNSt3__218shared_timed_mutexC2Ev"] = function() {
                return (__ZNSt3__218shared_timed_mutexC2Ev = Module["__ZNSt3__218shared_timed_mutexC2Ev"] = Module["asm"]["_ZNSt3__218shared_timed_mutexC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__218shared_timed_mutex4lockEv = Module["__ZNSt3__218shared_timed_mutex4lockEv"] = function() {
                return (__ZNSt3__218shared_timed_mutex4lockEv = Module["__ZNSt3__218shared_timed_mutex4lockEv"] = Module["asm"]["_ZNSt3__218shared_timed_mutex4lockEv"]).apply(null, arguments)
            };
            var __ZNSt3__218shared_timed_mutex8try_lockEv = Module["__ZNSt3__218shared_timed_mutex8try_lockEv"] = function() {
                return (__ZNSt3__218shared_timed_mutex8try_lockEv = Module["__ZNSt3__218shared_timed_mutex8try_lockEv"] = Module["asm"]["_ZNSt3__218shared_timed_mutex8try_lockEv"]).apply(null, arguments)
            };
            var __ZNSt3__218shared_timed_mutex6unlockEv = Module["__ZNSt3__218shared_timed_mutex6unlockEv"] = function() {
                return (__ZNSt3__218shared_timed_mutex6unlockEv = Module["__ZNSt3__218shared_timed_mutex6unlockEv"] = Module["asm"]["_ZNSt3__218shared_timed_mutex6unlockEv"]).apply(null, arguments)
            };
            var __ZNSt3__218shared_timed_mutex11lock_sharedEv = Module["__ZNSt3__218shared_timed_mutex11lock_sharedEv"] = function() {
                return (__ZNSt3__218shared_timed_mutex11lock_sharedEv = Module["__ZNSt3__218shared_timed_mutex11lock_sharedEv"] = Module["asm"]["_ZNSt3__218shared_timed_mutex11lock_sharedEv"]).apply(null, arguments)
            };
            var __ZNSt3__218shared_timed_mutex15try_lock_sharedEv = Module["__ZNSt3__218shared_timed_mutex15try_lock_sharedEv"] = function() {
                return (__ZNSt3__218shared_timed_mutex15try_lock_sharedEv = Module["__ZNSt3__218shared_timed_mutex15try_lock_sharedEv"] = Module["asm"]["_ZNSt3__218shared_timed_mutex15try_lock_sharedEv"]).apply(null, arguments)
            };
            var __ZNSt3__218shared_timed_mutex13unlock_sharedEv = Module["__ZNSt3__218shared_timed_mutex13unlock_sharedEv"] = function() {
                return (__ZNSt3__218shared_timed_mutex13unlock_sharedEv = Module["__ZNSt3__218shared_timed_mutex13unlock_sharedEv"] = Module["asm"]["_ZNSt3__218shared_timed_mutex13unlock_sharedEv"]).apply(null, arguments)
            };
            var __ZNSt3__219__shared_mutex_baseC1Ev = Module["__ZNSt3__219__shared_mutex_baseC1Ev"] = function() {
                return (__ZNSt3__219__shared_mutex_baseC1Ev = Module["__ZNSt3__219__shared_mutex_baseC1Ev"] = Module["asm"]["_ZNSt3__219__shared_mutex_baseC1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__218shared_timed_mutexC1Ev = Module["__ZNSt3__218shared_timed_mutexC1Ev"] = function() {
                return (__ZNSt3__218shared_timed_mutexC1Ev = Module["__ZNSt3__218shared_timed_mutexC1Ev"] = Module["asm"]["_ZNSt3__218shared_timed_mutexC1Ev"]).apply(null, arguments)
            };
            var __ZSt18uncaught_exceptionv = Module["__ZSt18uncaught_exceptionv"] = function() {
                return (__ZSt18uncaught_exceptionv = Module["__ZSt18uncaught_exceptionv"] = Module["asm"]["_ZSt18uncaught_exceptionv"]).apply(null, arguments)
            };
            var __ZSt19uncaught_exceptionsv = Module["__ZSt19uncaught_exceptionsv"] = function() {
                return (__ZSt19uncaught_exceptionsv = Module["__ZSt19uncaught_exceptionsv"] = Module["asm"]["_ZSt19uncaught_exceptionsv"]).apply(null, arguments)
            };
            var ___cxa_uncaught_exceptions = Module["___cxa_uncaught_exceptions"] = function() {
                return (___cxa_uncaught_exceptions = Module["___cxa_uncaught_exceptions"] = Module["asm"]["__cxa_uncaught_exceptions"]).apply(null, arguments)
            };
            var __ZNSt13exception_ptrD2Ev = Module["__ZNSt13exception_ptrD2Ev"] = function() {
                return (__ZNSt13exception_ptrD2Ev = Module["__ZNSt13exception_ptrD2Ev"] = Module["asm"]["_ZNSt13exception_ptrD2Ev"]).apply(null, arguments)
            };
            var ___cxa_decrement_exception_refcount = Module["___cxa_decrement_exception_refcount"] = function() {
                return (___cxa_decrement_exception_refcount = Module["___cxa_decrement_exception_refcount"] = Module["asm"]["__cxa_decrement_exception_refcount"]).apply(null, arguments)
            };
            var __ZNSt13exception_ptrC2ERKS_ = Module["__ZNSt13exception_ptrC2ERKS_"] = function() {
                return (__ZNSt13exception_ptrC2ERKS_ = Module["__ZNSt13exception_ptrC2ERKS_"] = Module["asm"]["_ZNSt13exception_ptrC2ERKS_"]).apply(null, arguments)
            };
            var ___cxa_increment_exception_refcount = Module["___cxa_increment_exception_refcount"] = function() {
                return (___cxa_increment_exception_refcount = Module["___cxa_increment_exception_refcount"] = Module["asm"]["__cxa_increment_exception_refcount"]).apply(null, arguments)
            };
            var __ZNSt13exception_ptraSERKS_ = Module["__ZNSt13exception_ptraSERKS_"] = function() {
                return (__ZNSt13exception_ptraSERKS_ = Module["__ZNSt13exception_ptraSERKS_"] = Module["asm"]["_ZNSt13exception_ptraSERKS_"]).apply(null, arguments)
            };
            var __ZNSt16nested_exceptionC2Ev = Module["__ZNSt16nested_exceptionC2Ev"] = function() {
                return (__ZNSt16nested_exceptionC2Ev = Module["__ZNSt16nested_exceptionC2Ev"] = Module["asm"]["_ZNSt16nested_exceptionC2Ev"]).apply(null, arguments)
            };
            var __ZSt17current_exceptionv = Module["__ZSt17current_exceptionv"] = function() {
                return (__ZSt17current_exceptionv = Module["__ZSt17current_exceptionv"] = Module["asm"]["_ZSt17current_exceptionv"]).apply(null, arguments)
            };
            var __ZNSt13exception_ptrC2Ev = Module["__ZNSt13exception_ptrC2Ev"] = function() {
                return (__ZNSt13exception_ptrC2Ev = Module["__ZNSt13exception_ptrC2Ev"] = Module["asm"]["_ZNSt13exception_ptrC2Ev"]).apply(null, arguments)
            };
            var ___cxa_current_primary_exception = Module["___cxa_current_primary_exception"] = function() {
                return (___cxa_current_primary_exception = Module["___cxa_current_primary_exception"] = Module["asm"]["__cxa_current_primary_exception"]).apply(null, arguments)
            };
            var __ZNSt16nested_exceptionD2Ev = Module["__ZNSt16nested_exceptionD2Ev"] = function() {
                return (__ZNSt16nested_exceptionD2Ev = Module["__ZNSt16nested_exceptionD2Ev"] = Module["asm"]["_ZNSt16nested_exceptionD2Ev"]).apply(null, arguments)
            };
            var __ZNSt16nested_exceptionD0Ev = Module["__ZNSt16nested_exceptionD0Ev"] = function() {
                return (__ZNSt16nested_exceptionD0Ev = Module["__ZNSt16nested_exceptionD0Ev"] = Module["asm"]["_ZNSt16nested_exceptionD0Ev"]).apply(null, arguments)
            };
            var __ZdlPv = Module["__ZdlPv"] = function() {
                return (__ZdlPv = Module["__ZdlPv"] = Module["asm"]["_ZdlPv"]).apply(null, arguments)
            };
            var __ZNKSt16nested_exception14rethrow_nestedEv = Module["__ZNKSt16nested_exception14rethrow_nestedEv"] = function() {
                return (__ZNKSt16nested_exception14rethrow_nestedEv = Module["__ZNKSt16nested_exception14rethrow_nestedEv"] = Module["asm"]["_ZNKSt16nested_exception14rethrow_nestedEv"]).apply(null, arguments)
            };
            var __ZNSt13exception_ptrC2EDn = Module["__ZNSt13exception_ptrC2EDn"] = function() {
                return (__ZNSt13exception_ptrC2EDn = Module["__ZNSt13exception_ptrC2EDn"] = Module["asm"]["_ZNSt13exception_ptrC2EDn"]).apply(null, arguments)
            };
            var __ZSteqRKSt13exception_ptrS1_ = Module["__ZSteqRKSt13exception_ptrS1_"] = function() {
                return (__ZSteqRKSt13exception_ptrS1_ = Module["__ZSteqRKSt13exception_ptrS1_"] = Module["asm"]["_ZSteqRKSt13exception_ptrS1_"]).apply(null, arguments)
            };
            var __ZSt9terminatev = Module["__ZSt9terminatev"] = function() {
                return (__ZSt9terminatev = Module["__ZSt9terminatev"] = Module["asm"]["_ZSt9terminatev"]).apply(null, arguments)
            };
            var __ZSt17rethrow_exceptionSt13exception_ptr = Module["__ZSt17rethrow_exceptionSt13exception_ptr"] = function() {
                return (__ZSt17rethrow_exceptionSt13exception_ptr = Module["__ZSt17rethrow_exceptionSt13exception_ptr"] = Module["asm"]["_ZSt17rethrow_exceptionSt13exception_ptr"]).apply(null, arguments)
            };
            var ___cxa_rethrow_primary_exception = Module["___cxa_rethrow_primary_exception"] = function() {
                return (___cxa_rethrow_primary_exception = Module["___cxa_rethrow_primary_exception"] = Module["asm"]["__cxa_rethrow_primary_exception"]).apply(null, arguments)
            };
            var __ZNSt13exception_ptrD1Ev = Module["__ZNSt13exception_ptrD1Ev"] = function() {
                return (__ZNSt13exception_ptrD1Ev = Module["__ZNSt13exception_ptrD1Ev"] = Module["asm"]["_ZNSt13exception_ptrD1Ev"]).apply(null, arguments)
            };
            var __ZNSt13exception_ptrC1ERKS_ = Module["__ZNSt13exception_ptrC1ERKS_"] = function() {
                return (__ZNSt13exception_ptrC1ERKS_ = Module["__ZNSt13exception_ptrC1ERKS_"] = Module["asm"]["_ZNSt13exception_ptrC1ERKS_"]).apply(null, arguments)
            };
            var __ZNSt16nested_exceptionC1Ev = Module["__ZNSt16nested_exceptionC1Ev"] = function() {
                return (__ZNSt16nested_exceptionC1Ev = Module["__ZNSt16nested_exceptionC1Ev"] = Module["asm"]["_ZNSt16nested_exceptionC1Ev"]).apply(null, arguments)
            };
            var __ZNSt16nested_exceptionD1Ev = Module["__ZNSt16nested_exceptionD1Ev"] = function() {
                return (__ZNSt16nested_exceptionD1Ev = Module["__ZNSt16nested_exceptionD1Ev"] = Module["asm"]["_ZNSt16nested_exceptionD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__219__libcpp_mutex_lockEP15pthread_mutex_t = Module["__ZNSt3__219__libcpp_mutex_lockEP15pthread_mutex_t"] = function() {
                return (__ZNSt3__219__libcpp_mutex_lockEP15pthread_mutex_t = Module["__ZNSt3__219__libcpp_mutex_lockEP15pthread_mutex_t"] = Module["asm"]["_ZNSt3__219__libcpp_mutex_lockEP15pthread_mutex_t"]).apply(null, arguments)
            };
            var __ZNSt3__220__throw_system_errorEiPKc = Module["__ZNSt3__220__throw_system_errorEiPKc"] = function() {
                return (__ZNSt3__220__throw_system_errorEiPKc = Module["__ZNSt3__220__throw_system_errorEiPKc"] = Module["asm"]["_ZNSt3__220__throw_system_errorEiPKc"]).apply(null, arguments)
            };
            var __ZNSt3__25mutex8try_lockEv = Module["__ZNSt3__25mutex8try_lockEv"] = function() {
                return (__ZNSt3__25mutex8try_lockEv = Module["__ZNSt3__25mutex8try_lockEv"] = Module["asm"]["_ZNSt3__25mutex8try_lockEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__libcpp_mutex_trylockEP15pthread_mutex_t = Module["__ZNSt3__222__libcpp_mutex_trylockEP15pthread_mutex_t"] = function() {
                return (__ZNSt3__222__libcpp_mutex_trylockEP15pthread_mutex_t = Module["__ZNSt3__222__libcpp_mutex_trylockEP15pthread_mutex_t"] = Module["asm"]["_ZNSt3__222__libcpp_mutex_trylockEP15pthread_mutex_t"]).apply(null, arguments)
            };
            var __ZNSt3__221__libcpp_mutex_unlockEP15pthread_mutex_t = Module["__ZNSt3__221__libcpp_mutex_unlockEP15pthread_mutex_t"] = function() {
                return (__ZNSt3__221__libcpp_mutex_unlockEP15pthread_mutex_t = Module["__ZNSt3__221__libcpp_mutex_unlockEP15pthread_mutex_t"] = Module["asm"]["_ZNSt3__221__libcpp_mutex_unlockEP15pthread_mutex_t"]).apply(null, arguments)
            };
            var __ZNSt3__215recursive_mutexC2Ev = Module["__ZNSt3__215recursive_mutexC2Ev"] = function() {
                return (__ZNSt3__215recursive_mutexC2Ev = Module["__ZNSt3__215recursive_mutexC2Ev"] = Module["asm"]["_ZNSt3__215recursive_mutexC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__229__libcpp_recursive_mutex_initEP15pthread_mutex_t = Module["__ZNSt3__229__libcpp_recursive_mutex_initEP15pthread_mutex_t"] = function() {
                return (__ZNSt3__229__libcpp_recursive_mutex_initEP15pthread_mutex_t = Module["__ZNSt3__229__libcpp_recursive_mutex_initEP15pthread_mutex_t"] = Module["asm"]["_ZNSt3__229__libcpp_recursive_mutex_initEP15pthread_mutex_t"]).apply(null, arguments)
            };
            var __ZNSt3__215recursive_mutexD2Ev = Module["__ZNSt3__215recursive_mutexD2Ev"] = function() {
                return (__ZNSt3__215recursive_mutexD2Ev = Module["__ZNSt3__215recursive_mutexD2Ev"] = Module["asm"]["_ZNSt3__215recursive_mutexD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__232__libcpp_recursive_mutex_destroyEP15pthread_mutex_t = Module["__ZNSt3__232__libcpp_recursive_mutex_destroyEP15pthread_mutex_t"] = function() {
                return (__ZNSt3__232__libcpp_recursive_mutex_destroyEP15pthread_mutex_t = Module["__ZNSt3__232__libcpp_recursive_mutex_destroyEP15pthread_mutex_t"] = Module["asm"]["_ZNSt3__232__libcpp_recursive_mutex_destroyEP15pthread_mutex_t"]).apply(null, arguments)
            };
            var __ZNSt3__215recursive_mutex4lockEv = Module["__ZNSt3__215recursive_mutex4lockEv"] = function() {
                return (__ZNSt3__215recursive_mutex4lockEv = Module["__ZNSt3__215recursive_mutex4lockEv"] = Module["asm"]["_ZNSt3__215recursive_mutex4lockEv"]).apply(null, arguments)
            };
            var __ZNSt3__229__libcpp_recursive_mutex_lockEP15pthread_mutex_t = Module["__ZNSt3__229__libcpp_recursive_mutex_lockEP15pthread_mutex_t"] = function() {
                return (__ZNSt3__229__libcpp_recursive_mutex_lockEP15pthread_mutex_t = Module["__ZNSt3__229__libcpp_recursive_mutex_lockEP15pthread_mutex_t"] = Module["asm"]["_ZNSt3__229__libcpp_recursive_mutex_lockEP15pthread_mutex_t"]).apply(null, arguments)
            };
            var __ZNSt3__215recursive_mutex6unlockEv = Module["__ZNSt3__215recursive_mutex6unlockEv"] = function() {
                return (__ZNSt3__215recursive_mutex6unlockEv = Module["__ZNSt3__215recursive_mutex6unlockEv"] = Module["asm"]["_ZNSt3__215recursive_mutex6unlockEv"]).apply(null, arguments)
            };
            var __ZNSt3__231__libcpp_recursive_mutex_unlockEP15pthread_mutex_t = Module["__ZNSt3__231__libcpp_recursive_mutex_unlockEP15pthread_mutex_t"] = function() {
                return (__ZNSt3__231__libcpp_recursive_mutex_unlockEP15pthread_mutex_t = Module["__ZNSt3__231__libcpp_recursive_mutex_unlockEP15pthread_mutex_t"] = Module["asm"]["_ZNSt3__231__libcpp_recursive_mutex_unlockEP15pthread_mutex_t"]).apply(null, arguments)
            };
            var __ZNSt3__215recursive_mutex8try_lockEv = Module["__ZNSt3__215recursive_mutex8try_lockEv"] = function() {
                return (__ZNSt3__215recursive_mutex8try_lockEv = Module["__ZNSt3__215recursive_mutex8try_lockEv"] = Module["asm"]["_ZNSt3__215recursive_mutex8try_lockEv"]).apply(null, arguments)
            };
            var __ZNSt3__232__libcpp_recursive_mutex_trylockEP15pthread_mutex_t = Module["__ZNSt3__232__libcpp_recursive_mutex_trylockEP15pthread_mutex_t"] = function() {
                return (__ZNSt3__232__libcpp_recursive_mutex_trylockEP15pthread_mutex_t = Module["__ZNSt3__232__libcpp_recursive_mutex_trylockEP15pthread_mutex_t"] = Module["asm"]["_ZNSt3__232__libcpp_recursive_mutex_trylockEP15pthread_mutex_t"]).apply(null, arguments)
            };
            var __ZNSt3__211timed_mutexC2Ev = Module["__ZNSt3__211timed_mutexC2Ev"] = function() {
                return (__ZNSt3__211timed_mutexC2Ev = Module["__ZNSt3__211timed_mutexC2Ev"] = Module["asm"]["_ZNSt3__211timed_mutexC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__211timed_mutexD2Ev = Module["__ZNSt3__211timed_mutexD2Ev"] = function() {
                return (__ZNSt3__211timed_mutexD2Ev = Module["__ZNSt3__211timed_mutexD2Ev"] = Module["asm"]["_ZNSt3__211timed_mutexD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__218condition_variableD1Ev = Module["__ZNSt3__218condition_variableD1Ev"] = function() {
                return (__ZNSt3__218condition_variableD1Ev = Module["__ZNSt3__218condition_variableD1Ev"] = Module["asm"]["_ZNSt3__218condition_variableD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__25mutexD1Ev = Module["__ZNSt3__25mutexD1Ev"] = function() {
                return (__ZNSt3__25mutexD1Ev = Module["__ZNSt3__25mutexD1Ev"] = Module["asm"]["_ZNSt3__25mutexD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__211timed_mutex4lockEv = Module["__ZNSt3__211timed_mutex4lockEv"] = function() {
                return (__ZNSt3__211timed_mutex4lockEv = Module["__ZNSt3__211timed_mutex4lockEv"] = Module["asm"]["_ZNSt3__211timed_mutex4lockEv"]).apply(null, arguments)
            };
            var __ZNSt3__211timed_mutex8try_lockEv = Module["__ZNSt3__211timed_mutex8try_lockEv"] = function() {
                return (__ZNSt3__211timed_mutex8try_lockEv = Module["__ZNSt3__211timed_mutex8try_lockEv"] = Module["asm"]["_ZNSt3__211timed_mutex8try_lockEv"]).apply(null, arguments)
            };
            var __ZNSt3__211unique_lockINS_5mutexEEC2ERS1_NS_13try_to_lock_tE = Module["__ZNSt3__211unique_lockINS_5mutexEEC2ERS1_NS_13try_to_lock_tE"] = function() {
                return (__ZNSt3__211unique_lockINS_5mutexEEC2ERS1_NS_13try_to_lock_tE = Module["__ZNSt3__211unique_lockINS_5mutexEEC2ERS1_NS_13try_to_lock_tE"] = Module["asm"]["_ZNSt3__211unique_lockINS_5mutexEEC2ERS1_NS_13try_to_lock_tE"]).apply(null, arguments)
            };
            var __ZNKSt3__211unique_lockINS_5mutexEE9owns_lockEv = Module["__ZNKSt3__211unique_lockINS_5mutexEE9owns_lockEv"] = function() {
                return (__ZNKSt3__211unique_lockINS_5mutexEE9owns_lockEv = Module["__ZNKSt3__211unique_lockINS_5mutexEE9owns_lockEv"] = Module["asm"]["_ZNKSt3__211unique_lockINS_5mutexEE9owns_lockEv"]).apply(null, arguments)
            };
            var __ZNSt3__211timed_mutex6unlockEv = Module["__ZNSt3__211timed_mutex6unlockEv"] = function() {
                return (__ZNSt3__211timed_mutex6unlockEv = Module["__ZNSt3__211timed_mutex6unlockEv"] = Module["asm"]["_ZNSt3__211timed_mutex6unlockEv"]).apply(null, arguments)
            };
            var __ZNSt3__221recursive_timed_mutexC2Ev = Module["__ZNSt3__221recursive_timed_mutexC2Ev"] = function() {
                return (__ZNSt3__221recursive_timed_mutexC2Ev = Module["__ZNSt3__221recursive_timed_mutexC2Ev"] = Module["asm"]["_ZNSt3__221recursive_timed_mutexC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__211__thread_idC2Ev = Module["__ZNSt3__211__thread_idC2Ev"] = function() {
                return (__ZNSt3__211__thread_idC2Ev = Module["__ZNSt3__211__thread_idC2Ev"] = Module["asm"]["_ZNSt3__211__thread_idC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__221recursive_timed_mutexD2Ev = Module["__ZNSt3__221recursive_timed_mutexD2Ev"] = function() {
                return (__ZNSt3__221recursive_timed_mutexD2Ev = Module["__ZNSt3__221recursive_timed_mutexD2Ev"] = Module["asm"]["_ZNSt3__221recursive_timed_mutexD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__221recursive_timed_mutex4lockEv = Module["__ZNSt3__221recursive_timed_mutex4lockEv"] = function() {
                return (__ZNSt3__221recursive_timed_mutex4lockEv = Module["__ZNSt3__221recursive_timed_mutex4lockEv"] = Module["asm"]["_ZNSt3__221recursive_timed_mutex4lockEv"]).apply(null, arguments)
            };
            var __ZNSt3__211this_thread6get_idEv = Module["__ZNSt3__211this_thread6get_idEv"] = function() {
                return (__ZNSt3__211this_thread6get_idEv = Module["__ZNSt3__211this_thread6get_idEv"] = Module["asm"]["_ZNSt3__211this_thread6get_idEv"]).apply(null, arguments)
            };
            var __ZNSt3__2eqENS_11__thread_idES0_ = Module["__ZNSt3__2eqENS_11__thread_idES0_"] = function() {
                return (__ZNSt3__2eqENS_11__thread_idES0_ = Module["__ZNSt3__2eqENS_11__thread_idES0_"] = Module["asm"]["_ZNSt3__2eqENS_11__thread_idES0_"]).apply(null, arguments)
            };
            var __ZNSt3__214numeric_limitsImE3maxEv = Module["__ZNSt3__214numeric_limitsImE3maxEv"] = function() {
                return (__ZNSt3__214numeric_limitsImE3maxEv = Module["__ZNSt3__214numeric_limitsImE3maxEv"] = Module["asm"]["_ZNSt3__214numeric_limitsImE3maxEv"]).apply(null, arguments)
            };
            var __ZNSt3__230__libcpp_thread_get_current_idEv = Module["__ZNSt3__230__libcpp_thread_get_current_idEv"] = function() {
                return (__ZNSt3__230__libcpp_thread_get_current_idEv = Module["__ZNSt3__230__libcpp_thread_get_current_idEv"] = Module["asm"]["_ZNSt3__230__libcpp_thread_get_current_idEv"]).apply(null, arguments)
            };
            var __ZNSt3__211__thread_idC2Em = Module["__ZNSt3__211__thread_idC2Em"] = function() {
                return (__ZNSt3__211__thread_idC2Em = Module["__ZNSt3__211__thread_idC2Em"] = Module["asm"]["_ZNSt3__211__thread_idC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__224__libcpp_thread_id_equalEmm = Module["__ZNSt3__224__libcpp_thread_id_equalEmm"] = function() {
                return (__ZNSt3__224__libcpp_thread_id_equalEmm = Module["__ZNSt3__224__libcpp_thread_id_equalEmm"] = Module["asm"]["_ZNSt3__224__libcpp_thread_id_equalEmm"]).apply(null, arguments)
            };
            var __ZNSt3__223__libcpp_numeric_limitsImLb1EE3maxEv = Module["__ZNSt3__223__libcpp_numeric_limitsImLb1EE3maxEv"] = function() {
                return (__ZNSt3__223__libcpp_numeric_limitsImLb1EE3maxEv = Module["__ZNSt3__223__libcpp_numeric_limitsImLb1EE3maxEv"] = Module["asm"]["_ZNSt3__223__libcpp_numeric_limitsImLb1EE3maxEv"]).apply(null, arguments)
            };
            var __ZNSt3__221recursive_timed_mutex8try_lockEv = Module["__ZNSt3__221recursive_timed_mutex8try_lockEv"] = function() {
                return (__ZNSt3__221recursive_timed_mutex8try_lockEv = Module["__ZNSt3__221recursive_timed_mutex8try_lockEv"] = Module["asm"]["_ZNSt3__221recursive_timed_mutex8try_lockEv"]).apply(null, arguments)
            };
            var __ZNSt3__221recursive_timed_mutex6unlockEv = Module["__ZNSt3__221recursive_timed_mutex6unlockEv"] = function() {
                return (__ZNSt3__221recursive_timed_mutex6unlockEv = Module["__ZNSt3__221recursive_timed_mutex6unlockEv"] = Module["asm"]["_ZNSt3__221recursive_timed_mutex6unlockEv"]).apply(null, arguments)
            };
            var __ZNSt3__211__thread_id7__resetEv = Module["__ZNSt3__211__thread_id7__resetEv"] = function() {
                return (__ZNSt3__211__thread_id7__resetEv = Module["__ZNSt3__211__thread_id7__resetEv"] = Module["asm"]["_ZNSt3__211__thread_id7__resetEv"]).apply(null, arguments)
            };
            var __ZNSt3__211unique_lockINS_5mutexEE6unlockEv = Module["__ZNSt3__211unique_lockINS_5mutexEE6unlockEv"] = function() {
                return (__ZNSt3__211unique_lockINS_5mutexEE6unlockEv = Module["__ZNSt3__211unique_lockINS_5mutexEE6unlockEv"] = Module["asm"]["_ZNSt3__211unique_lockINS_5mutexEE6unlockEv"]).apply(null, arguments)
            };
            var __ZNSt3__211__call_onceERVmPvPFvS2_E = Module["__ZNSt3__211__call_onceERVmPvPFvS2_E"] = function() {
                return (__ZNSt3__211__call_onceERVmPvPFvS2_E = Module["__ZNSt3__211__call_onceERVmPvPFvS2_E"] = Module["asm"]["_ZNSt3__211__call_onceERVmPvPFvS2_E"]).apply(null, arguments)
            };
            var __ZNSt3__221__libcpp_condvar_waitEP14pthread_cond_tP15pthread_mutex_t = Module["__ZNSt3__221__libcpp_condvar_waitEP14pthread_cond_tP15pthread_mutex_t"] = function() {
                return (__ZNSt3__221__libcpp_condvar_waitEP14pthread_cond_tP15pthread_mutex_t = Module["__ZNSt3__221__libcpp_condvar_waitEP14pthread_cond_tP15pthread_mutex_t"] = Module["asm"]["_ZNSt3__221__libcpp_condvar_waitEP14pthread_cond_tP15pthread_mutex_t"]).apply(null, arguments)
            };
            var __ZNSt3__226__libcpp_condvar_broadcastEP14pthread_cond_t = Module["__ZNSt3__226__libcpp_condvar_broadcastEP14pthread_cond_t"] = function() {
                return (__ZNSt3__226__libcpp_condvar_broadcastEP14pthread_cond_t = Module["__ZNSt3__226__libcpp_condvar_broadcastEP14pthread_cond_t"] = Module["asm"]["_ZNSt3__226__libcpp_condvar_broadcastEP14pthread_cond_t"]).apply(null, arguments)
            };
            var __ZNSt3__215recursive_mutexC1Ev = Module["__ZNSt3__215recursive_mutexC1Ev"] = function() {
                return (__ZNSt3__215recursive_mutexC1Ev = Module["__ZNSt3__215recursive_mutexC1Ev"] = Module["asm"]["_ZNSt3__215recursive_mutexC1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215recursive_mutexD1Ev = Module["__ZNSt3__215recursive_mutexD1Ev"] = function() {
                return (__ZNSt3__215recursive_mutexD1Ev = Module["__ZNSt3__215recursive_mutexD1Ev"] = Module["asm"]["_ZNSt3__215recursive_mutexD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__211timed_mutexC1Ev = Module["__ZNSt3__211timed_mutexC1Ev"] = function() {
                return (__ZNSt3__211timed_mutexC1Ev = Module["__ZNSt3__211timed_mutexC1Ev"] = Module["asm"]["_ZNSt3__211timed_mutexC1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__211timed_mutexD1Ev = Module["__ZNSt3__211timed_mutexD1Ev"] = function() {
                return (__ZNSt3__211timed_mutexD1Ev = Module["__ZNSt3__211timed_mutexD1Ev"] = Module["asm"]["_ZNSt3__211timed_mutexD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__221recursive_timed_mutexC1Ev = Module["__ZNSt3__221recursive_timed_mutexC1Ev"] = function() {
                return (__ZNSt3__221recursive_timed_mutexC1Ev = Module["__ZNSt3__221recursive_timed_mutexC1Ev"] = Module["asm"]["_ZNSt3__221recursive_timed_mutexC1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__221recursive_timed_mutexD1Ev = Module["__ZNSt3__221recursive_timed_mutexD1Ev"] = function() {
                return (__ZNSt3__221recursive_timed_mutexD1Ev = Module["__ZNSt3__221recursive_timed_mutexD1Ev"] = Module["asm"]["_ZNSt3__221recursive_timed_mutexD1Ev"]).apply(null, arguments)
            };
            var __ZNSt11logic_errorC2ERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE = Module["__ZNSt11logic_errorC2ERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE"] = function() {
                return (__ZNSt11logic_errorC2ERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE = Module["__ZNSt11logic_errorC2ERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE"] = Module["asm"]["_ZNSt11logic_errorC2ERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNSt9exceptionC2Ev = Module["__ZNSt9exceptionC2Ev"] = function() {
                return (__ZNSt9exceptionC2Ev = Module["__ZNSt9exceptionC2Ev"] = Module["asm"]["_ZNSt9exceptionC2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5c_strEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5c_strEv"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5c_strEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5c_strEv"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5c_strEv"]).apply(null, arguments)
            };
            var __ZNSt3__218__libcpp_refstringC2EPKc = Module["__ZNSt3__218__libcpp_refstringC2EPKc"] = function() {
                return (__ZNSt3__218__libcpp_refstringC2EPKc = Module["__ZNSt3__218__libcpp_refstringC2EPKc"] = Module["asm"]["_ZNSt3__218__libcpp_refstringC2EPKc"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4dataEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4dataEv"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4dataEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4dataEv"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4dataEv"]).apply(null, arguments)
            };
            var __Znwm = Module["__Znwm"] = function() {
                return (__Znwm = Module["__Znwm"] = Module["asm"]["_Znwm"]).apply(null, arguments)
            };
            var __ZNSt11logic_errorC2EPKc = Module["__ZNSt11logic_errorC2EPKc"] = function() {
                return (__ZNSt11logic_errorC2EPKc = Module["__ZNSt11logic_errorC2EPKc"] = Module["asm"]["_ZNSt11logic_errorC2EPKc"]).apply(null, arguments)
            };
            var __ZNSt11logic_errorC2ERKS_ = Module["__ZNSt11logic_errorC2ERKS_"] = function() {
                return (__ZNSt11logic_errorC2ERKS_ = Module["__ZNSt11logic_errorC2ERKS_"] = Module["asm"]["_ZNSt11logic_errorC2ERKS_"]).apply(null, arguments)
            };
            var __ZNSt3__218__libcpp_refstringC2ERKS0_ = Module["__ZNSt3__218__libcpp_refstringC2ERKS0_"] = function() {
                return (__ZNSt3__218__libcpp_refstringC2ERKS0_ = Module["__ZNSt3__218__libcpp_refstringC2ERKS0_"] = Module["asm"]["_ZNSt3__218__libcpp_refstringC2ERKS0_"]).apply(null, arguments)
            };
            var __ZNKSt3__218__libcpp_refstring15__uses_refcountEv = Module["__ZNKSt3__218__libcpp_refstring15__uses_refcountEv"] = function() {
                return (__ZNKSt3__218__libcpp_refstring15__uses_refcountEv = Module["__ZNKSt3__218__libcpp_refstring15__uses_refcountEv"] = Module["asm"]["_ZNKSt3__218__libcpp_refstring15__uses_refcountEv"]).apply(null, arguments)
            };
            var __ZNSt11logic_erroraSERKS_ = Module["__ZNSt11logic_erroraSERKS_"] = function() {
                return (__ZNSt11logic_erroraSERKS_ = Module["__ZNSt11logic_erroraSERKS_"] = Module["asm"]["_ZNSt11logic_erroraSERKS_"]).apply(null, arguments)
            };
            var __ZNSt3__218__libcpp_refstringaSERKS0_ = Module["__ZNSt3__218__libcpp_refstringaSERKS0_"] = function() {
                return (__ZNSt3__218__libcpp_refstringaSERKS0_ = Module["__ZNSt3__218__libcpp_refstringaSERKS0_"] = Module["asm"]["_ZNSt3__218__libcpp_refstringaSERKS0_"]).apply(null, arguments)
            };
            var __ZNSt13runtime_errorC2ERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE = Module["__ZNSt13runtime_errorC2ERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE"] = function() {
                return (__ZNSt13runtime_errorC2ERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE = Module["__ZNSt13runtime_errorC2ERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE"] = Module["asm"]["_ZNSt13runtime_errorC2ERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNSt13runtime_errorC2EPKc = Module["__ZNSt13runtime_errorC2EPKc"] = function() {
                return (__ZNSt13runtime_errorC2EPKc = Module["__ZNSt13runtime_errorC2EPKc"] = Module["asm"]["_ZNSt13runtime_errorC2EPKc"]).apply(null, arguments)
            };
            var __ZNSt13runtime_errorC2ERKS_ = Module["__ZNSt13runtime_errorC2ERKS_"] = function() {
                return (__ZNSt13runtime_errorC2ERKS_ = Module["__ZNSt13runtime_errorC2ERKS_"] = Module["asm"]["_ZNSt13runtime_errorC2ERKS_"]).apply(null, arguments)
            };
            var __ZNSt13runtime_erroraSERKS_ = Module["__ZNSt13runtime_erroraSERKS_"] = function() {
                return (__ZNSt13runtime_erroraSERKS_ = Module["__ZNSt13runtime_erroraSERKS_"] = Module["asm"]["_ZNSt13runtime_erroraSERKS_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE13__get_pointerEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE13__get_pointerEv"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE13__get_pointerEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE13__get_pointerEv"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE13__get_pointerEv"]).apply(null, arguments)
            };
            var __ZNSt3__212__to_addressIKcEEPT_S3_ = Module["__ZNSt3__212__to_addressIKcEEPT_S3_"] = function() {
                return (__ZNSt3__212__to_addressIKcEEPT_S3_ = Module["__ZNSt3__212__to_addressIKcEEPT_S3_"] = Module["asm"]["_ZNSt3__212__to_addressIKcEEPT_S3_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__is_longEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__is_longEv"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__is_longEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__is_longEv"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__is_longEv"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE18__get_long_pointerEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE18__get_long_pointerEv"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE18__get_long_pointerEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE18__get_long_pointerEv"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE18__get_long_pointerEv"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__get_short_pointerEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__get_short_pointerEv"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__get_short_pointerEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__get_short_pointerEv"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__get_short_pointerEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_E5firstEv = Module["__ZNKSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_E5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_E5firstEv = Module["__ZNKSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_E5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_E5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__214pointer_traitsIPKcE10pointer_toERS1_ = Module["__ZNSt3__214pointer_traitsIPKcE10pointer_toERS1_"] = function() {
                return (__ZNSt3__214pointer_traitsIPKcE10pointer_toERS1_ = Module["__ZNSt3__214pointer_traitsIPKcE10pointer_toERS1_"] = Module["asm"]["_ZNSt3__214pointer_traitsIPKcE10pointer_toERS1_"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repELi0ELb0EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repELi0ELb0EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__29addressofIKcEEPT_RS2_ = Module["__ZNSt3__29addressofIKcEEPT_RS2_"] = function() {
                return (__ZNSt3__29addressofIKcEEPT_RS2_ = Module["__ZNSt3__29addressofIKcEEPT_RS2_"] = Module["asm"]["_ZNSt3__29addressofIKcEEPT_RS2_"]).apply(null, arguments)
            };
            var __ZNSt11logic_errorC1ERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE = Module["__ZNSt11logic_errorC1ERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE"] = function() {
                return (__ZNSt11logic_errorC1ERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE = Module["__ZNSt11logic_errorC1ERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE"] = Module["asm"]["_ZNSt11logic_errorC1ERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNSt11logic_errorC1EPKc = Module["__ZNSt11logic_errorC1EPKc"] = function() {
                return (__ZNSt11logic_errorC1EPKc = Module["__ZNSt11logic_errorC1EPKc"] = Module["asm"]["_ZNSt11logic_errorC1EPKc"]).apply(null, arguments)
            };
            var __ZNSt11logic_errorC1ERKS_ = Module["__ZNSt11logic_errorC1ERKS_"] = function() {
                return (__ZNSt11logic_errorC1ERKS_ = Module["__ZNSt11logic_errorC1ERKS_"] = Module["asm"]["_ZNSt11logic_errorC1ERKS_"]).apply(null, arguments)
            };
            var __ZNSt13runtime_errorC1ERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE = Module["__ZNSt13runtime_errorC1ERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE"] = function() {
                return (__ZNSt13runtime_errorC1ERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE = Module["__ZNSt13runtime_errorC1ERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE"] = Module["asm"]["_ZNSt13runtime_errorC1ERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNSt13runtime_errorC1EPKc = Module["__ZNSt13runtime_errorC1EPKc"] = function() {
                return (__ZNSt13runtime_errorC1EPKc = Module["__ZNSt13runtime_errorC1EPKc"] = Module["asm"]["_ZNSt13runtime_errorC1EPKc"]).apply(null, arguments)
            };
            var __ZNSt13runtime_errorC1ERKS_ = Module["__ZNSt13runtime_errorC1ERKS_"] = function() {
                return (__ZNSt13runtime_errorC1ERKS_ = Module["__ZNSt13runtime_errorC1ERKS_"] = Module["asm"]["_ZNSt13runtime_errorC1ERKS_"]).apply(null, arguments)
            };
            var __ZNSt3__25mutexD2Ev = Module["__ZNSt3__25mutexD2Ev"] = function() {
                return (__ZNSt3__25mutexD2Ev = Module["__ZNSt3__25mutexD2Ev"] = Module["asm"]["_ZNSt3__25mutexD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__222__libcpp_mutex_destroyEP15pthread_mutex_t = Module["__ZNSt3__222__libcpp_mutex_destroyEP15pthread_mutex_t"] = function() {
                return (__ZNSt3__222__libcpp_mutex_destroyEP15pthread_mutex_t = Module["__ZNSt3__222__libcpp_mutex_destroyEP15pthread_mutex_t"] = Module["asm"]["_ZNSt3__222__libcpp_mutex_destroyEP15pthread_mutex_t"]).apply(null, arguments)
            };
            var __ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv = Module["__ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv"] = function() {
                return (__ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv = Module["__ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv"] = Module["asm"]["_ZNKSt3__221__basic_string_commonILb1EE20__throw_length_errorEv"]).apply(null, arguments)
            };
            var __ZNSt3__220__throw_length_errorEPKc = Module["__ZNSt3__220__throw_length_errorEPKc"] = function() {
                return (__ZNSt3__220__throw_length_errorEPKc = Module["__ZNSt3__220__throw_length_errorEPKc"] = Module["asm"]["_ZNSt3__220__throw_length_errorEPKc"]).apply(null, arguments)
            };
            var __ZNKSt3__221__basic_string_commonILb1EE20__throw_out_of_rangeEv = Module["__ZNKSt3__221__basic_string_commonILb1EE20__throw_out_of_rangeEv"] = function() {
                return (__ZNKSt3__221__basic_string_commonILb1EE20__throw_out_of_rangeEv = Module["__ZNKSt3__221__basic_string_commonILb1EE20__throw_out_of_rangeEv"] = Module["asm"]["_ZNKSt3__221__basic_string_commonILb1EE20__throw_out_of_rangeEv"]).apply(null, arguments)
            };
            var __ZNSt3__220__throw_out_of_rangeEPKc = Module["__ZNSt3__220__throw_out_of_rangeEPKc"] = function() {
                return (__ZNSt3__220__throw_out_of_rangeEPKc = Module["__ZNSt3__220__throw_out_of_rangeEPKc"] = Module["asm"]["_ZNSt3__220__throw_out_of_rangeEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7__allocEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7__allocEv"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7__allocEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7__allocEv"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7__allocEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorIcEEE37select_on_container_copy_constructionERKS2_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIcEEE37select_on_container_copy_constructionERKS2_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorIcEEE37select_on_container_copy_constructionERKS2_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIcEEE37select_on_container_copy_constructionERKS2_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorIcEEE37select_on_container_copy_constructionERKS2_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_EC2INS_18__default_init_tagES5_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_EC2INS_18__default_init_tagES5_EEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_EC2INS_18__default_init_tagES5_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_EC2INS_18__default_init_tagES5_EEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_EC2INS_18__default_init_tagES5_EEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_E5firstEv = Module["__ZNSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_E5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_E5firstEv = Module["__ZNSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_E5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_E5firstEv"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE15__get_long_sizeEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE15__get_long_sizeEv"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE15__get_long_sizeEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE15__get_long_sizeEv"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE15__get_long_sizeEv"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcm"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorIcEEE39__select_on_container_copy_constructionENS_17integral_constantIbLb0EEERKS2_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIcEEE39__select_on_container_copy_constructionENS_17integral_constantIbLb0EEERKS2_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorIcEEE39__select_on_container_copy_constructionENS_17integral_constantIbLb0EEERKS2_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIcEEE39__select_on_container_copy_constructionENS_17integral_constantIbLb0EEERKS2_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorIcEEE39__select_on_container_copy_constructionENS_17integral_constantIbLb0EEERKS2_"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_E6secondEv = Module["__ZNKSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_E6secondEv"] = function() {
                return (__ZNKSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_E6secondEv = Module["__ZNKSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_E6secondEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_E6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardINS_18__default_init_tagEEEOT_RNS_16remove_referenceIS2_E4typeE = Module["__ZNSt3__27forwardINS_18__default_init_tagEEEOT_RNS_16remove_referenceIS2_E4typeE"] = function() {
                return (__ZNSt3__27forwardINS_18__default_init_tagEEEOT_RNS_16remove_referenceIS2_E4typeE = Module["__ZNSt3__27forwardINS_18__default_init_tagEEEOT_RNS_16remove_referenceIS2_E4typeE"] = Module["asm"]["_ZNSt3__27forwardINS_18__default_init_tagEEEOT_RNS_16remove_referenceIS2_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repELi0ELb0EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repELi0ELb0EEC2ENS_18__default_init_tagE"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repELi0ELb0EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repELi0ELb0EEC2ENS_18__default_init_tagE"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repELi0ELb0EEC2ENS_18__default_init_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardINS_9allocatorIcEEEEOT_RNS_16remove_referenceIS3_E4typeE = Module["__ZNSt3__27forwardINS_9allocatorIcEEEEOT_RNS_16remove_referenceIS3_E4typeE"] = function() {
                return (__ZNSt3__27forwardINS_9allocatorIcEEEEOT_RNS_16remove_referenceIS3_E4typeE = Module["__ZNSt3__27forwardINS_9allocatorIcEEEEOT_RNS_16remove_referenceIS3_E4typeE"] = Module["asm"]["_ZNSt3__27forwardINS_9allocatorIcEEEEOT_RNS_16remove_referenceIS3_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_9allocatorIcEELi1ELb1EEC2IS2_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorIcEELi1ELb1EEC2IS2_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_9allocatorIcEELi1ELb1EEC2IS2_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorIcEELi1ELb1EEC2IS2_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_9allocatorIcEELi1ELb1EEC2IS2_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repELi0ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repELi0ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE8max_sizeEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE8max_sizeEv"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE8max_sizeEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE8max_sizeEv"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE8max_sizeEv"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE16__set_short_sizeEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE16__set_short_sizeEm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE16__set_short_sizeEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE16__set_short_sizeEm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE16__set_short_sizeEm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__get_short_pointerEv = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__get_short_pointerEv"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__get_short_pointerEv = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__get_short_pointerEv"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__get_short_pointerEv"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE11__recommendEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE11__recommendEm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE11__recommendEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE11__recommendEm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE11__recommendEm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7__allocEv = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7__allocEv"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7__allocEv = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7__allocEv"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7__allocEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorIcEEE8allocateERS2_m = Module["__ZNSt3__216allocator_traitsINS_9allocatorIcEEE8allocateERS2_m"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorIcEEE8allocateERS2_m = Module["__ZNSt3__216allocator_traitsINS_9allocatorIcEEE8allocateERS2_m"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorIcEEE8allocateERS2_m"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE18__set_long_pointerEPc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE18__set_long_pointerEPc"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE18__set_long_pointerEPc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE18__set_long_pointerEPc"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE18__set_long_pointerEPc"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE14__set_long_capEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE14__set_long_capEm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE14__set_long_capEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE14__set_long_capEm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE14__set_long_capEm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE15__set_long_sizeEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE15__set_long_sizeEm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE15__set_long_sizeEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE15__set_long_sizeEm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE15__set_long_sizeEm"]).apply(null, arguments)
            };
            var __ZNSt3__212__to_addressIcEEPT_S2_ = Module["__ZNSt3__212__to_addressIcEEPT_S2_"] = function() {
                return (__ZNSt3__212__to_addressIcEEPT_S2_ = Module["__ZNSt3__212__to_addressIcEEPT_S2_"] = Module["asm"]["_ZNSt3__212__to_addressIcEEPT_S2_"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIcE4copyEPcPKcm = Module["__ZNSt3__211char_traitsIcE4copyEPcPKcm"] = function() {
                return (__ZNSt3__211char_traitsIcE4copyEPcPKcm = Module["__ZNSt3__211char_traitsIcE4copyEPcPKcm"] = Module["asm"]["_ZNSt3__211char_traitsIcE4copyEPcPKcm"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIcE6assignERcRKc = Module["__ZNSt3__211char_traitsIcE6assignERcRKc"] = function() {
                return (__ZNSt3__211char_traitsIcE6assignERcRKc = Module["__ZNSt3__211char_traitsIcE6assignERcRKc"] = Module["asm"]["_ZNSt3__211char_traitsIcE6assignERcRKc"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_RKS4_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_RKS4_"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_RKS4_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_RKS4_"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_RKS4_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_EC2INS_18__default_init_tagERKS5_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_EC2INS_18__default_init_tagERKS5_EEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_EC2INS_18__default_init_tagERKS5_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_EC2INS_18__default_init_tagERKS5_EEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_EC2INS_18__default_init_tagERKS5_EEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRKNS_9allocatorIcEEEEOT_RNS_16remove_referenceIS5_E4typeE = Module["__ZNSt3__27forwardIRKNS_9allocatorIcEEEEOT_RNS_16remove_referenceIS5_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRKNS_9allocatorIcEEEEOT_RNS_16remove_referenceIS5_E4typeE = Module["__ZNSt3__27forwardIRKNS_9allocatorIcEEEEOT_RNS_16remove_referenceIS5_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRKNS_9allocatorIcEEEEOT_RNS_16remove_referenceIS5_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_9allocatorIcEELi1ELb1EEC2IRKS2_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorIcEELi1ELb1EEC2IRKS2_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_9allocatorIcEELi1ELb1EEC2IRKS2_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorIcEELi1ELb1EEC2IRKS2_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_9allocatorIcEELi1ELb1EEC2IRKS2_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_mmRKS4_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_mmRKS4_"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_mmRKS4_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_mmRKS4_"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS5_mmRKS4_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4sizeEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4sizeEv"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4sizeEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4sizeEv"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4sizeEv"]).apply(null, arguments)
            };
            var __ZNSt3__23minImEERKT_S3_S3_ = Module["__ZNSt3__23minImEERKT_S3_S3_"] = function() {
                return (__ZNSt3__23minImEERKT_S3_S3_ = Module["__ZNSt3__23minImEERKT_S3_S3_"] = Module["asm"]["_ZNSt3__23minImEERKT_S3_S3_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE16__get_short_sizeEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE16__get_short_sizeEv"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE16__get_short_sizeEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE16__get_short_sizeEv"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE16__get_short_sizeEv"]).apply(null, arguments)
            };
            var __ZNSt3__23minImNS_6__lessImmEEEERKT_S5_S5_T0_ = Module["__ZNSt3__23minImNS_6__lessImmEEEERKT_S5_S5_T0_"] = function() {
                return (__ZNSt3__23minImNS_6__lessImmEEEERKT_S5_S5_T0_ = Module["__ZNSt3__23minImNS_6__lessImmEEEERKT_S5_S5_T0_"] = Module["asm"]["_ZNSt3__23minImNS_6__lessImmEEEERKT_S5_S5_T0_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE18__get_long_pointerEv = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE18__get_long_pointerEv"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE18__get_long_pointerEv = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE18__get_long_pointerEv"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE18__get_long_pointerEv"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE14__get_long_capEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE14__get_long_capEv"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE14__get_long_capEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE14__get_long_capEv"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE14__get_long_capEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorIcEEE10deallocateERS2_Pcm = Module["__ZNSt3__216allocator_traitsINS_9allocatorIcEEE10deallocateERS2_Pcm"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorIcEEE10deallocateERS2_Pcm = Module["__ZNSt3__216allocator_traitsINS_9allocatorIcEEE10deallocateERS2_Pcm"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorIcEEE10deallocateERS2_Pcm"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorIcE10deallocateEPcm = Module["__ZNSt3__29allocatorIcE10deallocateEPcm"] = function() {
                return (__ZNSt3__29allocatorIcE10deallocateEPcm = Module["__ZNSt3__29allocatorIcE10deallocateEPcm"] = Module["asm"]["_ZNSt3__29allocatorIcE10deallocateEPcm"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_E6secondEv = Module["__ZNSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_E6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_E6secondEv = Module["__ZNSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_E6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_E6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSERKS5_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__copy_assign_allocERKS5_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__copy_assign_allocERKS5_"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__copy_assign_allocERKS5_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__copy_assign_allocERKS5_"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__copy_assign_allocERKS5_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKcm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKcm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKcm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKcm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKcm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__copy_assign_allocERKS5_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__copy_assign_allocERKS5_NS_17integral_constantIbLb0EEE"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__copy_assign_allocERKS5_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__copy_assign_allocERKS5_NS_17integral_constantIbLb0EEE"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__copy_assign_allocERKS5_NS_17integral_constantIbLb0EEE"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE8capacityEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE8capacityEv"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE8capacityEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE8capacityEv"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE8capacityEv"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE13__get_pointerEv = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE13__get_pointerEv"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE13__get_pointerEv = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE13__get_pointerEv"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE13__get_pointerEv"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIcE4moveEPcPKcm = Module["__ZNSt3__211char_traitsIcE4moveEPcPKcm"] = function() {
                return (__ZNSt3__211char_traitsIcE4moveEPcPKcm = Module["__ZNSt3__211char_traitsIcE4moveEPcPKcm"] = Module["asm"]["_ZNSt3__211char_traitsIcE4moveEPcPKcm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE10__set_sizeEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE10__set_sizeEm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE10__set_sizeEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE10__set_sizeEm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE10__set_sizeEm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE27__invalidate_iterators_pastEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE27__invalidate_iterators_pastEm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE27__invalidate_iterators_pastEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE27__invalidate_iterators_pastEm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE27__invalidate_iterators_pastEm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__grow_by_and_replaceEmmmmmmPKc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__grow_by_and_replaceEmmmmmmPKc"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__grow_by_and_replaceEmmmmmmPKc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__grow_by_and_replaceEmmmmmmPKc"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__grow_by_and_replaceEmmmmmmPKc"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSEc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSEc"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSEc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSEc"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSEc"]).apply(null, arguments)
            };
            var __ZNSt3__214pointer_traitsIPcE10pointer_toERc = Module["__ZNSt3__214pointer_traitsIPcE10pointer_toERc"] = function() {
                return (__ZNSt3__214pointer_traitsIPcE10pointer_toERc = Module["__ZNSt3__214pointer_traitsIPcE10pointer_toERc"] = Module["asm"]["_ZNSt3__214pointer_traitsIPcE10pointer_toERc"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEmc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEmc"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEmc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEmc"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEmc"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEmc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEmc"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEmc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEmc"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEmc"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE14__erase_to_endEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE14__erase_to_endEm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE14__erase_to_endEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE14__erase_to_endEm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE14__erase_to_endEm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__grow_byEmmmmmm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__grow_byEmmmmmm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__grow_byEmmmmmm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__grow_byEmmmmmm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9__grow_byEmmmmmm"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIcE6assignEPcmc = Module["__ZNSt3__211char_traitsIcE6assignEPcmc"] = function() {
                return (__ZNSt3__211char_traitsIcE6assignEPcmc = Module["__ZNSt3__211char_traitsIcE6assignEPcmc"] = Module["asm"]["_ZNSt3__211char_traitsIcE6assignEPcmc"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7reserveEm"]).apply(null, arguments)
            };
            var __ZNSt3__23maxImEERKT_S3_S3_ = Module["__ZNSt3__23maxImEERKT_S3_S3_"] = function() {
                return (__ZNSt3__23maxImEERKT_S3_S3_ = Module["__ZNSt3__23maxImEERKT_S3_S3_"] = Module["asm"]["_ZNSt3__23maxImEERKT_S3_S3_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE26__invalidate_all_iteratorsEv = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE26__invalidate_all_iteratorsEv"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE26__invalidate_all_iteratorsEv = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE26__invalidate_all_iteratorsEv"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE26__invalidate_all_iteratorsEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorIcEEE8max_sizeERKS2_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIcEEE8max_sizeERKS2_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorIcEEE8max_sizeERKS2_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIcEEE8max_sizeERKS2_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorIcEEE8max_sizeERKS2_"]).apply(null, arguments)
            };
            var __ZNSt3__23maxImNS_6__lessImmEEEERKT_S5_S5_T0_ = Module["__ZNSt3__23maxImNS_6__lessImmEEEERKT_S5_S5_T0_"] = function() {
                return (__ZNSt3__23maxImNS_6__lessImmEEEERKT_S5_S5_T0_ = Module["__ZNSt3__23maxImNS_6__lessImmEEEERKT_S5_S5_T0_"] = Module["asm"]["_ZNSt3__23maxImNS_6__lessImmEEEERKT_S5_S5_T0_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE10__align_itILm16EEEmm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE10__align_itILm16EEEmm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE10__align_itILm16EEEmm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE10__align_itILm16EEEmm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE10__align_itILm16EEEmm"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorIcE8allocateEmPKv = Module["__ZNSt3__29allocatorIcE8allocateEmPKv"] = function() {
                return (__ZNSt3__29allocatorIcE8allocateEmPKv = Module["__ZNSt3__29allocatorIcE8allocateEmPKv"] = Module["asm"]["_ZNSt3__29allocatorIcE8allocateEmPKv"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE2atEm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE2atEm"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE2atEm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE2atEm"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE2atEm"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEixEm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEixEm"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEixEm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEixEm"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEixEm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE2atEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE2atEm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE2atEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE2atEm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE2atEm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEixEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEixEm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEixEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEixEm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEixEm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendERKS5_mm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendERKS5_mm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendERKS5_mm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendERKS5_mm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendERKS5_mm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKcm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIcE6lengthEPKc = Module["__ZNSt3__211char_traitsIcE6lengthEPKc"] = function() {
                return (__ZNSt3__211char_traitsIcE6lengthEPKc = Module["__ZNSt3__211char_traitsIcE6lengthEPKc"] = Module["asm"]["_ZNSt3__211char_traitsIcE6lengthEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIcE11to_int_typeEc = Module["__ZNSt3__211char_traitsIcE11to_int_typeEc"] = function() {
                return (__ZNSt3__211char_traitsIcE11to_int_typeEc = Module["__ZNSt3__211char_traitsIcE11to_int_typeEc"] = Module["asm"]["_ZNSt3__211char_traitsIcE11to_int_typeEc"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE9push_backEc"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignERKS5_mm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignERKS5_mm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignERKS5_mm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignERKS5_mm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignERKS5_mm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEmc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEmc"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEmc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEmc"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6assignEmc"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEmRKS5_mm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEmRKS5_mm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEmRKS5_mm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEmRKS5_mm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEmRKS5_mm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEmPKcm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEmPKcm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEmPKcm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEmPKcm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEmPKcm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEmPKc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEmPKc"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEmPKc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEmPKc"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEmPKc"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEmmc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEmmc"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEmmc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEmmc"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertEmmc"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertENS_11__wrap_iterIPKcEEc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertENS_11__wrap_iterIPKcEEc"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertENS_11__wrap_iterIPKcEEc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertENS_11__wrap_iterIPKcEEc"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6insertENS_11__wrap_iterIPKcEEc"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5beginEv = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5beginEv"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5beginEv = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5beginEv"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5beginEv"]).apply(null, arguments)
            };
            var __ZNSt3__2miIPKcPcEEDTmicldtfp_4baseEcldtfp0_4baseEERKNS_11__wrap_iterIT_EERKNS5_IT0_EE = Module["__ZNSt3__2miIPKcPcEEDTmicldtfp_4baseEcldtfp0_4baseEERKNS_11__wrap_iterIT_EERKNS5_IT0_EE"] = function() {
                return (__ZNSt3__2miIPKcPcEEDTmicldtfp_4baseEcldtfp0_4baseEERKNS_11__wrap_iterIT_EERKNS5_IT0_EE = Module["__ZNSt3__2miIPKcPcEEDTmicldtfp_4baseEcldtfp0_4baseEERKNS_11__wrap_iterIT_EERKNS5_IT0_EE"] = Module["asm"]["_ZNSt3__2miIPKcPcEEDTmicldtfp_4baseEcldtfp0_4baseEERKNS_11__wrap_iterIT_EERKNS5_IT0_EE"]).apply(null, arguments)
            };
            var __ZNKSt3__211__wrap_iterIPcEplEl = Module["__ZNKSt3__211__wrap_iterIPcEplEl"] = function() {
                return (__ZNKSt3__211__wrap_iterIPcEplEl = Module["__ZNKSt3__211__wrap_iterIPcEplEl"] = Module["asm"]["_ZNKSt3__211__wrap_iterIPcEplEl"]).apply(null, arguments)
            };
            var __ZNKSt3__211__wrap_iterIPKcE4baseEv = Module["__ZNKSt3__211__wrap_iterIPKcE4baseEv"] = function() {
                return (__ZNKSt3__211__wrap_iterIPKcE4baseEv = Module["__ZNKSt3__211__wrap_iterIPKcE4baseEv"] = Module["asm"]["_ZNKSt3__211__wrap_iterIPKcE4baseEv"]).apply(null, arguments)
            };
            var __ZNKSt3__211__wrap_iterIPcE4baseEv = Module["__ZNKSt3__211__wrap_iterIPcE4baseEv"] = function() {
                return (__ZNKSt3__211__wrap_iterIPcE4baseEv = Module["__ZNKSt3__211__wrap_iterIPcE4baseEv"] = Module["asm"]["_ZNKSt3__211__wrap_iterIPcE4baseEv"]).apply(null, arguments)
            };
            var __ZNSt3__211__wrap_iterIPcEC2ES1_ = Module["__ZNSt3__211__wrap_iterIPcEC2ES1_"] = function() {
                return (__ZNSt3__211__wrap_iterIPcEC2ES1_ = Module["__ZNSt3__211__wrap_iterIPcEC2ES1_"] = Module["asm"]["_ZNSt3__211__wrap_iterIPcEC2ES1_"]).apply(null, arguments)
            };
            var __ZNSt3__211__wrap_iterIPcEpLEl = Module["__ZNSt3__211__wrap_iterIPcEpLEl"] = function() {
                return (__ZNSt3__211__wrap_iterIPcEpLEl = Module["__ZNSt3__211__wrap_iterIPcEpLEl"] = Module["asm"]["_ZNSt3__211__wrap_iterIPcEpLEl"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5eraseEmm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5eraseEmm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5eraseEmm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5eraseEmm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5eraseEmm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7replaceEmmRKS5_mm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7replaceEmmRKS5_mm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7replaceEmmRKS5_mm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7replaceEmmRKS5_mm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7replaceEmmRKS5_mm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7replaceEmmPKcm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7replaceEmmPKcm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7replaceEmmPKcm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7replaceEmmPKcm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7replaceEmmPKcm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7replaceEmmPKc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7replaceEmmPKc"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7replaceEmmPKc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7replaceEmmPKc"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7replaceEmmPKc"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7replaceEmmmc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7replaceEmmmc"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7replaceEmmmc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7replaceEmmmc"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7replaceEmmmc"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4copyEPcmm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4copyEPcmm"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4copyEPcmm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4copyEPcmm"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4copyEPcmm"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4findEPKcmm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4findEPKcmm"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4findEPKcmm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4findEPKcmm"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4findEPKcmm"]).apply(null, arguments)
            };
            var __ZNSt3__210__str_findIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_ = Module["__ZNSt3__210__str_findIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_"] = function() {
                return (__ZNSt3__210__str_findIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_ = Module["__ZNSt3__210__str_findIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_"] = Module["asm"]["_ZNSt3__210__str_findIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_"]).apply(null, arguments)
            };
            var __ZNSt3__218__search_substringIcNS_11char_traitsIcEEEEPKT_S5_S5_S5_S5_ = Module["__ZNSt3__218__search_substringIcNS_11char_traitsIcEEEEPKT_S5_S5_S5_S5_"] = function() {
                return (__ZNSt3__218__search_substringIcNS_11char_traitsIcEEEEPKT_S5_S5_S5_S5_ = Module["__ZNSt3__218__search_substringIcNS_11char_traitsIcEEEEPKT_S5_S5_S5_S5_"] = Module["asm"]["_ZNSt3__218__search_substringIcNS_11char_traitsIcEEEEPKT_S5_S5_S5_S5_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4findEcm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4findEcm"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4findEcm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4findEcm"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4findEcm"]).apply(null, arguments)
            };
            var __ZNSt3__210__str_findIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S4_S3_ = Module["__ZNSt3__210__str_findIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S4_S3_"] = function() {
                return (__ZNSt3__210__str_findIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S4_S3_ = Module["__ZNSt3__210__str_findIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S4_S3_"] = Module["asm"]["_ZNSt3__210__str_findIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S4_S3_"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIcE4findEPKcmRS2_ = Module["__ZNSt3__211char_traitsIcE4findEPKcmRS2_"] = function() {
                return (__ZNSt3__211char_traitsIcE4findEPKcmRS2_ = Module["__ZNSt3__211char_traitsIcE4findEPKcmRS2_"] = Module["asm"]["_ZNSt3__211char_traitsIcE4findEPKcmRS2_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5rfindEPKcmm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5rfindEPKcmm"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5rfindEPKcmm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5rfindEPKcmm"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5rfindEPKcmm"]).apply(null, arguments)
            };
            var __ZNSt3__211__str_rfindIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_ = Module["__ZNSt3__211__str_rfindIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_"] = function() {
                return (__ZNSt3__211__str_rfindIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_ = Module["__ZNSt3__211__str_rfindIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_"] = Module["asm"]["_ZNSt3__211__str_rfindIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIcE2eqEcc = Module["__ZNSt3__211char_traitsIcE2eqEcc"] = function() {
                return (__ZNSt3__211char_traitsIcE2eqEcc = Module["__ZNSt3__211char_traitsIcE2eqEcc"] = Module["asm"]["_ZNSt3__211char_traitsIcE2eqEcc"]).apply(null, arguments)
            };
            var __ZNSt3__210__find_endIPFbccEPKcS4_EET0_S5_S5_T1_S6_T_NS_26random_access_iterator_tagES8_ = Module["__ZNSt3__210__find_endIPFbccEPKcS4_EET0_S5_S5_T1_S6_T_NS_26random_access_iterator_tagES8_"] = function() {
                return (__ZNSt3__210__find_endIPFbccEPKcS4_EET0_S5_S5_T1_S6_T_NS_26random_access_iterator_tagES8_ = Module["__ZNSt3__210__find_endIPFbccEPKcS4_EET0_S5_S5_T1_S6_T_NS_26random_access_iterator_tagES8_"] = Module["asm"]["_ZNSt3__210__find_endIPFbccEPKcS4_EET0_S5_S5_T1_S6_T_NS_26random_access_iterator_tagES8_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5rfindEcm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5rfindEcm"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5rfindEcm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5rfindEcm"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5rfindEcm"]).apply(null, arguments)
            };
            var __ZNSt3__211__str_rfindIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S4_S3_ = Module["__ZNSt3__211__str_rfindIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S4_S3_"] = function() {
                return (__ZNSt3__211__str_rfindIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S4_S3_ = Module["__ZNSt3__211__str_rfindIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S4_S3_"] = Module["asm"]["_ZNSt3__211__str_rfindIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S4_S3_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE13find_first_ofEPKcmm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE13find_first_ofEPKcmm"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE13find_first_ofEPKcmm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE13find_first_ofEPKcmm"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE13find_first_ofEPKcmm"]).apply(null, arguments)
            };
            var __ZNSt3__219__str_find_first_ofIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_ = Module["__ZNSt3__219__str_find_first_ofIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_"] = function() {
                return (__ZNSt3__219__str_find_first_ofIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_ = Module["__ZNSt3__219__str_find_first_ofIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_"] = Module["asm"]["_ZNSt3__219__str_find_first_ofIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_"]).apply(null, arguments)
            };
            var __ZNSt3__218__find_first_of_ceIPKcS2_PFbccEEET_S5_S5_T0_S6_T1_ = Module["__ZNSt3__218__find_first_of_ceIPKcS2_PFbccEEET_S5_S5_T0_S6_T1_"] = function() {
                return (__ZNSt3__218__find_first_of_ceIPKcS2_PFbccEEET_S5_S5_T0_S6_T1_ = Module["__ZNSt3__218__find_first_of_ceIPKcS2_PFbccEEET_S5_S5_T0_S6_T1_"] = Module["asm"]["_ZNSt3__218__find_first_of_ceIPKcS2_PFbccEEET_S5_S5_T0_S6_T1_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE12find_last_ofEPKcmm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE12find_last_ofEPKcmm"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE12find_last_ofEPKcmm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE12find_last_ofEPKcmm"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE12find_last_ofEPKcmm"]).apply(null, arguments)
            };
            var __ZNSt3__218__str_find_last_ofIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_ = Module["__ZNSt3__218__str_find_last_ofIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_"] = function() {
                return (__ZNSt3__218__str_find_last_ofIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_ = Module["__ZNSt3__218__str_find_last_ofIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_"] = Module["asm"]["_ZNSt3__218__str_find_last_ofIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE17find_first_not_ofEPKcmm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE17find_first_not_ofEPKcmm"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE17find_first_not_ofEPKcmm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE17find_first_not_ofEPKcmm"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE17find_first_not_ofEPKcmm"]).apply(null, arguments)
            };
            var __ZNSt3__223__str_find_first_not_ofIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_ = Module["__ZNSt3__223__str_find_first_not_ofIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_"] = function() {
                return (__ZNSt3__223__str_find_first_not_ofIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_ = Module["__ZNSt3__223__str_find_first_not_ofIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_"] = Module["asm"]["_ZNSt3__223__str_find_first_not_ofIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE16find_last_not_ofEPKcmm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE16find_last_not_ofEPKcmm"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE16find_last_not_ofEPKcmm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE16find_last_not_ofEPKcmm"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE16find_last_not_ofEPKcmm"]).apply(null, arguments)
            };
            var __ZNSt3__222__str_find_last_not_ofIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_ = Module["__ZNSt3__222__str_find_last_not_ofIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_"] = function() {
                return (__ZNSt3__222__str_find_last_not_ofIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_ = Module["__ZNSt3__222__str_find_last_not_ofIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_"] = Module["asm"]["_ZNSt3__222__str_find_last_not_ofIcmNS_11char_traitsIcEELm4294967295EEET0_PKT_S3_S6_S3_S3_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEmmRKS5_mm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEmmRKS5_mm"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEmmRKS5_mm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEmmRKS5_mm"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEmmRKS5_mm"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEcvNS_17basic_string_viewIcS2_EEEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEcvNS_17basic_string_viewIcS2_EEEv"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEcvNS_17basic_string_viewIcS2_EEEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEcvNS_17basic_string_viewIcS2_EEEv"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEcvNS_17basic_string_viewIcS2_EEEv"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareINS_17basic_string_viewIcS2_EEEENS_9enable_ifIXsr33__can_be_converted_to_string_viewIcS2_T_EE5valueEiE4typeEmmRKSA_mm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareINS_17basic_string_viewIcS2_EEEENS_9enable_ifIXsr33__can_be_converted_to_string_viewIcS2_T_EE5valueEiE4typeEmmRKSA_mm"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareINS_17basic_string_viewIcS2_EEEENS_9enable_ifIXsr33__can_be_converted_to_string_viewIcS2_T_EE5valueEiE4typeEmmRKSA_mm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareINS_17basic_string_viewIcS2_EEEENS_9enable_ifIXsr33__can_be_converted_to_string_viewIcS2_T_EE5valueEiE4typeEmmRKSA_mm"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareINS_17basic_string_viewIcS2_EEEENS_9enable_ifIXsr33__can_be_converted_to_string_viewIcS2_T_EE5valueEiE4typeEmmRKSA_mm"]).apply(null, arguments)
            };
            var __ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE6substrEmm = Module["__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE6substrEmm"] = function() {
                return (__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE6substrEmm = Module["__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE6substrEmm"] = Module["asm"]["_ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE6substrEmm"]).apply(null, arguments)
            };
            var __ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE7compareES3_ = Module["__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE7compareES3_"] = function() {
                return (__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE7compareES3_ = Module["__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE7compareES3_"] = Module["asm"]["_ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE7compareES3_"]).apply(null, arguments)
            };
            var __ZNSt3__217basic_string_viewIcNS_11char_traitsIcEEEC2EPKcm = Module["__ZNSt3__217basic_string_viewIcNS_11char_traitsIcEEEC2EPKcm"] = function() {
                return (__ZNSt3__217basic_string_viewIcNS_11char_traitsIcEEEC2EPKcm = Module["__ZNSt3__217basic_string_viewIcNS_11char_traitsIcEEEC2EPKcm"] = Module["asm"]["_ZNSt3__217basic_string_viewIcNS_11char_traitsIcEEEC2EPKcm"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEPKc = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEPKc"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEPKc = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEPKc"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEPKc"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEmmPKcm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEmmPKcm"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEmmPKcm = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEmmPKcm"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEmmPKcm"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIcE7compareEPKcS3_m = Module["__ZNSt3__211char_traitsIcE7compareEPKcS3_m"] = function() {
                return (__ZNSt3__211char_traitsIcE7compareEPKcS3_m = Module["__ZNSt3__211char_traitsIcE7compareEPKcS3_m"] = Module["asm"]["_ZNSt3__211char_traitsIcE7compareEPKcS3_m"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEmmPKc = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEmmPKc"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEmmPKc = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEmmPKc"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE7compareEmmPKc"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcmm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcmm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcmm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcmm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEPKcmm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEmc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEmc"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEmc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEmc"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initEmc"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2ERKS5_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2ERKS5_"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2ERKS5_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2ERKS5_"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2ERKS5_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7__allocEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7__allocEv"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7__allocEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7__allocEv"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7__allocEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorIwEEE37select_on_container_copy_constructionERKS2_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIwEEE37select_on_container_copy_constructionERKS2_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorIwEEE37select_on_container_copy_constructionERKS2_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIwEEE37select_on_container_copy_constructionERKS2_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorIwEEE37select_on_container_copy_constructionERKS2_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_EC2INS_18__default_init_tagES5_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_EC2INS_18__default_init_tagES5_EEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_EC2INS_18__default_init_tagES5_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_EC2INS_18__default_init_tagES5_EEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_EC2INS_18__default_init_tagES5_EEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9__is_longEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9__is_longEv"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9__is_longEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9__is_longEv"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9__is_longEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_E5firstEv = Module["__ZNKSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_E5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_E5firstEv = Module["__ZNKSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_E5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_E5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_E5firstEv = Module["__ZNSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_E5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_E5firstEv = Module["__ZNSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_E5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_E5firstEv"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE18__get_long_pointerEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE18__get_long_pointerEv"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE18__get_long_pointerEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE18__get_long_pointerEv"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE18__get_long_pointerEv"]).apply(null, arguments)
            };
            var __ZNSt3__212__to_addressIKwEEPT_S3_ = Module["__ZNSt3__212__to_addressIKwEEPT_S3_"] = function() {
                return (__ZNSt3__212__to_addressIKwEEPT_S3_ = Module["__ZNSt3__212__to_addressIKwEEPT_S3_"] = Module["asm"]["_ZNSt3__212__to_addressIKwEEPT_S3_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE15__get_long_sizeEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE15__get_long_sizeEv"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE15__get_long_sizeEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE15__get_long_sizeEv"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE15__get_long_sizeEv"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEPKwm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEPKwm"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEPKwm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEPKwm"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEPKwm"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorIwEEE39__select_on_container_copy_constructionENS_17integral_constantIbLb0EEERKS2_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIwEEE39__select_on_container_copy_constructionENS_17integral_constantIbLb0EEERKS2_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorIwEEE39__select_on_container_copy_constructionENS_17integral_constantIbLb0EEERKS2_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIwEEE39__select_on_container_copy_constructionENS_17integral_constantIbLb0EEERKS2_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorIwEEE39__select_on_container_copy_constructionENS_17integral_constantIbLb0EEERKS2_"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_E6secondEv = Module["__ZNKSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_E6secondEv"] = function() {
                return (__ZNKSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_E6secondEv = Module["__ZNKSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_E6secondEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_E6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repELi0ELb0EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repELi0ELb0EEC2ENS_18__default_init_tagE"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repELi0ELb0EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repELi0ELb0EEC2ENS_18__default_init_tagE"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repELi0ELb0EEC2ENS_18__default_init_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardINS_9allocatorIwEEEEOT_RNS_16remove_referenceIS3_E4typeE = Module["__ZNSt3__27forwardINS_9allocatorIwEEEEOT_RNS_16remove_referenceIS3_E4typeE"] = function() {
                return (__ZNSt3__27forwardINS_9allocatorIwEEEEOT_RNS_16remove_referenceIS3_E4typeE = Module["__ZNSt3__27forwardINS_9allocatorIwEEEEOT_RNS_16remove_referenceIS3_E4typeE"] = Module["asm"]["_ZNSt3__27forwardINS_9allocatorIwEEEEOT_RNS_16remove_referenceIS3_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_9allocatorIwEELi1ELb1EEC2IS2_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorIwEELi1ELb1EEC2IS2_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_9allocatorIwEELi1ELb1EEC2IS2_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorIwEELi1ELb1EEC2IS2_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_9allocatorIwEELi1ELb1EEC2IS2_vEEOT_"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repELi0ELb0EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repELi0ELb0EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repELi0ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repELi0ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE8max_sizeEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE8max_sizeEv"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE8max_sizeEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE8max_sizeEv"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE8max_sizeEv"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE16__set_short_sizeEm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE16__set_short_sizeEm"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE16__set_short_sizeEm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE16__set_short_sizeEm"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE16__set_short_sizeEm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__get_short_pointerEv = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__get_short_pointerEv"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__get_short_pointerEv = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__get_short_pointerEv"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__get_short_pointerEv"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE11__recommendEm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE11__recommendEm"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE11__recommendEm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE11__recommendEm"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE11__recommendEm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7__allocEv = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7__allocEv"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7__allocEv = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7__allocEv"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7__allocEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorIwEEE8allocateERS2_m = Module["__ZNSt3__216allocator_traitsINS_9allocatorIwEEE8allocateERS2_m"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorIwEEE8allocateERS2_m = Module["__ZNSt3__216allocator_traitsINS_9allocatorIwEEE8allocateERS2_m"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorIwEEE8allocateERS2_m"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE18__set_long_pointerEPw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE18__set_long_pointerEPw"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE18__set_long_pointerEPw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE18__set_long_pointerEPw"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE18__set_long_pointerEPw"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE14__set_long_capEm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE14__set_long_capEm"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE14__set_long_capEm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE14__set_long_capEm"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE14__set_long_capEm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE15__set_long_sizeEm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE15__set_long_sizeEm"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE15__set_long_sizeEm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE15__set_long_sizeEm"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE15__set_long_sizeEm"]).apply(null, arguments)
            };
            var __ZNSt3__212__to_addressIwEEPT_S2_ = Module["__ZNSt3__212__to_addressIwEEPT_S2_"] = function() {
                return (__ZNSt3__212__to_addressIwEEPT_S2_ = Module["__ZNSt3__212__to_addressIwEEPT_S2_"] = Module["asm"]["_ZNSt3__212__to_addressIwEEPT_S2_"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIwE4copyEPwPKwm = Module["__ZNSt3__211char_traitsIwE4copyEPwPKwm"] = function() {
                return (__ZNSt3__211char_traitsIwE4copyEPwPKwm = Module["__ZNSt3__211char_traitsIwE4copyEPwPKwm"] = Module["asm"]["_ZNSt3__211char_traitsIwE4copyEPwPKwm"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIwE6assignERwRKw = Module["__ZNSt3__211char_traitsIwE6assignERwRKw"] = function() {
                return (__ZNSt3__211char_traitsIwE6assignERwRKw = Module["__ZNSt3__211char_traitsIwE6assignERwRKw"] = Module["asm"]["_ZNSt3__211char_traitsIwE6assignERwRKw"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2ERKS5_RKS4_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2ERKS5_RKS4_"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2ERKS5_RKS4_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2ERKS5_RKS4_"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2ERKS5_RKS4_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_EC2INS_18__default_init_tagERKS5_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_EC2INS_18__default_init_tagERKS5_EEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_EC2INS_18__default_init_tagERKS5_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_EC2INS_18__default_init_tagERKS5_EEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_EC2INS_18__default_init_tagERKS5_EEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRKNS_9allocatorIwEEEEOT_RNS_16remove_referenceIS5_E4typeE = Module["__ZNSt3__27forwardIRKNS_9allocatorIwEEEEOT_RNS_16remove_referenceIS5_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRKNS_9allocatorIwEEEEOT_RNS_16remove_referenceIS5_E4typeE = Module["__ZNSt3__27forwardIRKNS_9allocatorIwEEEEOT_RNS_16remove_referenceIS5_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRKNS_9allocatorIwEEEEOT_RNS_16remove_referenceIS5_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_9allocatorIwEELi1ELb1EEC2IRKS2_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorIwEELi1ELb1EEC2IRKS2_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_9allocatorIwEELi1ELb1EEC2IRKS2_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorIwEELi1ELb1EEC2IRKS2_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_9allocatorIwEELi1ELb1EEC2IRKS2_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2ERKS5_mmRKS4_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2ERKS5_mmRKS4_"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2ERKS5_mmRKS4_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2ERKS5_mmRKS4_"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2ERKS5_mmRKS4_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4sizeEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4sizeEv"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4sizeEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4sizeEv"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4sizeEv"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4dataEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4dataEv"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4dataEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4dataEv"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4dataEv"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE16__get_short_sizeEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE16__get_short_sizeEv"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE16__get_short_sizeEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE16__get_short_sizeEv"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE16__get_short_sizeEv"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE13__get_pointerEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE13__get_pointerEv"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE13__get_pointerEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE13__get_pointerEv"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE13__get_pointerEv"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE18__get_long_pointerEv = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE18__get_long_pointerEv"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE18__get_long_pointerEv = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE18__get_long_pointerEv"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE18__get_long_pointerEv"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE14__get_long_capEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE14__get_long_capEv"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE14__get_long_capEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE14__get_long_capEv"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE14__get_long_capEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorIwEEE10deallocateERS2_Pwm = Module["__ZNSt3__216allocator_traitsINS_9allocatorIwEEE10deallocateERS2_Pwm"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorIwEEE10deallocateERS2_Pwm = Module["__ZNSt3__216allocator_traitsINS_9allocatorIwEEE10deallocateERS2_Pwm"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorIwEEE10deallocateERS2_Pwm"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorIwE10deallocateEPwm = Module["__ZNSt3__29allocatorIwE10deallocateEPwm"] = function() {
                return (__ZNSt3__29allocatorIwE10deallocateEPwm = Module["__ZNSt3__29allocatorIwE10deallocateEPwm"] = Module["asm"]["_ZNSt3__29allocatorIwE10deallocateEPwm"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_E6secondEv = Module["__ZNSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_E6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_E6secondEv = Module["__ZNSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_E6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_E6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEaSERKS5_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEaSERKS5_"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEaSERKS5_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEaSERKS5_"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEaSERKS5_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__copy_assign_allocERKS5_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__copy_assign_allocERKS5_"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__copy_assign_allocERKS5_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__copy_assign_allocERKS5_"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__copy_assign_allocERKS5_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKwm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKwm"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKwm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKwm"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKwm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__copy_assign_allocERKS5_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__copy_assign_allocERKS5_NS_17integral_constantIbLb0EEE"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__copy_assign_allocERKS5_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__copy_assign_allocERKS5_NS_17integral_constantIbLb0EEE"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__copy_assign_allocERKS5_NS_17integral_constantIbLb0EEE"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE8capacityEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE8capacityEv"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE8capacityEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE8capacityEv"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE8capacityEv"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE13__get_pointerEv = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE13__get_pointerEv"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE13__get_pointerEv = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE13__get_pointerEv"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE13__get_pointerEv"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIwE4moveEPwPKwm = Module["__ZNSt3__211char_traitsIwE4moveEPwPKwm"] = function() {
                return (__ZNSt3__211char_traitsIwE4moveEPwPKwm = Module["__ZNSt3__211char_traitsIwE4moveEPwPKwm"] = Module["asm"]["_ZNSt3__211char_traitsIwE4moveEPwPKwm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE10__set_sizeEm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE10__set_sizeEm"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE10__set_sizeEm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE10__set_sizeEm"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE10__set_sizeEm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE27__invalidate_iterators_pastEm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE27__invalidate_iterators_pastEm"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE27__invalidate_iterators_pastEm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE27__invalidate_iterators_pastEm"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE27__invalidate_iterators_pastEm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE21__grow_by_and_replaceEmmmmmmPKw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE21__grow_by_and_replaceEmmmmmmPKw"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE21__grow_by_and_replaceEmmmmmmPKw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE21__grow_by_and_replaceEmmmmmmPKw"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE21__grow_by_and_replaceEmmmmmmPKw"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEaSEw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEaSEw"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEaSEw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEaSEw"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEaSEw"]).apply(null, arguments)
            };
            var __ZNSt3__214pointer_traitsIPwE10pointer_toERw = Module["__ZNSt3__214pointer_traitsIPwE10pointer_toERw"] = function() {
                return (__ZNSt3__214pointer_traitsIPwE10pointer_toERw = Module["__ZNSt3__214pointer_traitsIPwE10pointer_toERw"] = Module["asm"]["_ZNSt3__214pointer_traitsIPwE10pointer_toERw"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6resizeEmw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6resizeEmw"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6resizeEmw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6resizeEmw"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6resizeEmw"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendEmw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendEmw"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendEmw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendEmw"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendEmw"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE14__erase_to_endEm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE14__erase_to_endEm"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE14__erase_to_endEm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE14__erase_to_endEm"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE14__erase_to_endEm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9__grow_byEmmmmmm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9__grow_byEmmmmmm"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9__grow_byEmmmmmm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9__grow_byEmmmmmm"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9__grow_byEmmmmmm"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIwE6assignEPwmw = Module["__ZNSt3__211char_traitsIwE6assignEPwmw"] = function() {
                return (__ZNSt3__211char_traitsIwE6assignEPwmw = Module["__ZNSt3__211char_traitsIwE6assignEPwmw"] = Module["asm"]["_ZNSt3__211char_traitsIwE6assignEPwmw"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7reserveEm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7reserveEm"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7reserveEm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7reserveEm"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7reserveEm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE26__invalidate_all_iteratorsEv = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE26__invalidate_all_iteratorsEv"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE26__invalidate_all_iteratorsEv = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE26__invalidate_all_iteratorsEv"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE26__invalidate_all_iteratorsEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorIwEEE8max_sizeERKS2_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIwEEE8max_sizeERKS2_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorIwEEE8max_sizeERKS2_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIwEEE8max_sizeERKS2_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorIwEEE8max_sizeERKS2_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE10__align_itILm4EEEmm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE10__align_itILm4EEEmm"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE10__align_itILm4EEEmm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE10__align_itILm4EEEmm"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE10__align_itILm4EEEmm"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorIwE8allocateEmPKv = Module["__ZNSt3__29allocatorIwE8allocateEmPKv"] = function() {
                return (__ZNSt3__29allocatorIwE8allocateEmPKv = Module["__ZNSt3__29allocatorIwE8allocateEmPKv"] = Module["asm"]["_ZNSt3__29allocatorIwE8allocateEmPKv"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE2atEm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE2atEm"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE2atEm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE2atEm"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE2atEm"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEixEm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEixEm"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEixEm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEixEm"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEixEm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE2atEm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE2atEm"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE2atEm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE2atEm"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE2atEm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEixEm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEixEm"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEixEm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEixEm"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEixEm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendERKS5_mm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendERKS5_mm"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendERKS5_mm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendERKS5_mm"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendERKS5_mm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendEPKwm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendEPKwm"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendEPKwm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendEPKwm"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendEPKwm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendEPKw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendEPKw"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendEPKw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendEPKw"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendEPKw"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIwE6lengthEPKw = Module["__ZNSt3__211char_traitsIwE6lengthEPKw"] = function() {
                return (__ZNSt3__211char_traitsIwE6lengthEPKw = Module["__ZNSt3__211char_traitsIwE6lengthEPKw"] = Module["asm"]["_ZNSt3__211char_traitsIwE6lengthEPKw"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9push_backEw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9push_backEw"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9push_backEw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9push_backEw"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE9push_backEw"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignERKS5_mm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignERKS5_mm"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignERKS5_mm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignERKS5_mm"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignERKS5_mm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEPKw"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEmw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEmw"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEmw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEmw"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignEmw"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6insertEmRKS5_mm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6insertEmRKS5_mm"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6insertEmRKS5_mm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6insertEmRKS5_mm"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6insertEmRKS5_mm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6insertEmPKwm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6insertEmPKwm"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6insertEmPKwm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6insertEmPKwm"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6insertEmPKwm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6insertEmPKw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6insertEmPKw"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6insertEmPKw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6insertEmPKw"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6insertEmPKw"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6insertEmmw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6insertEmmw"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6insertEmmw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6insertEmmw"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6insertEmmw"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6insertENS_11__wrap_iterIPKwEEw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6insertENS_11__wrap_iterIPKwEEw"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6insertENS_11__wrap_iterIPKwEEw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6insertENS_11__wrap_iterIPKwEEw"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6insertENS_11__wrap_iterIPKwEEw"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5beginEv = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5beginEv"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5beginEv = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5beginEv"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5beginEv"]).apply(null, arguments)
            };
            var __ZNSt3__2miIPKwPwEEDTmicldtfp_4baseEcldtfp0_4baseEERKNS_11__wrap_iterIT_EERKNS5_IT0_EE = Module["__ZNSt3__2miIPKwPwEEDTmicldtfp_4baseEcldtfp0_4baseEERKNS_11__wrap_iterIT_EERKNS5_IT0_EE"] = function() {
                return (__ZNSt3__2miIPKwPwEEDTmicldtfp_4baseEcldtfp0_4baseEERKNS_11__wrap_iterIT_EERKNS5_IT0_EE = Module["__ZNSt3__2miIPKwPwEEDTmicldtfp_4baseEcldtfp0_4baseEERKNS_11__wrap_iterIT_EERKNS5_IT0_EE"] = Module["asm"]["_ZNSt3__2miIPKwPwEEDTmicldtfp_4baseEcldtfp0_4baseEERKNS_11__wrap_iterIT_EERKNS5_IT0_EE"]).apply(null, arguments)
            };
            var __ZNKSt3__211__wrap_iterIPwEplEl = Module["__ZNKSt3__211__wrap_iterIPwEplEl"] = function() {
                return (__ZNKSt3__211__wrap_iterIPwEplEl = Module["__ZNKSt3__211__wrap_iterIPwEplEl"] = Module["asm"]["_ZNKSt3__211__wrap_iterIPwEplEl"]).apply(null, arguments)
            };
            var __ZNKSt3__211__wrap_iterIPKwE4baseEv = Module["__ZNKSt3__211__wrap_iterIPKwE4baseEv"] = function() {
                return (__ZNKSt3__211__wrap_iterIPKwE4baseEv = Module["__ZNKSt3__211__wrap_iterIPKwE4baseEv"] = Module["asm"]["_ZNKSt3__211__wrap_iterIPKwE4baseEv"]).apply(null, arguments)
            };
            var __ZNKSt3__211__wrap_iterIPwE4baseEv = Module["__ZNKSt3__211__wrap_iterIPwE4baseEv"] = function() {
                return (__ZNKSt3__211__wrap_iterIPwE4baseEv = Module["__ZNKSt3__211__wrap_iterIPwE4baseEv"] = Module["asm"]["_ZNKSt3__211__wrap_iterIPwE4baseEv"]).apply(null, arguments)
            };
            var __ZNSt3__211__wrap_iterIPwEC2ES1_ = Module["__ZNSt3__211__wrap_iterIPwEC2ES1_"] = function() {
                return (__ZNSt3__211__wrap_iterIPwEC2ES1_ = Module["__ZNSt3__211__wrap_iterIPwEC2ES1_"] = Module["asm"]["_ZNSt3__211__wrap_iterIPwEC2ES1_"]).apply(null, arguments)
            };
            var __ZNSt3__211__wrap_iterIPwEpLEl = Module["__ZNSt3__211__wrap_iterIPwEpLEl"] = function() {
                return (__ZNSt3__211__wrap_iterIPwEpLEl = Module["__ZNSt3__211__wrap_iterIPwEpLEl"] = Module["asm"]["_ZNSt3__211__wrap_iterIPwEpLEl"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5eraseEmm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5eraseEmm"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5eraseEmm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5eraseEmm"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5eraseEmm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7replaceEmmRKS5_mm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7replaceEmmRKS5_mm"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7replaceEmmRKS5_mm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7replaceEmmRKS5_mm"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7replaceEmmRKS5_mm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7replaceEmmPKwm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7replaceEmmPKwm"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7replaceEmmPKwm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7replaceEmmPKwm"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7replaceEmmPKwm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7replaceEmmPKw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7replaceEmmPKw"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7replaceEmmPKw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7replaceEmmPKw"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7replaceEmmPKw"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7replaceEmmmw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7replaceEmmmw"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7replaceEmmmw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7replaceEmmmw"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7replaceEmmmw"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4copyEPwmm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4copyEPwmm"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4copyEPwmm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4copyEPwmm"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4copyEPwmm"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4findEPKwmm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4findEPKwmm"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4findEPKwmm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4findEPKwmm"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4findEPKwmm"]).apply(null, arguments)
            };
            var __ZNSt3__210__str_findIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_ = Module["__ZNSt3__210__str_findIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_"] = function() {
                return (__ZNSt3__210__str_findIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_ = Module["__ZNSt3__210__str_findIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_"] = Module["asm"]["_ZNSt3__210__str_findIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_"]).apply(null, arguments)
            };
            var __ZNSt3__218__search_substringIwNS_11char_traitsIwEEEEPKT_S5_S5_S5_S5_ = Module["__ZNSt3__218__search_substringIwNS_11char_traitsIwEEEEPKT_S5_S5_S5_S5_"] = function() {
                return (__ZNSt3__218__search_substringIwNS_11char_traitsIwEEEEPKT_S5_S5_S5_S5_ = Module["__ZNSt3__218__search_substringIwNS_11char_traitsIwEEEEPKT_S5_S5_S5_S5_"] = Module["asm"]["_ZNSt3__218__search_substringIwNS_11char_traitsIwEEEEPKT_S5_S5_S5_S5_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4findEwm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4findEwm"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4findEwm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4findEwm"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4findEwm"]).apply(null, arguments)
            };
            var __ZNSt3__210__str_findIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S4_S3_ = Module["__ZNSt3__210__str_findIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S4_S3_"] = function() {
                return (__ZNSt3__210__str_findIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S4_S3_ = Module["__ZNSt3__210__str_findIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S4_S3_"] = Module["asm"]["_ZNSt3__210__str_findIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S4_S3_"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIwE4findEPKwmRS2_ = Module["__ZNSt3__211char_traitsIwE4findEPKwmRS2_"] = function() {
                return (__ZNSt3__211char_traitsIwE4findEPKwmRS2_ = Module["__ZNSt3__211char_traitsIwE4findEPKwmRS2_"] = Module["asm"]["_ZNSt3__211char_traitsIwE4findEPKwmRS2_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5rfindEPKwmm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5rfindEPKwmm"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5rfindEPKwmm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5rfindEPKwmm"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5rfindEPKwmm"]).apply(null, arguments)
            };
            var __ZNSt3__211__str_rfindIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_ = Module["__ZNSt3__211__str_rfindIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_"] = function() {
                return (__ZNSt3__211__str_rfindIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_ = Module["__ZNSt3__211__str_rfindIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_"] = Module["asm"]["_ZNSt3__211__str_rfindIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIwE2eqEww = Module["__ZNSt3__211char_traitsIwE2eqEww"] = function() {
                return (__ZNSt3__211char_traitsIwE2eqEww = Module["__ZNSt3__211char_traitsIwE2eqEww"] = Module["asm"]["_ZNSt3__211char_traitsIwE2eqEww"]).apply(null, arguments)
            };
            var __ZNSt3__210__find_endIPFbwwEPKwS4_EET0_S5_S5_T1_S6_T_NS_26random_access_iterator_tagES8_ = Module["__ZNSt3__210__find_endIPFbwwEPKwS4_EET0_S5_S5_T1_S6_T_NS_26random_access_iterator_tagES8_"] = function() {
                return (__ZNSt3__210__find_endIPFbwwEPKwS4_EET0_S5_S5_T1_S6_T_NS_26random_access_iterator_tagES8_ = Module["__ZNSt3__210__find_endIPFbwwEPKwS4_EET0_S5_S5_T1_S6_T_NS_26random_access_iterator_tagES8_"] = Module["asm"]["_ZNSt3__210__find_endIPFbwwEPKwS4_EET0_S5_S5_T1_S6_T_NS_26random_access_iterator_tagES8_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5rfindEwm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5rfindEwm"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5rfindEwm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5rfindEwm"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5rfindEwm"]).apply(null, arguments)
            };
            var __ZNSt3__211__str_rfindIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S4_S3_ = Module["__ZNSt3__211__str_rfindIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S4_S3_"] = function() {
                return (__ZNSt3__211__str_rfindIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S4_S3_ = Module["__ZNSt3__211__str_rfindIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S4_S3_"] = Module["asm"]["_ZNSt3__211__str_rfindIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S4_S3_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE13find_first_ofEPKwmm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE13find_first_ofEPKwmm"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE13find_first_ofEPKwmm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE13find_first_ofEPKwmm"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE13find_first_ofEPKwmm"]).apply(null, arguments)
            };
            var __ZNSt3__219__str_find_first_ofIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_ = Module["__ZNSt3__219__str_find_first_ofIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_"] = function() {
                return (__ZNSt3__219__str_find_first_ofIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_ = Module["__ZNSt3__219__str_find_first_ofIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_"] = Module["asm"]["_ZNSt3__219__str_find_first_ofIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_"]).apply(null, arguments)
            };
            var __ZNSt3__218__find_first_of_ceIPKwS2_PFbwwEEET_S5_S5_T0_S6_T1_ = Module["__ZNSt3__218__find_first_of_ceIPKwS2_PFbwwEEET_S5_S5_T0_S6_T1_"] = function() {
                return (__ZNSt3__218__find_first_of_ceIPKwS2_PFbwwEEET_S5_S5_T0_S6_T1_ = Module["__ZNSt3__218__find_first_of_ceIPKwS2_PFbwwEEET_S5_S5_T0_S6_T1_"] = Module["asm"]["_ZNSt3__218__find_first_of_ceIPKwS2_PFbwwEEET_S5_S5_T0_S6_T1_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE12find_last_ofEPKwmm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE12find_last_ofEPKwmm"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE12find_last_ofEPKwmm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE12find_last_ofEPKwmm"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE12find_last_ofEPKwmm"]).apply(null, arguments)
            };
            var __ZNSt3__218__str_find_last_ofIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_ = Module["__ZNSt3__218__str_find_last_ofIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_"] = function() {
                return (__ZNSt3__218__str_find_last_ofIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_ = Module["__ZNSt3__218__str_find_last_ofIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_"] = Module["asm"]["_ZNSt3__218__str_find_last_ofIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE17find_first_not_ofEPKwmm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE17find_first_not_ofEPKwmm"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE17find_first_not_ofEPKwmm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE17find_first_not_ofEPKwmm"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE17find_first_not_ofEPKwmm"]).apply(null, arguments)
            };
            var __ZNSt3__223__str_find_first_not_ofIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_ = Module["__ZNSt3__223__str_find_first_not_ofIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_"] = function() {
                return (__ZNSt3__223__str_find_first_not_ofIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_ = Module["__ZNSt3__223__str_find_first_not_ofIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_"] = Module["asm"]["_ZNSt3__223__str_find_first_not_ofIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE16find_last_not_ofEPKwmm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE16find_last_not_ofEPKwmm"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE16find_last_not_ofEPKwmm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE16find_last_not_ofEPKwmm"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE16find_last_not_ofEPKwmm"]).apply(null, arguments)
            };
            var __ZNSt3__222__str_find_last_not_ofIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_ = Module["__ZNSt3__222__str_find_last_not_ofIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_"] = function() {
                return (__ZNSt3__222__str_find_last_not_ofIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_ = Module["__ZNSt3__222__str_find_last_not_ofIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_"] = Module["asm"]["_ZNSt3__222__str_find_last_not_ofIwmNS_11char_traitsIwEELm4294967295EEET0_PKT_S3_S6_S3_S3_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7compareEmmRKS5_mm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7compareEmmRKS5_mm"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7compareEmmRKS5_mm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7compareEmmRKS5_mm"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7compareEmmRKS5_mm"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEcvNS_17basic_string_viewIwS2_EEEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEcvNS_17basic_string_viewIwS2_EEEv"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEcvNS_17basic_string_viewIwS2_EEEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEcvNS_17basic_string_viewIwS2_EEEv"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEcvNS_17basic_string_viewIwS2_EEEv"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7compareINS_17basic_string_viewIwS2_EEEENS_9enable_ifIXsr33__can_be_converted_to_string_viewIwS2_T_EE5valueEiE4typeEmmRKSA_mm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7compareINS_17basic_string_viewIwS2_EEEENS_9enable_ifIXsr33__can_be_converted_to_string_viewIwS2_T_EE5valueEiE4typeEmmRKSA_mm"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7compareINS_17basic_string_viewIwS2_EEEENS_9enable_ifIXsr33__can_be_converted_to_string_viewIwS2_T_EE5valueEiE4typeEmmRKSA_mm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7compareINS_17basic_string_viewIwS2_EEEENS_9enable_ifIXsr33__can_be_converted_to_string_viewIwS2_T_EE5valueEiE4typeEmmRKSA_mm"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7compareINS_17basic_string_viewIwS2_EEEENS_9enable_ifIXsr33__can_be_converted_to_string_viewIwS2_T_EE5valueEiE4typeEmmRKSA_mm"]).apply(null, arguments)
            };
            var __ZNKSt3__217basic_string_viewIwNS_11char_traitsIwEEE6substrEmm = Module["__ZNKSt3__217basic_string_viewIwNS_11char_traitsIwEEE6substrEmm"] = function() {
                return (__ZNKSt3__217basic_string_viewIwNS_11char_traitsIwEEE6substrEmm = Module["__ZNKSt3__217basic_string_viewIwNS_11char_traitsIwEEE6substrEmm"] = Module["asm"]["_ZNKSt3__217basic_string_viewIwNS_11char_traitsIwEEE6substrEmm"]).apply(null, arguments)
            };
            var __ZNKSt3__217basic_string_viewIwNS_11char_traitsIwEEE7compareES3_ = Module["__ZNKSt3__217basic_string_viewIwNS_11char_traitsIwEEE7compareES3_"] = function() {
                return (__ZNKSt3__217basic_string_viewIwNS_11char_traitsIwEEE7compareES3_ = Module["__ZNKSt3__217basic_string_viewIwNS_11char_traitsIwEEE7compareES3_"] = Module["asm"]["_ZNKSt3__217basic_string_viewIwNS_11char_traitsIwEEE7compareES3_"]).apply(null, arguments)
            };
            var __ZNSt3__217basic_string_viewIwNS_11char_traitsIwEEEC2EPKwm = Module["__ZNSt3__217basic_string_viewIwNS_11char_traitsIwEEEC2EPKwm"] = function() {
                return (__ZNSt3__217basic_string_viewIwNS_11char_traitsIwEEEC2EPKwm = Module["__ZNSt3__217basic_string_viewIwNS_11char_traitsIwEEEC2EPKwm"] = Module["asm"]["_ZNSt3__217basic_string_viewIwNS_11char_traitsIwEEEC2EPKwm"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7compareEPKw = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7compareEPKw"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7compareEPKw = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7compareEPKw"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7compareEPKw"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7compareEmmPKwm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7compareEmmPKwm"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7compareEmmPKwm = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7compareEmmPKwm"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7compareEmmPKwm"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIwE7compareEPKwS3_m = Module["__ZNSt3__211char_traitsIwE7compareEPKwS3_m"] = function() {
                return (__ZNSt3__211char_traitsIwE7compareEPKwS3_m = Module["__ZNSt3__211char_traitsIwE7compareEPKwS3_m"] = Module["asm"]["_ZNSt3__211char_traitsIwE7compareEPKwS3_m"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7compareEmmPKw = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7compareEmmPKw"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7compareEmmPKw = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7compareEmmPKw"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE7compareEmmPKw"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEPKwmm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEPKwmm"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEPKwmm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEPKwmm"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEPKwmm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEmw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEmw"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEmw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEmw"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initEmw"]).apply(null, arguments)
            };
            var __ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_RKS9_ = Module["__ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_RKS9_"] = function() {
                return (__ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_RKS9_ = Module["__ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_RKS9_"] = Module["asm"]["_ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_RKS9_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE13get_allocatorEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE13get_allocatorEv"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE13get_allocatorEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE13get_allocatorEv"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE13get_allocatorEv"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS4_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS4_"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS4_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS4_"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2ERKS4_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__zeroEv = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__zeroEv"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__zeroEv = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__zeroEv"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__zeroEv"]).apply(null, arguments)
            };
            var __ZNSt3__24stoiERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi = Module["__ZNSt3__24stoiERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi"] = function() {
                return (__ZNSt3__24stoiERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi = Module["__ZNSt3__24stoiERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi"] = Module["asm"]["_ZNSt3__24stoiERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2IDnEEPKc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2IDnEEPKc"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2IDnEEPKc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2IDnEEPKc"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2IDnEEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__214numeric_limitsIiE3minEv = Module["__ZNSt3__214numeric_limitsIiE3minEv"] = function() {
                return (__ZNSt3__214numeric_limitsIiE3minEv = Module["__ZNSt3__214numeric_limitsIiE3minEv"] = Module["asm"]["_ZNSt3__214numeric_limitsIiE3minEv"]).apply(null, arguments)
            };
            var __ZNSt3__214numeric_limitsIiE3maxEv = Module["__ZNSt3__214numeric_limitsIiE3maxEv"] = function() {
                return (__ZNSt3__214numeric_limitsIiE3maxEv = Module["__ZNSt3__214numeric_limitsIiE3maxEv"] = Module["asm"]["_ZNSt3__214numeric_limitsIiE3maxEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_EC2INS_18__default_init_tagESA_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_EC2INS_18__default_init_tagESA_EEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_EC2INS_18__default_init_tagESA_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_EC2INS_18__default_init_tagESA_EEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES5_EC2INS_18__default_init_tagESA_EEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__24stoiERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi = Module["__ZNSt3__24stoiERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi"] = function() {
                return (__ZNSt3__24stoiERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi = Module["__ZNSt3__24stoiERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi"] = Module["asm"]["_ZNSt3__24stoiERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi"]).apply(null, arguments)
            };
            var __ZNSt3__24stolERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi = Module["__ZNSt3__24stolERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi"] = function() {
                return (__ZNSt3__24stolERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi = Module["__ZNSt3__24stolERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi"] = Module["asm"]["_ZNSt3__24stolERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi"]).apply(null, arguments)
            };
            var __ZNSt3__24stolERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi = Module["__ZNSt3__24stolERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi"] = function() {
                return (__ZNSt3__24stolERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi = Module["__ZNSt3__24stolERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi"] = Module["asm"]["_ZNSt3__24stolERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi"]).apply(null, arguments)
            };
            var __ZNSt3__25stoulERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi = Module["__ZNSt3__25stoulERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi"] = function() {
                return (__ZNSt3__25stoulERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi = Module["__ZNSt3__25stoulERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi"] = Module["asm"]["_ZNSt3__25stoulERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi"]).apply(null, arguments)
            };
            var __ZNSt3__25stoulERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi = Module["__ZNSt3__25stoulERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi"] = function() {
                return (__ZNSt3__25stoulERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi = Module["__ZNSt3__25stoulERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi"] = Module["asm"]["_ZNSt3__25stoulERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi"]).apply(null, arguments)
            };
            var __ZNSt3__25stollERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi = Module["__ZNSt3__25stollERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi"] = function() {
                return (__ZNSt3__25stollERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi = Module["__ZNSt3__25stollERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi"] = Module["asm"]["_ZNSt3__25stollERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi"]).apply(null, arguments)
            };
            var __ZNSt3__25stollERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi = Module["__ZNSt3__25stollERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi"] = function() {
                return (__ZNSt3__25stollERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi = Module["__ZNSt3__25stollERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi"] = Module["asm"]["_ZNSt3__25stollERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi"]).apply(null, arguments)
            };
            var __ZNSt3__26stoullERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi = Module["__ZNSt3__26stoullERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi"] = function() {
                return (__ZNSt3__26stoullERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi = Module["__ZNSt3__26stoullERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi"] = Module["asm"]["_ZNSt3__26stoullERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi"]).apply(null, arguments)
            };
            var __ZNSt3__26stoullERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi = Module["__ZNSt3__26stoullERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi"] = function() {
                return (__ZNSt3__26stoullERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi = Module["__ZNSt3__26stoullERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi"] = Module["asm"]["_ZNSt3__26stoullERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi"]).apply(null, arguments)
            };
            var __ZNSt3__24stofERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPm = Module["__ZNSt3__24stofERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPm"] = function() {
                return (__ZNSt3__24stofERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPm = Module["__ZNSt3__24stofERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPm"] = Module["asm"]["_ZNSt3__24stofERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPm"]).apply(null, arguments)
            };
            var __ZNSt3__24stofERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPm = Module["__ZNSt3__24stofERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPm"] = function() {
                return (__ZNSt3__24stofERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPm = Module["__ZNSt3__24stofERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPm"] = Module["asm"]["_ZNSt3__24stofERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPm"]).apply(null, arguments)
            };
            var __ZNSt3__24stodERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPm = Module["__ZNSt3__24stodERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPm"] = function() {
                return (__ZNSt3__24stodERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPm = Module["__ZNSt3__24stodERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPm"] = Module["asm"]["_ZNSt3__24stodERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPm"]).apply(null, arguments)
            };
            var __ZNSt3__24stodERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPm = Module["__ZNSt3__24stodERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPm"] = function() {
                return (__ZNSt3__24stodERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPm = Module["__ZNSt3__24stodERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPm"] = Module["asm"]["_ZNSt3__24stodERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPm"]).apply(null, arguments)
            };
            var __ZNSt3__25stoldERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPm = Module["__ZNSt3__25stoldERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPm"] = function() {
                return (__ZNSt3__25stoldERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPm = Module["__ZNSt3__25stoldERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPm"] = Module["asm"]["_ZNSt3__25stoldERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPm"]).apply(null, arguments)
            };
            var __ZNSt3__25stoldERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPm = Module["__ZNSt3__25stoldERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPm"] = function() {
                return (__ZNSt3__25stoldERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPm = Module["__ZNSt3__25stoldERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPm"] = Module["asm"]["_ZNSt3__25stoldERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPm"]).apply(null, arguments)
            };
            var __ZNSt3__29to_stringEi = Module["__ZNSt3__29to_stringEi"] = function() {
                return (__ZNSt3__29to_stringEi = Module["__ZNSt3__29to_stringEi"] = Module["asm"]["_ZNSt3__29to_stringEi"]).apply(null, arguments)
            };
            var __ZNSt3__28to_charsIiLi0EEENS_15to_chars_resultEPcS2_T_ = Module["__ZNSt3__28to_charsIiLi0EEENS_15to_chars_resultEPcS2_T_"] = function() {
                return (__ZNSt3__28to_charsIiLi0EEENS_15to_chars_resultEPcS2_T_ = Module["__ZNSt3__28to_charsIiLi0EEENS_15to_chars_resultEPcS2_T_"] = Module["asm"]["_ZNSt3__28to_charsIiLi0EEENS_15to_chars_resultEPcS2_T_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2IPcvEET_S8_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2IPcvEET_S8_"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2IPcvEET_S8_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2IPcvEET_S8_"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2IPcvEET_S8_"]).apply(null, arguments)
            };
            var __ZNSt3__29to_stringEl = Module["__ZNSt3__29to_stringEl"] = function() {
                return (__ZNSt3__29to_stringEl = Module["__ZNSt3__29to_stringEl"] = Module["asm"]["_ZNSt3__29to_stringEl"]).apply(null, arguments)
            };
            var __ZNSt3__28to_charsIlLi0EEENS_15to_chars_resultEPcS2_T_ = Module["__ZNSt3__28to_charsIlLi0EEENS_15to_chars_resultEPcS2_T_"] = function() {
                return (__ZNSt3__28to_charsIlLi0EEENS_15to_chars_resultEPcS2_T_ = Module["__ZNSt3__28to_charsIlLi0EEENS_15to_chars_resultEPcS2_T_"] = Module["asm"]["_ZNSt3__28to_charsIlLi0EEENS_15to_chars_resultEPcS2_T_"]).apply(null, arguments)
            };
            var __ZNSt3__29to_stringEx = Module["__ZNSt3__29to_stringEx"] = function() {
                return (__ZNSt3__29to_stringEx = Module["__ZNSt3__29to_stringEx"] = Module["asm"]["_ZNSt3__29to_stringEx"]).apply(null, arguments)
            };
            var __ZNSt3__28to_charsIxLi0EEENS_15to_chars_resultEPcS2_T_ = Module["__ZNSt3__28to_charsIxLi0EEENS_15to_chars_resultEPcS2_T_"] = function() {
                return (__ZNSt3__28to_charsIxLi0EEENS_15to_chars_resultEPcS2_T_ = Module["__ZNSt3__28to_charsIxLi0EEENS_15to_chars_resultEPcS2_T_"] = Module["asm"]["_ZNSt3__28to_charsIxLi0EEENS_15to_chars_resultEPcS2_T_"]).apply(null, arguments)
            };
            var __ZNSt3__29to_stringEj = Module["__ZNSt3__29to_stringEj"] = function() {
                return (__ZNSt3__29to_stringEj = Module["__ZNSt3__29to_stringEj"] = Module["asm"]["_ZNSt3__29to_stringEj"]).apply(null, arguments)
            };
            var __ZNSt3__28to_charsIjLi0EEENS_15to_chars_resultEPcS2_T_ = Module["__ZNSt3__28to_charsIjLi0EEENS_15to_chars_resultEPcS2_T_"] = function() {
                return (__ZNSt3__28to_charsIjLi0EEENS_15to_chars_resultEPcS2_T_ = Module["__ZNSt3__28to_charsIjLi0EEENS_15to_chars_resultEPcS2_T_"] = Module["asm"]["_ZNSt3__28to_charsIjLi0EEENS_15to_chars_resultEPcS2_T_"]).apply(null, arguments)
            };
            var __ZNSt3__29to_stringEm = Module["__ZNSt3__29to_stringEm"] = function() {
                return (__ZNSt3__29to_stringEm = Module["__ZNSt3__29to_stringEm"] = Module["asm"]["_ZNSt3__29to_stringEm"]).apply(null, arguments)
            };
            var __ZNSt3__28to_charsImLi0EEENS_15to_chars_resultEPcS2_T_ = Module["__ZNSt3__28to_charsImLi0EEENS_15to_chars_resultEPcS2_T_"] = function() {
                return (__ZNSt3__28to_charsImLi0EEENS_15to_chars_resultEPcS2_T_ = Module["__ZNSt3__28to_charsImLi0EEENS_15to_chars_resultEPcS2_T_"] = Module["asm"]["_ZNSt3__28to_charsImLi0EEENS_15to_chars_resultEPcS2_T_"]).apply(null, arguments)
            };
            var __ZNSt3__29to_stringEy = Module["__ZNSt3__29to_stringEy"] = function() {
                return (__ZNSt3__29to_stringEy = Module["__ZNSt3__29to_stringEy"] = Module["asm"]["_ZNSt3__29to_stringEy"]).apply(null, arguments)
            };
            var __ZNSt3__28to_charsIyLi0EEENS_15to_chars_resultEPcS2_T_ = Module["__ZNSt3__28to_charsIyLi0EEENS_15to_chars_resultEPcS2_T_"] = function() {
                return (__ZNSt3__28to_charsIyLi0EEENS_15to_chars_resultEPcS2_T_ = Module["__ZNSt3__28to_charsIyLi0EEENS_15to_chars_resultEPcS2_T_"] = Module["asm"]["_ZNSt3__28to_charsIyLi0EEENS_15to_chars_resultEPcS2_T_"]).apply(null, arguments)
            };
            var __ZNSt3__210to_wstringEi = Module["__ZNSt3__210to_wstringEi"] = function() {
                return (__ZNSt3__210to_wstringEi = Module["__ZNSt3__210to_wstringEi"] = Module["asm"]["_ZNSt3__210to_wstringEi"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2IPcvEET_S8_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2IPcvEET_S8_"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2IPcvEET_S8_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2IPcvEET_S8_"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2IPcvEET_S8_"]).apply(null, arguments)
            };
            var __ZNSt3__210to_wstringEl = Module["__ZNSt3__210to_wstringEl"] = function() {
                return (__ZNSt3__210to_wstringEl = Module["__ZNSt3__210to_wstringEl"] = Module["asm"]["_ZNSt3__210to_wstringEl"]).apply(null, arguments)
            };
            var __ZNSt3__210to_wstringEx = Module["__ZNSt3__210to_wstringEx"] = function() {
                return (__ZNSt3__210to_wstringEx = Module["__ZNSt3__210to_wstringEx"] = Module["asm"]["_ZNSt3__210to_wstringEx"]).apply(null, arguments)
            };
            var __ZNSt3__210to_wstringEj = Module["__ZNSt3__210to_wstringEj"] = function() {
                return (__ZNSt3__210to_wstringEj = Module["__ZNSt3__210to_wstringEj"] = Module["asm"]["_ZNSt3__210to_wstringEj"]).apply(null, arguments)
            };
            var __ZNSt3__210to_wstringEm = Module["__ZNSt3__210to_wstringEm"] = function() {
                return (__ZNSt3__210to_wstringEm = Module["__ZNSt3__210to_wstringEm"] = Module["asm"]["_ZNSt3__210to_wstringEm"]).apply(null, arguments)
            };
            var __ZNSt3__210to_wstringEy = Module["__ZNSt3__210to_wstringEy"] = function() {
                return (__ZNSt3__210to_wstringEy = Module["__ZNSt3__210to_wstringEy"] = Module["asm"]["_ZNSt3__210to_wstringEy"]).apply(null, arguments)
            };
            var __ZNSt3__29to_stringEf = Module["__ZNSt3__29to_stringEf"] = function() {
                return (__ZNSt3__29to_stringEf = Module["__ZNSt3__29to_stringEf"] = Module["asm"]["_ZNSt3__29to_stringEf"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6resizeEm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2EOS5_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2EOS5_"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2EOS5_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2EOS5_"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2EOS5_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2Ev = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2Ev"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2Ev = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2Ev"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29to_stringEd = Module["__ZNSt3__29to_stringEd"] = function() {
                return (__ZNSt3__29to_stringEd = Module["__ZNSt3__29to_stringEd"] = Module["asm"]["_ZNSt3__29to_stringEd"]).apply(null, arguments)
            };
            var __ZNSt3__29to_stringEe = Module["__ZNSt3__29to_stringEe"] = function() {
                return (__ZNSt3__29to_stringEe = Module["__ZNSt3__29to_stringEe"] = Module["asm"]["_ZNSt3__29to_stringEe"]).apply(null, arguments)
            };
            var __ZNSt3__210to_wstringEf = Module["__ZNSt3__210to_wstringEf"] = function() {
                return (__ZNSt3__210to_wstringEf = Module["__ZNSt3__210to_wstringEf"] = Module["asm"]["_ZNSt3__210to_wstringEf"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6resizeEm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6resizeEm"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6resizeEm = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6resizeEm"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6resizeEm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2EOS5_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2EOS5_"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2EOS5_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2EOS5_"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2EOS5_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2Emw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2Emw"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2Emw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2Emw"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2Emw"]).apply(null, arguments)
            };
            var __ZNSt3__210to_wstringEd = Module["__ZNSt3__210to_wstringEd"] = function() {
                return (__ZNSt3__210to_wstringEd = Module["__ZNSt3__210to_wstringEd"] = Module["asm"]["_ZNSt3__210to_wstringEd"]).apply(null, arguments)
            };
            var __ZNSt3__210to_wstringEe = Module["__ZNSt3__210to_wstringEe"] = function() {
                return (__ZNSt3__210to_wstringEe = Module["__ZNSt3__210to_wstringEe"] = Module["asm"]["_ZNSt3__210to_wstringEe"]).apply(null, arguments)
            };
            var __ZNKSt3__26__lessImmEclERKmS3_ = Module["__ZNKSt3__26__lessImmEclERKmS3_"] = function() {
                return (__ZNKSt3__26__lessImmEclERKmS3_ = Module["__ZNKSt3__26__lessImmEclERKmS3_"] = Module["asm"]["_ZNKSt3__26__lessImmEclERKmS3_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIiEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIiEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = function() {
                return (__ZNSt3__24swapIiEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIiEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = Module["asm"]["_ZNSt3__24swapIiEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"]).apply(null, arguments)
            };
            var __ZNSt3__223__libcpp_numeric_limitsIiLb1EE3minEv = Module["__ZNSt3__223__libcpp_numeric_limitsIiLb1EE3minEv"] = function() {
                return (__ZNSt3__223__libcpp_numeric_limitsIiLb1EE3minEv = Module["__ZNSt3__223__libcpp_numeric_limitsIiLb1EE3minEv"] = Module["asm"]["_ZNSt3__223__libcpp_numeric_limitsIiLb1EE3minEv"]).apply(null, arguments)
            };
            var __ZNSt3__223__libcpp_numeric_limitsIiLb1EE3maxEv = Module["__ZNSt3__223__libcpp_numeric_limitsIiLb1EE3maxEv"] = function() {
                return (__ZNSt3__223__libcpp_numeric_limitsIiLb1EE3maxEv = Module["__ZNSt3__223__libcpp_numeric_limitsIiLb1EE3maxEv"] = Module["asm"]["_ZNSt3__223__libcpp_numeric_limitsIiLb1EE3maxEv"]).apply(null, arguments)
            };
            var __ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_PKS6_ = Module["__ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_PKS6_"] = function() {
                return (__ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_PKS6_ = Module["__ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_PKS6_"] = Module["asm"]["_ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EERKS9_PKS6_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRiEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRiEEONS_16remove_referenceIT_E4typeEOS3_"] = function() {
                return (__ZNSt3__24moveIRiEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRiEEONS_16remove_referenceIT_E4typeEOS3_"] = Module["asm"]["_ZNSt3__24moveIRiEEONS_16remove_referenceIT_E4typeEOS3_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5c_strEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5c_strEv"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5c_strEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5c_strEv"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5c_strEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_9allocatorIcEELi1ELb1EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorIcEELi1ELb1EEC2ENS_18__default_init_tagE"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_9allocatorIcEELi1ELb1EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorIcEELi1ELb1EEC2ENS_18__default_init_tagE"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_9allocatorIcEELi1ELb1EEC2ENS_18__default_init_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorIcEC2Ev = Module["__ZNSt3__29allocatorIcEC2Ev"] = function() {
                return (__ZNSt3__29allocatorIcEC2Ev = Module["__ZNSt3__29allocatorIcEC2Ev"] = Module["asm"]["_ZNSt3__29allocatorIcEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_EC2INS_18__default_init_tagESA_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_EC2INS_18__default_init_tagESA_EEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_EC2INS_18__default_init_tagESA_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_EC2INS_18__default_init_tagESA_EEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES5_EC2INS_18__default_init_tagESA_EEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_9allocatorIwEELi1ELb1EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorIwEELi1ELb1EEC2ENS_18__default_init_tagE"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_9allocatorIwEELi1ELb1EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorIwEELi1ELb1EEC2ENS_18__default_init_tagE"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_9allocatorIwEELi1ELb1EEC2ENS_18__default_init_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorIwEC2Ev = Module["__ZNSt3__29allocatorIwEC2Ev"] = function() {
                return (__ZNSt3__29allocatorIwEC2Ev = Module["__ZNSt3__29allocatorIwEC2Ev"] = Module["asm"]["_ZNSt3__29allocatorIwEC2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemINS_9allocatorIcEELi1ELb1EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemINS_9allocatorIcEELi1ELb1EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemINS_9allocatorIcEELi1ELb1EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemINS_9allocatorIcEELi1ELb1EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemINS_9allocatorIcEELi1ELb1EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__219__libcpp_deallocateEPvmm = Module["__ZNSt3__219__libcpp_deallocateEPvmm"] = function() {
                return (__ZNSt3__219__libcpp_deallocateEPvmm = Module["__ZNSt3__219__libcpp_deallocateEPvmm"] = Module["asm"]["_ZNSt3__219__libcpp_deallocateEPvmm"]).apply(null, arguments)
            };
            var __ZNSt3__217_DeallocateCaller33__do_deallocate_handle_size_alignEPvmm = Module["__ZNSt3__217_DeallocateCaller33__do_deallocate_handle_size_alignEPvmm"] = function() {
                return (__ZNSt3__217_DeallocateCaller33__do_deallocate_handle_size_alignEPvmm = Module["__ZNSt3__217_DeallocateCaller33__do_deallocate_handle_size_alignEPvmm"] = Module["asm"]["_ZNSt3__217_DeallocateCaller33__do_deallocate_handle_size_alignEPvmm"]).apply(null, arguments)
            };
            var __ZNSt3__217_DeallocateCaller27__do_deallocate_handle_sizeEPvm = Module["__ZNSt3__217_DeallocateCaller27__do_deallocate_handle_sizeEPvm"] = function() {
                return (__ZNSt3__217_DeallocateCaller27__do_deallocate_handle_sizeEPvm = Module["__ZNSt3__217_DeallocateCaller27__do_deallocate_handle_sizeEPvm"] = Module["asm"]["_ZNSt3__217_DeallocateCaller27__do_deallocate_handle_sizeEPvm"]).apply(null, arguments)
            };
            var __ZNSt3__217_DeallocateCaller9__do_callEPv = Module["__ZNSt3__217_DeallocateCaller9__do_callEPv"] = function() {
                return (__ZNSt3__217_DeallocateCaller9__do_callEPv = Module["__ZNSt3__217_DeallocateCaller9__do_callEPv"] = Module["asm"]["_ZNSt3__217_DeallocateCaller9__do_callEPv"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_9allocatorIcEELi1ELb1EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorIcEELi1ELb1EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_9allocatorIcEELi1ELb1EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorIcEELi1ELb1EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_9allocatorIcEELi1ELb1EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__29addressofIcEEPT_RS1_ = Module["__ZNSt3__29addressofIcEEPT_RS1_"] = function() {
                return (__ZNSt3__29addressofIcEEPT_RS1_ = Module["__ZNSt3__29addressofIcEEPT_RS1_"] = Module["asm"]["_ZNSt3__29addressofIcEEPT_RS1_"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorIcEEE10__max_sizeENS_17integral_constantIbLb1EEERKS2_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIcEEE10__max_sizeENS_17integral_constantIbLb1EEERKS2_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorIcEEE10__max_sizeENS_17integral_constantIbLb1EEERKS2_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIcEEE10__max_sizeENS_17integral_constantIbLb1EEERKS2_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorIcEEE10__max_sizeENS_17integral_constantIbLb1EEERKS2_"]).apply(null, arguments)
            };
            var __ZNKSt3__29allocatorIcE8max_sizeEv = Module["__ZNKSt3__29allocatorIcE8max_sizeEv"] = function() {
                return (__ZNKSt3__29allocatorIcE8max_sizeEv = Module["__ZNKSt3__29allocatorIcE8max_sizeEv"] = Module["asm"]["_ZNKSt3__29allocatorIcE8max_sizeEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__libcpp_allocateEmm = Module["__ZNSt3__217__libcpp_allocateEmm"] = function() {
                return (__ZNSt3__217__libcpp_allocateEmm = Module["__ZNSt3__217__libcpp_allocateEmm"] = Module["asm"]["_ZNSt3__217__libcpp_allocateEmm"]).apply(null, arguments)
            };
            var __ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE4sizeEv = Module["__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE4sizeEv"] = function() {
                return (__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE4sizeEv = Module["__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE4sizeEv"] = Module["asm"]["_ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE4sizeEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE4dataEv = Module["__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE4dataEv"] = function() {
                return (__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE4dataEv = Module["__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE4dataEv"] = Module["asm"]["_ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE4dataEv"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemINS_9allocatorIwEELi1ELb1EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemINS_9allocatorIwEELi1ELb1EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemINS_9allocatorIwEELi1ELb1EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemINS_9allocatorIwEELi1ELb1EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemINS_9allocatorIwEELi1ELb1EE5__getEv"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__get_short_pointerEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__get_short_pointerEv"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__get_short_pointerEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__get_short_pointerEv"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__get_short_pointerEv"]).apply(null, arguments)
            };
            var __ZNSt3__214pointer_traitsIPKwE10pointer_toERS1_ = Module["__ZNSt3__214pointer_traitsIPKwE10pointer_toERS1_"] = function() {
                return (__ZNSt3__214pointer_traitsIPKwE10pointer_toERS1_ = Module["__ZNSt3__214pointer_traitsIPKwE10pointer_toERS1_"] = Module["asm"]["_ZNSt3__214pointer_traitsIPKwE10pointer_toERS1_"]).apply(null, arguments)
            };
            var __ZNSt3__29addressofIKwEEPT_RS2_ = Module["__ZNSt3__29addressofIKwEEPT_RS2_"] = function() {
                return (__ZNSt3__29addressofIKwEEPT_RS2_ = Module["__ZNSt3__29addressofIKwEEPT_RS2_"] = Module["asm"]["_ZNSt3__29addressofIKwEEPT_RS2_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_9allocatorIwEELi1ELb1EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorIwEELi1ELb1EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_9allocatorIwEELi1ELb1EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorIwEELi1ELb1EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_9allocatorIwEELi1ELb1EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__29addressofIwEEPT_RS1_ = Module["__ZNSt3__29addressofIwEEPT_RS1_"] = function() {
                return (__ZNSt3__29addressofIwEEPT_RS1_ = Module["__ZNSt3__29addressofIwEEPT_RS1_"] = Module["asm"]["_ZNSt3__29addressofIwEEPT_RS1_"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorIwEEE10__max_sizeENS_17integral_constantIbLb1EEERKS2_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIwEEE10__max_sizeENS_17integral_constantIbLb1EEERKS2_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorIwEEE10__max_sizeENS_17integral_constantIbLb1EEERKS2_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIwEEE10__max_sizeENS_17integral_constantIbLb1EEERKS2_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorIwEEE10__max_sizeENS_17integral_constantIbLb1EEERKS2_"]).apply(null, arguments)
            };
            var __ZNKSt3__29allocatorIwE8max_sizeEv = Module["__ZNKSt3__29allocatorIwE8max_sizeEv"] = function() {
                return (__ZNKSt3__29allocatorIwE8max_sizeEv = Module["__ZNKSt3__29allocatorIwE8max_sizeEv"] = Module["asm"]["_ZNKSt3__29allocatorIwE8max_sizeEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217basic_string_viewIwNS_11char_traitsIwEEE4sizeEv = Module["__ZNKSt3__217basic_string_viewIwNS_11char_traitsIwEEE4sizeEv"] = function() {
                return (__ZNKSt3__217basic_string_viewIwNS_11char_traitsIwEEE4sizeEv = Module["__ZNKSt3__217basic_string_viewIwNS_11char_traitsIwEEE4sizeEv"] = Module["asm"]["_ZNKSt3__217basic_string_viewIwNS_11char_traitsIwEEE4sizeEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217basic_string_viewIwNS_11char_traitsIwEEE4dataEv = Module["__ZNKSt3__217basic_string_viewIwNS_11char_traitsIwEEE4dataEv"] = function() {
                return (__ZNKSt3__217basic_string_viewIwNS_11char_traitsIwEEE4dataEv = Module["__ZNKSt3__217basic_string_viewIwNS_11char_traitsIwEEE4dataEv"] = Module["asm"]["_ZNKSt3__217basic_string_viewIwNS_11char_traitsIwEEE4dataEv"]).apply(null, arguments)
            };
            var __ZNSt3__215__to_chars_itoaIiEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb1EEE = Module["__ZNSt3__215__to_chars_itoaIiEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb1EEE"] = function() {
                return (__ZNSt3__215__to_chars_itoaIiEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb1EEE = Module["__ZNSt3__215__to_chars_itoaIiEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb1EEE"] = Module["asm"]["_ZNSt3__215__to_chars_itoaIiEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb1EEE"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initIPcEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeES9_S9_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initIPcEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeES9_S9_"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initIPcEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeES9_S9_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initIPcEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeES9_S9_"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initIPcEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeES9_S9_"]).apply(null, arguments)
            };
            var __ZNSt3__213__to_unsignedIiEENS_13make_unsignedIT_E4typeES2_ = Module["__ZNSt3__213__to_unsignedIiEENS_13make_unsignedIT_E4typeES2_"] = function() {
                return (__ZNSt3__213__to_unsignedIiEENS_13make_unsignedIT_E4typeES2_ = Module["__ZNSt3__213__to_unsignedIiEENS_13make_unsignedIT_E4typeES2_"] = Module["asm"]["_ZNSt3__213__to_unsignedIiEENS_13make_unsignedIT_E4typeES2_"]).apply(null, arguments)
            };
            var __ZNSt3__212__complementIjEET_S1_ = Module["__ZNSt3__212__complementIjEET_S1_"] = function() {
                return (__ZNSt3__212__complementIjEET_S1_ = Module["__ZNSt3__212__complementIjEET_S1_"] = Module["asm"]["_ZNSt3__212__complementIjEET_S1_"]).apply(null, arguments)
            };
            var __ZNSt3__215__to_chars_itoaIjEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__215__to_chars_itoaIjEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb0EEE"] = function() {
                return (__ZNSt3__215__to_chars_itoaIjEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__215__to_chars_itoaIjEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb0EEE"] = Module["asm"]["_ZNSt3__215__to_chars_itoaIjEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb0EEE"]).apply(null, arguments)
            };
            var __ZNSt3__26__itoa13__traits_baseIjvE7__widthEj = Module["__ZNSt3__26__itoa13__traits_baseIjvE7__widthEj"] = function() {
                return (__ZNSt3__26__itoa13__traits_baseIjvE7__widthEj = Module["__ZNSt3__26__itoa13__traits_baseIjvE7__widthEj"] = Module["asm"]["_ZNSt3__26__itoa13__traits_baseIjvE7__widthEj"]).apply(null, arguments)
            };
            var __ZNSt3__26__itoa13__traits_baseIjvE9__convertEjPc = Module["__ZNSt3__26__itoa13__traits_baseIjvE9__convertEjPc"] = function() {
                return (__ZNSt3__26__itoa13__traits_baseIjvE9__convertEjPc = Module["__ZNSt3__26__itoa13__traits_baseIjvE9__convertEjPc"] = Module["asm"]["_ZNSt3__26__itoa13__traits_baseIjvE9__convertEjPc"]).apply(null, arguments)
            };
            var __ZNSt3__26__itoa8__u32toaEjPc = Module["__ZNSt3__26__itoa8__u32toaEjPc"] = function() {
                return (__ZNSt3__26__itoa8__u32toaEjPc = Module["__ZNSt3__26__itoa8__u32toaEjPc"] = Module["asm"]["_ZNSt3__26__itoa8__u32toaEjPc"]).apply(null, arguments)
            };
            var __ZNSt3__28distanceIPcEENS_15iterator_traitsIT_E15difference_typeES3_S3_ = Module["__ZNSt3__28distanceIPcEENS_15iterator_traitsIT_E15difference_typeES3_S3_"] = function() {
                return (__ZNSt3__28distanceIPcEENS_15iterator_traitsIT_E15difference_typeES3_S3_ = Module["__ZNSt3__28distanceIPcEENS_15iterator_traitsIT_E15difference_typeES3_S3_"] = Module["asm"]["_ZNSt3__28distanceIPcEENS_15iterator_traitsIT_E15difference_typeES3_S3_"]).apply(null, arguments)
            };
            var __ZNSt3__210__distanceIPcEENS_15iterator_traitsIT_E15difference_typeES3_S3_NS_26random_access_iterator_tagE = Module["__ZNSt3__210__distanceIPcEENS_15iterator_traitsIT_E15difference_typeES3_S3_NS_26random_access_iterator_tagE"] = function() {
                return (__ZNSt3__210__distanceIPcEENS_15iterator_traitsIT_E15difference_typeES3_S3_NS_26random_access_iterator_tagE = Module["__ZNSt3__210__distanceIPcEENS_15iterator_traitsIT_E15difference_typeES3_S3_NS_26random_access_iterator_tagE"] = Module["asm"]["_ZNSt3__210__distanceIPcEENS_15iterator_traitsIT_E15difference_typeES3_S3_NS_26random_access_iterator_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__215__to_chars_itoaIlEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb1EEE = Module["__ZNSt3__215__to_chars_itoaIlEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb1EEE"] = function() {
                return (__ZNSt3__215__to_chars_itoaIlEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb1EEE = Module["__ZNSt3__215__to_chars_itoaIlEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb1EEE"] = Module["asm"]["_ZNSt3__215__to_chars_itoaIlEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb1EEE"]).apply(null, arguments)
            };
            var __ZNSt3__213__to_unsignedIlEENS_13make_unsignedIT_E4typeES2_ = Module["__ZNSt3__213__to_unsignedIlEENS_13make_unsignedIT_E4typeES2_"] = function() {
                return (__ZNSt3__213__to_unsignedIlEENS_13make_unsignedIT_E4typeES2_ = Module["__ZNSt3__213__to_unsignedIlEENS_13make_unsignedIT_E4typeES2_"] = Module["asm"]["_ZNSt3__213__to_unsignedIlEENS_13make_unsignedIT_E4typeES2_"]).apply(null, arguments)
            };
            var __ZNSt3__212__complementImEET_S1_ = Module["__ZNSt3__212__complementImEET_S1_"] = function() {
                return (__ZNSt3__212__complementImEET_S1_ = Module["__ZNSt3__212__complementImEET_S1_"] = Module["asm"]["_ZNSt3__212__complementImEET_S1_"]).apply(null, arguments)
            };
            var __ZNSt3__215__to_chars_itoaImEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__215__to_chars_itoaImEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb0EEE"] = function() {
                return (__ZNSt3__215__to_chars_itoaImEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__215__to_chars_itoaImEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb0EEE"] = Module["asm"]["_ZNSt3__215__to_chars_itoaImEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb0EEE"]).apply(null, arguments)
            };
            var __ZNSt3__26__itoa13__traits_baseImvE7__widthEm = Module["__ZNSt3__26__itoa13__traits_baseImvE7__widthEm"] = function() {
                return (__ZNSt3__26__itoa13__traits_baseImvE7__widthEm = Module["__ZNSt3__26__itoa13__traits_baseImvE7__widthEm"] = Module["asm"]["_ZNSt3__26__itoa13__traits_baseImvE7__widthEm"]).apply(null, arguments)
            };
            var __ZNSt3__26__itoa13__traits_baseImvE9__convertEmPc = Module["__ZNSt3__26__itoa13__traits_baseImvE9__convertEmPc"] = function() {
                return (__ZNSt3__26__itoa13__traits_baseImvE9__convertEmPc = Module["__ZNSt3__26__itoa13__traits_baseImvE9__convertEmPc"] = Module["asm"]["_ZNSt3__26__itoa13__traits_baseImvE9__convertEmPc"]).apply(null, arguments)
            };
            var __ZNSt3__215__to_chars_itoaIxEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb1EEE = Module["__ZNSt3__215__to_chars_itoaIxEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb1EEE"] = function() {
                return (__ZNSt3__215__to_chars_itoaIxEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb1EEE = Module["__ZNSt3__215__to_chars_itoaIxEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb1EEE"] = Module["asm"]["_ZNSt3__215__to_chars_itoaIxEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb1EEE"]).apply(null, arguments)
            };
            var __ZNSt3__213__to_unsignedIxEENS_13make_unsignedIT_E4typeES2_ = Module["__ZNSt3__213__to_unsignedIxEENS_13make_unsignedIT_E4typeES2_"] = function() {
                return (__ZNSt3__213__to_unsignedIxEENS_13make_unsignedIT_E4typeES2_ = Module["__ZNSt3__213__to_unsignedIxEENS_13make_unsignedIT_E4typeES2_"] = Module["asm"]["_ZNSt3__213__to_unsignedIxEENS_13make_unsignedIT_E4typeES2_"]).apply(null, arguments)
            };
            var __ZNSt3__212__complementIyEET_S1_ = Module["__ZNSt3__212__complementIyEET_S1_"] = function() {
                return (__ZNSt3__212__complementIyEET_S1_ = Module["__ZNSt3__212__complementIyEET_S1_"] = Module["asm"]["_ZNSt3__212__complementIyEET_S1_"]).apply(null, arguments)
            };
            var __ZNSt3__215__to_chars_itoaIyEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__215__to_chars_itoaIyEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb0EEE"] = function() {
                return (__ZNSt3__215__to_chars_itoaIyEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__215__to_chars_itoaIyEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb0EEE"] = Module["asm"]["_ZNSt3__215__to_chars_itoaIyEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb0EEE"]).apply(null, arguments)
            };
            var __ZNSt3__26__itoa13__traits_baseIyvE7__widthEy = Module["__ZNSt3__26__itoa13__traits_baseIyvE7__widthEy"] = function() {
                return (__ZNSt3__26__itoa13__traits_baseIyvE7__widthEy = Module["__ZNSt3__26__itoa13__traits_baseIyvE7__widthEy"] = Module["asm"]["_ZNSt3__26__itoa13__traits_baseIyvE7__widthEy"]).apply(null, arguments)
            };
            var __ZNSt3__26__itoa13__traits_baseIyvE9__convertEyPc = Module["__ZNSt3__26__itoa13__traits_baseIyvE9__convertEyPc"] = function() {
                return (__ZNSt3__26__itoa13__traits_baseIyvE9__convertEyPc = Module["__ZNSt3__26__itoa13__traits_baseIyvE9__convertEyPc"] = Module["asm"]["_ZNSt3__26__itoa13__traits_baseIyvE9__convertEyPc"]).apply(null, arguments)
            };
            var __ZNSt3__26__itoa8__u64toaEyPc = Module["__ZNSt3__26__itoa8__u64toaEyPc"] = function() {
                return (__ZNSt3__26__itoa8__u64toaEyPc = Module["__ZNSt3__26__itoa8__u64toaEyPc"] = Module["asm"]["_ZNSt3__26__itoa8__u64toaEyPc"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initIPcEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeES9_S9_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initIPcEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeES9_S9_"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initIPcEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeES9_S9_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initIPcEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeES9_S9_"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initIPcEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeES9_S9_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRNS_17__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES6_EEEEONS_16remove_referenceIT_E4typeEOSC_ = Module["__ZNSt3__24moveIRNS_17__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES6_EEEEONS_16remove_referenceIT_E4typeEOSC_"] = function() {
                return (__ZNSt3__24moveIRNS_17__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES6_EEEEONS_16remove_referenceIT_E4typeEOSC_ = Module["__ZNSt3__24moveIRNS_17__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES6_EEEEONS_16remove_referenceIT_E4typeEOSC_"] = Module["asm"]["_ZNSt3__24moveIRNS_17__compressed_pairINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5__repES6_EEEEONS_16remove_referenceIT_E4typeEOSC_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRNS_17__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES6_EEEEONS_16remove_referenceIT_E4typeEOSC_ = Module["__ZNSt3__24moveIRNS_17__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES6_EEEEONS_16remove_referenceIT_E4typeEOSC_"] = function() {
                return (__ZNSt3__24moveIRNS_17__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES6_EEEEONS_16remove_referenceIT_E4typeEOSC_ = Module["__ZNSt3__24moveIRNS_17__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES6_EEEEONS_16remove_referenceIT_E4typeEOSC_"] = Module["asm"]["_ZNSt3__24moveIRNS_17__compressed_pairINS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5__repES6_EEEEONS_16remove_referenceIT_E4typeEOSC_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__zeroEv = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__zeroEv"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__zeroEv = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__zeroEv"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__zeroEv"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC1ERKS5_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC1ERKS5_"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC1ERKS5_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC1ERKS5_"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC1ERKS5_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC1ERKS5_RKS4_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC1ERKS5_RKS4_"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC1ERKS5_RKS4_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC1ERKS5_RKS4_"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC1ERKS5_RKS4_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC1ERKS5_mmRKS4_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC1ERKS5_mmRKS4_"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC1ERKS5_mmRKS4_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC1ERKS5_mmRKS4_"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC1ERKS5_mmRKS4_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC1ERKS5_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC1ERKS5_"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC1ERKS5_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC1ERKS5_"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC1ERKS5_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC1ERKS5_RKS4_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC1ERKS5_RKS4_"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC1ERKS5_RKS4_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC1ERKS5_RKS4_"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC1ERKS5_RKS4_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC1ERKS5_mmRKS4_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC1ERKS5_mmRKS4_"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC1ERKS5_mmRKS4_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC1ERKS5_mmRKS4_"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC1ERKS5_mmRKS4_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28valarrayImE6resizeEmm = Module["__ZNSt3__28valarrayImE6resizeEmm"] = function() {
                return (__ZNSt3__28valarrayImE6resizeEmm = Module["__ZNSt3__28valarrayImE6resizeEmm"] = Module["asm"]["_ZNSt3__28valarrayImE6resizeEmm"]).apply(null, arguments)
            };
            var __ZNKSt3__28valarrayImE4sizeEv = Module["__ZNKSt3__28valarrayImE4sizeEv"] = function() {
                return (__ZNKSt3__28valarrayImE4sizeEv = Module["__ZNKSt3__28valarrayImE4sizeEv"] = Module["asm"]["_ZNKSt3__28valarrayImE4sizeEv"]).apply(null, arguments)
            };
            var __ZNSt3__28valarrayImE7__clearEm = Module["__ZNSt3__28valarrayImE7__clearEm"] = function() {
                return (__ZNSt3__28valarrayImE7__clearEm = Module["__ZNSt3__28valarrayImE7__clearEm"] = Module["asm"]["_ZNSt3__28valarrayImE7__clearEm"]).apply(null, arguments)
            };
            var __ZNSt3__26gslice6__initEm = Module["__ZNSt3__26gslice6__initEm"] = function() {
                return (__ZNSt3__26gslice6__initEm = Module["__ZNSt3__26gslice6__initEm"] = Module["asm"]["_ZNSt3__26gslice6__initEm"]).apply(null, arguments)
            };
            var __ZNSt3__28valarrayImEC2Em = Module["__ZNSt3__28valarrayImEC2Em"] = function() {
                return (__ZNSt3__28valarrayImEC2Em = Module["__ZNSt3__28valarrayImEC2Em"] = Module["asm"]["_ZNSt3__28valarrayImEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__28valarrayImEixEm = Module["__ZNSt3__28valarrayImEixEm"] = function() {
                return (__ZNSt3__28valarrayImEixEm = Module["__ZNSt3__28valarrayImEixEm"] = Module["asm"]["_ZNSt3__28valarrayImEixEm"]).apply(null, arguments)
            };
            var __ZNSt3__28valarrayImED2Ev = Module["__ZNSt3__28valarrayImED2Ev"] = function() {
                return (__ZNSt3__28valarrayImED2Ev = Module["__ZNSt3__28valarrayImED2Ev"] = Module["asm"]["_ZNSt3__28valarrayImED2Ev"]).apply(null, arguments)
            };
            var __ZNSt19bad_optional_accessD2Ev = Module["__ZNSt19bad_optional_accessD2Ev"] = function() {
                return (__ZNSt19bad_optional_accessD2Ev = Module["__ZNSt19bad_optional_accessD2Ev"] = Module["asm"]["_ZNSt19bad_optional_accessD2Ev"]).apply(null, arguments)
            };
            var __ZNSt9exceptionD2Ev = Module["__ZNSt9exceptionD2Ev"] = function() {
                return (__ZNSt9exceptionD2Ev = Module["__ZNSt9exceptionD2Ev"] = Module["asm"]["_ZNSt9exceptionD2Ev"]).apply(null, arguments)
            };
            var __ZNSt19bad_optional_accessD0Ev = Module["__ZNSt19bad_optional_accessD0Ev"] = function() {
                return (__ZNSt19bad_optional_accessD0Ev = Module["__ZNSt19bad_optional_accessD0Ev"] = Module["asm"]["_ZNSt19bad_optional_accessD0Ev"]).apply(null, arguments)
            };
            var __ZNKSt19bad_optional_access4whatEv = Module["__ZNKSt19bad_optional_access4whatEv"] = function() {
                return (__ZNKSt19bad_optional_access4whatEv = Module["__ZNKSt19bad_optional_access4whatEv"] = Module["asm"]["_ZNKSt19bad_optional_access4whatEv"]).apply(null, arguments)
            };
            var __ZNSt12experimental19bad_optional_accessD2Ev = Module["__ZNSt12experimental19bad_optional_accessD2Ev"] = function() {
                return (__ZNSt12experimental19bad_optional_accessD2Ev = Module["__ZNSt12experimental19bad_optional_accessD2Ev"] = Module["asm"]["_ZNSt12experimental19bad_optional_accessD2Ev"]).apply(null, arguments)
            };
            var __ZNSt11logic_errorD2Ev = Module["__ZNSt11logic_errorD2Ev"] = function() {
                return (__ZNSt11logic_errorD2Ev = Module["__ZNSt11logic_errorD2Ev"] = Module["asm"]["_ZNSt11logic_errorD2Ev"]).apply(null, arguments)
            };
            var __ZNSt12experimental19bad_optional_accessD0Ev = Module["__ZNSt12experimental19bad_optional_accessD0Ev"] = function() {
                return (__ZNSt12experimental19bad_optional_accessD0Ev = Module["__ZNSt12experimental19bad_optional_accessD0Ev"] = Module["asm"]["_ZNSt12experimental19bad_optional_accessD0Ev"]).apply(null, arguments)
            };
            var __ZNKSt11logic_error4whatEv = Module["__ZNKSt11logic_error4whatEv"] = function() {
                return (__ZNKSt11logic_error4whatEv = Module["__ZNKSt11logic_error4whatEv"] = Module["asm"]["_ZNKSt11logic_error4whatEv"]).apply(null, arguments)
            };
            var __ZNSt19bad_optional_accessD1Ev = Module["__ZNSt19bad_optional_accessD1Ev"] = function() {
                return (__ZNSt19bad_optional_accessD1Ev = Module["__ZNSt19bad_optional_accessD1Ev"] = Module["asm"]["_ZNSt19bad_optional_accessD1Ev"]).apply(null, arguments)
            };
            var __ZNSt12experimental19bad_optional_accessD1Ev = Module["__ZNSt12experimental19bad_optional_accessD1Ev"] = function() {
                return (__ZNSt12experimental19bad_optional_accessD1Ev = Module["__ZNSt12experimental19bad_optional_accessD1Ev"] = Module["asm"]["_ZNSt12experimental19bad_optional_accessD1Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__223__future_error_category4nameEv = Module["__ZNKSt3__223__future_error_category4nameEv"] = function() {
                return (__ZNKSt3__223__future_error_category4nameEv = Module["__ZNKSt3__223__future_error_category4nameEv"] = Module["asm"]["_ZNKSt3__223__future_error_category4nameEv"]).apply(null, arguments)
            };
            var __ZNKSt3__223__future_error_category7messageEi = Module["__ZNKSt3__223__future_error_category7messageEi"] = function() {
                return (__ZNKSt3__223__future_error_category7messageEi = Module["__ZNKSt3__223__future_error_category7messageEi"] = Module["asm"]["_ZNKSt3__223__future_error_category7messageEi"]).apply(null, arguments)
            };
            var __ZNSt3__215future_categoryEv = Module["__ZNSt3__215future_categoryEv"] = function() {
                return (__ZNSt3__215future_categoryEv = Module["__ZNSt3__215future_categoryEv"] = Module["asm"]["_ZNSt3__215future_categoryEv"]).apply(null, arguments)
            };
            var ___cxa_guard_acquire = Module["___cxa_guard_acquire"] = function() {
                return (___cxa_guard_acquire = Module["___cxa_guard_acquire"] = Module["asm"]["__cxa_guard_acquire"]).apply(null, arguments)
            };
            var ___cxa_guard_release = Module["___cxa_guard_release"] = function() {
                return (___cxa_guard_release = Module["___cxa_guard_release"] = Module["asm"]["__cxa_guard_release"]).apply(null, arguments)
            };
            var __ZNSt3__214error_categoryD2Ev = Module["__ZNSt3__214error_categoryD2Ev"] = function() {
                return (__ZNSt3__214error_categoryD2Ev = Module["__ZNSt3__214error_categoryD2Ev"] = Module["asm"]["_ZNSt3__214error_categoryD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212future_errorC2ENS_10error_codeE = Module["__ZNSt3__212future_errorC2ENS_10error_codeE"] = function() {
                return (__ZNSt3__212future_errorC2ENS_10error_codeE = Module["__ZNSt3__212future_errorC2ENS_10error_codeE"] = Module["asm"]["_ZNSt3__212future_errorC2ENS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNKSt3__210error_code7messageEv = Module["__ZNKSt3__210error_code7messageEv"] = function() {
                return (__ZNKSt3__210error_code7messageEv = Module["__ZNKSt3__210error_code7messageEv"] = Module["asm"]["_ZNKSt3__210error_code7messageEv"]).apply(null, arguments)
            };
            var __ZNSt3__212future_errorD2Ev = Module["__ZNSt3__212future_errorD2Ev"] = function() {
                return (__ZNSt3__212future_errorD2Ev = Module["__ZNSt3__212future_errorD2Ev"] = Module["asm"]["_ZNSt3__212future_errorD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212future_errorD0Ev = Module["__ZNSt3__212future_errorD0Ev"] = function() {
                return (__ZNSt3__212future_errorD0Ev = Module["__ZNSt3__212future_errorD0Ev"] = Module["asm"]["_ZNSt3__212future_errorD0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217__assoc_sub_state16__on_zero_sharedEv = Module["__ZNSt3__217__assoc_sub_state16__on_zero_sharedEv"] = function() {
                return (__ZNSt3__217__assoc_sub_state16__on_zero_sharedEv = Module["__ZNSt3__217__assoc_sub_state16__on_zero_sharedEv"] = Module["asm"]["_ZNSt3__217__assoc_sub_state16__on_zero_sharedEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__assoc_sub_state9set_valueEv = Module["__ZNSt3__217__assoc_sub_state9set_valueEv"] = function() {
                return (__ZNSt3__217__assoc_sub_state9set_valueEv = Module["__ZNSt3__217__assoc_sub_state9set_valueEv"] = Module["asm"]["_ZNSt3__217__assoc_sub_state9set_valueEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217__assoc_sub_state11__has_valueEv = Module["__ZNKSt3__217__assoc_sub_state11__has_valueEv"] = function() {
                return (__ZNKSt3__217__assoc_sub_state11__has_valueEv = Module["__ZNKSt3__217__assoc_sub_state11__has_valueEv"] = Module["asm"]["_ZNKSt3__217__assoc_sub_state11__has_valueEv"]).apply(null, arguments)
            };
            var __ZNSt3__220__throw_future_errorENS_11future_errcE = Module["__ZNSt3__220__throw_future_errorENS_11future_errcE"] = function() {
                return (__ZNSt3__220__throw_future_errorENS_11future_errcE = Module["__ZNSt3__220__throw_future_errorENS_11future_errcE"] = Module["asm"]["_ZNSt3__220__throw_future_errorENS_11future_errcE"]).apply(null, arguments)
            };
            var __ZStneRKSt13exception_ptrS1_ = Module["__ZStneRKSt13exception_ptrS1_"] = function() {
                return (__ZStneRKSt13exception_ptrS1_ = Module["__ZStneRKSt13exception_ptrS1_"] = Module["asm"]["_ZStneRKSt13exception_ptrS1_"]).apply(null, arguments)
            };
            var __ZNSt3__217__assoc_sub_state24set_value_at_thread_exitEv = Module["__ZNSt3__217__assoc_sub_state24set_value_at_thread_exitEv"] = function() {
                return (__ZNSt3__217__assoc_sub_state24set_value_at_thread_exitEv = Module["__ZNSt3__217__assoc_sub_state24set_value_at_thread_exitEv"] = Module["asm"]["_ZNSt3__217__assoc_sub_state24set_value_at_thread_exitEv"]).apply(null, arguments)
            };
            var __ZNSt3__219__thread_local_dataEv = Module["__ZNSt3__219__thread_local_dataEv"] = function() {
                return (__ZNSt3__219__thread_local_dataEv = Module["__ZNSt3__219__thread_local_dataEv"] = Module["asm"]["_ZNSt3__219__thread_local_dataEv"]).apply(null, arguments)
            };
            var __ZNKSt3__221__thread_specific_ptrINS_15__thread_structEEptEv = Module["__ZNKSt3__221__thread_specific_ptrINS_15__thread_structEEptEv"] = function() {
                return (__ZNKSt3__221__thread_specific_ptrINS_15__thread_structEEptEv = Module["__ZNKSt3__221__thread_specific_ptrINS_15__thread_structEEptEv"] = Module["asm"]["_ZNKSt3__221__thread_specific_ptrINS_15__thread_structEEptEv"]).apply(null, arguments)
            };
            var __ZNSt3__215__thread_struct27__make_ready_at_thread_exitEPNS_17__assoc_sub_stateE = Module["__ZNSt3__215__thread_struct27__make_ready_at_thread_exitEPNS_17__assoc_sub_stateE"] = function() {
                return (__ZNSt3__215__thread_struct27__make_ready_at_thread_exitEPNS_17__assoc_sub_stateE = Module["__ZNSt3__215__thread_struct27__make_ready_at_thread_exitEPNS_17__assoc_sub_stateE"] = Module["asm"]["_ZNSt3__215__thread_struct27__make_ready_at_thread_exitEPNS_17__assoc_sub_stateE"]).apply(null, arguments)
            };
            var __ZNKSt3__221__thread_specific_ptrINS_15__thread_structEE3getEv = Module["__ZNKSt3__221__thread_specific_ptrINS_15__thread_structEE3getEv"] = function() {
                return (__ZNKSt3__221__thread_specific_ptrINS_15__thread_structEE3getEv = Module["__ZNKSt3__221__thread_specific_ptrINS_15__thread_structEE3getEv"] = Module["asm"]["_ZNKSt3__221__thread_specific_ptrINS_15__thread_structEE3getEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__assoc_sub_state13set_exceptionESt13exception_ptr = Module["__ZNSt3__217__assoc_sub_state13set_exceptionESt13exception_ptr"] = function() {
                return (__ZNSt3__217__assoc_sub_state13set_exceptionESt13exception_ptr = Module["__ZNSt3__217__assoc_sub_state13set_exceptionESt13exception_ptr"] = Module["asm"]["_ZNSt3__217__assoc_sub_state13set_exceptionESt13exception_ptr"]).apply(null, arguments)
            };
            var __ZNSt3__217__assoc_sub_state28set_exception_at_thread_exitESt13exception_ptr = Module["__ZNSt3__217__assoc_sub_state28set_exception_at_thread_exitESt13exception_ptr"] = function() {
                return (__ZNSt3__217__assoc_sub_state28set_exception_at_thread_exitESt13exception_ptr = Module["__ZNSt3__217__assoc_sub_state28set_exception_at_thread_exitESt13exception_ptr"] = Module["asm"]["_ZNSt3__217__assoc_sub_state28set_exception_at_thread_exitESt13exception_ptr"]).apply(null, arguments)
            };
            var __ZNSt3__217__assoc_sub_state12__make_readyEv = Module["__ZNSt3__217__assoc_sub_state12__make_readyEv"] = function() {
                return (__ZNSt3__217__assoc_sub_state12__make_readyEv = Module["__ZNSt3__217__assoc_sub_state12__make_readyEv"] = Module["asm"]["_ZNSt3__217__assoc_sub_state12__make_readyEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__assoc_sub_state4copyEv = Module["__ZNSt3__217__assoc_sub_state4copyEv"] = function() {
                return (__ZNSt3__217__assoc_sub_state4copyEv = Module["__ZNSt3__217__assoc_sub_state4copyEv"] = Module["asm"]["_ZNSt3__217__assoc_sub_state4copyEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__assoc_sub_state10__sub_waitERNS_11unique_lockINS_5mutexEEE = Module["__ZNSt3__217__assoc_sub_state10__sub_waitERNS_11unique_lockINS_5mutexEEE"] = function() {
                return (__ZNSt3__217__assoc_sub_state10__sub_waitERNS_11unique_lockINS_5mutexEEE = Module["__ZNSt3__217__assoc_sub_state10__sub_waitERNS_11unique_lockINS_5mutexEEE"] = Module["asm"]["_ZNSt3__217__assoc_sub_state10__sub_waitERNS_11unique_lockINS_5mutexEEE"]).apply(null, arguments)
            };
            var __ZNKSt3__217__assoc_sub_state10__is_readyEv = Module["__ZNKSt3__217__assoc_sub_state10__is_readyEv"] = function() {
                return (__ZNKSt3__217__assoc_sub_state10__is_readyEv = Module["__ZNKSt3__217__assoc_sub_state10__is_readyEv"] = Module["asm"]["_ZNKSt3__217__assoc_sub_state10__is_readyEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__assoc_sub_state4waitEv = Module["__ZNSt3__217__assoc_sub_state4waitEv"] = function() {
                return (__ZNSt3__217__assoc_sub_state4waitEv = Module["__ZNSt3__217__assoc_sub_state4waitEv"] = Module["asm"]["_ZNSt3__217__assoc_sub_state4waitEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__assoc_sub_state9__executeEv = Module["__ZNSt3__217__assoc_sub_state9__executeEv"] = function() {
                return (__ZNSt3__217__assoc_sub_state9__executeEv = Module["__ZNSt3__217__assoc_sub_state9__executeEv"] = Module["asm"]["_ZNSt3__217__assoc_sub_state9__executeEv"]).apply(null, arguments)
            };
            var __ZNSt3__26futureIvEC2EPNS_17__assoc_sub_stateE = Module["__ZNSt3__26futureIvEC2EPNS_17__assoc_sub_stateE"] = function() {
                return (__ZNSt3__26futureIvEC2EPNS_17__assoc_sub_stateE = Module["__ZNSt3__26futureIvEC2EPNS_17__assoc_sub_stateE"] = Module["asm"]["_ZNSt3__26futureIvEC2EPNS_17__assoc_sub_stateE"]).apply(null, arguments)
            };
            var __ZNSt3__217__assoc_sub_state15__attach_futureEv = Module["__ZNSt3__217__assoc_sub_state15__attach_futureEv"] = function() {
                return (__ZNSt3__217__assoc_sub_state15__attach_futureEv = Module["__ZNSt3__217__assoc_sub_state15__attach_futureEv"] = Module["asm"]["_ZNSt3__217__assoc_sub_state15__attach_futureEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__shared_count12__add_sharedEv = Module["__ZNSt3__214__shared_count12__add_sharedEv"] = function() {
                return (__ZNSt3__214__shared_count12__add_sharedEv = Module["__ZNSt3__214__shared_count12__add_sharedEv"] = Module["asm"]["_ZNSt3__214__shared_count12__add_sharedEv"]).apply(null, arguments)
            };
            var __ZNSt3__26futureIvED2Ev = Module["__ZNSt3__26futureIvED2Ev"] = function() {
                return (__ZNSt3__26futureIvED2Ev = Module["__ZNSt3__26futureIvED2Ev"] = Module["asm"]["_ZNSt3__26futureIvED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214__shared_count16__release_sharedEv = Module["__ZNSt3__214__shared_count16__release_sharedEv"] = function() {
                return (__ZNSt3__214__shared_count16__release_sharedEv = Module["__ZNSt3__214__shared_count16__release_sharedEv"] = Module["asm"]["_ZNSt3__214__shared_count16__release_sharedEv"]).apply(null, arguments)
            };
            var __ZNSt3__234__libcpp_atomic_refcount_decrementIlEET_RS1_ = Module["__ZNSt3__234__libcpp_atomic_refcount_decrementIlEET_RS1_"] = function() {
                return (__ZNSt3__234__libcpp_atomic_refcount_decrementIlEET_RS1_ = Module["__ZNSt3__234__libcpp_atomic_refcount_decrementIlEET_RS1_"] = Module["asm"]["_ZNSt3__234__libcpp_atomic_refcount_decrementIlEET_RS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26futureIvE3getEv = Module["__ZNSt3__26futureIvE3getEv"] = function() {
                return (__ZNSt3__26futureIvE3getEv = Module["__ZNSt3__26futureIvE3getEv"] = Module["asm"]["_ZNSt3__26futureIvE3getEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrINS_14__shared_countENS_22__release_shared_countEEC2ILb1EvEEPS1_ = Module["__ZNSt3__210unique_ptrINS_14__shared_countENS_22__release_shared_countEEC2ILb1EvEEPS1_"] = function() {
                return (__ZNSt3__210unique_ptrINS_14__shared_countENS_22__release_shared_countEEC2ILb1EvEEPS1_ = Module["__ZNSt3__210unique_ptrINS_14__shared_countENS_22__release_shared_countEEC2ILb1EvEEPS1_"] = Module["asm"]["_ZNSt3__210unique_ptrINS_14__shared_countENS_22__release_shared_countEEC2ILb1EvEEPS1_"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrINS_14__shared_countENS_22__release_shared_countEED2Ev = Module["__ZNSt3__210unique_ptrINS_14__shared_countENS_22__release_shared_countEED2Ev"] = function() {
                return (__ZNSt3__210unique_ptrINS_14__shared_countENS_22__release_shared_countEED2Ev = Module["__ZNSt3__210unique_ptrINS_14__shared_countENS_22__release_shared_countEED2Ev"] = Module["asm"]["_ZNSt3__210unique_ptrINS_14__shared_countENS_22__release_shared_countEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_14__shared_countENS_22__release_shared_countEEC2IRS2_NS_18__default_init_tagEEEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPNS_14__shared_countENS_22__release_shared_countEEC2IRS2_NS_18__default_init_tagEEEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_14__shared_countENS_22__release_shared_countEEC2IRS2_NS_18__default_init_tagEEEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPNS_14__shared_countENS_22__release_shared_countEEC2IRS2_NS_18__default_init_tagEEEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_14__shared_countENS_22__release_shared_countEEC2IRS2_NS_18__default_init_tagEEEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrINS_14__shared_countENS_22__release_shared_countEE5resetEPS1_ = Module["__ZNSt3__210unique_ptrINS_14__shared_countENS_22__release_shared_countEE5resetEPS1_"] = function() {
                return (__ZNSt3__210unique_ptrINS_14__shared_countENS_22__release_shared_countEE5resetEPS1_ = Module["__ZNSt3__210unique_ptrINS_14__shared_countENS_22__release_shared_countEE5resetEPS1_"] = Module["asm"]["_ZNSt3__210unique_ptrINS_14__shared_countENS_22__release_shared_countEE5resetEPS1_"]).apply(null, arguments)
            };
            var __ZNSt3__27promiseIvEC2Ev = Module["__ZNSt3__27promiseIvEC2Ev"] = function() {
                return (__ZNSt3__27promiseIvEC2Ev = Module["__ZNSt3__27promiseIvEC2Ev"] = Module["asm"]["_ZNSt3__27promiseIvEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217__assoc_sub_stateC2Ev = Module["__ZNSt3__217__assoc_sub_stateC2Ev"] = function() {
                return (__ZNSt3__217__assoc_sub_stateC2Ev = Module["__ZNSt3__217__assoc_sub_stateC2Ev"] = Module["asm"]["_ZNSt3__217__assoc_sub_stateC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214__shared_countC2El = Module["__ZNSt3__214__shared_countC2El"] = function() {
                return (__ZNSt3__214__shared_countC2El = Module["__ZNSt3__214__shared_countC2El"] = Module["asm"]["_ZNSt3__214__shared_countC2El"]).apply(null, arguments)
            };
            var __ZNSt3__27promiseIvED2Ev = Module["__ZNSt3__27promiseIvED2Ev"] = function() {
                return (__ZNSt3__27promiseIvED2Ev = Module["__ZNSt3__27promiseIvED2Ev"] = Module["asm"]["_ZNSt3__27promiseIvED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__27promiseIvE10get_futureEv = Module["__ZNSt3__27promiseIvE10get_futureEv"] = function() {
                return (__ZNSt3__27promiseIvE10get_futureEv = Module["__ZNSt3__27promiseIvE10get_futureEv"] = Module["asm"]["_ZNSt3__27promiseIvE10get_futureEv"]).apply(null, arguments)
            };
            var __ZNSt3__27promiseIvE9set_valueEv = Module["__ZNSt3__27promiseIvE9set_valueEv"] = function() {
                return (__ZNSt3__27promiseIvE9set_valueEv = Module["__ZNSt3__27promiseIvE9set_valueEv"] = Module["asm"]["_ZNSt3__27promiseIvE9set_valueEv"]).apply(null, arguments)
            };
            var __ZNSt3__27promiseIvE13set_exceptionESt13exception_ptr = Module["__ZNSt3__27promiseIvE13set_exceptionESt13exception_ptr"] = function() {
                return (__ZNSt3__27promiseIvE13set_exceptionESt13exception_ptr = Module["__ZNSt3__27promiseIvE13set_exceptionESt13exception_ptr"] = Module["asm"]["_ZNSt3__27promiseIvE13set_exceptionESt13exception_ptr"]).apply(null, arguments)
            };
            var __ZNSt3__27promiseIvE24set_value_at_thread_exitEv = Module["__ZNSt3__27promiseIvE24set_value_at_thread_exitEv"] = function() {
                return (__ZNSt3__27promiseIvE24set_value_at_thread_exitEv = Module["__ZNSt3__27promiseIvE24set_value_at_thread_exitEv"] = Module["asm"]["_ZNSt3__27promiseIvE24set_value_at_thread_exitEv"]).apply(null, arguments)
            };
            var __ZNSt3__27promiseIvE28set_exception_at_thread_exitESt13exception_ptr = Module["__ZNSt3__27promiseIvE28set_exception_at_thread_exitESt13exception_ptr"] = function() {
                return (__ZNSt3__27promiseIvE28set_exception_at_thread_exitESt13exception_ptr = Module["__ZNSt3__27promiseIvE28set_exception_at_thread_exitESt13exception_ptr"] = Module["asm"]["_ZNSt3__27promiseIvE28set_exception_at_thread_exitESt13exception_ptr"]).apply(null, arguments)
            };
            var __ZNSt3__213shared_futureIvED2Ev = Module["__ZNSt3__213shared_futureIvED2Ev"] = function() {
                return (__ZNSt3__213shared_futureIvED2Ev = Module["__ZNSt3__213shared_futureIvED2Ev"] = Module["asm"]["_ZNSt3__213shared_futureIvED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213shared_futureIvEaSERKS1_ = Module["__ZNSt3__213shared_futureIvEaSERKS1_"] = function() {
                return (__ZNSt3__213shared_futureIvEaSERKS1_ = Module["__ZNSt3__213shared_futureIvEaSERKS1_"] = Module["asm"]["_ZNSt3__213shared_futureIvEaSERKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__234__libcpp_atomic_refcount_incrementIlEET_RS1_ = Module["__ZNSt3__234__libcpp_atomic_refcount_incrementIlEET_RS1_"] = function() {
                return (__ZNSt3__234__libcpp_atomic_refcount_incrementIlEET_RS1_ = Module["__ZNSt3__234__libcpp_atomic_refcount_incrementIlEET_RS1_"] = Module["asm"]["_ZNSt3__234__libcpp_atomic_refcount_incrementIlEET_RS1_"]).apply(null, arguments)
            };
            var __ZNSt3__217__assoc_sub_stateD2Ev = Module["__ZNSt3__217__assoc_sub_stateD2Ev"] = function() {
                return (__ZNSt3__217__assoc_sub_stateD2Ev = Module["__ZNSt3__217__assoc_sub_stateD2Ev"] = Module["asm"]["_ZNSt3__217__assoc_sub_stateD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214__shared_countD2Ev = Module["__ZNSt3__214__shared_countD2Ev"] = function() {
                return (__ZNSt3__214__shared_countD2Ev = Module["__ZNSt3__214__shared_countD2Ev"] = Module["asm"]["_ZNSt3__214__shared_countD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217__assoc_sub_stateD0Ev = Module["__ZNSt3__217__assoc_sub_stateD0Ev"] = function() {
                return (__ZNSt3__217__assoc_sub_stateD0Ev = Module["__ZNSt3__217__assoc_sub_stateD0Ev"] = Module["asm"]["_ZNSt3__217__assoc_sub_stateD0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__223__future_error_categoryD0Ev = Module["__ZNSt3__223__future_error_categoryD0Ev"] = function() {
                return (__ZNSt3__223__future_error_categoryD0Ev = Module["__ZNSt3__223__future_error_categoryD0Ev"] = Module["asm"]["_ZNSt3__223__future_error_categoryD0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__216__libcpp_tls_getEj = Module["__ZNSt3__216__libcpp_tls_getEj"] = function() {
                return (__ZNSt3__216__libcpp_tls_getEj = Module["__ZNSt3__216__libcpp_tls_getEj"] = Module["asm"]["_ZNSt3__216__libcpp_tls_getEj"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRPNS_14__shared_countEEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRPNS_14__shared_countEEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRPNS_14__shared_countEEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRPNS_14__shared_countEEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRPNS_14__shared_countEEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPNS_14__shared_countELi0ELb0EEC2IRS2_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPNS_14__shared_countELi0ELb0EEC2IRS2_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPNS_14__shared_countELi0ELb0EEC2IRS2_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPNS_14__shared_countELi0ELb0EEC2IRS2_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPNS_14__shared_countELi0ELb0EEC2IRS2_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_22__release_shared_countELi1ELb1EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_22__release_shared_countELi1ELb1EEC2ENS_18__default_init_tagE"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_22__release_shared_countELi1ELb1EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_22__release_shared_countELi1ELb1EEC2ENS_18__default_init_tagE"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_22__release_shared_countELi1ELb1EEC2ENS_18__default_init_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_14__shared_countENS_22__release_shared_countEE5firstEv = Module["__ZNSt3__217__compressed_pairIPNS_14__shared_countENS_22__release_shared_countEE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_14__shared_countENS_22__release_shared_countEE5firstEv = Module["__ZNSt3__217__compressed_pairIPNS_14__shared_countENS_22__release_shared_countEE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_14__shared_countENS_22__release_shared_countEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_14__shared_countENS_22__release_shared_countEE6secondEv = Module["__ZNSt3__217__compressed_pairIPNS_14__shared_countENS_22__release_shared_countEE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_14__shared_countENS_22__release_shared_countEE6secondEv = Module["__ZNSt3__217__compressed_pairIPNS_14__shared_countENS_22__release_shared_countEE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_14__shared_countENS_22__release_shared_countEE6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__release_shared_countclEPNS_14__shared_countE = Module["__ZNSt3__222__release_shared_countclEPNS_14__shared_countE"] = function() {
                return (__ZNSt3__222__release_shared_countclEPNS_14__shared_countE = Module["__ZNSt3__222__release_shared_countclEPNS_14__shared_countE"] = Module["asm"]["_ZNSt3__222__release_shared_countclEPNS_14__shared_countE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPNS_14__shared_countELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPNS_14__shared_countELi0ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPNS_14__shared_countELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPNS_14__shared_countELi0ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPNS_14__shared_countELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_22__release_shared_countELi1ELb1EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_22__release_shared_countELi1ELb1EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_22__release_shared_countELi1ELb1EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_22__release_shared_countELi1ELb1EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_22__release_shared_countELi1ELb1EE5__getEv"]).apply(null, arguments)
            };
            var __ZNKSt3__214error_category23default_error_conditionEi = Module["__ZNKSt3__214error_category23default_error_conditionEi"] = function() {
                return (__ZNKSt3__214error_category23default_error_conditionEi = Module["__ZNKSt3__214error_category23default_error_conditionEi"] = Module["asm"]["_ZNKSt3__214error_category23default_error_conditionEi"]).apply(null, arguments)
            };
            var __ZNKSt3__214error_category10equivalentEiRKNS_15error_conditionE = Module["__ZNKSt3__214error_category10equivalentEiRKNS_15error_conditionE"] = function() {
                return (__ZNKSt3__214error_category10equivalentEiRKNS_15error_conditionE = Module["__ZNKSt3__214error_category10equivalentEiRKNS_15error_conditionE"] = Module["asm"]["_ZNKSt3__214error_category10equivalentEiRKNS_15error_conditionE"]).apply(null, arguments)
            };
            var __ZNKSt3__214error_category10equivalentERKNS_10error_codeEi = Module["__ZNKSt3__214error_category10equivalentERKNS_10error_codeEi"] = function() {
                return (__ZNKSt3__214error_category10equivalentERKNS_10error_codeEi = Module["__ZNKSt3__214error_category10equivalentERKNS_10error_codeEi"] = Module["asm"]["_ZNKSt3__214error_category10equivalentERKNS_10error_codeEi"]).apply(null, arguments)
            };
            var __ZNSt3__212future_errorC1ENS_10error_codeE = Module["__ZNSt3__212future_errorC1ENS_10error_codeE"] = function() {
                return (__ZNSt3__212future_errorC1ENS_10error_codeE = Module["__ZNSt3__212future_errorC1ENS_10error_codeE"] = Module["asm"]["_ZNSt3__212future_errorC1ENS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__212future_errorD1Ev = Module["__ZNSt3__212future_errorD1Ev"] = function() {
                return (__ZNSt3__212future_errorD1Ev = Module["__ZNSt3__212future_errorD1Ev"] = Module["asm"]["_ZNSt3__212future_errorD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__26futureIvEC1EPNS_17__assoc_sub_stateE = Module["__ZNSt3__26futureIvEC1EPNS_17__assoc_sub_stateE"] = function() {
                return (__ZNSt3__26futureIvEC1EPNS_17__assoc_sub_stateE = Module["__ZNSt3__26futureIvEC1EPNS_17__assoc_sub_stateE"] = Module["asm"]["_ZNSt3__26futureIvEC1EPNS_17__assoc_sub_stateE"]).apply(null, arguments)
            };
            var __ZNSt3__26futureIvED1Ev = Module["__ZNSt3__26futureIvED1Ev"] = function() {
                return (__ZNSt3__26futureIvED1Ev = Module["__ZNSt3__26futureIvED1Ev"] = Module["asm"]["_ZNSt3__26futureIvED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__27promiseIvEC1Ev = Module["__ZNSt3__27promiseIvEC1Ev"] = function() {
                return (__ZNSt3__27promiseIvEC1Ev = Module["__ZNSt3__27promiseIvEC1Ev"] = Module["asm"]["_ZNSt3__27promiseIvEC1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__27promiseIvED1Ev = Module["__ZNSt3__27promiseIvED1Ev"] = function() {
                return (__ZNSt3__27promiseIvED1Ev = Module["__ZNSt3__27promiseIvED1Ev"] = Module["asm"]["_ZNSt3__27promiseIvED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213shared_futureIvED1Ev = Module["__ZNSt3__213shared_futureIvED1Ev"] = function() {
                return (__ZNSt3__213shared_futureIvED1Ev = Module["__ZNSt3__213shared_futureIvED1Ev"] = Module["asm"]["_ZNSt3__213shared_futureIvED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__211regex_errorC2ENS_15regex_constants10error_typeE = Module["__ZNSt3__211regex_errorC2ENS_15regex_constants10error_typeE"] = function() {
                return (__ZNSt3__211regex_errorC2ENS_15regex_constants10error_typeE = Module["__ZNSt3__211regex_errorC2ENS_15regex_constants10error_typeE"] = Module["asm"]["_ZNSt3__211regex_errorC2ENS_15regex_constants10error_typeE"]).apply(null, arguments)
            };
            var __ZNSt3__211regex_errorD2Ev = Module["__ZNSt3__211regex_errorD2Ev"] = function() {
                return (__ZNSt3__211regex_errorD2Ev = Module["__ZNSt3__211regex_errorD2Ev"] = Module["asm"]["_ZNSt3__211regex_errorD2Ev"]).apply(null, arguments)
            };
            var __ZNSt13runtime_errorD2Ev = Module["__ZNSt13runtime_errorD2Ev"] = function() {
                return (__ZNSt13runtime_errorD2Ev = Module["__ZNSt13runtime_errorD2Ev"] = Module["asm"]["_ZNSt13runtime_errorD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__211regex_errorD0Ev = Module["__ZNSt3__211regex_errorD0Ev"] = function() {
                return (__ZNSt3__211regex_errorD0Ev = Module["__ZNSt3__211regex_errorD0Ev"] = Module["asm"]["_ZNSt3__211regex_errorD0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__220__get_collation_nameEPKc = Module["__ZNSt3__220__get_collation_nameEPKc"] = function() {
                return (__ZNSt3__220__get_collation_nameEPKc = Module["__ZNSt3__220__get_collation_nameEPKc"] = Module["asm"]["_ZNSt3__220__get_collation_nameEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__215__get_classnameEPKcb = Module["__ZNSt3__215__get_classnameEPKcb"] = function() {
                return (__ZNSt3__215__get_classnameEPKcb = Module["__ZNSt3__215__get_classnameEPKcb"] = Module["asm"]["_ZNSt3__215__get_classnameEPKcb"]).apply(null, arguments)
            };
            var __ZNKSt3__223__match_any_but_newlineIcE6__execERNS_7__stateIcEE = Module["__ZNKSt3__223__match_any_but_newlineIcE6__execERNS_7__stateIcEE"] = function() {
                return (__ZNKSt3__223__match_any_but_newlineIcE6__execERNS_7__stateIcEE = Module["__ZNKSt3__223__match_any_but_newlineIcE6__execERNS_7__stateIcEE"] = Module["asm"]["_ZNKSt3__223__match_any_but_newlineIcE6__execERNS_7__stateIcEE"]).apply(null, arguments)
            };
            var __ZNKSt3__215__has_one_stateIcE5firstEv = Module["__ZNKSt3__215__has_one_stateIcE5firstEv"] = function() {
                return (__ZNKSt3__215__has_one_stateIcE5firstEv = Module["__ZNKSt3__215__has_one_stateIcE5firstEv"] = Module["asm"]["_ZNKSt3__215__has_one_stateIcE5firstEv"]).apply(null, arguments)
            };
            var __ZNKSt3__223__match_any_but_newlineIwE6__execERNS_7__stateIwEE = Module["__ZNKSt3__223__match_any_but_newlineIwE6__execERNS_7__stateIwEE"] = function() {
                return (__ZNKSt3__223__match_any_but_newlineIwE6__execERNS_7__stateIwEE = Module["__ZNKSt3__223__match_any_but_newlineIwE6__execERNS_7__stateIwEE"] = Module["asm"]["_ZNKSt3__223__match_any_but_newlineIwE6__execERNS_7__stateIwEE"]).apply(null, arguments)
            };
            var __ZNKSt3__215__has_one_stateIwE5firstEv = Module["__ZNKSt3__215__has_one_stateIwE5firstEv"] = function() {
                return (__ZNKSt3__215__has_one_stateIwE5firstEv = Module["__ZNKSt3__215__has_one_stateIwE5firstEv"] = Module["asm"]["_ZNKSt3__215__has_one_stateIwE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__215__half_positiveIlEENS_9enable_ifIXsr11is_integralIT_EE5valueES2_E4typeES2_ = Module["__ZNSt3__215__half_positiveIlEENS_9enable_ifIXsr11is_integralIT_EE5valueES2_E4typeES2_"] = function() {
                return (__ZNSt3__215__half_positiveIlEENS_9enable_ifIXsr11is_integralIT_EE5valueES2_E4typeES2_ = Module["__ZNSt3__215__half_positiveIlEENS_9enable_ifIXsr11is_integralIT_EE5valueES2_E4typeES2_"] = Module["asm"]["_ZNSt3__215__half_positiveIlEENS_9enable_ifIXsr11is_integralIT_EE5valueES2_E4typeES2_"]).apply(null, arguments)
            };
            var __ZNKSt13runtime_error4whatEv = Module["__ZNKSt13runtime_error4whatEv"] = function() {
                return (__ZNKSt13runtime_error4whatEv = Module["__ZNKSt13runtime_error4whatEv"] = Module["asm"]["_ZNKSt13runtime_error4whatEv"]).apply(null, arguments)
            };
            var __ZNSt3__211regex_errorC1ENS_15regex_constants10error_typeE = Module["__ZNSt3__211regex_errorC1ENS_15regex_constants10error_typeE"] = function() {
                return (__ZNSt3__211regex_errorC1ENS_15regex_constants10error_typeE = Module["__ZNSt3__211regex_errorC1ENS_15regex_constants10error_typeE"] = Module["asm"]["_ZNSt3__211regex_errorC1ENS_15regex_constants10error_typeE"]).apply(null, arguments)
            };
            var __ZNSt3__211regex_errorD1Ev = Module["__ZNSt3__211regex_errorD1Ev"] = function() {
                return (__ZNSt3__211regex_errorD1Ev = Module["__ZNSt3__211regex_errorD1Ev"] = Module["asm"]["_ZNSt3__211regex_errorD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__26__itoa16append8_no_zerosIjEEPcS2_T_ = Module["__ZNSt3__26__itoa16append8_no_zerosIjEEPcS2_T_"] = function() {
                return (__ZNSt3__26__itoa16append8_no_zerosIjEEPcS2_T_ = Module["__ZNSt3__26__itoa16append8_no_zerosIjEEPcS2_T_"] = Module["asm"]["_ZNSt3__26__itoa16append8_no_zerosIjEEPcS2_T_"]).apply(null, arguments)
            };
            var __ZNSt3__26__itoa16append2_no_zerosIjEEPcS2_T_ = Module["__ZNSt3__26__itoa16append2_no_zerosIjEEPcS2_T_"] = function() {
                return (__ZNSt3__26__itoa16append2_no_zerosIjEEPcS2_T_ = Module["__ZNSt3__26__itoa16append2_no_zerosIjEEPcS2_T_"] = Module["asm"]["_ZNSt3__26__itoa16append2_no_zerosIjEEPcS2_T_"]).apply(null, arguments)
            };
            var __ZNSt3__26__itoa7append4IjEEPcS2_T_ = Module["__ZNSt3__26__itoa7append4IjEEPcS2_T_"] = function() {
                return (__ZNSt3__26__itoa7append4IjEEPcS2_T_ = Module["__ZNSt3__26__itoa7append4IjEEPcS2_T_"] = Module["asm"]["_ZNSt3__26__itoa7append4IjEEPcS2_T_"]).apply(null, arguments)
            };
            var __ZNSt3__26__itoa16append4_no_zerosIjEEPcS2_T_ = Module["__ZNSt3__26__itoa16append4_no_zerosIjEEPcS2_T_"] = function() {
                return (__ZNSt3__26__itoa16append4_no_zerosIjEEPcS2_T_ = Module["__ZNSt3__26__itoa16append4_no_zerosIjEEPcS2_T_"] = Module["asm"]["_ZNSt3__26__itoa16append4_no_zerosIjEEPcS2_T_"]).apply(null, arguments)
            };
            var __ZNSt3__26__itoa7append1IjEEPcS2_T_ = Module["__ZNSt3__26__itoa7append1IjEEPcS2_T_"] = function() {
                return (__ZNSt3__26__itoa7append1IjEEPcS2_T_ = Module["__ZNSt3__26__itoa7append1IjEEPcS2_T_"] = Module["asm"]["_ZNSt3__26__itoa7append1IjEEPcS2_T_"]).apply(null, arguments)
            };
            var __ZNSt3__26__itoa7append2IjEEPcS2_T_ = Module["__ZNSt3__26__itoa7append2IjEEPcS2_T_"] = function() {
                return (__ZNSt3__26__itoa7append2IjEEPcS2_T_ = Module["__ZNSt3__26__itoa7append2IjEEPcS2_T_"] = Module["asm"]["_ZNSt3__26__itoa7append2IjEEPcS2_T_"]).apply(null, arguments)
            };
            var __ZNSt3__26__itoa7append3IjEEPcS2_T_ = Module["__ZNSt3__26__itoa7append3IjEEPcS2_T_"] = function() {
                return (__ZNSt3__26__itoa7append3IjEEPcS2_T_ = Module["__ZNSt3__26__itoa7append3IjEEPcS2_T_"] = Module["asm"]["_ZNSt3__26__itoa7append3IjEEPcS2_T_"]).apply(null, arguments)
            };
            var __ZNSt3__212bad_weak_ptrD2Ev = Module["__ZNSt3__212bad_weak_ptrD2Ev"] = function() {
                return (__ZNSt3__212bad_weak_ptrD2Ev = Module["__ZNSt3__212bad_weak_ptrD2Ev"] = Module["asm"]["_ZNSt3__212bad_weak_ptrD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212bad_weak_ptrD0Ev = Module["__ZNSt3__212bad_weak_ptrD0Ev"] = function() {
                return (__ZNSt3__212bad_weak_ptrD0Ev = Module["__ZNSt3__212bad_weak_ptrD0Ev"] = Module["asm"]["_ZNSt3__212bad_weak_ptrD0Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__212bad_weak_ptr4whatEv = Module["__ZNKSt3__212bad_weak_ptr4whatEv"] = function() {
                return (__ZNKSt3__212bad_weak_ptr4whatEv = Module["__ZNKSt3__212bad_weak_ptr4whatEv"] = Module["asm"]["_ZNKSt3__212bad_weak_ptr4whatEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__shared_countD0Ev = Module["__ZNSt3__214__shared_countD0Ev"] = function() {
                return (__ZNSt3__214__shared_countD0Ev = Module["__ZNSt3__214__shared_countD0Ev"] = Module["asm"]["_ZNSt3__214__shared_countD0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__219__shared_weak_countD0Ev = Module["__ZNSt3__219__shared_weak_countD0Ev"] = function() {
                return (__ZNSt3__219__shared_weak_countD0Ev = Module["__ZNSt3__219__shared_weak_countD0Ev"] = Module["asm"]["_ZNSt3__219__shared_weak_countD0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__219__shared_weak_count14__release_weakEv = Module["__ZNSt3__219__shared_weak_count14__release_weakEv"] = function() {
                return (__ZNSt3__219__shared_weak_count14__release_weakEv = Module["__ZNSt3__219__shared_weak_count14__release_weakEv"] = Module["asm"]["_ZNSt3__219__shared_weak_count14__release_weakEv"]).apply(null, arguments)
            };
            var __ZNSt3__219__shared_weak_count4lockEv = Module["__ZNSt3__219__shared_weak_count4lockEv"] = function() {
                return (__ZNSt3__219__shared_weak_count4lockEv = Module["__ZNSt3__219__shared_weak_count4lockEv"] = Module["asm"]["_ZNSt3__219__shared_weak_count4lockEv"]).apply(null, arguments)
            };
            var __ZNKSt3__219__shared_weak_count13__get_deleterERKSt9type_info = Module["__ZNKSt3__219__shared_weak_count13__get_deleterERKSt9type_info"] = function() {
                return (__ZNKSt3__219__shared_weak_count13__get_deleterERKSt9type_info = Module["__ZNKSt3__219__shared_weak_count13__get_deleterERKSt9type_info"] = Module["asm"]["_ZNKSt3__219__shared_weak_count13__get_deleterERKSt9type_info"]).apply(null, arguments)
            };
            var __ZNSt3__28__sp_mut4lockEv = Module["__ZNSt3__28__sp_mut4lockEv"] = function() {
                return (__ZNSt3__28__sp_mut4lockEv = Module["__ZNSt3__28__sp_mut4lockEv"] = Module["asm"]["_ZNSt3__28__sp_mut4lockEv"]).apply(null, arguments)
            };
            var __ZNSt3__211this_thread5yieldEv = Module["__ZNSt3__211this_thread5yieldEv"] = function() {
                return (__ZNSt3__211this_thread5yieldEv = Module["__ZNSt3__211this_thread5yieldEv"] = Module["asm"]["_ZNSt3__211this_thread5yieldEv"]).apply(null, arguments)
            };
            var __ZNSt3__221__libcpp_thread_yieldEv = Module["__ZNSt3__221__libcpp_thread_yieldEv"] = function() {
                return (__ZNSt3__221__libcpp_thread_yieldEv = Module["__ZNSt3__221__libcpp_thread_yieldEv"] = Module["asm"]["_ZNSt3__221__libcpp_thread_yieldEv"]).apply(null, arguments)
            };
            var __ZNSt3__28__sp_mut6unlockEv = Module["__ZNSt3__28__sp_mut6unlockEv"] = function() {
                return (__ZNSt3__28__sp_mut6unlockEv = Module["__ZNSt3__28__sp_mut6unlockEv"] = Module["asm"]["_ZNSt3__28__sp_mut6unlockEv"]).apply(null, arguments)
            };
            var __ZNSt3__212__get_sp_mutEPKv = Module["__ZNSt3__212__get_sp_mutEPKv"] = function() {
                return (__ZNSt3__212__get_sp_mutEPKv = Module["__ZNSt3__212__get_sp_mutEPKv"] = Module["asm"]["_ZNSt3__212__get_sp_mutEPKv"]).apply(null, arguments)
            };
            var __ZNSt3__28__sp_mutC2EPv = Module["__ZNSt3__28__sp_mutC2EPv"] = function() {
                return (__ZNSt3__28__sp_mutC2EPv = Module["__ZNSt3__28__sp_mutC2EPv"] = Module["asm"]["_ZNSt3__28__sp_mutC2EPv"]).apply(null, arguments)
            };
            var __ZNKSt3__24hashIPKvEclES2_ = Module["__ZNKSt3__24hashIPKvEclES2_"] = function() {
                return (__ZNKSt3__24hashIPKvEclES2_ = Module["__ZNKSt3__24hashIPKvEclES2_"] = Module["asm"]["_ZNKSt3__24hashIPKvEclES2_"]).apply(null, arguments)
            };
            var __ZNSt3__221__murmur2_or_cityhashImLm32EEclEPKvm = Module["__ZNSt3__221__murmur2_or_cityhashImLm32EEclEPKvm"] = function() {
                return (__ZNSt3__221__murmur2_or_cityhashImLm32EEclEPKvm = Module["__ZNSt3__221__murmur2_or_cityhashImLm32EEclEPKvm"] = Module["asm"]["_ZNSt3__221__murmur2_or_cityhashImLm32EEclEPKvm"]).apply(null, arguments)
            };
            var __ZNSt3__217declare_reachableEPv = Module["__ZNSt3__217declare_reachableEPv"] = function() {
                return (__ZNSt3__217declare_reachableEPv = Module["__ZNSt3__217declare_reachableEPv"] = Module["asm"]["_ZNSt3__217declare_reachableEPv"]).apply(null, arguments)
            };
            var __ZNSt3__219declare_no_pointersEPcm = Module["__ZNSt3__219declare_no_pointersEPcm"] = function() {
                return (__ZNSt3__219declare_no_pointersEPcm = Module["__ZNSt3__219declare_no_pointersEPcm"] = Module["asm"]["_ZNSt3__219declare_no_pointersEPcm"]).apply(null, arguments)
            };
            var __ZNSt3__221undeclare_no_pointersEPcm = Module["__ZNSt3__221undeclare_no_pointersEPcm"] = function() {
                return (__ZNSt3__221undeclare_no_pointersEPcm = Module["__ZNSt3__221undeclare_no_pointersEPcm"] = Module["asm"]["_ZNSt3__221undeclare_no_pointersEPcm"]).apply(null, arguments)
            };
            var __ZNSt3__221__undeclare_reachableEPv = Module["__ZNSt3__221__undeclare_reachableEPv"] = function() {
                return (__ZNSt3__221__undeclare_reachableEPv = Module["__ZNSt3__221__undeclare_reachableEPv"] = Module["asm"]["_ZNSt3__221__undeclare_reachableEPv"]).apply(null, arguments)
            };
            var __ZNSt3__25alignEmmRPvRm = Module["__ZNSt3__25alignEmmRPvRm"] = function() {
                return (__ZNSt3__25alignEmmRPvRm = Module["__ZNSt3__25alignEmmRPvRm"] = Module["asm"]["_ZNSt3__25alignEmmRPvRm"]).apply(null, arguments)
            };
            var __ZNSt3__210__loadwordImEET_PKv = Module["__ZNSt3__210__loadwordImEET_PKv"] = function() {
                return (__ZNSt3__210__loadwordImEET_PKv = Module["__ZNSt3__210__loadwordImEET_PKv"] = Module["asm"]["_ZNSt3__210__loadwordImEET_PKv"]).apply(null, arguments)
            };
            var ___cxa_pure_virtual = Module["___cxa_pure_virtual"] = function() {
                return (___cxa_pure_virtual = Module["___cxa_pure_virtual"] = Module["asm"]["__cxa_pure_virtual"]).apply(null, arguments)
            };
            var __ZNSt3__212bad_weak_ptrD1Ev = Module["__ZNSt3__212bad_weak_ptrD1Ev"] = function() {
                return (__ZNSt3__212bad_weak_ptrD1Ev = Module["__ZNSt3__212bad_weak_ptrD1Ev"] = Module["asm"]["_ZNSt3__212bad_weak_ptrD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214__shared_countD1Ev = Module["__ZNSt3__214__shared_countD1Ev"] = function() {
                return (__ZNSt3__214__shared_countD1Ev = Module["__ZNSt3__214__shared_countD1Ev"] = Module["asm"]["_ZNSt3__214__shared_countD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__219__shared_weak_countD2Ev = Module["__ZNSt3__219__shared_weak_countD2Ev"] = function() {
                return (__ZNSt3__219__shared_weak_countD2Ev = Module["__ZNSt3__219__shared_weak_countD2Ev"] = Module["asm"]["_ZNSt3__219__shared_weak_countD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__219__shared_weak_countD1Ev = Module["__ZNSt3__219__shared_weak_countD1Ev"] = function() {
                return (__ZNSt3__219__shared_weak_countD1Ev = Module["__ZNSt3__219__shared_weak_countD1Ev"] = Module["asm"]["_ZNSt3__219__shared_weak_countD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__27collateIcED2Ev = Module["__ZNSt3__27collateIcED2Ev"] = function() {
                return (__ZNSt3__27collateIcED2Ev = Module["__ZNSt3__27collateIcED2Ev"] = Module["asm"]["_ZNSt3__27collateIcED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5facetD2Ev = Module["__ZNSt3__26locale5facetD2Ev"] = function() {
                return (__ZNSt3__26locale5facetD2Ev = Module["__ZNSt3__26locale5facetD2Ev"] = Module["asm"]["_ZNSt3__26locale5facetD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__27collateIcED0Ev = Module["__ZNSt3__27collateIcED0Ev"] = function() {
                return (__ZNSt3__27collateIcED0Ev = Module["__ZNSt3__27collateIcED0Ev"] = Module["asm"]["_ZNSt3__27collateIcED0Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__27collateIcE10do_compareEPKcS3_S3_S3_ = Module["__ZNKSt3__27collateIcE10do_compareEPKcS3_S3_S3_"] = function() {
                return (__ZNKSt3__27collateIcE10do_compareEPKcS3_S3_S3_ = Module["__ZNKSt3__27collateIcE10do_compareEPKcS3_S3_S3_"] = Module["asm"]["_ZNKSt3__27collateIcE10do_compareEPKcS3_S3_S3_"]).apply(null, arguments)
            };
            var __ZNKSt3__27collateIcE12do_transformEPKcS3_ = Module["__ZNKSt3__27collateIcE12do_transformEPKcS3_"] = function() {
                return (__ZNKSt3__27collateIcE12do_transformEPKcS3_ = Module["__ZNKSt3__27collateIcE12do_transformEPKcS3_"] = Module["asm"]["_ZNKSt3__27collateIcE12do_transformEPKcS3_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2IPKcvEET_S9_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2IPKcvEET_S9_"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2IPKcvEET_S9_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2IPKcvEET_S9_"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2IPKcvEET_S9_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initIPKcEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeESA_SA_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initIPKcEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeESA_SA_"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initIPKcEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeESA_SA_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initIPKcEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeESA_SA_"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6__initIPKcEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeESA_SA_"]).apply(null, arguments)
            };
            var __ZNKSt3__27collateIcE7do_hashEPKcS3_ = Module["__ZNKSt3__27collateIcE7do_hashEPKcS3_"] = function() {
                return (__ZNKSt3__27collateIcE7do_hashEPKcS3_ = Module["__ZNKSt3__27collateIcE7do_hashEPKcS3_"] = Module["asm"]["_ZNKSt3__27collateIcE7do_hashEPKcS3_"]).apply(null, arguments)
            };
            var __ZNSt3__27collateIwED2Ev = Module["__ZNSt3__27collateIwED2Ev"] = function() {
                return (__ZNSt3__27collateIwED2Ev = Module["__ZNSt3__27collateIwED2Ev"] = Module["asm"]["_ZNSt3__27collateIwED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__27collateIwED0Ev = Module["__ZNSt3__27collateIwED0Ev"] = function() {
                return (__ZNSt3__27collateIwED0Ev = Module["__ZNSt3__27collateIwED0Ev"] = Module["asm"]["_ZNSt3__27collateIwED0Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__27collateIwE10do_compareEPKwS3_S3_S3_ = Module["__ZNKSt3__27collateIwE10do_compareEPKwS3_S3_S3_"] = function() {
                return (__ZNKSt3__27collateIwE10do_compareEPKwS3_S3_S3_ = Module["__ZNKSt3__27collateIwE10do_compareEPKwS3_S3_S3_"] = Module["asm"]["_ZNKSt3__27collateIwE10do_compareEPKwS3_S3_S3_"]).apply(null, arguments)
            };
            var __ZNKSt3__27collateIwE12do_transformEPKwS3_ = Module["__ZNKSt3__27collateIwE12do_transformEPKwS3_"] = function() {
                return (__ZNKSt3__27collateIwE12do_transformEPKwS3_ = Module["__ZNKSt3__27collateIwE12do_transformEPKwS3_"] = Module["asm"]["_ZNKSt3__27collateIwE12do_transformEPKwS3_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2IPKwvEET_S9_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2IPKwvEET_S9_"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2IPKwvEET_S9_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2IPKwvEET_S9_"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2IPKwvEET_S9_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initIPKwEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeESA_SA_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initIPKwEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeESA_SA_"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initIPKwEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeESA_SA_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initIPKwEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeESA_SA_"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initIPKwEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeESA_SA_"]).apply(null, arguments)
            };
            var __ZNKSt3__27collateIwE7do_hashEPKwS3_ = Module["__ZNKSt3__27collateIwE7do_hashEPKwS3_"] = function() {
                return (__ZNKSt3__27collateIwE7do_hashEPKwS3_ = Module["__ZNKSt3__27collateIwE7do_hashEPKwS3_"] = Module["asm"]["_ZNKSt3__27collateIwE7do_hashEPKwS3_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRb = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRb"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRb = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRb"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRb"]).apply(null, arguments)
            };
            var __ZNKSt3__28ios_base5flagsEv = Module["__ZNKSt3__28ios_base5flagsEv"] = function() {
                return (__ZNKSt3__28ios_base5flagsEv = Module["__ZNKSt3__28ios_base5flagsEv"] = Module["asm"]["_ZNKSt3__28ios_base5flagsEv"]).apply(null, arguments)
            };
            var __ZNKSt3__28ios_base6getlocEv = Module["__ZNKSt3__28ios_base6getlocEv"] = function() {
                return (__ZNKSt3__28ios_base6getlocEv = Module["__ZNKSt3__28ios_base6getlocEv"] = Module["asm"]["_ZNKSt3__28ios_base6getlocEv"]).apply(null, arguments)
            };
            var __ZNSt3__29use_facetINS_5ctypeIcEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_5ctypeIcEEEERKT_RKNS_6localeE"] = function() {
                return (__ZNSt3__29use_facetINS_5ctypeIcEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_5ctypeIcEEEERKT_RKNS_6localeE"] = Module["asm"]["_ZNSt3__29use_facetINS_5ctypeIcEEEERKT_RKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNSt3__26localeD2Ev = Module["__ZNSt3__26localeD2Ev"] = function() {
                return (__ZNSt3__26localeD2Ev = Module["__ZNSt3__26localeD2Ev"] = Module["asm"]["_ZNSt3__26localeD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29use_facetINS_8numpunctIcEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_8numpunctIcEEEERKT_RKNS_6localeE"] = function() {
                return (__ZNSt3__29use_facetINS_8numpunctIcEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_8numpunctIcEEEERKT_RKNS_6localeE"] = Module["asm"]["_ZNSt3__29use_facetINS_8numpunctIcEEEERKT_RKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNKSt3__28numpunctIcE8truenameEv = Module["__ZNKSt3__28numpunctIcE8truenameEv"] = function() {
                return (__ZNKSt3__28numpunctIcE8truenameEv = Module["__ZNKSt3__28numpunctIcE8truenameEv"] = Module["asm"]["_ZNKSt3__28numpunctIcE8truenameEv"]).apply(null, arguments)
            };
            var __ZNKSt3__28numpunctIcE9falsenameEv = Module["__ZNKSt3__28numpunctIcE9falsenameEv"] = function() {
                return (__ZNKSt3__28numpunctIcE9falsenameEv = Module["__ZNKSt3__28numpunctIcE9falsenameEv"] = Module["asm"]["_ZNKSt3__28numpunctIcE9falsenameEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEPKNS_12basic_stringIcS3_NS_9allocatorIcEEEENS_5ctypeIcEEEET0_RT_SE_SD_SD_RKT1_Rjb = Module["__ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEPKNS_12basic_stringIcS3_NS_9allocatorIcEEEENS_5ctypeIcEEEET0_RT_SE_SD_SD_RKT1_Rjb"] = function() {
                return (__ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEPKNS_12basic_stringIcS3_NS_9allocatorIcEEEENS_5ctypeIcEEEET0_RT_SE_SD_SD_RKT1_Rjb = Module["__ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEPKNS_12basic_stringIcS3_NS_9allocatorIcEEEENS_5ctypeIcEEEET0_RT_SE_SD_SD_RKT1_Rjb"] = Module["asm"]["_ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEPKNS_12basic_stringIcS3_NS_9allocatorIcEEEENS_5ctypeIcEEEET0_RT_SE_SD_SD_RKT1_Rjb"]).apply(null, arguments)
            };
            var __ZNKSt3__26locale9use_facetERNS0_2idE = Module["__ZNKSt3__26locale9use_facetERNS0_2idE"] = function() {
                return (__ZNKSt3__26locale9use_facetERNS0_2idE = Module["__ZNKSt3__26locale9use_facetERNS0_2idE"] = Module["asm"]["_ZNKSt3__26locale9use_facetERNS0_2idE"]).apply(null, arguments)
            };
            var __ZNSt3__28distanceIPKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_15iterator_traitsIT_E15difference_typeESA_SA_ = Module["__ZNSt3__28distanceIPKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_15iterator_traitsIT_E15difference_typeESA_SA_"] = function() {
                return (__ZNSt3__28distanceIPKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_15iterator_traitsIT_E15difference_typeESA_SA_ = Module["__ZNSt3__28distanceIPKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_15iterator_traitsIT_E15difference_typeESA_SA_"] = Module["asm"]["_ZNSt3__28distanceIPKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_15iterator_traitsIT_E15difference_typeESA_SA_"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIhPFvPvEEC2ILb1EvEEPhNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE = Module["__ZNSt3__210unique_ptrIhPFvPvEEC2ILb1EvEEPhNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE"] = function() {
                return (__ZNSt3__210unique_ptrIhPFvPvEEC2ILb1EvEEPhNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE = Module["__ZNSt3__210unique_ptrIhPFvPvEEC2ILb1EvEEPhNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE"] = Module["asm"]["_ZNSt3__210unique_ptrIhPFvPvEEC2ILb1EvEEPhNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIhPFvPvEE5resetEPh = Module["__ZNSt3__210unique_ptrIhPFvPvEE5resetEPh"] = function() {
                return (__ZNSt3__210unique_ptrIhPFvPvEE5resetEPh = Module["__ZNSt3__210unique_ptrIhPFvPvEE5resetEPh"] = Module["asm"]["_ZNSt3__210unique_ptrIhPFvPvEE5resetEPh"]).apply(null, arguments)
            };
            var __ZNSt3__2neIcNS_11char_traitsIcEEEEbRKNS_19istreambuf_iteratorIT_T0_EES8_ = Module["__ZNSt3__2neIcNS_11char_traitsIcEEEEbRKNS_19istreambuf_iteratorIT_T0_EES8_"] = function() {
                return (__ZNSt3__2neIcNS_11char_traitsIcEEEEbRKNS_19istreambuf_iteratorIT_T0_EES8_ = Module["__ZNSt3__2neIcNS_11char_traitsIcEEEEbRKNS_19istreambuf_iteratorIT_T0_EES8_"] = Module["asm"]["_ZNSt3__2neIcNS_11char_traitsIcEEEEbRKNS_19istreambuf_iteratorIT_T0_EES8_"]).apply(null, arguments)
            };
            var __ZNSt3__2eqIcNS_11char_traitsIcEEEEbRKNS_19istreambuf_iteratorIT_T0_EES8_ = Module["__ZNSt3__2eqIcNS_11char_traitsIcEEEEbRKNS_19istreambuf_iteratorIT_T0_EES8_"] = function() {
                return (__ZNSt3__2eqIcNS_11char_traitsIcEEEEbRKNS_19istreambuf_iteratorIT_T0_EES8_ = Module["__ZNSt3__2eqIcNS_11char_traitsIcEEEEbRKNS_19istreambuf_iteratorIT_T0_EES8_"] = Module["asm"]["_ZNSt3__2eqIcNS_11char_traitsIcEEEEbRKNS_19istreambuf_iteratorIT_T0_EES8_"]).apply(null, arguments)
            };
            var __ZNKSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEdeEv = Module["__ZNKSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEdeEv"] = function() {
                return (__ZNKSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEdeEv = Module["__ZNKSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEdeEv"] = Module["asm"]["_ZNKSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEdeEv"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIcE7toupperEc = Module["__ZNKSt3__25ctypeIcE7toupperEc"] = function() {
                return (__ZNKSt3__25ctypeIcE7toupperEc = Module["__ZNKSt3__25ctypeIcE7toupperEc"] = Module["asm"]["_ZNKSt3__25ctypeIcE7toupperEc"]).apply(null, arguments)
            };
            var __ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEppEv = Module["__ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEppEv"] = function() {
                return (__ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEppEv = Module["__ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEppEv"] = Module["asm"]["_ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEppEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIhPFvPvEED2Ev = Module["__ZNSt3__210unique_ptrIhPFvPvEED2Ev"] = function() {
                return (__ZNSt3__210unique_ptrIhPFvPvEED2Ev = Module["__ZNSt3__210unique_ptrIhPFvPvEED2Ev"] = Module["asm"]["_ZNSt3__210unique_ptrIhPFvPvEED2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5emptyEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5emptyEv"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5emptyEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5emptyEv"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5emptyEv"]).apply(null, arguments)
            };
            var __ZSt17__throw_bad_allocv = Module["__ZSt17__throw_bad_allocv"] = function() {
                return (__ZSt17__throw_bad_allocv = Module["__ZSt17__throw_bad_allocv"] = Module["asm"]["_ZSt17__throw_bad_allocv"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRl = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRl"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRl = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRl"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRl"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__do_get_signedIlEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__do_get_signedIlEES4_S4_S4_RNS_8ios_baseERjRT_"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__do_get_signedIlEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__do_get_signedIlEES4_S4_S4_RNS_8ios_baseERjRT_"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__do_get_signedIlEES4_S4_S4_RNS_8ios_baseERjRT_"]).apply(null, arguments)
            };
            var __ZNSt3__214__num_get_base10__get_baseERNS_8ios_baseE = Module["__ZNSt3__214__num_get_base10__get_baseERNS_8ios_baseE"] = function() {
                return (__ZNSt3__214__num_get_base10__get_baseERNS_8ios_baseE = Module["__ZNSt3__214__num_get_base10__get_baseERNS_8ios_baseE"] = Module["asm"]["_ZNSt3__214__num_get_base10__get_baseERNS_8ios_baseE"]).apply(null, arguments)
            };
            var __ZNKSt3__29__num_getIcE10__do_widenERNS_8ios_baseEPc = Module["__ZNKSt3__29__num_getIcE10__do_widenERNS_8ios_baseEPc"] = function() {
                return (__ZNKSt3__29__num_getIcE10__do_widenERNS_8ios_baseEPc = Module["__ZNKSt3__29__num_getIcE10__do_widenERNS_8ios_baseEPc"] = Module["asm"]["_ZNKSt3__29__num_getIcE10__do_widenERNS_8ios_baseEPc"]).apply(null, arguments)
            };
            var __ZNSt3__29__num_getIcE17__stage2_int_prepERNS_8ios_baseERc = Module["__ZNSt3__29__num_getIcE17__stage2_int_prepERNS_8ios_baseERc"] = function() {
                return (__ZNSt3__29__num_getIcE17__stage2_int_prepERNS_8ios_baseERc = Module["__ZNSt3__29__num_getIcE17__stage2_int_prepERNS_8ios_baseERc"] = Module["asm"]["_ZNSt3__29__num_getIcE17__stage2_int_prepERNS_8ios_baseERc"]).apply(null, arguments)
            };
            var __ZNSt3__29__num_getIcE17__stage2_int_loopEciPcRS2_RjcRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_PKc = Module["__ZNSt3__29__num_getIcE17__stage2_int_loopEciPcRS2_RjcRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_PKc"] = function() {
                return (__ZNSt3__29__num_getIcE17__stage2_int_loopEciPcRS2_RjcRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_PKc = Module["__ZNSt3__29__num_getIcE17__stage2_int_loopEciPcRS2_RjcRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_PKc"] = Module["asm"]["_ZNSt3__29__num_getIcE17__stage2_int_loopEciPcRS2_RjcRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_PKc"]).apply(null, arguments)
            };
            var __ZNSt3__225__num_get_signed_integralIlEET_PKcS3_Rji = Module["__ZNSt3__225__num_get_signed_integralIlEET_PKcS3_Rji"] = function() {
                return (__ZNSt3__225__num_get_signed_integralIlEET_PKcS3_Rji = Module["__ZNSt3__225__num_get_signed_integralIlEET_PKcS3_Rji"] = Module["asm"]["_ZNSt3__225__num_get_signed_integralIlEET_PKcS3_Rji"]).apply(null, arguments)
            };
            var __ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj = Module["__ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj"] = function() {
                return (__ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj = Module["__ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj"] = Module["asm"]["_ZNSt3__216__check_groupingERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjS8_Rj"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRx = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRx"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRx = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRx"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRx"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__do_get_signedIxEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__do_get_signedIxEES4_S4_S4_RNS_8ios_baseERjRT_"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__do_get_signedIxEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__do_get_signedIxEES4_S4_S4_RNS_8ios_baseERjRT_"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__do_get_signedIxEES4_S4_S4_RNS_8ios_baseERjRT_"]).apply(null, arguments)
            };
            var __ZNSt3__225__num_get_signed_integralIxEET_PKcS3_Rji = Module["__ZNSt3__225__num_get_signed_integralIxEET_PKcS3_Rji"] = function() {
                return (__ZNSt3__225__num_get_signed_integralIxEET_PKcS3_Rji = Module["__ZNSt3__225__num_get_signed_integralIxEET_PKcS3_Rji"] = Module["asm"]["_ZNSt3__225__num_get_signed_integralIxEET_PKcS3_Rji"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRt = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRt"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRt = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRt"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRt"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedItEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedItEES4_S4_S4_RNS_8ios_baseERjRT_"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedItEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedItEES4_S4_S4_RNS_8ios_baseERjRT_"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedItEES4_S4_S4_RNS_8ios_baseERjRT_"]).apply(null, arguments)
            };
            var __ZNSt3__227__num_get_unsigned_integralItEET_PKcS3_Rji = Module["__ZNSt3__227__num_get_unsigned_integralItEET_PKcS3_Rji"] = function() {
                return (__ZNSt3__227__num_get_unsigned_integralItEET_PKcS3_Rji = Module["__ZNSt3__227__num_get_unsigned_integralItEET_PKcS3_Rji"] = Module["asm"]["_ZNSt3__227__num_get_unsigned_integralItEET_PKcS3_Rji"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjS8_ = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjS8_"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjS8_ = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjS8_"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjS8_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedIjEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedIjEES4_S4_S4_RNS_8ios_baseERjRT_"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedIjEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedIjEES4_S4_S4_RNS_8ios_baseERjRT_"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedIjEES4_S4_S4_RNS_8ios_baseERjRT_"]).apply(null, arguments)
            };
            var __ZNSt3__227__num_get_unsigned_integralIjEET_PKcS3_Rji = Module["__ZNSt3__227__num_get_unsigned_integralIjEET_PKcS3_Rji"] = function() {
                return (__ZNSt3__227__num_get_unsigned_integralIjEET_PKcS3_Rji = Module["__ZNSt3__227__num_get_unsigned_integralIjEET_PKcS3_Rji"] = Module["asm"]["_ZNSt3__227__num_get_unsigned_integralIjEET_PKcS3_Rji"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRm = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRm"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRm = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRm"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRm"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedImEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedImEES4_S4_S4_RNS_8ios_baseERjRT_"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedImEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedImEES4_S4_S4_RNS_8ios_baseERjRT_"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedImEES4_S4_S4_RNS_8ios_baseERjRT_"]).apply(null, arguments)
            };
            var __ZNSt3__227__num_get_unsigned_integralImEET_PKcS3_Rji = Module["__ZNSt3__227__num_get_unsigned_integralImEET_PKcS3_Rji"] = function() {
                return (__ZNSt3__227__num_get_unsigned_integralImEET_PKcS3_Rji = Module["__ZNSt3__227__num_get_unsigned_integralImEET_PKcS3_Rji"] = Module["asm"]["_ZNSt3__227__num_get_unsigned_integralImEET_PKcS3_Rji"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRy = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRy"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRy = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRy"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRy"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedIyEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedIyEES4_S4_S4_RNS_8ios_baseERjRT_"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedIyEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedIyEES4_S4_S4_RNS_8ios_baseERjRT_"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__do_get_unsignedIyEES4_S4_S4_RNS_8ios_baseERjRT_"]).apply(null, arguments)
            };
            var __ZNSt3__227__num_get_unsigned_integralIyEET_PKcS3_Rji = Module["__ZNSt3__227__num_get_unsigned_integralIyEET_PKcS3_Rji"] = function() {
                return (__ZNSt3__227__num_get_unsigned_integralIyEET_PKcS3_Rji = Module["__ZNSt3__227__num_get_unsigned_integralIyEET_PKcS3_Rji"] = Module["asm"]["_ZNSt3__227__num_get_unsigned_integralIyEET_PKcS3_Rji"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRf = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRf"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRf = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRf"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRf"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIfEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIfEES4_S4_S4_RNS_8ios_baseERjRT_"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIfEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIfEES4_S4_S4_RNS_8ios_baseERjRT_"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIfEES4_S4_S4_RNS_8ios_baseERjRT_"]).apply(null, arguments)
            };
            var __ZNSt3__29__num_getIcE19__stage2_float_prepERNS_8ios_baseEPcRcS5_ = Module["__ZNSt3__29__num_getIcE19__stage2_float_prepERNS_8ios_baseEPcRcS5_"] = function() {
                return (__ZNSt3__29__num_getIcE19__stage2_float_prepERNS_8ios_baseEPcRcS5_ = Module["__ZNSt3__29__num_getIcE19__stage2_float_prepERNS_8ios_baseEPcRcS5_"] = Module["asm"]["_ZNSt3__29__num_getIcE19__stage2_float_prepERNS_8ios_baseEPcRcS5_"]).apply(null, arguments)
            };
            var __ZNSt3__29__num_getIcE19__stage2_float_loopEcRbRcPcRS4_ccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjS4_ = Module["__ZNSt3__29__num_getIcE19__stage2_float_loopEcRbRcPcRS4_ccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjS4_"] = function() {
                return (__ZNSt3__29__num_getIcE19__stage2_float_loopEcRbRcPcRS4_ccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjS4_ = Module["__ZNSt3__29__num_getIcE19__stage2_float_loopEcRbRcPcRS4_ccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjS4_"] = Module["asm"]["_ZNSt3__29__num_getIcE19__stage2_float_loopEcRbRcPcRS4_ccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjS4_"]).apply(null, arguments)
            };
            var __ZNSt3__215__num_get_floatIfEET_PKcS3_Rj = Module["__ZNSt3__215__num_get_floatIfEET_PKcS3_Rj"] = function() {
                return (__ZNSt3__215__num_get_floatIfEET_PKcS3_Rj = Module["__ZNSt3__215__num_get_floatIfEET_PKcS3_Rj"] = Module["asm"]["_ZNSt3__215__num_get_floatIfEET_PKcS3_Rj"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRd = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRd"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRd = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRd"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRd"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIdEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIdEES4_S4_S4_RNS_8ios_baseERjRT_"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIdEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIdEES4_S4_S4_RNS_8ios_baseERjRT_"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIdEES4_S4_S4_RNS_8ios_baseERjRT_"]).apply(null, arguments)
            };
            var __ZNSt3__215__num_get_floatIdEET_PKcS3_Rj = Module["__ZNSt3__215__num_get_floatIdEET_PKcS3_Rj"] = function() {
                return (__ZNSt3__215__num_get_floatIdEET_PKcS3_Rj = Module["__ZNSt3__215__num_get_floatIdEET_PKcS3_Rj"] = Module["asm"]["_ZNSt3__215__num_get_floatIdEET_PKcS3_Rj"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRe = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRe"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRe = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRe"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRe"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIeEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIeEES4_S4_S4_RNS_8ios_baseERjRT_"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIeEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIeEES4_S4_S4_RNS_8ios_baseERjRT_"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE23__do_get_floating_pointIeEES4_S4_S4_RNS_8ios_baseERjRT_"]).apply(null, arguments)
            };
            var __ZNSt3__215__num_get_floatIeEET_PKcS3_Rj = Module["__ZNSt3__215__num_get_floatIeEET_PKcS3_Rj"] = function() {
                return (__ZNSt3__215__num_get_floatIeEET_PKcS3_Rj = Module["__ZNSt3__215__num_get_floatIeEET_PKcS3_Rj"] = Module["asm"]["_ZNSt3__215__num_get_floatIeEET_PKcS3_Rj"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRPv = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRPv"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRPv = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRPv"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjRPv"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIcE5widenEPKcS3_Pc = Module["__ZNKSt3__25ctypeIcE5widenEPKcS3_Pc"] = function() {
                return (__ZNKSt3__25ctypeIcE5widenEPKcS3_Pc = Module["__ZNKSt3__25ctypeIcE5widenEPKcS3_Pc"] = Module["asm"]["_ZNKSt3__25ctypeIcE5widenEPKcS3_Pc"]).apply(null, arguments)
            };
            var __ZNSt3__26__clocEv = Module["__ZNSt3__26__clocEv"] = function() {
                return (__ZNSt3__26__clocEv = Module["__ZNSt3__26__clocEv"] = Module["asm"]["_ZNSt3__26__clocEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__libcpp_sscanf_lEPKcP15__locale_structS1_z = Module["__ZNSt3__217__libcpp_sscanf_lEPKcP15__locale_structS1_z"] = function() {
                return (__ZNSt3__217__libcpp_sscanf_lEPKcP15__locale_structS1_z = Module["__ZNSt3__217__libcpp_sscanf_lEPKcP15__locale_structS1_z"] = Module["asm"]["_ZNSt3__217__libcpp_sscanf_lEPKcP15__locale_structS1_z"]).apply(null, arguments)
            };
            var __ZNKSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEE5equalERKS3_ = Module["__ZNKSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEE5equalERKS3_"] = function() {
                return (__ZNKSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEE5equalERKS3_ = Module["__ZNKSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEE5equalERKS3_"] = Module["asm"]["_ZNKSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEE5equalERKS3_"]).apply(null, arguments)
            };
            var __ZNSt3__24findIPKccEET_S3_S3_RKT0_ = Module["__ZNSt3__24findIPKccEET_S3_S3_RKT0_"] = function() {
                return (__ZNSt3__24findIPKccEET_S3_S3_RKT0_ = Module["__ZNSt3__24findIPKccEET_S3_S3_RKT0_"] = Module["asm"]["_ZNSt3__24findIPKccEET_S3_S3_RKT0_"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5sgetcEv = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5sgetcEv"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5sgetcEv = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5sgetcEv"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5sgetcEv"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6sbumpcEv = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6sbumpcEv"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6sbumpcEv = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6sbumpcEv"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6sbumpcEv"]).apply(null, arguments)
            };
            var __ZNSt3__221__libcpp_locale_guardC2ERP15__locale_struct = Module["__ZNSt3__221__libcpp_locale_guardC2ERP15__locale_struct"] = function() {
                return (__ZNSt3__221__libcpp_locale_guardC2ERP15__locale_struct = Module["__ZNSt3__221__libcpp_locale_guardC2ERP15__locale_struct"] = Module["asm"]["_ZNSt3__221__libcpp_locale_guardC2ERP15__locale_struct"]).apply(null, arguments)
            };
            var __ZNSt3__221__libcpp_locale_guardD2Ev = Module["__ZNSt3__221__libcpp_locale_guardD2Ev"] = function() {
                return (__ZNSt3__221__libcpp_locale_guardD2Ev = Module["__ZNSt3__221__libcpp_locale_guardD2Ev"] = Module["asm"]["_ZNSt3__221__libcpp_locale_guardD2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRb = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRb"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRb = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRb"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRb"]).apply(null, arguments)
            };
            var __ZNSt3__29use_facetINS_5ctypeIwEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_5ctypeIwEEEERKT_RKNS_6localeE"] = function() {
                return (__ZNSt3__29use_facetINS_5ctypeIwEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_5ctypeIwEEEERKT_RKNS_6localeE"] = Module["asm"]["_ZNSt3__29use_facetINS_5ctypeIwEEEERKT_RKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNSt3__29use_facetINS_8numpunctIwEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_8numpunctIwEEEERKT_RKNS_6localeE"] = function() {
                return (__ZNSt3__29use_facetINS_8numpunctIwEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_8numpunctIwEEEERKT_RKNS_6localeE"] = Module["asm"]["_ZNSt3__29use_facetINS_8numpunctIwEEEERKT_RKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNKSt3__28numpunctIwE8truenameEv = Module["__ZNKSt3__28numpunctIwE8truenameEv"] = function() {
                return (__ZNKSt3__28numpunctIwE8truenameEv = Module["__ZNKSt3__28numpunctIwE8truenameEv"] = Module["asm"]["_ZNKSt3__28numpunctIwE8truenameEv"]).apply(null, arguments)
            };
            var __ZNKSt3__28numpunctIwE9falsenameEv = Module["__ZNKSt3__28numpunctIwE9falsenameEv"] = function() {
                return (__ZNKSt3__28numpunctIwE9falsenameEv = Module["__ZNKSt3__28numpunctIwE9falsenameEv"] = Module["asm"]["_ZNKSt3__28numpunctIwE9falsenameEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEPKNS_12basic_stringIwS3_NS_9allocatorIwEEEENS_5ctypeIwEEEET0_RT_SE_SD_SD_RKT1_Rjb = Module["__ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEPKNS_12basic_stringIwS3_NS_9allocatorIwEEEENS_5ctypeIwEEEET0_RT_SE_SD_SD_RKT1_Rjb"] = function() {
                return (__ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEPKNS_12basic_stringIwS3_NS_9allocatorIwEEEENS_5ctypeIwEEEET0_RT_SE_SD_SD_RKT1_Rjb = Module["__ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEPKNS_12basic_stringIwS3_NS_9allocatorIwEEEENS_5ctypeIwEEEET0_RT_SE_SD_SD_RKT1_Rjb"] = Module["asm"]["_ZNSt3__214__scan_keywordINS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEPKNS_12basic_stringIwS3_NS_9allocatorIwEEEENS_5ctypeIwEEEET0_RT_SE_SD_SD_RKT1_Rjb"]).apply(null, arguments)
            };
            var __ZNSt3__28distanceIPKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEEENS_15iterator_traitsIT_E15difference_typeESA_SA_ = Module["__ZNSt3__28distanceIPKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEEENS_15iterator_traitsIT_E15difference_typeESA_SA_"] = function() {
                return (__ZNSt3__28distanceIPKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEEENS_15iterator_traitsIT_E15difference_typeESA_SA_ = Module["__ZNSt3__28distanceIPKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEEENS_15iterator_traitsIT_E15difference_typeESA_SA_"] = Module["asm"]["_ZNSt3__28distanceIPKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEEENS_15iterator_traitsIT_E15difference_typeESA_SA_"]).apply(null, arguments)
            };
            var __ZNSt3__2neIwNS_11char_traitsIwEEEEbRKNS_19istreambuf_iteratorIT_T0_EES8_ = Module["__ZNSt3__2neIwNS_11char_traitsIwEEEEbRKNS_19istreambuf_iteratorIT_T0_EES8_"] = function() {
                return (__ZNSt3__2neIwNS_11char_traitsIwEEEEbRKNS_19istreambuf_iteratorIT_T0_EES8_ = Module["__ZNSt3__2neIwNS_11char_traitsIwEEEEbRKNS_19istreambuf_iteratorIT_T0_EES8_"] = Module["asm"]["_ZNSt3__2neIwNS_11char_traitsIwEEEEbRKNS_19istreambuf_iteratorIT_T0_EES8_"]).apply(null, arguments)
            };
            var __ZNSt3__2eqIwNS_11char_traitsIwEEEEbRKNS_19istreambuf_iteratorIT_T0_EES8_ = Module["__ZNSt3__2eqIwNS_11char_traitsIwEEEEbRKNS_19istreambuf_iteratorIT_T0_EES8_"] = function() {
                return (__ZNSt3__2eqIwNS_11char_traitsIwEEEEbRKNS_19istreambuf_iteratorIT_T0_EES8_ = Module["__ZNSt3__2eqIwNS_11char_traitsIwEEEEbRKNS_19istreambuf_iteratorIT_T0_EES8_"] = Module["asm"]["_ZNSt3__2eqIwNS_11char_traitsIwEEEEbRKNS_19istreambuf_iteratorIT_T0_EES8_"]).apply(null, arguments)
            };
            var __ZNKSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEdeEv = Module["__ZNKSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEdeEv"] = function() {
                return (__ZNKSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEdeEv = Module["__ZNKSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEdeEv"] = Module["asm"]["_ZNKSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEdeEv"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIwE7toupperEw = Module["__ZNKSt3__25ctypeIwE7toupperEw"] = function() {
                return (__ZNKSt3__25ctypeIwE7toupperEw = Module["__ZNKSt3__25ctypeIwE7toupperEw"] = Module["asm"]["_ZNKSt3__25ctypeIwE7toupperEw"]).apply(null, arguments)
            };
            var __ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEppEv = Module["__ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEppEv"] = function() {
                return (__ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEppEv = Module["__ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEppEv"] = Module["asm"]["_ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEppEv"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5emptyEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5emptyEv"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5emptyEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5emptyEv"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5emptyEv"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRl = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRl"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRl = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRl"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRl"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__do_get_signedIlEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__do_get_signedIlEES4_S4_S4_RNS_8ios_baseERjRT_"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__do_get_signedIlEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__do_get_signedIlEES4_S4_S4_RNS_8ios_baseERjRT_"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__do_get_signedIlEES4_S4_S4_RNS_8ios_baseERjRT_"]).apply(null, arguments)
            };
            var __ZNKSt3__29__num_getIwE10__do_widenERNS_8ios_baseEPw = Module["__ZNKSt3__29__num_getIwE10__do_widenERNS_8ios_baseEPw"] = function() {
                return (__ZNKSt3__29__num_getIwE10__do_widenERNS_8ios_baseEPw = Module["__ZNKSt3__29__num_getIwE10__do_widenERNS_8ios_baseEPw"] = Module["asm"]["_ZNKSt3__29__num_getIwE10__do_widenERNS_8ios_baseEPw"]).apply(null, arguments)
            };
            var __ZNSt3__29__num_getIwE17__stage2_int_prepERNS_8ios_baseERw = Module["__ZNSt3__29__num_getIwE17__stage2_int_prepERNS_8ios_baseERw"] = function() {
                return (__ZNSt3__29__num_getIwE17__stage2_int_prepERNS_8ios_baseERw = Module["__ZNSt3__29__num_getIwE17__stage2_int_prepERNS_8ios_baseERw"] = Module["asm"]["_ZNSt3__29__num_getIwE17__stage2_int_prepERNS_8ios_baseERw"]).apply(null, arguments)
            };
            var __ZNSt3__29__num_getIwE17__stage2_int_loopEwiPcRS2_RjwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_PKw = Module["__ZNSt3__29__num_getIwE17__stage2_int_loopEwiPcRS2_RjwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_PKw"] = function() {
                return (__ZNSt3__29__num_getIwE17__stage2_int_loopEwiPcRS2_RjwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_PKw = Module["__ZNSt3__29__num_getIwE17__stage2_int_loopEwiPcRS2_RjwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_PKw"] = Module["asm"]["_ZNSt3__29__num_getIwE17__stage2_int_loopEwiPcRS2_RjwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSD_PKw"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRx = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRx"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRx = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRx"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRx"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__do_get_signedIxEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__do_get_signedIxEES4_S4_S4_RNS_8ios_baseERjRT_"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__do_get_signedIxEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__do_get_signedIxEES4_S4_S4_RNS_8ios_baseERjRT_"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__do_get_signedIxEES4_S4_S4_RNS_8ios_baseERjRT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRt = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRt"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRt = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRt"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRt"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedItEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedItEES4_S4_S4_RNS_8ios_baseERjRT_"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedItEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedItEES4_S4_S4_RNS_8ios_baseERjRT_"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedItEES4_S4_S4_RNS_8ios_baseERjRT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjS8_ = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjS8_"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjS8_ = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjS8_"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjS8_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedIjEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedIjEES4_S4_S4_RNS_8ios_baseERjRT_"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedIjEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedIjEES4_S4_S4_RNS_8ios_baseERjRT_"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedIjEES4_S4_S4_RNS_8ios_baseERjRT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRm = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRm"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRm = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRm"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRm"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedImEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedImEES4_S4_S4_RNS_8ios_baseERjRT_"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedImEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedImEES4_S4_S4_RNS_8ios_baseERjRT_"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedImEES4_S4_S4_RNS_8ios_baseERjRT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRy = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRy"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRy = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRy"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRy"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedIyEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedIyEES4_S4_S4_RNS_8ios_baseERjRT_"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedIyEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedIyEES4_S4_S4_RNS_8ios_baseERjRT_"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__do_get_unsignedIyEES4_S4_S4_RNS_8ios_baseERjRT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRf = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRf"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRf = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRf"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRf"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIfEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIfEES4_S4_S4_RNS_8ios_baseERjRT_"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIfEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIfEES4_S4_S4_RNS_8ios_baseERjRT_"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIfEES4_S4_S4_RNS_8ios_baseERjRT_"]).apply(null, arguments)
            };
            var __ZNSt3__29__num_getIwE19__stage2_float_prepERNS_8ios_baseEPwRwS5_ = Module["__ZNSt3__29__num_getIwE19__stage2_float_prepERNS_8ios_baseEPwRwS5_"] = function() {
                return (__ZNSt3__29__num_getIwE19__stage2_float_prepERNS_8ios_baseEPwRwS5_ = Module["__ZNSt3__29__num_getIwE19__stage2_float_prepERNS_8ios_baseEPwRwS5_"] = Module["asm"]["_ZNSt3__29__num_getIwE19__stage2_float_prepERNS_8ios_baseEPwRwS5_"]).apply(null, arguments)
            };
            var __ZNSt3__29__num_getIwE19__stage2_float_loopEwRbRcPcRS4_wwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjPw = Module["__ZNSt3__29__num_getIwE19__stage2_float_loopEwRbRcPcRS4_wwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjPw"] = function() {
                return (__ZNSt3__29__num_getIwE19__stage2_float_loopEwRbRcPcRS4_wwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjPw = Module["__ZNSt3__29__num_getIwE19__stage2_float_loopEwRbRcPcRS4_wwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjPw"] = Module["asm"]["_ZNSt3__29__num_getIwE19__stage2_float_loopEwRbRcPcRS4_wwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPjRSE_RjPw"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRd = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRd"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRd = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRd"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRd"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIdEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIdEES4_S4_S4_RNS_8ios_baseERjRT_"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIdEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIdEES4_S4_S4_RNS_8ios_baseERjRT_"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIdEES4_S4_S4_RNS_8ios_baseERjRT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRe = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRe"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRe = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRe"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRe"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIeEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIeEES4_S4_S4_RNS_8ios_baseERjRT_"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIeEES4_S4_S4_RNS_8ios_baseERjRT_ = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIeEES4_S4_S4_RNS_8ios_baseERjRT_"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE23__do_get_floating_pointIeEES4_S4_S4_RNS_8ios_baseERjRT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRPv = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRPv"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRPv = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRPv"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjRPv"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIwE5widenEPKcS3_Pw = Module["__ZNKSt3__25ctypeIwE5widenEPKcS3_Pw"] = function() {
                return (__ZNKSt3__25ctypeIwE5widenEPKcS3_Pw = Module["__ZNKSt3__25ctypeIwE5widenEPKcS3_Pw"] = Module["asm"]["_ZNKSt3__25ctypeIwE5widenEPKcS3_Pw"]).apply(null, arguments)
            };
            var __ZNKSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEE5equalERKS3_ = Module["__ZNKSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEE5equalERKS3_"] = function() {
                return (__ZNKSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEE5equalERKS3_ = Module["__ZNKSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEE5equalERKS3_"] = Module["asm"]["_ZNKSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEE5equalERKS3_"]).apply(null, arguments)
            };
            var __ZNSt3__24findIPKwwEET_S3_S3_RKT0_ = Module["__ZNSt3__24findIPKwwEET_S3_S3_RKT0_"] = function() {
                return (__ZNSt3__24findIPKwwEET_S3_S3_RKT0_ = Module["__ZNSt3__24findIPKwwEET_S3_S3_RKT0_"] = Module["asm"]["_ZNSt3__24findIPKwwEET_S3_S3_RKT0_"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5sgetcEv = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5sgetcEv"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5sgetcEv = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5sgetcEv"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5sgetcEv"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6sbumpcEv = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6sbumpcEv"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6sbumpcEv = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6sbumpcEv"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6sbumpcEv"]).apply(null, arguments)
            };
            var __ZNKSt3__28numpunctIcE13decimal_pointEv = Module["__ZNKSt3__28numpunctIcE13decimal_pointEv"] = function() {
                return (__ZNKSt3__28numpunctIcE13decimal_pointEv = Module["__ZNKSt3__28numpunctIcE13decimal_pointEv"] = Module["asm"]["_ZNKSt3__28numpunctIcE13decimal_pointEv"]).apply(null, arguments)
            };
            var __ZNKSt3__28numpunctIcE13thousands_sepEv = Module["__ZNKSt3__28numpunctIcE13thousands_sepEv"] = function() {
                return (__ZNKSt3__28numpunctIcE13thousands_sepEv = Module["__ZNKSt3__28numpunctIcE13thousands_sepEv"] = Module["asm"]["_ZNKSt3__28numpunctIcE13thousands_sepEv"]).apply(null, arguments)
            };
            var __ZNKSt3__28numpunctIcE8groupingEv = Module["__ZNKSt3__28numpunctIcE8groupingEv"] = function() {
                return (__ZNKSt3__28numpunctIcE8groupingEv = Module["__ZNKSt3__28numpunctIcE8groupingEv"] = Module["asm"]["_ZNKSt3__28numpunctIcE8groupingEv"]).apply(null, arguments)
            };
            var __ZNSt3__24findIPccEET_S2_S2_RKT0_ = Module["__ZNSt3__24findIPccEET_S2_S2_RKT0_"] = function() {
                return (__ZNSt3__24findIPccEET_S2_S2_RKT0_ = Module["__ZNSt3__24findIPccEET_S2_S2_RKT0_"] = Module["asm"]["_ZNSt3__24findIPccEET_S2_S2_RKT0_"]).apply(null, arguments)
            };
            var __ZNKSt3__29__num_getIcE12__do_widen_pERNS_8ios_baseEPc = Module["__ZNKSt3__29__num_getIcE12__do_widen_pERNS_8ios_baseEPc"] = function() {
                return (__ZNKSt3__29__num_getIcE12__do_widen_pERNS_8ios_baseEPc = Module["__ZNKSt3__29__num_getIcE12__do_widen_pERNS_8ios_baseEPc"] = Module["asm"]["_ZNKSt3__29__num_getIcE12__do_widen_pERNS_8ios_baseEPc"]).apply(null, arguments)
            };
            var __ZNKSt3__28numpunctIwE13decimal_pointEv = Module["__ZNKSt3__28numpunctIwE13decimal_pointEv"] = function() {
                return (__ZNKSt3__28numpunctIwE13decimal_pointEv = Module["__ZNKSt3__28numpunctIwE13decimal_pointEv"] = Module["asm"]["_ZNKSt3__28numpunctIwE13decimal_pointEv"]).apply(null, arguments)
            };
            var __ZNKSt3__28numpunctIwE13thousands_sepEv = Module["__ZNKSt3__28numpunctIwE13thousands_sepEv"] = function() {
                return (__ZNKSt3__28numpunctIwE13thousands_sepEv = Module["__ZNKSt3__28numpunctIwE13thousands_sepEv"] = Module["asm"]["_ZNKSt3__28numpunctIwE13thousands_sepEv"]).apply(null, arguments)
            };
            var __ZNKSt3__28numpunctIwE8groupingEv = Module["__ZNKSt3__28numpunctIwE8groupingEv"] = function() {
                return (__ZNKSt3__28numpunctIwE8groupingEv = Module["__ZNKSt3__28numpunctIwE8groupingEv"] = Module["asm"]["_ZNKSt3__28numpunctIwE8groupingEv"]).apply(null, arguments)
            };
            var __ZNSt3__24findIPwwEET_S2_S2_RKT0_ = Module["__ZNSt3__24findIPwwEET_S2_S2_RKT0_"] = function() {
                return (__ZNSt3__24findIPwwEET_S2_S2_RKT0_ = Module["__ZNSt3__24findIPwwEET_S2_S2_RKT0_"] = Module["asm"]["_ZNSt3__24findIPwwEET_S2_S2_RKT0_"]).apply(null, arguments)
            };
            var __ZNKSt3__29__num_getIwE12__do_widen_pIwEEPKT_RNS_8ios_baseEPS3_ = Module["__ZNKSt3__29__num_getIwE12__do_widen_pIwEEPKT_RNS_8ios_baseEPS3_"] = function() {
                return (__ZNKSt3__29__num_getIwE12__do_widen_pIwEEPKT_RNS_8ios_baseEPS3_ = Module["__ZNKSt3__29__num_getIwE12__do_widen_pIwEEPKT_RNS_8ios_baseEPS3_"] = Module["asm"]["_ZNKSt3__29__num_getIwE12__do_widen_pIwEEPKT_RNS_8ios_baseEPS3_"]).apply(null, arguments)
            };
            var __ZNKSt3__29__num_getIwE12__do_widen_pERNS_8ios_baseEPc = Module["__ZNKSt3__29__num_getIwE12__do_widen_pERNS_8ios_baseEPc"] = function() {
                return (__ZNKSt3__29__num_getIwE12__do_widen_pERNS_8ios_baseEPc = Module["__ZNKSt3__29__num_getIwE12__do_widen_pERNS_8ios_baseEPc"] = Module["asm"]["_ZNKSt3__29__num_getIwE12__do_widen_pERNS_8ios_baseEPc"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcb = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcb"] = function() {
                return (__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcb = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcb"] = Module["asm"]["_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcb"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE3endEv = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE3endEv"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE3endEv = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE3endEv"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE3endEv"]).apply(null, arguments)
            };
            var __ZNSt3__2neIPcEEbRKNS_11__wrap_iterIT_EES6_ = Module["__ZNSt3__2neIPcEEbRKNS_11__wrap_iterIT_EES6_"] = function() {
                return (__ZNSt3__2neIPcEEbRKNS_11__wrap_iterIT_EES6_ = Module["__ZNSt3__2neIPcEEbRKNS_11__wrap_iterIT_EES6_"] = Module["asm"]["_ZNSt3__2neIPcEEbRKNS_11__wrap_iterIT_EES6_"]).apply(null, arguments)
            };
            var __ZNKSt3__211__wrap_iterIPcEdeEv = Module["__ZNKSt3__211__wrap_iterIPcEdeEv"] = function() {
                return (__ZNKSt3__211__wrap_iterIPcEdeEv = Module["__ZNKSt3__211__wrap_iterIPcEdeEv"] = Module["asm"]["_ZNKSt3__211__wrap_iterIPcEdeEv"]).apply(null, arguments)
            };
            var __ZNSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEEdeEv = Module["__ZNSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEEdeEv"] = function() {
                return (__ZNSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEEdeEv = Module["__ZNSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEEdeEv"] = Module["asm"]["_ZNSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEEdeEv"]).apply(null, arguments)
            };
            var __ZNSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEEaSEc = Module["__ZNSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEEaSEc"] = function() {
                return (__ZNSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEEaSEc = Module["__ZNSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEEaSEc"] = Module["asm"]["_ZNSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEEaSEc"]).apply(null, arguments)
            };
            var __ZNSt3__211__wrap_iterIPcEppEv = Module["__ZNSt3__211__wrap_iterIPcEppEv"] = function() {
                return (__ZNSt3__211__wrap_iterIPcEppEv = Module["__ZNSt3__211__wrap_iterIPcEppEv"] = Module["asm"]["_ZNSt3__211__wrap_iterIPcEppEv"]).apply(null, arguments)
            };
            var __ZNSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEEppEv = Module["__ZNSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEEppEv"] = function() {
                return (__ZNSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEEppEv = Module["__ZNSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEEppEv"] = Module["asm"]["_ZNSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEEppEv"]).apply(null, arguments)
            };
            var __ZNSt3__2eqIPcS1_EEbRKNS_11__wrap_iterIT_EERKNS2_IT0_EE = Module["__ZNSt3__2eqIPcS1_EEbRKNS_11__wrap_iterIT_EERKNS2_IT0_EE"] = function() {
                return (__ZNSt3__2eqIPcS1_EEbRKNS_11__wrap_iterIT_EERKNS2_IT0_EE = Module["__ZNSt3__2eqIPcS1_EEbRKNS_11__wrap_iterIT_EERKNS2_IT0_EE"] = Module["asm"]["_ZNSt3__2eqIPcS1_EEbRKNS_11__wrap_iterIT_EERKNS2_IT0_EE"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5sputcEc = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5sputcEc"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5sputcEc = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5sputcEc"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5sputcEc"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIcE3eofEv = Module["__ZNSt3__211char_traitsIcE3eofEv"] = function() {
                return (__ZNSt3__211char_traitsIcE3eofEv = Module["__ZNSt3__211char_traitsIcE3eofEv"] = Module["asm"]["_ZNSt3__211char_traitsIcE3eofEv"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIcE11eq_int_typeEii = Module["__ZNSt3__211char_traitsIcE11eq_int_typeEii"] = function() {
                return (__ZNSt3__211char_traitsIcE11eq_int_typeEii = Module["__ZNSt3__211char_traitsIcE11eq_int_typeEii"] = Module["asm"]["_ZNSt3__211char_traitsIcE11eq_int_typeEii"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcl = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcl"] = function() {
                return (__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcl = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcl"] = Module["asm"]["_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcl"]).apply(null, arguments)
            };
            var __ZNSt3__214__num_put_base12__format_intEPcPKcbj = Module["__ZNSt3__214__num_put_base12__format_intEPcPKcbj"] = function() {
                return (__ZNSt3__214__num_put_base12__format_intEPcPKcbj = Module["__ZNSt3__214__num_put_base12__format_intEPcPKcbj"] = Module["asm"]["_ZNSt3__214__num_put_base12__format_intEPcPKcbj"]).apply(null, arguments)
            };
            var __ZNSt3__219__libcpp_snprintf_lEPcmP15__locale_structPKcz = Module["__ZNSt3__219__libcpp_snprintf_lEPcmP15__locale_structPKcz"] = function() {
                return (__ZNSt3__219__libcpp_snprintf_lEPcmP15__locale_structPKcz = Module["__ZNSt3__219__libcpp_snprintf_lEPcmP15__locale_structPKcz"] = Module["asm"]["_ZNSt3__219__libcpp_snprintf_lEPcmP15__locale_structPKcz"]).apply(null, arguments)
            };
            var __ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE = Module["__ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE"] = function() {
                return (__ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE = Module["__ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE"] = Module["asm"]["_ZNSt3__214__num_put_base18__identify_paddingEPcS1_RKNS_8ios_baseE"]).apply(null, arguments)
            };
            var __ZNSt3__29__num_putIcE21__widen_and_group_intEPcS2_S2_S2_RS2_S3_RKNS_6localeE = Module["__ZNSt3__29__num_putIcE21__widen_and_group_intEPcS2_S2_S2_RS2_S3_RKNS_6localeE"] = function() {
                return (__ZNSt3__29__num_putIcE21__widen_and_group_intEPcS2_S2_S2_RS2_S3_RKNS_6localeE = Module["__ZNSt3__29__num_putIcE21__widen_and_group_intEPcS2_S2_S2_RS2_S3_RKNS_6localeE"] = Module["asm"]["_ZNSt3__29__num_putIcE21__widen_and_group_intEPcS2_S2_S2_RS2_S3_RKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNSt3__216__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_ = Module["__ZNSt3__216__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_"] = function() {
                return (__ZNSt3__216__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_ = Module["__ZNSt3__216__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_"] = Module["asm"]["_ZNSt3__216__pad_and_outputIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIcE5widenEc = Module["__ZNKSt3__25ctypeIcE5widenEc"] = function() {
                return (__ZNKSt3__25ctypeIcE5widenEc = Module["__ZNKSt3__25ctypeIcE5widenEc"] = Module["asm"]["_ZNKSt3__25ctypeIcE5widenEc"]).apply(null, arguments)
            };
            var __ZNSt3__27reverseIPcEEvT_S2_ = Module["__ZNSt3__27reverseIPcEEvT_S2_"] = function() {
                return (__ZNSt3__27reverseIPcEEvT_S2_ = Module["__ZNSt3__27reverseIPcEEvT_S2_"] = Module["asm"]["_ZNSt3__27reverseIPcEEvT_S2_"]).apply(null, arguments)
            };
            var __ZNKSt3__28ios_base5widthEv = Module["__ZNKSt3__28ios_base5widthEv"] = function() {
                return (__ZNKSt3__28ios_base5widthEv = Module["__ZNKSt3__28ios_base5widthEv"] = Module["asm"]["_ZNKSt3__28ios_base5widthEv"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5sputnEPKcl = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5sputnEPKcl"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5sputnEPKcl = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5sputnEPKcl"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5sputnEPKcl"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2Emc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2Emc"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2Emc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2Emc"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2Emc"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4dataEv = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4dataEv"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4dataEv = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4dataEv"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4dataEv"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base5widthEl = Module["__ZNSt3__28ios_base5widthEl"] = function() {
                return (__ZNSt3__28ios_base5widthEl = Module["__ZNSt3__28ios_base5widthEl"] = Module["asm"]["_ZNSt3__28ios_base5widthEl"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcx = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcx"] = function() {
                return (__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcx = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcx"] = Module["asm"]["_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcx"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcm = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcm"] = function() {
                return (__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcm = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcm"] = Module["asm"]["_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcm"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcy = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcy"] = function() {
                return (__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcy = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcy"] = Module["asm"]["_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcy"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcd = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcd"] = function() {
                return (__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcd = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcd"] = Module["asm"]["_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcd"]).apply(null, arguments)
            };
            var __ZNSt3__214__num_put_base14__format_floatEPcPKcj = Module["__ZNSt3__214__num_put_base14__format_floatEPcPKcj"] = function() {
                return (__ZNSt3__214__num_put_base14__format_floatEPcPKcj = Module["__ZNSt3__214__num_put_base14__format_floatEPcPKcj"] = Module["asm"]["_ZNSt3__214__num_put_base14__format_floatEPcPKcj"]).apply(null, arguments)
            };
            var __ZNKSt3__28ios_base9precisionEv = Module["__ZNKSt3__28ios_base9precisionEv"] = function() {
                return (__ZNKSt3__28ios_base9precisionEv = Module["__ZNKSt3__28ios_base9precisionEv"] = Module["asm"]["_ZNKSt3__28ios_base9precisionEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIcPFvPvEEC2ILb1EvEEPcNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE = Module["__ZNSt3__210unique_ptrIcPFvPvEEC2ILb1EvEEPcNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE"] = function() {
                return (__ZNSt3__210unique_ptrIcPFvPvEEC2ILb1EvEEPcNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE = Module["__ZNSt3__210unique_ptrIcPFvPvEEC2ILb1EvEEPcNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE"] = Module["asm"]["_ZNSt3__210unique_ptrIcPFvPvEEC2ILb1EvEEPcNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE"]).apply(null, arguments)
            };
            var __ZNSt3__219__libcpp_asprintf_lEPPcP15__locale_structPKcz = Module["__ZNSt3__219__libcpp_asprintf_lEPPcP15__locale_structPKcz"] = function() {
                return (__ZNSt3__219__libcpp_asprintf_lEPPcP15__locale_structPKcz = Module["__ZNSt3__219__libcpp_asprintf_lEPPcP15__locale_structPKcz"] = Module["asm"]["_ZNSt3__219__libcpp_asprintf_lEPPcP15__locale_structPKcz"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIcPFvPvEE5resetEPc = Module["__ZNSt3__210unique_ptrIcPFvPvEE5resetEPc"] = function() {
                return (__ZNSt3__210unique_ptrIcPFvPvEE5resetEPc = Module["__ZNSt3__210unique_ptrIcPFvPvEE5resetEPc"] = Module["asm"]["_ZNSt3__210unique_ptrIcPFvPvEE5resetEPc"]).apply(null, arguments)
            };
            var __ZNSt3__29__num_putIcE23__widen_and_group_floatEPcS2_S2_S2_RS2_S3_RKNS_6localeE = Module["__ZNSt3__29__num_putIcE23__widen_and_group_floatEPcS2_S2_S2_RS2_S3_RKNS_6localeE"] = function() {
                return (__ZNSt3__29__num_putIcE23__widen_and_group_floatEPcS2_S2_S2_RS2_S3_RKNS_6localeE = Module["__ZNSt3__29__num_putIcE23__widen_and_group_floatEPcS2_S2_S2_RS2_S3_RKNS_6localeE"] = Module["asm"]["_ZNSt3__29__num_putIcE23__widen_and_group_floatEPcS2_S2_S2_RS2_S3_RKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIcPFvPvEED2Ev = Module["__ZNSt3__210unique_ptrIcPFvPvEED2Ev"] = function() {
                return (__ZNSt3__210unique_ptrIcPFvPvEED2Ev = Module["__ZNSt3__210unique_ptrIcPFvPvEED2Ev"] = Module["asm"]["_ZNSt3__210unique_ptrIcPFvPvEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRPFvPvEEEONS_16remove_referenceIT_E4typeEOS6_ = Module["__ZNSt3__24moveIRPFvPvEEEONS_16remove_referenceIT_E4typeEOS6_"] = function() {
                return (__ZNSt3__24moveIRPFvPvEEEONS_16remove_referenceIT_E4typeEOS6_ = Module["__ZNSt3__24moveIRPFvPvEEEONS_16remove_referenceIT_E4typeEOS6_"] = Module["asm"]["_ZNSt3__24moveIRPFvPvEEEONS_16remove_referenceIT_E4typeEOS6_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPcPFvPvEEC2IRS1_S4_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPcPFvPvEEC2IRS1_S4_EEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIPcPFvPvEEC2IRS1_S4_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPcPFvPvEEC2IRS1_S4_EEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIPcPFvPvEEC2IRS1_S4_EEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPcPFvPvEE5firstEv = Module["__ZNSt3__217__compressed_pairIPcPFvPvEE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPcPFvPvEE5firstEv = Module["__ZNSt3__217__compressed_pairIPcPFvPvEE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPcPFvPvEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPcPFvPvEE6secondEv = Module["__ZNSt3__217__compressed_pairIPcPFvPvEE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPcPFvPvEE6secondEv = Module["__ZNSt3__217__compressed_pairIPcPFvPvEE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPcPFvPvEE6secondEv"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEce = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEce"] = function() {
                return (__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEce = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEce"] = Module["asm"]["_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEce"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcPKv = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcPKv"] = function() {
                return (__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcPKv = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcPKv"] = Module["asm"]["_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcPKv"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwb = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwb"] = function() {
                return (__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwb = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwb"] = Module["asm"]["_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwb"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE3endEv = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE3endEv"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE3endEv = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE3endEv"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE3endEv"]).apply(null, arguments)
            };
            var __ZNSt3__2neIPwEEbRKNS_11__wrap_iterIT_EES6_ = Module["__ZNSt3__2neIPwEEbRKNS_11__wrap_iterIT_EES6_"] = function() {
                return (__ZNSt3__2neIPwEEbRKNS_11__wrap_iterIT_EES6_ = Module["__ZNSt3__2neIPwEEbRKNS_11__wrap_iterIT_EES6_"] = Module["asm"]["_ZNSt3__2neIPwEEbRKNS_11__wrap_iterIT_EES6_"]).apply(null, arguments)
            };
            var __ZNKSt3__211__wrap_iterIPwEdeEv = Module["__ZNKSt3__211__wrap_iterIPwEdeEv"] = function() {
                return (__ZNKSt3__211__wrap_iterIPwEdeEv = Module["__ZNKSt3__211__wrap_iterIPwEdeEv"] = Module["asm"]["_ZNKSt3__211__wrap_iterIPwEdeEv"]).apply(null, arguments)
            };
            var __ZNSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEEdeEv = Module["__ZNSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEEdeEv"] = function() {
                return (__ZNSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEEdeEv = Module["__ZNSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEEdeEv"] = Module["asm"]["_ZNSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEEdeEv"]).apply(null, arguments)
            };
            var __ZNSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEEaSEw = Module["__ZNSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEEaSEw"] = function() {
                return (__ZNSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEEaSEw = Module["__ZNSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEEaSEw"] = Module["asm"]["_ZNSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEEaSEw"]).apply(null, arguments)
            };
            var __ZNSt3__211__wrap_iterIPwEppEv = Module["__ZNSt3__211__wrap_iterIPwEppEv"] = function() {
                return (__ZNSt3__211__wrap_iterIPwEppEv = Module["__ZNSt3__211__wrap_iterIPwEppEv"] = Module["asm"]["_ZNSt3__211__wrap_iterIPwEppEv"]).apply(null, arguments)
            };
            var __ZNSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEEppEv = Module["__ZNSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEEppEv"] = function() {
                return (__ZNSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEEppEv = Module["__ZNSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEEppEv"] = Module["asm"]["_ZNSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEEppEv"]).apply(null, arguments)
            };
            var __ZNSt3__2eqIPwS1_EEbRKNS_11__wrap_iterIT_EERKNS2_IT0_EE = Module["__ZNSt3__2eqIPwS1_EEbRKNS_11__wrap_iterIT_EERKNS2_IT0_EE"] = function() {
                return (__ZNSt3__2eqIPwS1_EEbRKNS_11__wrap_iterIT_EERKNS2_IT0_EE = Module["__ZNSt3__2eqIPwS1_EEbRKNS_11__wrap_iterIT_EERKNS2_IT0_EE"] = Module["asm"]["_ZNSt3__2eqIPwS1_EEbRKNS_11__wrap_iterIT_EERKNS2_IT0_EE"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5sputcEw = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5sputcEw"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5sputcEw = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5sputcEw"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5sputcEw"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIwE3eofEv = Module["__ZNSt3__211char_traitsIwE3eofEv"] = function() {
                return (__ZNSt3__211char_traitsIwE3eofEv = Module["__ZNSt3__211char_traitsIwE3eofEv"] = Module["asm"]["_ZNSt3__211char_traitsIwE3eofEv"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIwE11eq_int_typeEjj = Module["__ZNSt3__211char_traitsIwE11eq_int_typeEjj"] = function() {
                return (__ZNSt3__211char_traitsIwE11eq_int_typeEjj = Module["__ZNSt3__211char_traitsIwE11eq_int_typeEjj"] = Module["asm"]["_ZNSt3__211char_traitsIwE11eq_int_typeEjj"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwl = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwl"] = function() {
                return (__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwl = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwl"] = Module["asm"]["_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwl"]).apply(null, arguments)
            };
            var __ZNSt3__29__num_putIwE21__widen_and_group_intEPcS2_S2_PwRS3_S4_RKNS_6localeE = Module["__ZNSt3__29__num_putIwE21__widen_and_group_intEPcS2_S2_PwRS3_S4_RKNS_6localeE"] = function() {
                return (__ZNSt3__29__num_putIwE21__widen_and_group_intEPcS2_S2_PwRS3_S4_RKNS_6localeE = Module["__ZNSt3__29__num_putIwE21__widen_and_group_intEPcS2_S2_PwRS3_S4_RKNS_6localeE"] = Module["asm"]["_ZNSt3__29__num_putIwE21__widen_and_group_intEPcS2_S2_PwRS3_S4_RKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNSt3__216__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_ = Module["__ZNSt3__216__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_"] = function() {
                return (__ZNSt3__216__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_ = Module["__ZNSt3__216__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_"] = Module["asm"]["_ZNSt3__216__pad_and_outputIwNS_11char_traitsIwEEEENS_19ostreambuf_iteratorIT_T0_EES6_PKS4_S8_S8_RNS_8ios_baseES4_"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIwE5widenEc = Module["__ZNKSt3__25ctypeIwE5widenEc"] = function() {
                return (__ZNKSt3__25ctypeIwE5widenEc = Module["__ZNKSt3__25ctypeIwE5widenEc"] = Module["asm"]["_ZNKSt3__25ctypeIwE5widenEc"]).apply(null, arguments)
            };
            var __ZNSt3__27reverseIPwEEvT_S2_ = Module["__ZNSt3__27reverseIPwEEvT_S2_"] = function() {
                return (__ZNSt3__27reverseIPwEEvT_S2_ = Module["__ZNSt3__27reverseIPwEEvT_S2_"] = Module["asm"]["_ZNSt3__27reverseIPwEEvT_S2_"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5sputnEPKwl = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5sputnEPKwl"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5sputnEPKwl = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5sputnEPKwl"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5sputnEPKwl"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4dataEv = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4dataEv"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4dataEv = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4dataEv"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4dataEv"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwx = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwx"] = function() {
                return (__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwx = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwx"] = Module["asm"]["_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwx"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwm = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwm"] = function() {
                return (__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwm = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwm"] = Module["asm"]["_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwm"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwy = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwy"] = function() {
                return (__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwy = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwy"] = Module["asm"]["_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwy"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwd = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwd"] = function() {
                return (__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwd = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwd"] = Module["asm"]["_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwd"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIwPFvPvEEC2ILb1EvEEPwNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE = Module["__ZNSt3__210unique_ptrIwPFvPvEEC2ILb1EvEEPwNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE"] = function() {
                return (__ZNSt3__210unique_ptrIwPFvPvEEC2ILb1EvEEPwNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE = Module["__ZNSt3__210unique_ptrIwPFvPvEEC2ILb1EvEEPwNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE"] = Module["asm"]["_ZNSt3__210unique_ptrIwPFvPvEEC2ILb1EvEEPwNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIwPFvPvEE5resetEPw = Module["__ZNSt3__210unique_ptrIwPFvPvEE5resetEPw"] = function() {
                return (__ZNSt3__210unique_ptrIwPFvPvEE5resetEPw = Module["__ZNSt3__210unique_ptrIwPFvPvEE5resetEPw"] = Module["asm"]["_ZNSt3__210unique_ptrIwPFvPvEE5resetEPw"]).apply(null, arguments)
            };
            var __ZNSt3__29__num_putIwE23__widen_and_group_floatEPcS2_S2_PwRS3_S4_RKNS_6localeE = Module["__ZNSt3__29__num_putIwE23__widen_and_group_floatEPcS2_S2_PwRS3_S4_RKNS_6localeE"] = function() {
                return (__ZNSt3__29__num_putIwE23__widen_and_group_floatEPcS2_S2_PwRS3_S4_RKNS_6localeE = Module["__ZNSt3__29__num_putIwE23__widen_and_group_floatEPcS2_S2_PwRS3_S4_RKNS_6localeE"] = Module["asm"]["_ZNSt3__29__num_putIwE23__widen_and_group_floatEPcS2_S2_PwRS3_S4_RKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIwPFvPvEED2Ev = Module["__ZNSt3__210unique_ptrIwPFvPvEED2Ev"] = function() {
                return (__ZNSt3__210unique_ptrIwPFvPvEED2Ev = Module["__ZNSt3__210unique_ptrIwPFvPvEED2Ev"] = Module["asm"]["_ZNSt3__210unique_ptrIwPFvPvEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPwPFvPvEEC2IRS1_S4_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPwPFvPvEEC2IRS1_S4_EEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIPwPFvPvEEC2IRS1_S4_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPwPFvPvEEC2IRS1_S4_EEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIPwPFvPvEEC2IRS1_S4_EEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPwPFvPvEE5firstEv = Module["__ZNSt3__217__compressed_pairIPwPFvPvEE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPwPFvPvEE5firstEv = Module["__ZNSt3__217__compressed_pairIPwPFvPvEE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPwPFvPvEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPwPFvPvEE6secondEv = Module["__ZNSt3__217__compressed_pairIPwPFvPvEE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPwPFvPvEE6secondEv = Module["__ZNSt3__217__compressed_pairIPwPFvPvEE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPwPFvPvEE6secondEv"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwe = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwe"] = function() {
                return (__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwe = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwe"] = Module["asm"]["_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwe"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwPKv = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwPKv"] = function() {
                return (__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwPKv = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwPKv"] = Module["asm"]["_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwPKv"]).apply(null, arguments)
            };
            var __ZNSt3__29__reverseIPcEEvT_S2_NS_26random_access_iterator_tagE = Module["__ZNSt3__29__reverseIPcEEvT_S2_NS_26random_access_iterator_tagE"] = function() {
                return (__ZNSt3__29__reverseIPcEEvT_S2_NS_26random_access_iterator_tagE = Module["__ZNSt3__29__reverseIPcEEvT_S2_NS_26random_access_iterator_tagE"] = Module["asm"]["_ZNSt3__29__reverseIPcEEvT_S2_NS_26random_access_iterator_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__29__reverseIPwEEvT_S2_NS_26random_access_iterator_tagE = Module["__ZNSt3__29__reverseIPwEEvT_S2_NS_26random_access_iterator_tagE"] = function() {
                return (__ZNSt3__29__reverseIPwEEvT_S2_NS_26random_access_iterator_tagE = Module["__ZNSt3__29__reverseIPwEEvT_S2_NS_26random_access_iterator_tagE"] = Module["asm"]["_ZNSt3__29__reverseIPwEEvT_S2_NS_26random_access_iterator_tagE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_ = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_"] = function() {
                return (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_ = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_"] = Module["asm"]["_ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKcSC_"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIcE6narrowEcc = Module["__ZNKSt3__25ctypeIcE6narrowEcc"] = function() {
                return (__ZNKSt3__25ctypeIcE6narrowEcc = Module["__ZNKSt3__25ctypeIcE6narrowEcc"] = Module["asm"]["_ZNKSt3__25ctypeIcE6narrowEcc"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIcE2isEtc = Module["__ZNKSt3__25ctypeIcE2isEtc"] = function() {
                return (__ZNKSt3__25ctypeIcE2isEtc = Module["__ZNKSt3__25ctypeIcE2isEtc"] = Module["asm"]["_ZNKSt3__25ctypeIcE2isEtc"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13do_date_orderEv = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13do_date_orderEv"] = function() {
                return (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13do_date_orderEv = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13do_date_orderEv"] = Module["asm"]["_ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13do_date_orderEv"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_timeES4_S4_RNS_8ios_baseERjP2tm = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_timeES4_S4_RNS_8ios_baseERjP2tm"] = function() {
                return (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_timeES4_S4_RNS_8ios_baseERjP2tm = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_timeES4_S4_RNS_8ios_baseERjP2tm"] = Module["asm"]["_ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_timeES4_S4_RNS_8ios_baseERjP2tm"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_dateES4_S4_RNS_8ios_baseERjP2tm = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_dateES4_S4_RNS_8ios_baseERjP2tm"] = function() {
                return (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_dateES4_S4_RNS_8ios_baseERjP2tm = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_dateES4_S4_RNS_8ios_baseERjP2tm"] = Module["asm"]["_ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_dateES4_S4_RNS_8ios_baseERjP2tm"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE14do_get_weekdayES4_S4_RNS_8ios_baseERjP2tm = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE14do_get_weekdayES4_S4_RNS_8ios_baseERjP2tm"] = function() {
                return (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE14do_get_weekdayES4_S4_RNS_8ios_baseERjP2tm = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE14do_get_weekdayES4_S4_RNS_8ios_baseERjP2tm"] = Module["asm"]["_ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE14do_get_weekdayES4_S4_RNS_8ios_baseERjP2tm"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIcEE"] = function() {
                return (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIcEE"] = Module["asm"]["_ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIcEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE16do_get_monthnameES4_S4_RNS_8ios_baseERjP2tm = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE16do_get_monthnameES4_S4_RNS_8ios_baseERjP2tm"] = function() {
                return (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE16do_get_monthnameES4_S4_RNS_8ios_baseERjP2tm = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE16do_get_monthnameES4_S4_RNS_8ios_baseERjP2tm"] = Module["asm"]["_ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE16do_get_monthnameES4_S4_RNS_8ios_baseERjP2tm"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIcEE"] = function() {
                return (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIcEE"] = Module["asm"]["_ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIcEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_yearES4_S4_RNS_8ios_baseERjP2tm = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_yearES4_S4_RNS_8ios_baseERjP2tm"] = function() {
                return (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_yearES4_S4_RNS_8ios_baseERjP2tm = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_yearES4_S4_RNS_8ios_baseERjP2tm"] = Module["asm"]["_ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11do_get_yearES4_S4_RNS_8ios_baseERjP2tm"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIcEE"] = function() {
                return (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIcEE"] = Module["asm"]["_ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIcEE"]).apply(null, arguments)
            };
            var __ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi = Module["__ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi"] = function() {
                return (__ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi = Module["__ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi"] = Module["asm"]["_ZNSt3__220__get_up_to_n_digitsIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjP2tmcc = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjP2tmcc"] = function() {
                return (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjP2tmcc = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjP2tmcc"] = Module["asm"]["_ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_RNS_8ios_baseERjP2tmcc"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE9__get_dayERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE9__get_dayERiRS4_S4_RjRKNS_5ctypeIcEE"] = function() {
                return (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE9__get_dayERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE9__get_dayERiRS4_S4_RjRKNS_5ctypeIcEE"] = Module["asm"]["_ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE9__get_dayERiRS4_S4_RjRKNS_5ctypeIcEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE10__get_hourERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE10__get_hourERiRS4_S4_RjRKNS_5ctypeIcEE"] = function() {
                return (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE10__get_hourERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE10__get_hourERiRS4_S4_RjRKNS_5ctypeIcEE"] = Module["asm"]["_ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE10__get_hourERiRS4_S4_RjRKNS_5ctypeIcEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_12_hourERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_12_hourERiRS4_S4_RjRKNS_5ctypeIcEE"] = function() {
                return (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_12_hourERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_12_hourERiRS4_S4_RjRKNS_5ctypeIcEE"] = Module["asm"]["_ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_12_hourERiRS4_S4_RjRKNS_5ctypeIcEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE18__get_day_year_numERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE18__get_day_year_numERiRS4_S4_RjRKNS_5ctypeIcEE"] = function() {
                return (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE18__get_day_year_numERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE18__get_day_year_numERiRS4_S4_RjRKNS_5ctypeIcEE"] = Module["asm"]["_ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE18__get_day_year_numERiRS4_S4_RjRKNS_5ctypeIcEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_monthERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_monthERiRS4_S4_RjRKNS_5ctypeIcEE"] = function() {
                return (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_monthERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_monthERiRS4_S4_RjRKNS_5ctypeIcEE"] = Module["asm"]["_ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_monthERiRS4_S4_RjRKNS_5ctypeIcEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE12__get_minuteERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE12__get_minuteERiRS4_S4_RjRKNS_5ctypeIcEE"] = function() {
                return (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE12__get_minuteERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE12__get_minuteERiRS4_S4_RjRKNS_5ctypeIcEE"] = Module["asm"]["_ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE12__get_minuteERiRS4_S4_RjRKNS_5ctypeIcEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__get_white_spaceERS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__get_white_spaceERS4_S4_RjRKNS_5ctypeIcEE"] = function() {
                return (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__get_white_spaceERS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__get_white_spaceERS4_S4_RjRKNS_5ctypeIcEE"] = Module["asm"]["_ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE17__get_white_spaceERS4_S4_RjRKNS_5ctypeIcEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_am_pmERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_am_pmERiRS4_S4_RjRKNS_5ctypeIcEE"] = function() {
                return (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_am_pmERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_am_pmERiRS4_S4_RjRKNS_5ctypeIcEE"] = Module["asm"]["_ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_am_pmERiRS4_S4_RjRKNS_5ctypeIcEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE12__get_secondERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE12__get_secondERiRS4_S4_RjRKNS_5ctypeIcEE"] = function() {
                return (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE12__get_secondERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE12__get_secondERiRS4_S4_RjRKNS_5ctypeIcEE"] = Module["asm"]["_ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE12__get_secondERiRS4_S4_RjRKNS_5ctypeIcEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_weekdayERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_weekdayERiRS4_S4_RjRKNS_5ctypeIcEE"] = function() {
                return (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_weekdayERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_weekdayERiRS4_S4_RjRKNS_5ctypeIcEE"] = Module["asm"]["_ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_weekdayERiRS4_S4_RjRKNS_5ctypeIcEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_year4ERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_year4ERiRS4_S4_RjRKNS_5ctypeIcEE"] = function() {
                return (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_year4ERiRS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_year4ERiRS4_S4_RjRKNS_5ctypeIcEE"] = Module["asm"]["_ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE11__get_year4ERiRS4_S4_RjRKNS_5ctypeIcEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_percentERS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_percentERS4_S4_RjRKNS_5ctypeIcEE"] = function() {
                return (__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_percentERS4_S4_RjRKNS_5ctypeIcEE = Module["__ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_percentERS4_S4_RjRKNS_5ctypeIcEE"] = Module["asm"]["_ZNKSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13__get_percentERS4_S4_RjRKNS_5ctypeIcEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_ = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_"] = function() {
                return (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_ = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_"] = Module["asm"]["_ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjP2tmPKwSC_"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIwE6narrowEwc = Module["__ZNKSt3__25ctypeIwE6narrowEwc"] = function() {
                return (__ZNKSt3__25ctypeIwE6narrowEwc = Module["__ZNKSt3__25ctypeIwE6narrowEwc"] = Module["asm"]["_ZNKSt3__25ctypeIwE6narrowEwc"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIwE2isEtw = Module["__ZNKSt3__25ctypeIwE2isEtw"] = function() {
                return (__ZNKSt3__25ctypeIwE2isEtw = Module["__ZNKSt3__25ctypeIwE2isEtw"] = Module["asm"]["_ZNKSt3__25ctypeIwE2isEtw"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13do_date_orderEv = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13do_date_orderEv"] = function() {
                return (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13do_date_orderEv = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13do_date_orderEv"] = Module["asm"]["_ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13do_date_orderEv"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_timeES4_S4_RNS_8ios_baseERjP2tm = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_timeES4_S4_RNS_8ios_baseERjP2tm"] = function() {
                return (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_timeES4_S4_RNS_8ios_baseERjP2tm = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_timeES4_S4_RNS_8ios_baseERjP2tm"] = Module["asm"]["_ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_timeES4_S4_RNS_8ios_baseERjP2tm"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_dateES4_S4_RNS_8ios_baseERjP2tm = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_dateES4_S4_RNS_8ios_baseERjP2tm"] = function() {
                return (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_dateES4_S4_RNS_8ios_baseERjP2tm = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_dateES4_S4_RNS_8ios_baseERjP2tm"] = Module["asm"]["_ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_dateES4_S4_RNS_8ios_baseERjP2tm"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE14do_get_weekdayES4_S4_RNS_8ios_baseERjP2tm = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE14do_get_weekdayES4_S4_RNS_8ios_baseERjP2tm"] = function() {
                return (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE14do_get_weekdayES4_S4_RNS_8ios_baseERjP2tm = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE14do_get_weekdayES4_S4_RNS_8ios_baseERjP2tm"] = Module["asm"]["_ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE14do_get_weekdayES4_S4_RNS_8ios_baseERjP2tm"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIwEE"] = function() {
                return (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIwEE"] = Module["asm"]["_ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__get_weekdaynameERiRS4_S4_RjRKNS_5ctypeIwEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE16do_get_monthnameES4_S4_RNS_8ios_baseERjP2tm = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE16do_get_monthnameES4_S4_RNS_8ios_baseERjP2tm"] = function() {
                return (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE16do_get_monthnameES4_S4_RNS_8ios_baseERjP2tm = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE16do_get_monthnameES4_S4_RNS_8ios_baseERjP2tm"] = Module["asm"]["_ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE16do_get_monthnameES4_S4_RNS_8ios_baseERjP2tm"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIwEE"] = function() {
                return (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIwEE"] = Module["asm"]["_ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE15__get_monthnameERiRS4_S4_RjRKNS_5ctypeIwEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_yearES4_S4_RNS_8ios_baseERjP2tm = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_yearES4_S4_RNS_8ios_baseERjP2tm"] = function() {
                return (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_yearES4_S4_RNS_8ios_baseERjP2tm = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_yearES4_S4_RNS_8ios_baseERjP2tm"] = Module["asm"]["_ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11do_get_yearES4_S4_RNS_8ios_baseERjP2tm"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIwEE"] = function() {
                return (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIwEE"] = Module["asm"]["_ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE10__get_yearERiRS4_S4_RjRKNS_5ctypeIwEE"]).apply(null, arguments)
            };
            var __ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi = Module["__ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi"] = function() {
                return (__ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi = Module["__ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi"] = Module["asm"]["_ZNSt3__220__get_up_to_n_digitsIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEiRT0_S5_RjRKNS_5ctypeIT_EEi"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjP2tmcc = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjP2tmcc"] = function() {
                return (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjP2tmcc = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjP2tmcc"] = Module["asm"]["_ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_RNS_8ios_baseERjP2tmcc"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE9__get_dayERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE9__get_dayERiRS4_S4_RjRKNS_5ctypeIwEE"] = function() {
                return (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE9__get_dayERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE9__get_dayERiRS4_S4_RjRKNS_5ctypeIwEE"] = Module["asm"]["_ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE9__get_dayERiRS4_S4_RjRKNS_5ctypeIwEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE10__get_hourERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE10__get_hourERiRS4_S4_RjRKNS_5ctypeIwEE"] = function() {
                return (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE10__get_hourERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE10__get_hourERiRS4_S4_RjRKNS_5ctypeIwEE"] = Module["asm"]["_ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE10__get_hourERiRS4_S4_RjRKNS_5ctypeIwEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_12_hourERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_12_hourERiRS4_S4_RjRKNS_5ctypeIwEE"] = function() {
                return (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_12_hourERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_12_hourERiRS4_S4_RjRKNS_5ctypeIwEE"] = Module["asm"]["_ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_12_hourERiRS4_S4_RjRKNS_5ctypeIwEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE18__get_day_year_numERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE18__get_day_year_numERiRS4_S4_RjRKNS_5ctypeIwEE"] = function() {
                return (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE18__get_day_year_numERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE18__get_day_year_numERiRS4_S4_RjRKNS_5ctypeIwEE"] = Module["asm"]["_ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE18__get_day_year_numERiRS4_S4_RjRKNS_5ctypeIwEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_monthERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_monthERiRS4_S4_RjRKNS_5ctypeIwEE"] = function() {
                return (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_monthERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_monthERiRS4_S4_RjRKNS_5ctypeIwEE"] = Module["asm"]["_ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_monthERiRS4_S4_RjRKNS_5ctypeIwEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE12__get_minuteERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE12__get_minuteERiRS4_S4_RjRKNS_5ctypeIwEE"] = function() {
                return (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE12__get_minuteERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE12__get_minuteERiRS4_S4_RjRKNS_5ctypeIwEE"] = Module["asm"]["_ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE12__get_minuteERiRS4_S4_RjRKNS_5ctypeIwEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__get_white_spaceERS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__get_white_spaceERS4_S4_RjRKNS_5ctypeIwEE"] = function() {
                return (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__get_white_spaceERS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__get_white_spaceERS4_S4_RjRKNS_5ctypeIwEE"] = Module["asm"]["_ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE17__get_white_spaceERS4_S4_RjRKNS_5ctypeIwEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_am_pmERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_am_pmERiRS4_S4_RjRKNS_5ctypeIwEE"] = function() {
                return (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_am_pmERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_am_pmERiRS4_S4_RjRKNS_5ctypeIwEE"] = Module["asm"]["_ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_am_pmERiRS4_S4_RjRKNS_5ctypeIwEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE12__get_secondERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE12__get_secondERiRS4_S4_RjRKNS_5ctypeIwEE"] = function() {
                return (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE12__get_secondERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE12__get_secondERiRS4_S4_RjRKNS_5ctypeIwEE"] = Module["asm"]["_ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE12__get_secondERiRS4_S4_RjRKNS_5ctypeIwEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_weekdayERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_weekdayERiRS4_S4_RjRKNS_5ctypeIwEE"] = function() {
                return (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_weekdayERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_weekdayERiRS4_S4_RjRKNS_5ctypeIwEE"] = Module["asm"]["_ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_weekdayERiRS4_S4_RjRKNS_5ctypeIwEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_year4ERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_year4ERiRS4_S4_RjRKNS_5ctypeIwEE"] = function() {
                return (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_year4ERiRS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_year4ERiRS4_S4_RjRKNS_5ctypeIwEE"] = Module["asm"]["_ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE11__get_year4ERiRS4_S4_RjRKNS_5ctypeIwEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_percentERS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_percentERS4_S4_RjRKNS_5ctypeIwEE"] = function() {
                return (__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_percentERS4_S4_RjRKNS_5ctypeIwEE = Module["__ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_percentERS4_S4_RjRKNS_5ctypeIwEE"] = Module["asm"]["_ZNKSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13__get_percentERS4_S4_RjRKNS_5ctypeIwEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcPK2tmPKcSC_ = Module["__ZNKSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcPK2tmPKcSC_"] = function() {
                return (__ZNKSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcPK2tmPKcSC_ = Module["__ZNKSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcPK2tmPKcSC_"] = Module["asm"]["_ZNKSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcPK2tmPKcSC_"]).apply(null, arguments)
            };
            var __ZNSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEEppEi = Module["__ZNSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEEppEi"] = function() {
                return (__ZNSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEEppEi = Module["__ZNSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEEppEi"] = Module["asm"]["_ZNSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEEppEi"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcPK2tmcc = Module["__ZNKSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcPK2tmcc"] = function() {
                return (__ZNKSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcPK2tmcc = Module["__ZNKSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcPK2tmcc"] = Module["asm"]["_ZNKSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcPK2tmcc"]).apply(null, arguments)
            };
            var __ZNKSt3__210__time_put8__do_putEPcRS1_PK2tmcc = Module["__ZNKSt3__210__time_put8__do_putEPcRS1_PK2tmcc"] = function() {
                return (__ZNKSt3__210__time_put8__do_putEPcRS1_PK2tmcc = Module["__ZNKSt3__210__time_put8__do_putEPcRS1_PK2tmcc"] = Module["asm"]["_ZNKSt3__210__time_put8__do_putEPcRS1_PK2tmcc"]).apply(null, arguments)
            };
            var __ZNSt3__24copyIPcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEET0_T_S7_S6_ = Module["__ZNSt3__24copyIPcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEET0_T_S7_S6_"] = function() {
                return (__ZNSt3__24copyIPcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEET0_T_S7_S6_ = Module["__ZNSt3__24copyIPcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEET0_T_S7_S6_"] = Module["asm"]["_ZNSt3__24copyIPcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEET0_T_S7_S6_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIcEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIcEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = function() {
                return (__ZNSt3__24swapIcEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIcEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = Module["asm"]["_ZNSt3__24swapIcEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"]).apply(null, arguments)
            };
            var __ZNSt3__213__unwrap_iterIPcEET_S2_ = Module["__ZNSt3__213__unwrap_iterIPcEET_S2_"] = function() {
                return (__ZNSt3__213__unwrap_iterIPcEET_S2_ = Module["__ZNSt3__213__unwrap_iterIPcEET_S2_"] = Module["asm"]["_ZNSt3__213__unwrap_iterIPcEET_S2_"]).apply(null, arguments)
            };
            var __ZNSt3__213__unwrap_iterINS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEET_S5_ = Module["__ZNSt3__213__unwrap_iterINS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEET_S5_"] = function() {
                return (__ZNSt3__213__unwrap_iterINS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEET_S5_ = Module["__ZNSt3__213__unwrap_iterINS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEET_S5_"] = Module["asm"]["_ZNSt3__213__unwrap_iterINS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEET_S5_"]).apply(null, arguments)
            };
            var __ZNSt3__26__copyIPcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEET0_T_S7_S6_ = Module["__ZNSt3__26__copyIPcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEET0_T_S7_S6_"] = function() {
                return (__ZNSt3__26__copyIPcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEET0_T_S7_S6_ = Module["__ZNSt3__26__copyIPcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEET0_T_S7_S6_"] = Module["asm"]["_ZNSt3__26__copyIPcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEET0_T_S7_S6_"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwPK2tmPKwSC_ = Module["__ZNKSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwPK2tmPKwSC_"] = function() {
                return (__ZNKSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwPK2tmPKwSC_ = Module["__ZNKSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwPK2tmPKwSC_"] = Module["asm"]["_ZNKSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwPK2tmPKwSC_"]).apply(null, arguments)
            };
            var __ZNSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEEppEi = Module["__ZNSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEEppEi"] = function() {
                return (__ZNSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEEppEi = Module["__ZNSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEEppEi"] = Module["asm"]["_ZNSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEEppEi"]).apply(null, arguments)
            };
            var __ZNKSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwPK2tmcc = Module["__ZNKSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwPK2tmcc"] = function() {
                return (__ZNKSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwPK2tmcc = Module["__ZNKSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwPK2tmcc"] = Module["asm"]["_ZNKSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwPK2tmcc"]).apply(null, arguments)
            };
            var __ZNKSt3__210__time_put8__do_putEPwRS1_PK2tmcc = Module["__ZNKSt3__210__time_put8__do_putEPwRS1_PK2tmcc"] = function() {
                return (__ZNKSt3__210__time_put8__do_putEPwRS1_PK2tmcc = Module["__ZNKSt3__210__time_put8__do_putEPwRS1_PK2tmcc"] = Module["asm"]["_ZNKSt3__210__time_put8__do_putEPwRS1_PK2tmcc"]).apply(null, arguments)
            };
            var __ZNSt3__24copyIPwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEET0_T_S7_S6_ = Module["__ZNSt3__24copyIPwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEET0_T_S7_S6_"] = function() {
                return (__ZNSt3__24copyIPwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEET0_T_S7_S6_ = Module["__ZNSt3__24copyIPwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEET0_T_S7_S6_"] = Module["asm"]["_ZNSt3__24copyIPwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEET0_T_S7_S6_"]).apply(null, arguments)
            };
            var __ZNSt3__220__libcpp_mbsrtowcs_lEPwPPKcmP11__mbstate_tP15__locale_struct = Module["__ZNSt3__220__libcpp_mbsrtowcs_lEPwPPKcmP11__mbstate_tP15__locale_struct"] = function() {
                return (__ZNSt3__220__libcpp_mbsrtowcs_lEPwPPKcmP11__mbstate_tP15__locale_struct = Module["__ZNSt3__220__libcpp_mbsrtowcs_lEPwPPKcmP11__mbstate_tP15__locale_struct"] = Module["asm"]["_ZNSt3__220__libcpp_mbsrtowcs_lEPwPPKcmP11__mbstate_tP15__locale_struct"]).apply(null, arguments)
            };
            var __ZNSt3__221__throw_runtime_errorEPKc = Module["__ZNSt3__221__throw_runtime_errorEPKc"] = function() {
                return (__ZNSt3__221__throw_runtime_errorEPKc = Module["__ZNSt3__221__throw_runtime_errorEPKc"] = Module["asm"]["_ZNSt3__221__throw_runtime_errorEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__213__unwrap_iterIPwEET_S2_ = Module["__ZNSt3__213__unwrap_iterIPwEET_S2_"] = function() {
                return (__ZNSt3__213__unwrap_iterIPwEET_S2_ = Module["__ZNSt3__213__unwrap_iterIPwEET_S2_"] = Module["asm"]["_ZNSt3__213__unwrap_iterIPwEET_S2_"]).apply(null, arguments)
            };
            var __ZNSt3__213__unwrap_iterINS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEET_S5_ = Module["__ZNSt3__213__unwrap_iterINS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEET_S5_"] = function() {
                return (__ZNSt3__213__unwrap_iterINS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEET_S5_ = Module["__ZNSt3__213__unwrap_iterINS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEET_S5_"] = Module["asm"]["_ZNSt3__213__unwrap_iterINS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEET_S5_"]).apply(null, arguments)
            };
            var __ZNSt3__26__copyIPwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEET0_T_S7_S6_ = Module["__ZNSt3__26__copyIPwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEET0_T_S7_S6_"] = function() {
                return (__ZNSt3__26__copyIPwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEET0_T_S7_S6_ = Module["__ZNSt3__26__copyIPwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEET0_T_S7_S6_"] = Module["asm"]["_ZNSt3__26__copyIPwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEET0_T_S7_S6_"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb0EE16do_decimal_pointEv = Module["__ZNKSt3__210moneypunctIcLb0EE16do_decimal_pointEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb0EE16do_decimal_pointEv = Module["__ZNKSt3__210moneypunctIcLb0EE16do_decimal_pointEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb0EE16do_decimal_pointEv"]).apply(null, arguments)
            };
            var __ZNSt3__214numeric_limitsIcE3maxEv = Module["__ZNSt3__214numeric_limitsIcE3maxEv"] = function() {
                return (__ZNSt3__214numeric_limitsIcE3maxEv = Module["__ZNSt3__214numeric_limitsIcE3maxEv"] = Module["asm"]["_ZNSt3__214numeric_limitsIcE3maxEv"]).apply(null, arguments)
            };
            var __ZNSt3__223__libcpp_numeric_limitsIcLb1EE3maxEv = Module["__ZNSt3__223__libcpp_numeric_limitsIcLb1EE3maxEv"] = function() {
                return (__ZNSt3__223__libcpp_numeric_limitsIcLb1EE3maxEv = Module["__ZNSt3__223__libcpp_numeric_limitsIcLb1EE3maxEv"] = Module["asm"]["_ZNSt3__223__libcpp_numeric_limitsIcLb1EE3maxEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb0EE16do_thousands_sepEv = Module["__ZNKSt3__210moneypunctIcLb0EE16do_thousands_sepEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb0EE16do_thousands_sepEv = Module["__ZNKSt3__210moneypunctIcLb0EE16do_thousands_sepEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb0EE16do_thousands_sepEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb0EE11do_groupingEv = Module["__ZNKSt3__210moneypunctIcLb0EE11do_groupingEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb0EE11do_groupingEv = Module["__ZNKSt3__210moneypunctIcLb0EE11do_groupingEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb0EE11do_groupingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb0EE14do_curr_symbolEv = Module["__ZNKSt3__210moneypunctIcLb0EE14do_curr_symbolEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb0EE14do_curr_symbolEv = Module["__ZNKSt3__210moneypunctIcLb0EE14do_curr_symbolEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb0EE14do_curr_symbolEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb0EE16do_positive_signEv = Module["__ZNKSt3__210moneypunctIcLb0EE16do_positive_signEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb0EE16do_positive_signEv = Module["__ZNKSt3__210moneypunctIcLb0EE16do_positive_signEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb0EE16do_positive_signEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb0EE16do_negative_signEv = Module["__ZNKSt3__210moneypunctIcLb0EE16do_negative_signEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb0EE16do_negative_signEv = Module["__ZNKSt3__210moneypunctIcLb0EE16do_negative_signEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb0EE16do_negative_signEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb0EE14do_frac_digitsEv = Module["__ZNKSt3__210moneypunctIcLb0EE14do_frac_digitsEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb0EE14do_frac_digitsEv = Module["__ZNKSt3__210moneypunctIcLb0EE14do_frac_digitsEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb0EE14do_frac_digitsEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb0EE13do_pos_formatEv = Module["__ZNKSt3__210moneypunctIcLb0EE13do_pos_formatEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb0EE13do_pos_formatEv = Module["__ZNKSt3__210moneypunctIcLb0EE13do_pos_formatEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb0EE13do_pos_formatEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb0EE13do_neg_formatEv = Module["__ZNKSt3__210moneypunctIcLb0EE13do_neg_formatEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb0EE13do_neg_formatEv = Module["__ZNKSt3__210moneypunctIcLb0EE13do_neg_formatEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb0EE13do_neg_formatEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb1EE16do_decimal_pointEv = Module["__ZNKSt3__210moneypunctIcLb1EE16do_decimal_pointEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb1EE16do_decimal_pointEv = Module["__ZNKSt3__210moneypunctIcLb1EE16do_decimal_pointEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb1EE16do_decimal_pointEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb1EE16do_thousands_sepEv = Module["__ZNKSt3__210moneypunctIcLb1EE16do_thousands_sepEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb1EE16do_thousands_sepEv = Module["__ZNKSt3__210moneypunctIcLb1EE16do_thousands_sepEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb1EE16do_thousands_sepEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb1EE11do_groupingEv = Module["__ZNKSt3__210moneypunctIcLb1EE11do_groupingEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb1EE11do_groupingEv = Module["__ZNKSt3__210moneypunctIcLb1EE11do_groupingEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb1EE11do_groupingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb1EE14do_curr_symbolEv = Module["__ZNKSt3__210moneypunctIcLb1EE14do_curr_symbolEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb1EE14do_curr_symbolEv = Module["__ZNKSt3__210moneypunctIcLb1EE14do_curr_symbolEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb1EE14do_curr_symbolEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb1EE16do_positive_signEv = Module["__ZNKSt3__210moneypunctIcLb1EE16do_positive_signEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb1EE16do_positive_signEv = Module["__ZNKSt3__210moneypunctIcLb1EE16do_positive_signEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb1EE16do_positive_signEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb1EE16do_negative_signEv = Module["__ZNKSt3__210moneypunctIcLb1EE16do_negative_signEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb1EE16do_negative_signEv = Module["__ZNKSt3__210moneypunctIcLb1EE16do_negative_signEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb1EE16do_negative_signEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb1EE14do_frac_digitsEv = Module["__ZNKSt3__210moneypunctIcLb1EE14do_frac_digitsEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb1EE14do_frac_digitsEv = Module["__ZNKSt3__210moneypunctIcLb1EE14do_frac_digitsEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb1EE14do_frac_digitsEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb1EE13do_pos_formatEv = Module["__ZNKSt3__210moneypunctIcLb1EE13do_pos_formatEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb1EE13do_pos_formatEv = Module["__ZNKSt3__210moneypunctIcLb1EE13do_pos_formatEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb1EE13do_pos_formatEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb1EE13do_neg_formatEv = Module["__ZNKSt3__210moneypunctIcLb1EE13do_neg_formatEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb1EE13do_neg_formatEv = Module["__ZNKSt3__210moneypunctIcLb1EE13do_neg_formatEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb1EE13do_neg_formatEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb0EE16do_decimal_pointEv = Module["__ZNKSt3__210moneypunctIwLb0EE16do_decimal_pointEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb0EE16do_decimal_pointEv = Module["__ZNKSt3__210moneypunctIwLb0EE16do_decimal_pointEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb0EE16do_decimal_pointEv"]).apply(null, arguments)
            };
            var __ZNSt3__214numeric_limitsIwE3maxEv = Module["__ZNSt3__214numeric_limitsIwE3maxEv"] = function() {
                return (__ZNSt3__214numeric_limitsIwE3maxEv = Module["__ZNSt3__214numeric_limitsIwE3maxEv"] = Module["asm"]["_ZNSt3__214numeric_limitsIwE3maxEv"]).apply(null, arguments)
            };
            var __ZNSt3__223__libcpp_numeric_limitsIwLb1EE3maxEv = Module["__ZNSt3__223__libcpp_numeric_limitsIwLb1EE3maxEv"] = function() {
                return (__ZNSt3__223__libcpp_numeric_limitsIwLb1EE3maxEv = Module["__ZNSt3__223__libcpp_numeric_limitsIwLb1EE3maxEv"] = Module["asm"]["_ZNSt3__223__libcpp_numeric_limitsIwLb1EE3maxEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb0EE16do_thousands_sepEv = Module["__ZNKSt3__210moneypunctIwLb0EE16do_thousands_sepEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb0EE16do_thousands_sepEv = Module["__ZNKSt3__210moneypunctIwLb0EE16do_thousands_sepEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb0EE16do_thousands_sepEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb0EE11do_groupingEv = Module["__ZNKSt3__210moneypunctIwLb0EE11do_groupingEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb0EE11do_groupingEv = Module["__ZNKSt3__210moneypunctIwLb0EE11do_groupingEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb0EE11do_groupingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb0EE14do_curr_symbolEv = Module["__ZNKSt3__210moneypunctIwLb0EE14do_curr_symbolEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb0EE14do_curr_symbolEv = Module["__ZNKSt3__210moneypunctIwLb0EE14do_curr_symbolEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb0EE14do_curr_symbolEv"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2Ev = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2Ev"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2Ev = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2Ev"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb0EE16do_positive_signEv = Module["__ZNKSt3__210moneypunctIwLb0EE16do_positive_signEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb0EE16do_positive_signEv = Module["__ZNKSt3__210moneypunctIwLb0EE16do_positive_signEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb0EE16do_positive_signEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb0EE16do_negative_signEv = Module["__ZNKSt3__210moneypunctIwLb0EE16do_negative_signEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb0EE16do_negative_signEv = Module["__ZNKSt3__210moneypunctIwLb0EE16do_negative_signEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb0EE16do_negative_signEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb0EE14do_frac_digitsEv = Module["__ZNKSt3__210moneypunctIwLb0EE14do_frac_digitsEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb0EE14do_frac_digitsEv = Module["__ZNKSt3__210moneypunctIwLb0EE14do_frac_digitsEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb0EE14do_frac_digitsEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb0EE13do_pos_formatEv = Module["__ZNKSt3__210moneypunctIwLb0EE13do_pos_formatEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb0EE13do_pos_formatEv = Module["__ZNKSt3__210moneypunctIwLb0EE13do_pos_formatEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb0EE13do_pos_formatEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb0EE13do_neg_formatEv = Module["__ZNKSt3__210moneypunctIwLb0EE13do_neg_formatEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb0EE13do_neg_formatEv = Module["__ZNKSt3__210moneypunctIwLb0EE13do_neg_formatEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb0EE13do_neg_formatEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb1EE16do_decimal_pointEv = Module["__ZNKSt3__210moneypunctIwLb1EE16do_decimal_pointEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb1EE16do_decimal_pointEv = Module["__ZNKSt3__210moneypunctIwLb1EE16do_decimal_pointEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb1EE16do_decimal_pointEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb1EE16do_thousands_sepEv = Module["__ZNKSt3__210moneypunctIwLb1EE16do_thousands_sepEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb1EE16do_thousands_sepEv = Module["__ZNKSt3__210moneypunctIwLb1EE16do_thousands_sepEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb1EE16do_thousands_sepEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb1EE11do_groupingEv = Module["__ZNKSt3__210moneypunctIwLb1EE11do_groupingEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb1EE11do_groupingEv = Module["__ZNKSt3__210moneypunctIwLb1EE11do_groupingEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb1EE11do_groupingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb1EE14do_curr_symbolEv = Module["__ZNKSt3__210moneypunctIwLb1EE14do_curr_symbolEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb1EE14do_curr_symbolEv = Module["__ZNKSt3__210moneypunctIwLb1EE14do_curr_symbolEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb1EE14do_curr_symbolEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb1EE16do_positive_signEv = Module["__ZNKSt3__210moneypunctIwLb1EE16do_positive_signEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb1EE16do_positive_signEv = Module["__ZNKSt3__210moneypunctIwLb1EE16do_positive_signEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb1EE16do_positive_signEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb1EE16do_negative_signEv = Module["__ZNKSt3__210moneypunctIwLb1EE16do_negative_signEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb1EE16do_negative_signEv = Module["__ZNKSt3__210moneypunctIwLb1EE16do_negative_signEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb1EE16do_negative_signEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb1EE14do_frac_digitsEv = Module["__ZNKSt3__210moneypunctIwLb1EE14do_frac_digitsEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb1EE14do_frac_digitsEv = Module["__ZNKSt3__210moneypunctIwLb1EE14do_frac_digitsEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb1EE14do_frac_digitsEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb1EE13do_pos_formatEv = Module["__ZNKSt3__210moneypunctIwLb1EE13do_pos_formatEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb1EE13do_pos_formatEv = Module["__ZNKSt3__210moneypunctIwLb1EE13do_pos_formatEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb1EE13do_pos_formatEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb1EE13do_neg_formatEv = Module["__ZNKSt3__210moneypunctIwLb1EE13do_neg_formatEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb1EE13do_neg_formatEv = Module["__ZNKSt3__210moneypunctIwLb1EE13do_neg_formatEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb1EE13do_neg_formatEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIcLb0EE16do_decimal_pointEv = Module["__ZNKSt3__217moneypunct_bynameIcLb0EE16do_decimal_pointEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIcLb0EE16do_decimal_pointEv = Module["__ZNKSt3__217moneypunct_bynameIcLb0EE16do_decimal_pointEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIcLb0EE16do_decimal_pointEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIcLb0EE16do_thousands_sepEv = Module["__ZNKSt3__217moneypunct_bynameIcLb0EE16do_thousands_sepEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIcLb0EE16do_thousands_sepEv = Module["__ZNKSt3__217moneypunct_bynameIcLb0EE16do_thousands_sepEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIcLb0EE16do_thousands_sepEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIcLb0EE11do_groupingEv = Module["__ZNKSt3__217moneypunct_bynameIcLb0EE11do_groupingEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIcLb0EE11do_groupingEv = Module["__ZNKSt3__217moneypunct_bynameIcLb0EE11do_groupingEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIcLb0EE11do_groupingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIcLb0EE14do_curr_symbolEv = Module["__ZNKSt3__217moneypunct_bynameIcLb0EE14do_curr_symbolEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIcLb0EE14do_curr_symbolEv = Module["__ZNKSt3__217moneypunct_bynameIcLb0EE14do_curr_symbolEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIcLb0EE14do_curr_symbolEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIcLb0EE16do_positive_signEv = Module["__ZNKSt3__217moneypunct_bynameIcLb0EE16do_positive_signEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIcLb0EE16do_positive_signEv = Module["__ZNKSt3__217moneypunct_bynameIcLb0EE16do_positive_signEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIcLb0EE16do_positive_signEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIcLb0EE16do_negative_signEv = Module["__ZNKSt3__217moneypunct_bynameIcLb0EE16do_negative_signEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIcLb0EE16do_negative_signEv = Module["__ZNKSt3__217moneypunct_bynameIcLb0EE16do_negative_signEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIcLb0EE16do_negative_signEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIcLb0EE14do_frac_digitsEv = Module["__ZNKSt3__217moneypunct_bynameIcLb0EE14do_frac_digitsEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIcLb0EE14do_frac_digitsEv = Module["__ZNKSt3__217moneypunct_bynameIcLb0EE14do_frac_digitsEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIcLb0EE14do_frac_digitsEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIcLb0EE13do_pos_formatEv = Module["__ZNKSt3__217moneypunct_bynameIcLb0EE13do_pos_formatEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIcLb0EE13do_pos_formatEv = Module["__ZNKSt3__217moneypunct_bynameIcLb0EE13do_pos_formatEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIcLb0EE13do_pos_formatEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIcLb0EE13do_neg_formatEv = Module["__ZNKSt3__217moneypunct_bynameIcLb0EE13do_neg_formatEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIcLb0EE13do_neg_formatEv = Module["__ZNKSt3__217moneypunct_bynameIcLb0EE13do_neg_formatEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIcLb0EE13do_neg_formatEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIcLb1EE16do_decimal_pointEv = Module["__ZNKSt3__217moneypunct_bynameIcLb1EE16do_decimal_pointEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIcLb1EE16do_decimal_pointEv = Module["__ZNKSt3__217moneypunct_bynameIcLb1EE16do_decimal_pointEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIcLb1EE16do_decimal_pointEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIcLb1EE16do_thousands_sepEv = Module["__ZNKSt3__217moneypunct_bynameIcLb1EE16do_thousands_sepEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIcLb1EE16do_thousands_sepEv = Module["__ZNKSt3__217moneypunct_bynameIcLb1EE16do_thousands_sepEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIcLb1EE16do_thousands_sepEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIcLb1EE11do_groupingEv = Module["__ZNKSt3__217moneypunct_bynameIcLb1EE11do_groupingEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIcLb1EE11do_groupingEv = Module["__ZNKSt3__217moneypunct_bynameIcLb1EE11do_groupingEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIcLb1EE11do_groupingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIcLb1EE14do_curr_symbolEv = Module["__ZNKSt3__217moneypunct_bynameIcLb1EE14do_curr_symbolEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIcLb1EE14do_curr_symbolEv = Module["__ZNKSt3__217moneypunct_bynameIcLb1EE14do_curr_symbolEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIcLb1EE14do_curr_symbolEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIcLb1EE16do_positive_signEv = Module["__ZNKSt3__217moneypunct_bynameIcLb1EE16do_positive_signEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIcLb1EE16do_positive_signEv = Module["__ZNKSt3__217moneypunct_bynameIcLb1EE16do_positive_signEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIcLb1EE16do_positive_signEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIcLb1EE16do_negative_signEv = Module["__ZNKSt3__217moneypunct_bynameIcLb1EE16do_negative_signEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIcLb1EE16do_negative_signEv = Module["__ZNKSt3__217moneypunct_bynameIcLb1EE16do_negative_signEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIcLb1EE16do_negative_signEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIcLb1EE14do_frac_digitsEv = Module["__ZNKSt3__217moneypunct_bynameIcLb1EE14do_frac_digitsEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIcLb1EE14do_frac_digitsEv = Module["__ZNKSt3__217moneypunct_bynameIcLb1EE14do_frac_digitsEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIcLb1EE14do_frac_digitsEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIcLb1EE13do_pos_formatEv = Module["__ZNKSt3__217moneypunct_bynameIcLb1EE13do_pos_formatEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIcLb1EE13do_pos_formatEv = Module["__ZNKSt3__217moneypunct_bynameIcLb1EE13do_pos_formatEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIcLb1EE13do_pos_formatEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIcLb1EE13do_neg_formatEv = Module["__ZNKSt3__217moneypunct_bynameIcLb1EE13do_neg_formatEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIcLb1EE13do_neg_formatEv = Module["__ZNKSt3__217moneypunct_bynameIcLb1EE13do_neg_formatEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIcLb1EE13do_neg_formatEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIwLb0EE16do_decimal_pointEv = Module["__ZNKSt3__217moneypunct_bynameIwLb0EE16do_decimal_pointEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIwLb0EE16do_decimal_pointEv = Module["__ZNKSt3__217moneypunct_bynameIwLb0EE16do_decimal_pointEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIwLb0EE16do_decimal_pointEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIwLb0EE16do_thousands_sepEv = Module["__ZNKSt3__217moneypunct_bynameIwLb0EE16do_thousands_sepEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIwLb0EE16do_thousands_sepEv = Module["__ZNKSt3__217moneypunct_bynameIwLb0EE16do_thousands_sepEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIwLb0EE16do_thousands_sepEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIwLb0EE11do_groupingEv = Module["__ZNKSt3__217moneypunct_bynameIwLb0EE11do_groupingEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIwLb0EE11do_groupingEv = Module["__ZNKSt3__217moneypunct_bynameIwLb0EE11do_groupingEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIwLb0EE11do_groupingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIwLb0EE14do_curr_symbolEv = Module["__ZNKSt3__217moneypunct_bynameIwLb0EE14do_curr_symbolEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIwLb0EE14do_curr_symbolEv = Module["__ZNKSt3__217moneypunct_bynameIwLb0EE14do_curr_symbolEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIwLb0EE14do_curr_symbolEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIwLb0EE16do_positive_signEv = Module["__ZNKSt3__217moneypunct_bynameIwLb0EE16do_positive_signEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIwLb0EE16do_positive_signEv = Module["__ZNKSt3__217moneypunct_bynameIwLb0EE16do_positive_signEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIwLb0EE16do_positive_signEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIwLb0EE16do_negative_signEv = Module["__ZNKSt3__217moneypunct_bynameIwLb0EE16do_negative_signEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIwLb0EE16do_negative_signEv = Module["__ZNKSt3__217moneypunct_bynameIwLb0EE16do_negative_signEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIwLb0EE16do_negative_signEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIwLb0EE14do_frac_digitsEv = Module["__ZNKSt3__217moneypunct_bynameIwLb0EE14do_frac_digitsEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIwLb0EE14do_frac_digitsEv = Module["__ZNKSt3__217moneypunct_bynameIwLb0EE14do_frac_digitsEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIwLb0EE14do_frac_digitsEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIwLb0EE13do_pos_formatEv = Module["__ZNKSt3__217moneypunct_bynameIwLb0EE13do_pos_formatEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIwLb0EE13do_pos_formatEv = Module["__ZNKSt3__217moneypunct_bynameIwLb0EE13do_pos_formatEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIwLb0EE13do_pos_formatEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIwLb0EE13do_neg_formatEv = Module["__ZNKSt3__217moneypunct_bynameIwLb0EE13do_neg_formatEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIwLb0EE13do_neg_formatEv = Module["__ZNKSt3__217moneypunct_bynameIwLb0EE13do_neg_formatEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIwLb0EE13do_neg_formatEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIwLb1EE16do_decimal_pointEv = Module["__ZNKSt3__217moneypunct_bynameIwLb1EE16do_decimal_pointEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIwLb1EE16do_decimal_pointEv = Module["__ZNKSt3__217moneypunct_bynameIwLb1EE16do_decimal_pointEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIwLb1EE16do_decimal_pointEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIwLb1EE16do_thousands_sepEv = Module["__ZNKSt3__217moneypunct_bynameIwLb1EE16do_thousands_sepEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIwLb1EE16do_thousands_sepEv = Module["__ZNKSt3__217moneypunct_bynameIwLb1EE16do_thousands_sepEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIwLb1EE16do_thousands_sepEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIwLb1EE11do_groupingEv = Module["__ZNKSt3__217moneypunct_bynameIwLb1EE11do_groupingEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIwLb1EE11do_groupingEv = Module["__ZNKSt3__217moneypunct_bynameIwLb1EE11do_groupingEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIwLb1EE11do_groupingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIwLb1EE14do_curr_symbolEv = Module["__ZNKSt3__217moneypunct_bynameIwLb1EE14do_curr_symbolEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIwLb1EE14do_curr_symbolEv = Module["__ZNKSt3__217moneypunct_bynameIwLb1EE14do_curr_symbolEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIwLb1EE14do_curr_symbolEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIwLb1EE16do_positive_signEv = Module["__ZNKSt3__217moneypunct_bynameIwLb1EE16do_positive_signEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIwLb1EE16do_positive_signEv = Module["__ZNKSt3__217moneypunct_bynameIwLb1EE16do_positive_signEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIwLb1EE16do_positive_signEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIwLb1EE16do_negative_signEv = Module["__ZNKSt3__217moneypunct_bynameIwLb1EE16do_negative_signEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIwLb1EE16do_negative_signEv = Module["__ZNKSt3__217moneypunct_bynameIwLb1EE16do_negative_signEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIwLb1EE16do_negative_signEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIwLb1EE14do_frac_digitsEv = Module["__ZNKSt3__217moneypunct_bynameIwLb1EE14do_frac_digitsEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIwLb1EE14do_frac_digitsEv = Module["__ZNKSt3__217moneypunct_bynameIwLb1EE14do_frac_digitsEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIwLb1EE14do_frac_digitsEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIwLb1EE13do_pos_formatEv = Module["__ZNKSt3__217moneypunct_bynameIwLb1EE13do_pos_formatEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIwLb1EE13do_pos_formatEv = Module["__ZNKSt3__217moneypunct_bynameIwLb1EE13do_pos_formatEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIwLb1EE13do_pos_formatEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217moneypunct_bynameIwLb1EE13do_neg_formatEv = Module["__ZNKSt3__217moneypunct_bynameIwLb1EE13do_neg_formatEv"] = function() {
                return (__ZNKSt3__217moneypunct_bynameIwLb1EE13do_neg_formatEv = Module["__ZNKSt3__217moneypunct_bynameIwLb1EE13do_neg_formatEv"] = Module["asm"]["_ZNKSt3__217moneypunct_bynameIwLb1EE13do_neg_formatEv"]).apply(null, arguments)
            };
            var __ZNKSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_bRNS_8ios_baseERjRe = Module["__ZNKSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_bRNS_8ios_baseERjRe"] = function() {
                return (__ZNKSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_bRNS_8ios_baseERjRe = Module["__ZNKSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_bRNS_8ios_baseERjRe"] = Module["asm"]["_ZNKSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_bRNS_8ios_baseERjRe"]).apply(null, arguments)
            };
            var __ZNSt3__212__do_nothingEPv = Module["__ZNSt3__212__do_nothingEPv"] = function() {
                return (__ZNSt3__212__do_nothingEPv = Module["__ZNSt3__212__do_nothingEPv"] = Module["asm"]["_ZNSt3__212__do_nothingEPv"]).apply(null, arguments)
            };
            var __ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE8__do_getERS4_S4_bRKNS_6localeEjRjRbRKNS_5ctypeIcEERNS_10unique_ptrIcPFvPvEEERPcSM_ = Module["__ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE8__do_getERS4_S4_bRKNS_6localeEjRjRbRKNS_5ctypeIcEERNS_10unique_ptrIcPFvPvEEERPcSM_"] = function() {
                return (__ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE8__do_getERS4_S4_bRKNS_6localeEjRjRbRKNS_5ctypeIcEERNS_10unique_ptrIcPFvPvEEERPcSM_ = Module["__ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE8__do_getERS4_S4_bRKNS_6localeEjRjRbRKNS_5ctypeIcEERNS_10unique_ptrIcPFvPvEEERPcSM_"] = Module["asm"]["_ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE8__do_getERS4_S4_bRKNS_6localeEjRjRbRKNS_5ctypeIcEERNS_10unique_ptrIcPFvPvEEERPcSM_"]).apply(null, arguments)
            };
            var __ZNKSt3__210unique_ptrIcPFvPvEE3getEv = Module["__ZNKSt3__210unique_ptrIcPFvPvEE3getEv"] = function() {
                return (__ZNKSt3__210unique_ptrIcPFvPvEE3getEv = Module["__ZNKSt3__210unique_ptrIcPFvPvEE3getEv"] = Module["asm"]["_ZNKSt3__210unique_ptrIcPFvPvEE3getEv"]).apply(null, arguments)
            };
            var __ZNSt3__23endIcLm10EEEPT_RAT0__S1_ = Module["__ZNSt3__23endIcLm10EEEPT_RAT0__S1_"] = function() {
                return (__ZNSt3__23endIcLm10EEEPT_RAT0__S1_ = Module["__ZNSt3__23endIcLm10EEEPT_RAT0__S1_"] = Module["asm"]["_ZNSt3__23endIcLm10EEEPT_RAT0__S1_"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIjPFvPvEEC2ILb1EvEEPjNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE = Module["__ZNSt3__210unique_ptrIjPFvPvEEC2ILb1EvEEPjNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE"] = function() {
                return (__ZNSt3__210unique_ptrIjPFvPvEEC2ILb1EvEEPjNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE = Module["__ZNSt3__210unique_ptrIjPFvPvEEC2ILb1EvEEPjNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE"] = Module["asm"]["_ZNSt3__210unique_ptrIjPFvPvEEC2ILb1EvEEPjNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE"]).apply(null, arguments)
            };
            var __ZNKSt3__210unique_ptrIjPFvPvEE3getEv = Module["__ZNKSt3__210unique_ptrIjPFvPvEE3getEv"] = function() {
                return (__ZNKSt3__210unique_ptrIjPFvPvEE3getEv = Module["__ZNKSt3__210unique_ptrIjPFvPvEE3getEv"] = Module["asm"]["_ZNKSt3__210unique_ptrIjPFvPvEE3getEv"]).apply(null, arguments)
            };
            var __ZNSt3__211__money_getIcE13__gather_infoEbRKNS_6localeERNS_10money_base7patternERcS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESF_SF_SF_Ri = Module["__ZNSt3__211__money_getIcE13__gather_infoEbRKNS_6localeERNS_10money_base7patternERcS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESF_SF_SF_Ri"] = function() {
                return (__ZNSt3__211__money_getIcE13__gather_infoEbRKNS_6localeERNS_10money_base7patternERcS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESF_SF_SF_Ri = Module["__ZNSt3__211__money_getIcE13__gather_infoEbRKNS_6localeERNS_10money_base7patternERcS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESF_SF_SF_Ri"] = Module["asm"]["_ZNSt3__211__money_getIcE13__gather_infoEbRKNS_6localeERNS_10money_base7patternERcS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESF_SF_SF_Ri"]).apply(null, arguments)
            };
            var __ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEppEi = Module["__ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEppEi"] = function() {
                return (__ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEppEi = Module["__ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEppEi"] = Module["asm"]["_ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEppEi"]).apply(null, arguments)
            };
            var __ZNKSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEE7__proxydeEv = Module["__ZNKSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEE7__proxydeEv"] = function() {
                return (__ZNKSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEE7__proxydeEv = Module["__ZNKSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEE7__proxydeEv"] = Module["asm"]["_ZNKSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEE7__proxydeEv"]).apply(null, arguments)
            };
            var __ZNSt3__211__wrap_iterIPKcEC2IPcEERKNS0_IT_EEPNS_9enable_ifIXsr14is_convertibleIS6_S2_EE5valueEvE4typeE = Module["__ZNSt3__211__wrap_iterIPKcEC2IPcEERKNS0_IT_EEPNS_9enable_ifIXsr14is_convertibleIS6_S2_EE5valueEvE4typeE"] = function() {
                return (__ZNSt3__211__wrap_iterIPKcEC2IPcEERKNS0_IT_EEPNS_9enable_ifIXsr14is_convertibleIS6_S2_EE5valueEvE4typeE = Module["__ZNSt3__211__wrap_iterIPKcEC2IPcEERKNS0_IT_EEPNS_9enable_ifIXsr14is_convertibleIS6_S2_EE5valueEvE4typeE"] = Module["asm"]["_ZNSt3__211__wrap_iterIPKcEC2IPcEERKNS0_IT_EEPNS_9enable_ifIXsr14is_convertibleIS6_S2_EE5valueEvE4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__2neIPKcPcEEbRKNS_11__wrap_iterIT_EERKNS4_IT0_EE = Module["__ZNSt3__2neIPKcPcEEbRKNS_11__wrap_iterIT_EERKNS4_IT0_EE"] = function() {
                return (__ZNSt3__2neIPKcPcEEbRKNS_11__wrap_iterIT_EERKNS4_IT0_EE = Module["__ZNSt3__2neIPKcPcEEbRKNS_11__wrap_iterIT_EERKNS4_IT0_EE"] = Module["asm"]["_ZNSt3__2neIPKcPcEEbRKNS_11__wrap_iterIT_EERKNS4_IT0_EE"]).apply(null, arguments)
            };
            var __ZNKSt3__211__wrap_iterIPKcEdeEv = Module["__ZNKSt3__211__wrap_iterIPKcEdeEv"] = function() {
                return (__ZNKSt3__211__wrap_iterIPKcEdeEv = Module["__ZNKSt3__211__wrap_iterIPKcEdeEv"] = Module["asm"]["_ZNKSt3__211__wrap_iterIPKcEdeEv"]).apply(null, arguments)
            };
            var __ZNSt3__211__wrap_iterIPKcEppEv = Module["__ZNSt3__211__wrap_iterIPKcEppEv"] = function() {
                return (__ZNSt3__211__wrap_iterIPKcEppEv = Module["__ZNSt3__211__wrap_iterIPKcEppEv"] = Module["asm"]["_ZNSt3__211__wrap_iterIPKcEppEv"]).apply(null, arguments)
            };
            var __ZNKSt3__211__wrap_iterIPcEmiEl = Module["__ZNKSt3__211__wrap_iterIPcEmiEl"] = function() {
                return (__ZNKSt3__211__wrap_iterIPcEmiEl = Module["__ZNKSt3__211__wrap_iterIPcEmiEl"] = Module["asm"]["_ZNKSt3__211__wrap_iterIPcEmiEl"]).apply(null, arguments)
            };
            var __ZNSt3__25equalINS_11__wrap_iterIPcEES3_EEbT_S4_T0_ = Module["__ZNSt3__25equalINS_11__wrap_iterIPcEES3_EEbT_S4_T0_"] = function() {
                return (__ZNSt3__25equalINS_11__wrap_iterIPcEES3_EEbT_S4_T0_ = Module["__ZNSt3__25equalINS_11__wrap_iterIPcEES3_EEbT_S4_T0_"] = Module["asm"]["_ZNSt3__25equalINS_11__wrap_iterIPcEES3_EEbT_S4_T0_"]).apply(null, arguments)
            };
            var __ZNSt3__219__double_or_nothingIcEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_ = Module["__ZNSt3__219__double_or_nothingIcEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_"] = function() {
                return (__ZNSt3__219__double_or_nothingIcEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_ = Module["__ZNSt3__219__double_or_nothingIcEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_"] = Module["asm"]["_ZNSt3__219__double_or_nothingIcEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_"]).apply(null, arguments)
            };
            var __ZNSt3__219__double_or_nothingIjEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_ = Module["__ZNSt3__219__double_or_nothingIjEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_"] = function() {
                return (__ZNSt3__219__double_or_nothingIjEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_ = Module["__ZNSt3__219__double_or_nothingIjEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_"] = Module["asm"]["_ZNSt3__219__double_or_nothingIjEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIjPFvPvEED2Ev = Module["__ZNSt3__210unique_ptrIjPFvPvEED2Ev"] = function() {
                return (__ZNSt3__210unique_ptrIjPFvPvEED2Ev = Module["__ZNSt3__210unique_ptrIjPFvPvEED2Ev"] = Module["asm"]["_ZNSt3__210unique_ptrIjPFvPvEED2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPcPFvPvEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPcPFvPvEE5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPcPFvPvEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPcPFvPvEE5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPcPFvPvEE5firstEv"]).apply(null, arguments)
            };
            var __ZNKSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_bRNS_8ios_baseERjRNS_12basic_stringIcS3_NS_9allocatorIcEEEE = Module["__ZNKSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_bRNS_8ios_baseERjRNS_12basic_stringIcS3_NS_9allocatorIcEEEE"] = function() {
                return (__ZNKSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_bRNS_8ios_baseERjRNS_12basic_stringIcS3_NS_9allocatorIcEEEE = Module["__ZNKSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_bRNS_8ios_baseERjRNS_12basic_stringIcS3_NS_9allocatorIcEEEE"] = Module["asm"]["_ZNKSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_getES4_S4_bRNS_8ios_baseERjRNS_12basic_stringIcS3_NS_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5clearEv = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5clearEv"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5clearEv = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5clearEv"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5clearEv"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendIPcEENS_9enable_ifIXaasr27__is_cpp17_forward_iteratorIT_EE5valuesr38__libcpp_string_gets_noexcept_iteratorIS9_EE5valueERS5_E4typeES9_S9_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendIPcEENS_9enable_ifIXaasr27__is_cpp17_forward_iteratorIT_EE5valuesr38__libcpp_string_gets_noexcept_iteratorIS9_EE5valueERS5_E4typeES9_S9_"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendIPcEENS_9enable_ifIXaasr27__is_cpp17_forward_iteratorIT_EE5valuesr38__libcpp_string_gets_noexcept_iteratorIS9_EE5valueERS5_E4typeES9_S9_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendIPcEENS_9enable_ifIXaasr27__is_cpp17_forward_iteratorIT_EE5valuesr38__libcpp_string_gets_noexcept_iteratorIS9_EE5valueERS5_E4typeES9_S9_"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendIPcEENS_9enable_ifIXaasr27__is_cpp17_forward_iteratorIT_EE5valuesr38__libcpp_string_gets_noexcept_iteratorIS9_EE5valueERS5_E4typeES9_S9_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE23__append_forward_unsafeIPcEERS5_T_S9_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE23__append_forward_unsafeIPcEERS5_T_S9_"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE23__append_forward_unsafeIPcEERS5_T_S9_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE23__append_forward_unsafeIPcEERS5_T_S9_"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE23__append_forward_unsafeIPcEERS5_T_S9_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPjPFvPvEEC2IRS1_S4_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPjPFvPvEEC2IRS1_S4_EEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIPjPFvPvEEC2IRS1_S4_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPjPFvPvEEC2IRS1_S4_EEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIPjPFvPvEEC2IRS1_S4_EEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPjPFvPvEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPjPFvPvEE5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPjPFvPvEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPjPFvPvEE5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPjPFvPvEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__29use_facetINS_10moneypunctIcLb1EEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_10moneypunctIcLb1EEEEERKT_RKNS_6localeE"] = function() {
                return (__ZNSt3__29use_facetINS_10moneypunctIcLb1EEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_10moneypunctIcLb1EEEEERKT_RKNS_6localeE"] = Module["asm"]["_ZNSt3__29use_facetINS_10moneypunctIcLb1EEEEERKT_RKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb1EE10neg_formatEv = Module["__ZNKSt3__210moneypunctIcLb1EE10neg_formatEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb1EE10neg_formatEv = Module["__ZNKSt3__210moneypunctIcLb1EE10neg_formatEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb1EE10neg_formatEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb1EE13negative_signEv = Module["__ZNKSt3__210moneypunctIcLb1EE13negative_signEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb1EE13negative_signEv = Module["__ZNKSt3__210moneypunctIcLb1EE13negative_signEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb1EE13negative_signEv"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSEOS5_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSEOS5_"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSEOS5_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSEOS5_"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSEOS5_"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb1EE13positive_signEv = Module["__ZNKSt3__210moneypunctIcLb1EE13positive_signEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb1EE13positive_signEv = Module["__ZNKSt3__210moneypunctIcLb1EE13positive_signEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb1EE13positive_signEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb1EE13decimal_pointEv = Module["__ZNKSt3__210moneypunctIcLb1EE13decimal_pointEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb1EE13decimal_pointEv = Module["__ZNKSt3__210moneypunctIcLb1EE13decimal_pointEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb1EE13decimal_pointEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb1EE13thousands_sepEv = Module["__ZNKSt3__210moneypunctIcLb1EE13thousands_sepEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb1EE13thousands_sepEv = Module["__ZNKSt3__210moneypunctIcLb1EE13thousands_sepEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb1EE13thousands_sepEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb1EE8groupingEv = Module["__ZNKSt3__210moneypunctIcLb1EE8groupingEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb1EE8groupingEv = Module["__ZNKSt3__210moneypunctIcLb1EE8groupingEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb1EE8groupingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb1EE11curr_symbolEv = Module["__ZNKSt3__210moneypunctIcLb1EE11curr_symbolEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb1EE11curr_symbolEv = Module["__ZNKSt3__210moneypunctIcLb1EE11curr_symbolEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb1EE11curr_symbolEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb1EE11frac_digitsEv = Module["__ZNKSt3__210moneypunctIcLb1EE11frac_digitsEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb1EE11frac_digitsEv = Module["__ZNKSt3__210moneypunctIcLb1EE11frac_digitsEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb1EE11frac_digitsEv"]).apply(null, arguments)
            };
            var __ZNSt3__29use_facetINS_10moneypunctIcLb0EEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_10moneypunctIcLb0EEEEERKT_RKNS_6localeE"] = function() {
                return (__ZNSt3__29use_facetINS_10moneypunctIcLb0EEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_10moneypunctIcLb0EEEEERKT_RKNS_6localeE"] = Module["asm"]["_ZNSt3__29use_facetINS_10moneypunctIcLb0EEEEERKT_RKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb0EE10neg_formatEv = Module["__ZNKSt3__210moneypunctIcLb0EE10neg_formatEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb0EE10neg_formatEv = Module["__ZNKSt3__210moneypunctIcLb0EE10neg_formatEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb0EE10neg_formatEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb0EE13negative_signEv = Module["__ZNKSt3__210moneypunctIcLb0EE13negative_signEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb0EE13negative_signEv = Module["__ZNKSt3__210moneypunctIcLb0EE13negative_signEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb0EE13negative_signEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb0EE13positive_signEv = Module["__ZNKSt3__210moneypunctIcLb0EE13positive_signEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb0EE13positive_signEv = Module["__ZNKSt3__210moneypunctIcLb0EE13positive_signEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb0EE13positive_signEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb0EE13decimal_pointEv = Module["__ZNKSt3__210moneypunctIcLb0EE13decimal_pointEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb0EE13decimal_pointEv = Module["__ZNKSt3__210moneypunctIcLb0EE13decimal_pointEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb0EE13decimal_pointEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb0EE13thousands_sepEv = Module["__ZNKSt3__210moneypunctIcLb0EE13thousands_sepEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb0EE13thousands_sepEv = Module["__ZNKSt3__210moneypunctIcLb0EE13thousands_sepEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb0EE13thousands_sepEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb0EE8groupingEv = Module["__ZNKSt3__210moneypunctIcLb0EE8groupingEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb0EE8groupingEv = Module["__ZNKSt3__210moneypunctIcLb0EE8groupingEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb0EE8groupingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb0EE11curr_symbolEv = Module["__ZNKSt3__210moneypunctIcLb0EE11curr_symbolEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb0EE11curr_symbolEv = Module["__ZNKSt3__210moneypunctIcLb0EE11curr_symbolEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb0EE11curr_symbolEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb0EE11frac_digitsEv = Module["__ZNKSt3__210moneypunctIcLb0EE11frac_digitsEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb0EE11frac_digitsEv = Module["__ZNKSt3__210moneypunctIcLb0EE11frac_digitsEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb0EE11frac_digitsEv"]).apply(null, arguments)
            };
            var __ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEE7__proxyC2EcPNS_15basic_streambufIcS2_EE = Module["__ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEE7__proxyC2EcPNS_15basic_streambufIcS2_EE"] = function() {
                return (__ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEE7__proxyC2EcPNS_15basic_streambufIcS2_EE = Module["__ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEE7__proxyC2EcPNS_15basic_streambufIcS2_EE"] = Module["asm"]["_ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEE7__proxyC2EcPNS_15basic_streambufIcS2_EE"]).apply(null, arguments)
            };
            var __ZNSt3__2eqIPKcPcEEbRKNS_11__wrap_iterIT_EERKNS4_IT0_EE = Module["__ZNSt3__2eqIPKcPcEEbRKNS_11__wrap_iterIT_EERKNS4_IT0_EE"] = function() {
                return (__ZNSt3__2eqIPKcPcEEbRKNS_11__wrap_iterIT_EERKNS4_IT0_EE = Module["__ZNSt3__2eqIPKcPcEEbRKNS_11__wrap_iterIT_EERKNS4_IT0_EE"] = Module["asm"]["_ZNSt3__2eqIPKcPcEEbRKNS_11__wrap_iterIT_EERKNS4_IT0_EE"]).apply(null, arguments)
            };
            var __ZNSt3__25equalINS_11__wrap_iterIPcEES3_NS_10__equal_toIccEEEEbT_S6_T0_T1_ = Module["__ZNSt3__25equalINS_11__wrap_iterIPcEES3_NS_10__equal_toIccEEEEbT_S6_T0_T1_"] = function() {
                return (__ZNSt3__25equalINS_11__wrap_iterIPcEES3_NS_10__equal_toIccEEEEbT_S6_T0_T1_ = Module["__ZNSt3__25equalINS_11__wrap_iterIPcEES3_NS_10__equal_toIccEEEEbT_S6_T0_T1_"] = Module["asm"]["_ZNSt3__25equalINS_11__wrap_iterIPcEES3_NS_10__equal_toIccEEEEbT_S6_T0_T1_"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIcPFvPvEE11get_deleterEv = Module["__ZNSt3__210unique_ptrIcPFvPvEE11get_deleterEv"] = function() {
                return (__ZNSt3__210unique_ptrIcPFvPvEE11get_deleterEv = Module["__ZNSt3__210unique_ptrIcPFvPvEE11get_deleterEv"] = Module["asm"]["_ZNSt3__210unique_ptrIcPFvPvEE11get_deleterEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIcPFvPvEE7releaseEv = Module["__ZNSt3__210unique_ptrIcPFvPvEE7releaseEv"] = function() {
                return (__ZNSt3__210unique_ptrIcPFvPvEE7releaseEv = Module["__ZNSt3__210unique_ptrIcPFvPvEE7releaseEv"] = Module["asm"]["_ZNSt3__210unique_ptrIcPFvPvEE7releaseEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIcPFvPvEEaSEOS4_ = Module["__ZNSt3__210unique_ptrIcPFvPvEEaSEOS4_"] = function() {
                return (__ZNSt3__210unique_ptrIcPFvPvEEaSEOS4_ = Module["__ZNSt3__210unique_ptrIcPFvPvEEaSEOS4_"] = Module["asm"]["_ZNSt3__210unique_ptrIcPFvPvEEaSEOS4_"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIjPFvPvEE11get_deleterEv = Module["__ZNSt3__210unique_ptrIjPFvPvEE11get_deleterEv"] = function() {
                return (__ZNSt3__210unique_ptrIjPFvPvEE11get_deleterEv = Module["__ZNSt3__210unique_ptrIjPFvPvEE11get_deleterEv"] = Module["asm"]["_ZNSt3__210unique_ptrIjPFvPvEE11get_deleterEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIjPFvPvEE7releaseEv = Module["__ZNSt3__210unique_ptrIjPFvPvEE7releaseEv"] = function() {
                return (__ZNSt3__210unique_ptrIjPFvPvEE7releaseEv = Module["__ZNSt3__210unique_ptrIjPFvPvEE7releaseEv"] = Module["asm"]["_ZNSt3__210unique_ptrIjPFvPvEE7releaseEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIjPFvPvEEaSEOS4_ = Module["__ZNSt3__210unique_ptrIjPFvPvEEaSEOS4_"] = function() {
                return (__ZNSt3__210unique_ptrIjPFvPvEEaSEOS4_ = Module["__ZNSt3__210unique_ptrIjPFvPvEEaSEOS4_"] = Module["asm"]["_ZNSt3__210unique_ptrIjPFvPvEEaSEOS4_"]).apply(null, arguments)
            };
            var __ZNSt3__27reverseIPjEEvT_S2_ = Module["__ZNSt3__27reverseIPjEEvT_S2_"] = function() {
                return (__ZNSt3__27reverseIPjEEvT_S2_ = Module["__ZNSt3__27reverseIPjEEvT_S2_"] = Module["asm"]["_ZNSt3__27reverseIPjEEvT_S2_"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIjPFvPvEE5resetEPj = Module["__ZNSt3__210unique_ptrIjPFvPvEE5resetEPj"] = function() {
                return (__ZNSt3__210unique_ptrIjPFvPvEE5resetEPj = Module["__ZNSt3__210unique_ptrIjPFvPvEE5resetEPj"] = Module["asm"]["_ZNSt3__210unique_ptrIjPFvPvEE5resetEPj"]).apply(null, arguments)
            };
            var __ZNKSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_bRNS_8ios_baseERjRe = Module["__ZNKSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_bRNS_8ios_baseERjRe"] = function() {
                return (__ZNKSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_bRNS_8ios_baseERjRe = Module["__ZNKSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_bRNS_8ios_baseERjRe"] = Module["asm"]["_ZNKSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_bRNS_8ios_baseERjRe"]).apply(null, arguments)
            };
            var __ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE8__do_getERS4_S4_bRKNS_6localeEjRjRbRKNS_5ctypeIwEERNS_10unique_ptrIwPFvPvEEERPwSM_ = Module["__ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE8__do_getERS4_S4_bRKNS_6localeEjRjRbRKNS_5ctypeIwEERNS_10unique_ptrIwPFvPvEEERPwSM_"] = function() {
                return (__ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE8__do_getERS4_S4_bRKNS_6localeEjRjRbRKNS_5ctypeIwEERNS_10unique_ptrIwPFvPvEEERPwSM_ = Module["__ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE8__do_getERS4_S4_bRKNS_6localeEjRjRbRKNS_5ctypeIwEERNS_10unique_ptrIwPFvPvEEERPwSM_"] = Module["asm"]["_ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE8__do_getERS4_S4_bRKNS_6localeEjRjRbRKNS_5ctypeIwEERNS_10unique_ptrIwPFvPvEEERPwSM_"]).apply(null, arguments)
            };
            var __ZNKSt3__210unique_ptrIwPFvPvEE3getEv = Module["__ZNKSt3__210unique_ptrIwPFvPvEE3getEv"] = function() {
                return (__ZNKSt3__210unique_ptrIwPFvPvEE3getEv = Module["__ZNKSt3__210unique_ptrIwPFvPvEE3getEv"] = Module["asm"]["_ZNKSt3__210unique_ptrIwPFvPvEE3getEv"]).apply(null, arguments)
            };
            var __ZNSt3__23endIwLm10EEEPT_RAT0__S1_ = Module["__ZNSt3__23endIwLm10EEEPT_RAT0__S1_"] = function() {
                return (__ZNSt3__23endIwLm10EEEPT_RAT0__S1_ = Module["__ZNSt3__23endIwLm10EEEPT_RAT0__S1_"] = Module["asm"]["_ZNSt3__23endIwLm10EEEPT_RAT0__S1_"]).apply(null, arguments)
            };
            var __ZNSt3__211__money_getIwE13__gather_infoEbRKNS_6localeERNS_10money_base7patternERwS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS9_IwNSA_IwEENSC_IwEEEESJ_SJ_Ri = Module["__ZNSt3__211__money_getIwE13__gather_infoEbRKNS_6localeERNS_10money_base7patternERwS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS9_IwNSA_IwEENSC_IwEEEESJ_SJ_Ri"] = function() {
                return (__ZNSt3__211__money_getIwE13__gather_infoEbRKNS_6localeERNS_10money_base7patternERwS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS9_IwNSA_IwEENSC_IwEEEESJ_SJ_Ri = Module["__ZNSt3__211__money_getIwE13__gather_infoEbRKNS_6localeERNS_10money_base7patternERwS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS9_IwNSA_IwEENSC_IwEEEESJ_SJ_Ri"] = Module["asm"]["_ZNSt3__211__money_getIwE13__gather_infoEbRKNS_6localeERNS_10money_base7patternERwS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS9_IwNSA_IwEENSC_IwEEEESJ_SJ_Ri"]).apply(null, arguments)
            };
            var __ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEppEi = Module["__ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEppEi"] = function() {
                return (__ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEppEi = Module["__ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEppEi"] = Module["asm"]["_ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEppEi"]).apply(null, arguments)
            };
            var __ZNKSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEE7__proxydeEv = Module["__ZNKSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEE7__proxydeEv"] = function() {
                return (__ZNKSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEE7__proxydeEv = Module["__ZNKSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEE7__proxydeEv"] = Module["asm"]["_ZNKSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEE7__proxydeEv"]).apply(null, arguments)
            };
            var __ZNSt3__211__wrap_iterIPKwEC2IPwEERKNS0_IT_EEPNS_9enable_ifIXsr14is_convertibleIS6_S2_EE5valueEvE4typeE = Module["__ZNSt3__211__wrap_iterIPKwEC2IPwEERKNS0_IT_EEPNS_9enable_ifIXsr14is_convertibleIS6_S2_EE5valueEvE4typeE"] = function() {
                return (__ZNSt3__211__wrap_iterIPKwEC2IPwEERKNS0_IT_EEPNS_9enable_ifIXsr14is_convertibleIS6_S2_EE5valueEvE4typeE = Module["__ZNSt3__211__wrap_iterIPKwEC2IPwEERKNS0_IT_EEPNS_9enable_ifIXsr14is_convertibleIS6_S2_EE5valueEvE4typeE"] = Module["asm"]["_ZNSt3__211__wrap_iterIPKwEC2IPwEERKNS0_IT_EEPNS_9enable_ifIXsr14is_convertibleIS6_S2_EE5valueEvE4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__2neIPKwPwEEbRKNS_11__wrap_iterIT_EERKNS4_IT0_EE = Module["__ZNSt3__2neIPKwPwEEbRKNS_11__wrap_iterIT_EERKNS4_IT0_EE"] = function() {
                return (__ZNSt3__2neIPKwPwEEbRKNS_11__wrap_iterIT_EERKNS4_IT0_EE = Module["__ZNSt3__2neIPKwPwEEbRKNS_11__wrap_iterIT_EERKNS4_IT0_EE"] = Module["asm"]["_ZNSt3__2neIPKwPwEEbRKNS_11__wrap_iterIT_EERKNS4_IT0_EE"]).apply(null, arguments)
            };
            var __ZNKSt3__211__wrap_iterIPKwEdeEv = Module["__ZNKSt3__211__wrap_iterIPKwEdeEv"] = function() {
                return (__ZNKSt3__211__wrap_iterIPKwEdeEv = Module["__ZNKSt3__211__wrap_iterIPKwEdeEv"] = Module["asm"]["_ZNKSt3__211__wrap_iterIPKwEdeEv"]).apply(null, arguments)
            };
            var __ZNSt3__211__wrap_iterIPKwEppEv = Module["__ZNSt3__211__wrap_iterIPKwEppEv"] = function() {
                return (__ZNSt3__211__wrap_iterIPKwEppEv = Module["__ZNSt3__211__wrap_iterIPKwEppEv"] = Module["asm"]["_ZNSt3__211__wrap_iterIPKwEppEv"]).apply(null, arguments)
            };
            var __ZNKSt3__211__wrap_iterIPwEmiEl = Module["__ZNKSt3__211__wrap_iterIPwEmiEl"] = function() {
                return (__ZNKSt3__211__wrap_iterIPwEmiEl = Module["__ZNKSt3__211__wrap_iterIPwEmiEl"] = Module["asm"]["_ZNKSt3__211__wrap_iterIPwEmiEl"]).apply(null, arguments)
            };
            var __ZNSt3__25equalINS_11__wrap_iterIPwEES3_EEbT_S4_T0_ = Module["__ZNSt3__25equalINS_11__wrap_iterIPwEES3_EEbT_S4_T0_"] = function() {
                return (__ZNSt3__25equalINS_11__wrap_iterIPwEES3_EEbT_S4_T0_ = Module["__ZNSt3__25equalINS_11__wrap_iterIPwEES3_EEbT_S4_T0_"] = Module["asm"]["_ZNSt3__25equalINS_11__wrap_iterIPwEES3_EEbT_S4_T0_"]).apply(null, arguments)
            };
            var __ZNSt3__219__double_or_nothingIwEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_ = Module["__ZNSt3__219__double_or_nothingIwEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_"] = function() {
                return (__ZNSt3__219__double_or_nothingIwEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_ = Module["__ZNSt3__219__double_or_nothingIwEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_"] = Module["asm"]["_ZNSt3__219__double_or_nothingIwEEvRNS_10unique_ptrIT_PFvPvEEERPS2_S9_"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPwPFvPvEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPwPFvPvEE5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPwPFvPvEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPwPFvPvEE5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPwPFvPvEE5firstEv"]).apply(null, arguments)
            };
            var __ZNKSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_bRNS_8ios_baseERjRNS_12basic_stringIwS3_NS_9allocatorIwEEEE = Module["__ZNKSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_bRNS_8ios_baseERjRNS_12basic_stringIwS3_NS_9allocatorIwEEEE"] = function() {
                return (__ZNKSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_bRNS_8ios_baseERjRNS_12basic_stringIwS3_NS_9allocatorIwEEEE = Module["__ZNKSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_bRNS_8ios_baseERjRNS_12basic_stringIwS3_NS_9allocatorIwEEEE"] = Module["asm"]["_ZNKSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_getES4_S4_bRNS_8ios_baseERjRNS_12basic_stringIwS3_NS_9allocatorIwEEEE"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5clearEv = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5clearEv"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5clearEv = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5clearEv"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5clearEv"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendIPwEENS_9enable_ifIXaasr27__is_cpp17_forward_iteratorIT_EE5valuesr38__libcpp_string_gets_noexcept_iteratorIS9_EE5valueERS5_E4typeES9_S9_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendIPwEENS_9enable_ifIXaasr27__is_cpp17_forward_iteratorIT_EE5valuesr38__libcpp_string_gets_noexcept_iteratorIS9_EE5valueERS5_E4typeES9_S9_"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendIPwEENS_9enable_ifIXaasr27__is_cpp17_forward_iteratorIT_EE5valuesr38__libcpp_string_gets_noexcept_iteratorIS9_EE5valueERS5_E4typeES9_S9_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendIPwEENS_9enable_ifIXaasr27__is_cpp17_forward_iteratorIT_EE5valuesr38__libcpp_string_gets_noexcept_iteratorIS9_EE5valueERS5_E4typeES9_S9_"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6appendIPwEENS_9enable_ifIXaasr27__is_cpp17_forward_iteratorIT_EE5valuesr38__libcpp_string_gets_noexcept_iteratorIS9_EE5valueERS5_E4typeES9_S9_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE23__append_forward_unsafeIPwEERS5_T_S9_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE23__append_forward_unsafeIPwEERS5_T_S9_"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE23__append_forward_unsafeIPwEERS5_T_S9_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE23__append_forward_unsafeIPwEERS5_T_S9_"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE23__append_forward_unsafeIPwEERS5_T_S9_"]).apply(null, arguments)
            };
            var __ZNSt3__29use_facetINS_10moneypunctIwLb1EEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_10moneypunctIwLb1EEEEERKT_RKNS_6localeE"] = function() {
                return (__ZNSt3__29use_facetINS_10moneypunctIwLb1EEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_10moneypunctIwLb1EEEEERKT_RKNS_6localeE"] = Module["asm"]["_ZNSt3__29use_facetINS_10moneypunctIwLb1EEEEERKT_RKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb1EE10neg_formatEv = Module["__ZNKSt3__210moneypunctIwLb1EE10neg_formatEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb1EE10neg_formatEv = Module["__ZNKSt3__210moneypunctIwLb1EE10neg_formatEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb1EE10neg_formatEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb1EE13negative_signEv = Module["__ZNKSt3__210moneypunctIwLb1EE13negative_signEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb1EE13negative_signEv = Module["__ZNKSt3__210moneypunctIwLb1EE13negative_signEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb1EE13negative_signEv"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEaSEOS5_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEaSEOS5_"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEaSEOS5_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEaSEOS5_"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEaSEOS5_"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb1EE13positive_signEv = Module["__ZNKSt3__210moneypunctIwLb1EE13positive_signEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb1EE13positive_signEv = Module["__ZNKSt3__210moneypunctIwLb1EE13positive_signEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb1EE13positive_signEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb1EE13decimal_pointEv = Module["__ZNKSt3__210moneypunctIwLb1EE13decimal_pointEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb1EE13decimal_pointEv = Module["__ZNKSt3__210moneypunctIwLb1EE13decimal_pointEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb1EE13decimal_pointEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb1EE13thousands_sepEv = Module["__ZNKSt3__210moneypunctIwLb1EE13thousands_sepEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb1EE13thousands_sepEv = Module["__ZNKSt3__210moneypunctIwLb1EE13thousands_sepEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb1EE13thousands_sepEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb1EE8groupingEv = Module["__ZNKSt3__210moneypunctIwLb1EE8groupingEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb1EE8groupingEv = Module["__ZNKSt3__210moneypunctIwLb1EE8groupingEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb1EE8groupingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb1EE11curr_symbolEv = Module["__ZNKSt3__210moneypunctIwLb1EE11curr_symbolEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb1EE11curr_symbolEv = Module["__ZNKSt3__210moneypunctIwLb1EE11curr_symbolEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb1EE11curr_symbolEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb1EE11frac_digitsEv = Module["__ZNKSt3__210moneypunctIwLb1EE11frac_digitsEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb1EE11frac_digitsEv = Module["__ZNKSt3__210moneypunctIwLb1EE11frac_digitsEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb1EE11frac_digitsEv"]).apply(null, arguments)
            };
            var __ZNSt3__29use_facetINS_10moneypunctIwLb0EEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_10moneypunctIwLb0EEEEERKT_RKNS_6localeE"] = function() {
                return (__ZNSt3__29use_facetINS_10moneypunctIwLb0EEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_10moneypunctIwLb0EEEEERKT_RKNS_6localeE"] = Module["asm"]["_ZNSt3__29use_facetINS_10moneypunctIwLb0EEEEERKT_RKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb0EE10neg_formatEv = Module["__ZNKSt3__210moneypunctIwLb0EE10neg_formatEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb0EE10neg_formatEv = Module["__ZNKSt3__210moneypunctIwLb0EE10neg_formatEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb0EE10neg_formatEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb0EE13negative_signEv = Module["__ZNKSt3__210moneypunctIwLb0EE13negative_signEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb0EE13negative_signEv = Module["__ZNKSt3__210moneypunctIwLb0EE13negative_signEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb0EE13negative_signEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb0EE13positive_signEv = Module["__ZNKSt3__210moneypunctIwLb0EE13positive_signEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb0EE13positive_signEv = Module["__ZNKSt3__210moneypunctIwLb0EE13positive_signEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb0EE13positive_signEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb0EE13decimal_pointEv = Module["__ZNKSt3__210moneypunctIwLb0EE13decimal_pointEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb0EE13decimal_pointEv = Module["__ZNKSt3__210moneypunctIwLb0EE13decimal_pointEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb0EE13decimal_pointEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb0EE13thousands_sepEv = Module["__ZNKSt3__210moneypunctIwLb0EE13thousands_sepEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb0EE13thousands_sepEv = Module["__ZNKSt3__210moneypunctIwLb0EE13thousands_sepEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb0EE13thousands_sepEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb0EE8groupingEv = Module["__ZNKSt3__210moneypunctIwLb0EE8groupingEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb0EE8groupingEv = Module["__ZNKSt3__210moneypunctIwLb0EE8groupingEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb0EE8groupingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb0EE11curr_symbolEv = Module["__ZNKSt3__210moneypunctIwLb0EE11curr_symbolEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb0EE11curr_symbolEv = Module["__ZNKSt3__210moneypunctIwLb0EE11curr_symbolEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb0EE11curr_symbolEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb0EE11frac_digitsEv = Module["__ZNKSt3__210moneypunctIwLb0EE11frac_digitsEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb0EE11frac_digitsEv = Module["__ZNKSt3__210moneypunctIwLb0EE11frac_digitsEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb0EE11frac_digitsEv"]).apply(null, arguments)
            };
            var __ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEE7__proxyC2EwPNS_15basic_streambufIwS2_EE = Module["__ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEE7__proxyC2EwPNS_15basic_streambufIwS2_EE"] = function() {
                return (__ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEE7__proxyC2EwPNS_15basic_streambufIwS2_EE = Module["__ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEE7__proxyC2EwPNS_15basic_streambufIwS2_EE"] = Module["asm"]["_ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEE7__proxyC2EwPNS_15basic_streambufIwS2_EE"]).apply(null, arguments)
            };
            var __ZNSt3__2eqIPKwPwEEbRKNS_11__wrap_iterIT_EERKNS4_IT0_EE = Module["__ZNSt3__2eqIPKwPwEEbRKNS_11__wrap_iterIT_EERKNS4_IT0_EE"] = function() {
                return (__ZNSt3__2eqIPKwPwEEbRKNS_11__wrap_iterIT_EERKNS4_IT0_EE = Module["__ZNSt3__2eqIPKwPwEEbRKNS_11__wrap_iterIT_EERKNS4_IT0_EE"] = Module["asm"]["_ZNSt3__2eqIPKwPwEEbRKNS_11__wrap_iterIT_EERKNS4_IT0_EE"]).apply(null, arguments)
            };
            var __ZNSt3__25equalINS_11__wrap_iterIPwEES3_NS_10__equal_toIwwEEEEbT_S6_T0_T1_ = Module["__ZNSt3__25equalINS_11__wrap_iterIPwEES3_NS_10__equal_toIwwEEEEbT_S6_T0_T1_"] = function() {
                return (__ZNSt3__25equalINS_11__wrap_iterIPwEES3_NS_10__equal_toIwwEEEEbT_S6_T0_T1_ = Module["__ZNSt3__25equalINS_11__wrap_iterIPwEES3_NS_10__equal_toIwwEEEEbT_S6_T0_T1_"] = Module["asm"]["_ZNSt3__25equalINS_11__wrap_iterIPwEES3_NS_10__equal_toIwwEEEEbT_S6_T0_T1_"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIwPFvPvEE11get_deleterEv = Module["__ZNSt3__210unique_ptrIwPFvPvEE11get_deleterEv"] = function() {
                return (__ZNSt3__210unique_ptrIwPFvPvEE11get_deleterEv = Module["__ZNSt3__210unique_ptrIwPFvPvEE11get_deleterEv"] = Module["asm"]["_ZNSt3__210unique_ptrIwPFvPvEE11get_deleterEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIwPFvPvEE7releaseEv = Module["__ZNSt3__210unique_ptrIwPFvPvEE7releaseEv"] = function() {
                return (__ZNSt3__210unique_ptrIwPFvPvEE7releaseEv = Module["__ZNSt3__210unique_ptrIwPFvPvEE7releaseEv"] = Module["asm"]["_ZNSt3__210unique_ptrIwPFvPvEE7releaseEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIwPFvPvEEaSEOS4_ = Module["__ZNSt3__210unique_ptrIwPFvPvEEaSEOS4_"] = function() {
                return (__ZNSt3__210unique_ptrIwPFvPvEEaSEOS4_ = Module["__ZNSt3__210unique_ptrIwPFvPvEEaSEOS4_"] = Module["asm"]["_ZNSt3__210unique_ptrIwPFvPvEEaSEOS4_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE13__move_assignERS5_NS_17integral_constantIbLb1EEE = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE13__move_assignERS5_NS_17integral_constantIbLb1EEE"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE13__move_assignERS5_NS_17integral_constantIbLb1EEE = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE13__move_assignERS5_NS_17integral_constantIbLb1EEE"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE13__move_assignERS5_NS_17integral_constantIbLb1EEE"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE13__move_assignERS5_NS_17integral_constantIbLb1EEE = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE13__move_assignERS5_NS_17integral_constantIbLb1EEE"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE13__move_assignERS5_NS_17integral_constantIbLb1EEE = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE13__move_assignERS5_NS_17integral_constantIbLb1EEE"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE13__move_assignERS5_NS_17integral_constantIbLb1EEE"]).apply(null, arguments)
            };
            var __ZNKSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEce = Module["__ZNKSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEce"] = function() {
                return (__ZNKSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEce = Module["__ZNKSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEce"] = Module["asm"]["_ZNKSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEce"]).apply(null, arguments)
            };
            var __ZNSt3__2eqIcPFvPvEEEbRKNS_10unique_ptrIT_T0_EEDn = Module["__ZNSt3__2eqIcPFvPvEEEbRKNS_10unique_ptrIT_T0_EEDn"] = function() {
                return (__ZNSt3__2eqIcPFvPvEEEbRKNS_10unique_ptrIT_T0_EEDn = Module["__ZNSt3__2eqIcPFvPvEEEbRKNS_10unique_ptrIT_T0_EEDn"] = Module["asm"]["_ZNSt3__2eqIcPFvPvEEEbRKNS_10unique_ptrIT_T0_EEDn"]).apply(null, arguments)
            };
            var __ZNSt3__211__money_putIcE13__gather_infoEbbRKNS_6localeERNS_10money_base7patternERcS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESF_SF_Ri = Module["__ZNSt3__211__money_putIcE13__gather_infoEbbRKNS_6localeERNS_10money_base7patternERcS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESF_SF_Ri"] = function() {
                return (__ZNSt3__211__money_putIcE13__gather_infoEbbRKNS_6localeERNS_10money_base7patternERcS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESF_SF_Ri = Module["__ZNSt3__211__money_putIcE13__gather_infoEbbRKNS_6localeERNS_10money_base7patternERcS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESF_SF_Ri"] = Module["asm"]["_ZNSt3__211__money_putIcE13__gather_infoEbbRKNS_6localeERNS_10money_base7patternERcS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESF_SF_Ri"]).apply(null, arguments)
            };
            var __ZNSt3__211__money_putIcE8__formatEPcRS2_S3_jPKcS5_RKNS_5ctypeIcEEbRKNS_10money_base7patternEccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESL_SL_i = Module["__ZNSt3__211__money_putIcE8__formatEPcRS2_S3_jPKcS5_RKNS_5ctypeIcEEbRKNS_10money_base7patternEccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESL_SL_i"] = function() {
                return (__ZNSt3__211__money_putIcE8__formatEPcRS2_S3_jPKcS5_RKNS_5ctypeIcEEbRKNS_10money_base7patternEccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESL_SL_i = Module["__ZNSt3__211__money_putIcE8__formatEPcRS2_S3_jPKcS5_RKNS_5ctypeIcEEbRKNS_10money_base7patternEccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESL_SL_i"] = Module["asm"]["_ZNSt3__211__money_putIcE8__formatEPcRS2_S3_jPKcS5_RKNS_5ctypeIcEEbRKNS_10money_base7patternEccRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEESL_SL_i"]).apply(null, arguments)
            };
            var __ZNKSt3__210unique_ptrIcPFvPvEEcvbEv = Module["__ZNKSt3__210unique_ptrIcPFvPvEEcvbEv"] = function() {
                return (__ZNKSt3__210unique_ptrIcPFvPvEEcvbEv = Module["__ZNKSt3__210unique_ptrIcPFvPvEEcvbEv"] = Module["asm"]["_ZNKSt3__210unique_ptrIcPFvPvEEcvbEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb1EE10pos_formatEv = Module["__ZNKSt3__210moneypunctIcLb1EE10pos_formatEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb1EE10pos_formatEv = Module["__ZNKSt3__210moneypunctIcLb1EE10pos_formatEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb1EE10pos_formatEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIcLb0EE10pos_formatEv = Module["__ZNKSt3__210moneypunctIcLb0EE10pos_formatEv"] = function() {
                return (__ZNKSt3__210moneypunctIcLb0EE10pos_formatEv = Module["__ZNKSt3__210moneypunctIcLb0EE10pos_formatEv"] = Module["asm"]["_ZNKSt3__210moneypunctIcLb0EE10pos_formatEv"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5beginEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5beginEv"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5beginEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5beginEv"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5beginEv"]).apply(null, arguments)
            };
            var __ZNKSt3__211__wrap_iterIPKcEplEl = Module["__ZNKSt3__211__wrap_iterIPKcEplEl"] = function() {
                return (__ZNKSt3__211__wrap_iterIPKcEplEl = Module["__ZNKSt3__211__wrap_iterIPKcEplEl"] = Module["asm"]["_ZNKSt3__211__wrap_iterIPKcEplEl"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE3endEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE3endEv"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE3endEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE3endEv"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE3endEv"]).apply(null, arguments)
            };
            var __ZNSt3__24copyINS_11__wrap_iterIPKcEEPcEET0_T_S7_S6_ = Module["__ZNSt3__24copyINS_11__wrap_iterIPKcEEPcEET0_T_S7_S6_"] = function() {
                return (__ZNSt3__24copyINS_11__wrap_iterIPKcEEPcEET0_T_S7_S6_ = Module["__ZNSt3__24copyINS_11__wrap_iterIPKcEEPcEET0_T_S7_S6_"] = Module["asm"]["_ZNSt3__24copyINS_11__wrap_iterIPKcEEPcEET0_T_S7_S6_"]).apply(null, arguments)
            };
            var __ZNSt3__214numeric_limitsIjE3maxEv = Module["__ZNSt3__214numeric_limitsIjE3maxEv"] = function() {
                return (__ZNSt3__214numeric_limitsIjE3maxEv = Module["__ZNSt3__214numeric_limitsIjE3maxEv"] = Module["asm"]["_ZNSt3__214numeric_limitsIjE3maxEv"]).apply(null, arguments)
            };
            var __ZNKSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEcRKNS_12basic_stringIcS3_NS_9allocatorIcEEEE = Module["__ZNKSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEcRKNS_12basic_stringIcS3_NS_9allocatorIcEEEE"] = function() {
                return (__ZNKSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEcRKNS_12basic_stringIcS3_NS_9allocatorIcEEEE = Module["__ZNKSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEcRKNS_12basic_stringIcS3_NS_9allocatorIcEEEE"] = Module["asm"]["_ZNKSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEcRKNS_12basic_stringIcS3_NS_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNKSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwe = Module["__ZNKSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwe"] = function() {
                return (__ZNKSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwe = Module["__ZNKSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwe"] = Module["asm"]["_ZNKSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwe"]).apply(null, arguments)
            };
            var __ZNSt3__2eqIwPFvPvEEEbRKNS_10unique_ptrIT_T0_EEDn = Module["__ZNSt3__2eqIwPFvPvEEEbRKNS_10unique_ptrIT_T0_EEDn"] = function() {
                return (__ZNSt3__2eqIwPFvPvEEEbRKNS_10unique_ptrIT_T0_EEDn = Module["__ZNSt3__2eqIwPFvPvEEEbRKNS_10unique_ptrIT_T0_EEDn"] = Module["asm"]["_ZNSt3__2eqIwPFvPvEEEbRKNS_10unique_ptrIT_T0_EEDn"]).apply(null, arguments)
            };
            var __ZNSt3__211__money_putIwE13__gather_infoEbbRKNS_6localeERNS_10money_base7patternERwS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS9_IwNSA_IwEENSC_IwEEEESJ_Ri = Module["__ZNSt3__211__money_putIwE13__gather_infoEbbRKNS_6localeERNS_10money_base7patternERwS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS9_IwNSA_IwEENSC_IwEEEESJ_Ri"] = function() {
                return (__ZNSt3__211__money_putIwE13__gather_infoEbbRKNS_6localeERNS_10money_base7patternERwS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS9_IwNSA_IwEENSC_IwEEEESJ_Ri = Module["__ZNSt3__211__money_putIwE13__gather_infoEbbRKNS_6localeERNS_10money_base7patternERwS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS9_IwNSA_IwEENSC_IwEEEESJ_Ri"] = Module["asm"]["_ZNSt3__211__money_putIwE13__gather_infoEbbRKNS_6localeERNS_10money_base7patternERwS8_RNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERNS9_IwNSA_IwEENSC_IwEEEESJ_Ri"]).apply(null, arguments)
            };
            var __ZNSt3__211__money_putIwE8__formatEPwRS2_S3_jPKwS5_RKNS_5ctypeIwEEbRKNS_10money_base7patternEwwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNSE_IwNSF_IwEENSH_IwEEEESQ_i = Module["__ZNSt3__211__money_putIwE8__formatEPwRS2_S3_jPKwS5_RKNS_5ctypeIwEEbRKNS_10money_base7patternEwwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNSE_IwNSF_IwEENSH_IwEEEESQ_i"] = function() {
                return (__ZNSt3__211__money_putIwE8__formatEPwRS2_S3_jPKwS5_RKNS_5ctypeIwEEbRKNS_10money_base7patternEwwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNSE_IwNSF_IwEENSH_IwEEEESQ_i = Module["__ZNSt3__211__money_putIwE8__formatEPwRS2_S3_jPKwS5_RKNS_5ctypeIwEEbRKNS_10money_base7patternEwwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNSE_IwNSF_IwEENSH_IwEEEESQ_i"] = Module["asm"]["_ZNSt3__211__money_putIwE8__formatEPwRS2_S3_jPKwS5_RKNS_5ctypeIwEEbRKNS_10money_base7patternEwwRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNSE_IwNSF_IwEENSH_IwEEEESQ_i"]).apply(null, arguments)
            };
            var __ZNKSt3__210unique_ptrIwPFvPvEEcvbEv = Module["__ZNKSt3__210unique_ptrIwPFvPvEEcvbEv"] = function() {
                return (__ZNKSt3__210unique_ptrIwPFvPvEEcvbEv = Module["__ZNKSt3__210unique_ptrIwPFvPvEEcvbEv"] = Module["asm"]["_ZNKSt3__210unique_ptrIwPFvPvEEcvbEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb1EE10pos_formatEv = Module["__ZNKSt3__210moneypunctIwLb1EE10pos_formatEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb1EE10pos_formatEv = Module["__ZNKSt3__210moneypunctIwLb1EE10pos_formatEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb1EE10pos_formatEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210moneypunctIwLb0EE10pos_formatEv = Module["__ZNKSt3__210moneypunctIwLb0EE10pos_formatEv"] = function() {
                return (__ZNKSt3__210moneypunctIwLb0EE10pos_formatEv = Module["__ZNKSt3__210moneypunctIwLb0EE10pos_formatEv"] = Module["asm"]["_ZNKSt3__210moneypunctIwLb0EE10pos_formatEv"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5beginEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5beginEv"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5beginEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5beginEv"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5beginEv"]).apply(null, arguments)
            };
            var __ZNKSt3__211__wrap_iterIPKwEplEl = Module["__ZNKSt3__211__wrap_iterIPKwEplEl"] = function() {
                return (__ZNKSt3__211__wrap_iterIPKwEplEl = Module["__ZNKSt3__211__wrap_iterIPKwEplEl"] = Module["asm"]["_ZNKSt3__211__wrap_iterIPKwEplEl"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE3endEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE3endEv"] = function() {
                return (__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE3endEv = Module["__ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE3endEv"] = Module["asm"]["_ZNKSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE3endEv"]).apply(null, arguments)
            };
            var __ZNSt3__24copyINS_11__wrap_iterIPKwEEPwEET0_T_S7_S6_ = Module["__ZNSt3__24copyINS_11__wrap_iterIPKwEEPwEET0_T_S7_S6_"] = function() {
                return (__ZNSt3__24copyINS_11__wrap_iterIPKwEEPwEET0_T_S7_S6_ = Module["__ZNSt3__24copyINS_11__wrap_iterIPKwEEPwEET0_T_S7_S6_"] = Module["asm"]["_ZNSt3__24copyINS_11__wrap_iterIPKwEEPwEET0_T_S7_S6_"]).apply(null, arguments)
            };
            var __ZNKSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwRKNS_12basic_stringIwS3_NS_9allocatorIwEEEE = Module["__ZNKSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwRKNS_12basic_stringIwS3_NS_9allocatorIwEEEE"] = function() {
                return (__ZNKSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwRKNS_12basic_stringIwS3_NS_9allocatorIwEEEE = Module["__ZNKSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwRKNS_12basic_stringIwS3_NS_9allocatorIwEEEE"] = Module["asm"]["_ZNKSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwRKNS_12basic_stringIwS3_NS_9allocatorIwEEEE"]).apply(null, arguments)
            };
            var __ZNSt3__213__unwrap_iterIcEENS_9enable_ifIXsr28is_trivially_copy_assignableIT_EE5valueEPKS2_E4typeENS_11__wrap_iterIS4_EE = Module["__ZNSt3__213__unwrap_iterIcEENS_9enable_ifIXsr28is_trivially_copy_assignableIT_EE5valueEPKS2_E4typeENS_11__wrap_iterIS4_EE"] = function() {
                return (__ZNSt3__213__unwrap_iterIcEENS_9enable_ifIXsr28is_trivially_copy_assignableIT_EE5valueEPKS2_E4typeENS_11__wrap_iterIS4_EE = Module["__ZNSt3__213__unwrap_iterIcEENS_9enable_ifIXsr28is_trivially_copy_assignableIT_EE5valueEPKS2_E4typeENS_11__wrap_iterIS4_EE"] = Module["asm"]["_ZNSt3__213__unwrap_iterIcEENS_9enable_ifIXsr28is_trivially_copy_assignableIT_EE5valueEPKS2_E4typeENS_11__wrap_iterIS4_EE"]).apply(null, arguments)
            };
            var __ZNSt3__26__copyIKccEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS7_EE5valueEPS7_E4typeEPS4_SB_S8_ = Module["__ZNSt3__26__copyIKccEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS7_EE5valueEPS7_E4typeEPS4_SB_S8_"] = function() {
                return (__ZNSt3__26__copyIKccEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS7_EE5valueEPS7_E4typeEPS4_SB_S8_ = Module["__ZNSt3__26__copyIKccEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS7_EE5valueEPS7_E4typeEPS4_SB_S8_"] = Module["asm"]["_ZNSt3__26__copyIKccEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS7_EE5valueEPS7_E4typeEPS4_SB_S8_"]).apply(null, arguments)
            };
            var __ZNSt3__211__wrap_iterIPKcEC2ES2_ = Module["__ZNSt3__211__wrap_iterIPKcEC2ES2_"] = function() {
                return (__ZNSt3__211__wrap_iterIPKcEC2ES2_ = Module["__ZNSt3__211__wrap_iterIPKcEC2ES2_"] = Module["asm"]["_ZNSt3__211__wrap_iterIPKcEC2ES2_"]).apply(null, arguments)
            };
            var __ZNSt3__223__libcpp_numeric_limitsIjLb1EE3maxEv = Module["__ZNSt3__223__libcpp_numeric_limitsIjLb1EE3maxEv"] = function() {
                return (__ZNSt3__223__libcpp_numeric_limitsIjLb1EE3maxEv = Module["__ZNSt3__223__libcpp_numeric_limitsIjLb1EE3maxEv"] = Module["asm"]["_ZNSt3__223__libcpp_numeric_limitsIjLb1EE3maxEv"]).apply(null, arguments)
            };
            var __ZNSt3__211__wrap_iterIPKcEpLEl = Module["__ZNSt3__211__wrap_iterIPKcEpLEl"] = function() {
                return (__ZNSt3__211__wrap_iterIPKcEpLEl = Module["__ZNSt3__211__wrap_iterIPKcEpLEl"] = Module["asm"]["_ZNSt3__211__wrap_iterIPKcEpLEl"]).apply(null, arguments)
            };
            var __ZNSt3__213__unwrap_iterIwEENS_9enable_ifIXsr28is_trivially_copy_assignableIT_EE5valueEPKS2_E4typeENS_11__wrap_iterIS4_EE = Module["__ZNSt3__213__unwrap_iterIwEENS_9enable_ifIXsr28is_trivially_copy_assignableIT_EE5valueEPKS2_E4typeENS_11__wrap_iterIS4_EE"] = function() {
                return (__ZNSt3__213__unwrap_iterIwEENS_9enable_ifIXsr28is_trivially_copy_assignableIT_EE5valueEPKS2_E4typeENS_11__wrap_iterIS4_EE = Module["__ZNSt3__213__unwrap_iterIwEENS_9enable_ifIXsr28is_trivially_copy_assignableIT_EE5valueEPKS2_E4typeENS_11__wrap_iterIS4_EE"] = Module["asm"]["_ZNSt3__213__unwrap_iterIwEENS_9enable_ifIXsr28is_trivially_copy_assignableIT_EE5valueEPKS2_E4typeENS_11__wrap_iterIS4_EE"]).apply(null, arguments)
            };
            var __ZNSt3__26__copyIKwwEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS7_EE5valueEPS7_E4typeEPS4_SB_S8_ = Module["__ZNSt3__26__copyIKwwEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS7_EE5valueEPS7_E4typeEPS4_SB_S8_"] = function() {
                return (__ZNSt3__26__copyIKwwEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS7_EE5valueEPS7_E4typeEPS4_SB_S8_ = Module["__ZNSt3__26__copyIKwwEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS7_EE5valueEPS7_E4typeEPS4_SB_S8_"] = Module["asm"]["_ZNSt3__26__copyIKwwEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS7_EE5valueEPS7_E4typeEPS4_SB_S8_"]).apply(null, arguments)
            };
            var __ZNSt3__211__wrap_iterIPKwEC2ES2_ = Module["__ZNSt3__211__wrap_iterIPKwEC2ES2_"] = function() {
                return (__ZNSt3__211__wrap_iterIPKwEC2ES2_ = Module["__ZNSt3__211__wrap_iterIPKwEC2ES2_"] = Module["asm"]["_ZNSt3__211__wrap_iterIPKwEC2ES2_"]).apply(null, arguments)
            };
            var __ZNSt3__211__wrap_iterIPKwEpLEl = Module["__ZNSt3__211__wrap_iterIPKwEpLEl"] = function() {
                return (__ZNSt3__211__wrap_iterIPKwEpLEl = Module["__ZNSt3__211__wrap_iterIPKwEpLEl"] = Module["asm"]["_ZNSt3__211__wrap_iterIPKwEpLEl"]).apply(null, arguments)
            };
            var __ZNKSt3__28messagesIcE7do_openERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_6localeE = Module["__ZNKSt3__28messagesIcE7do_openERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_6localeE"] = function() {
                return (__ZNKSt3__28messagesIcE7do_openERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_6localeE = Module["__ZNKSt3__28messagesIcE7do_openERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_6localeE"] = Module["asm"]["_ZNKSt3__28messagesIcE7do_openERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNKSt3__28messagesIcE6do_getEliiRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNKSt3__28messagesIcE6do_getEliiRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = function() {
                return (__ZNKSt3__28messagesIcE6do_getEliiRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNKSt3__28messagesIcE6do_getEliiRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = Module["asm"]["_ZNKSt3__28messagesIcE6do_getEliiRKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28messagesIcE8do_closeEl = Module["__ZNKSt3__28messagesIcE8do_closeEl"] = function() {
                return (__ZNKSt3__28messagesIcE8do_closeEl = Module["__ZNKSt3__28messagesIcE8do_closeEl"] = Module["asm"]["_ZNKSt3__28messagesIcE8do_closeEl"]).apply(null, arguments)
            };
            var __ZNKSt3__28messagesIwE7do_openERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_6localeE = Module["__ZNKSt3__28messagesIwE7do_openERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_6localeE"] = function() {
                return (__ZNKSt3__28messagesIwE7do_openERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_6localeE = Module["__ZNKSt3__28messagesIwE7do_openERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_6localeE"] = Module["asm"]["_ZNKSt3__28messagesIwE7do_openERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNKSt3__28messagesIwE6do_getEliiRKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEE = Module["__ZNKSt3__28messagesIwE6do_getEliiRKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEE"] = function() {
                return (__ZNKSt3__28messagesIwE6do_getEliiRKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEE = Module["__ZNKSt3__28messagesIwE6do_getEliiRKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEE"] = Module["asm"]["_ZNKSt3__28messagesIwE6do_getEliiRKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEE"]).apply(null, arguments)
            };
            var __ZNKSt3__28messagesIwE8do_closeEl = Module["__ZNKSt3__28messagesIwE8do_closeEl"] = function() {
                return (__ZNKSt3__28messagesIwE8do_closeEl = Module["__ZNKSt3__28messagesIwE8do_closeEl"] = Module["asm"]["_ZNKSt3__28messagesIwE8do_closeEl"]).apply(null, arguments)
            };
            var __ZNSt3__214codecvt_bynameIcc11__mbstate_tED2Ev = Module["__ZNSt3__214codecvt_bynameIcc11__mbstate_tED2Ev"] = function() {
                return (__ZNSt3__214codecvt_bynameIcc11__mbstate_tED2Ev = Module["__ZNSt3__214codecvt_bynameIcc11__mbstate_tED2Ev"] = Module["asm"]["_ZNSt3__214codecvt_bynameIcc11__mbstate_tED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214codecvt_bynameIcc11__mbstate_tED0Ev = Module["__ZNSt3__214codecvt_bynameIcc11__mbstate_tED0Ev"] = function() {
                return (__ZNSt3__214codecvt_bynameIcc11__mbstate_tED0Ev = Module["__ZNSt3__214codecvt_bynameIcc11__mbstate_tED0Ev"] = Module["asm"]["_ZNSt3__214codecvt_bynameIcc11__mbstate_tED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214codecvt_bynameIwc11__mbstate_tED2Ev = Module["__ZNSt3__214codecvt_bynameIwc11__mbstate_tED2Ev"] = function() {
                return (__ZNSt3__214codecvt_bynameIwc11__mbstate_tED2Ev = Module["__ZNSt3__214codecvt_bynameIwc11__mbstate_tED2Ev"] = Module["asm"]["_ZNSt3__214codecvt_bynameIwc11__mbstate_tED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__27codecvtIwc11__mbstate_tED2Ev = Module["__ZNSt3__27codecvtIwc11__mbstate_tED2Ev"] = function() {
                return (__ZNSt3__27codecvtIwc11__mbstate_tED2Ev = Module["__ZNSt3__27codecvtIwc11__mbstate_tED2Ev"] = Module["asm"]["_ZNSt3__27codecvtIwc11__mbstate_tED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214codecvt_bynameIwc11__mbstate_tED0Ev = Module["__ZNSt3__214codecvt_bynameIwc11__mbstate_tED0Ev"] = function() {
                return (__ZNSt3__214codecvt_bynameIwc11__mbstate_tED0Ev = Module["__ZNSt3__214codecvt_bynameIwc11__mbstate_tED0Ev"] = Module["asm"]["_ZNSt3__214codecvt_bynameIwc11__mbstate_tED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214codecvt_bynameIDsc11__mbstate_tED2Ev = Module["__ZNSt3__214codecvt_bynameIDsc11__mbstate_tED2Ev"] = function() {
                return (__ZNSt3__214codecvt_bynameIDsc11__mbstate_tED2Ev = Module["__ZNSt3__214codecvt_bynameIDsc11__mbstate_tED2Ev"] = Module["asm"]["_ZNSt3__214codecvt_bynameIDsc11__mbstate_tED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214codecvt_bynameIDsc11__mbstate_tED0Ev = Module["__ZNSt3__214codecvt_bynameIDsc11__mbstate_tED0Ev"] = function() {
                return (__ZNSt3__214codecvt_bynameIDsc11__mbstate_tED0Ev = Module["__ZNSt3__214codecvt_bynameIDsc11__mbstate_tED0Ev"] = Module["asm"]["_ZNSt3__214codecvt_bynameIDsc11__mbstate_tED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214codecvt_bynameIDic11__mbstate_tED2Ev = Module["__ZNSt3__214codecvt_bynameIDic11__mbstate_tED2Ev"] = function() {
                return (__ZNSt3__214codecvt_bynameIDic11__mbstate_tED2Ev = Module["__ZNSt3__214codecvt_bynameIDic11__mbstate_tED2Ev"] = Module["asm"]["_ZNSt3__214codecvt_bynameIDic11__mbstate_tED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214codecvt_bynameIDic11__mbstate_tED0Ev = Module["__ZNSt3__214codecvt_bynameIDic11__mbstate_tED0Ev"] = function() {
                return (__ZNSt3__214codecvt_bynameIDic11__mbstate_tED0Ev = Module["__ZNSt3__214codecvt_bynameIDic11__mbstate_tED0Ev"] = Module["asm"]["_ZNSt3__214codecvt_bynameIDic11__mbstate_tED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__impC2Em = Module["__ZNSt3__26locale5__impC2Em"] = function() {
                return (__ZNSt3__26locale5__impC2Em = Module["__ZNSt3__26locale5__impC2Em"] = Module["asm"]["_ZNSt3__26locale5__impC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5facetC2Em = Module["__ZNSt3__26locale5facetC2Em"] = function() {
                return (__ZNSt3__26locale5facetC2Em = Module["__ZNSt3__26locale5facetC2Em"] = Module["asm"]["_ZNSt3__26locale5facetC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEC2Em = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEC2Em"] = function() {
                return (__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEC2Em = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEC2Em"] = Module["asm"]["_ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE5clearEv = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE5clearEv"] = function() {
                return (__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE5clearEv = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE5clearEv"] = Module["asm"]["_ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE5clearEv"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_7collateIcEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_7collateIcEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_7collateIcEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_7collateIcEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_7collateIcEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_7collateIwEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_7collateIwEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_7collateIwEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_7collateIwEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_7collateIwEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_5ctypeIcEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_5ctypeIcEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_5ctypeIcEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_5ctypeIcEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_5ctypeIcEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_5ctypeIwEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_5ctypeIwEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_5ctypeIwEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_5ctypeIwEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_5ctypeIwEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_7codecvtIcc11__mbstate_tEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_7codecvtIcc11__mbstate_tEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_7codecvtIcc11__mbstate_tEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_7codecvtIcc11__mbstate_tEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_7codecvtIcc11__mbstate_tEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_7codecvtIwc11__mbstate_tEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_7codecvtIwc11__mbstate_tEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_7codecvtIwc11__mbstate_tEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_7codecvtIwc11__mbstate_tEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_7codecvtIwc11__mbstate_tEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_7codecvtIDsc11__mbstate_tEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_7codecvtIDsc11__mbstate_tEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_7codecvtIDsc11__mbstate_tEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_7codecvtIDsc11__mbstate_tEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_7codecvtIDsc11__mbstate_tEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_7codecvtIDic11__mbstate_tEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_7codecvtIDic11__mbstate_tEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_7codecvtIDic11__mbstate_tEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_7codecvtIDic11__mbstate_tEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_7codecvtIDic11__mbstate_tEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_8numpunctIcEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_8numpunctIcEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_8numpunctIcEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_8numpunctIcEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_8numpunctIcEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_8numpunctIwEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_8numpunctIwEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_8numpunctIwEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_8numpunctIwEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_8numpunctIwEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_7num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_7num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_7num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_7num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_7num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_7num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_7num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_7num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_7num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_7num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_7num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_7num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_7num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_7num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_7num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_7num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_7num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_7num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_7num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_7num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_10moneypunctIcLb0EEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_10moneypunctIcLb0EEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_10moneypunctIcLb0EEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_10moneypunctIcLb0EEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_10moneypunctIcLb0EEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_10moneypunctIcLb1EEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_10moneypunctIcLb1EEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_10moneypunctIcLb1EEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_10moneypunctIcLb1EEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_10moneypunctIcLb1EEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_10moneypunctIwLb0EEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_10moneypunctIwLb0EEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_10moneypunctIwLb0EEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_10moneypunctIwLb0EEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_10moneypunctIwLb0EEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_10moneypunctIwLb1EEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_10moneypunctIwLb1EEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_10moneypunctIwLb1EEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_10moneypunctIwLb1EEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_10moneypunctIwLb1EEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_9money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_9money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_9money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_9money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_9money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_9money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_9money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_9money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_9money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_9money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_9money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_9money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_9money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_9money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_9money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_9money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_9money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_9money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_9money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_9money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_8time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_8time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_8time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_8time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_8time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_8time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_8time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_8time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_8time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_8time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_8time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_8time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_8time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_8time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_8time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_8time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_8time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_8time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_8time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_8time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_8messagesIcEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_8messagesIcEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_8messagesIcEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_8messagesIcEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_8messagesIcEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_8messagesIwEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_8messagesIwEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_8messagesIwEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_8messagesIwEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_8messagesIwEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEC2Ev = Module["__ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEC2Ev"] = function() {
                return (__ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEC2Ev = Module["__ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEC2Ev"] = Module["asm"]["_ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE11__vallocateEm = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE11__vallocateEm"] = function() {
                return (__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE11__vallocateEm = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE11__vallocateEm"] = Module["asm"]["_ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE11__vallocateEm"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE18__construct_at_endEm = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE18__construct_at_endEm"] = function() {
                return (__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE18__construct_at_endEm = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE18__construct_at_endEm"] = Module["asm"]["_ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE18__construct_at_endEm"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE4sizeEv = Module["__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE4sizeEv"] = function() {
                return (__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE4sizeEv = Module["__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE4sizeEv"] = Module["asm"]["_ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE4sizeEv"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE5clearEv = Module["__ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE5clearEv"] = function() {
                return (__ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE5clearEv = Module["__ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE5clearEv"] = Module["asm"]["_ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE5clearEv"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE17__annotate_shrinkEm = Module["__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE17__annotate_shrinkEm"] = function() {
                return (__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE17__annotate_shrinkEm = Module["__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE17__annotate_shrinkEm"] = Module["asm"]["_ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE17__annotate_shrinkEm"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE26__invalidate_all_iteratorsEv = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE26__invalidate_all_iteratorsEv"] = function() {
                return (__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE26__invalidate_all_iteratorsEv = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE26__invalidate_all_iteratorsEv"] = Module["asm"]["_ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE26__invalidate_all_iteratorsEv"]).apply(null, arguments)
            };
            var __ZNSt3__26locale2id5__getEv = Module["__ZNSt3__26locale2id5__getEv"] = function() {
                return (__ZNSt3__26locale2id5__getEv = Module["__ZNSt3__26locale2id5__getEv"] = Module["asm"]["_ZNSt3__26locale2id5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installEPNS0_5facetEl = Module["__ZNSt3__26locale5__imp7installEPNS0_5facetEl"] = function() {
                return (__ZNSt3__26locale5__imp7installEPNS0_5facetEl = Module["__ZNSt3__26locale5__imp7installEPNS0_5facetEl"] = Module["asm"]["_ZNSt3__26locale5__imp7installEPNS0_5facetEl"]).apply(null, arguments)
            };
            var __ZNSt3__27collateIcEC2Em = Module["__ZNSt3__27collateIcEC2Em"] = function() {
                return (__ZNSt3__27collateIcEC2Em = Module["__ZNSt3__27collateIcEC2Em"] = Module["asm"]["_ZNSt3__27collateIcEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__27collateIwEC2Em = Module["__ZNSt3__27collateIwEC2Em"] = function() {
                return (__ZNSt3__27collateIwEC2Em = Module["__ZNSt3__27collateIwEC2Em"] = Module["asm"]["_ZNSt3__27collateIwEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__25ctypeIcEC2EPKtbm = Module["__ZNSt3__25ctypeIcEC2EPKtbm"] = function() {
                return (__ZNSt3__25ctypeIcEC2EPKtbm = Module["__ZNSt3__25ctypeIcEC2EPKtbm"] = Module["asm"]["_ZNSt3__25ctypeIcEC2EPKtbm"]).apply(null, arguments)
            };
            var __ZNSt3__25ctypeIwEC2Em = Module["__ZNSt3__25ctypeIwEC2Em"] = function() {
                return (__ZNSt3__25ctypeIwEC2Em = Module["__ZNSt3__25ctypeIwEC2Em"] = Module["asm"]["_ZNSt3__25ctypeIwEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__27codecvtIcc11__mbstate_tEC2Em = Module["__ZNSt3__27codecvtIcc11__mbstate_tEC2Em"] = function() {
                return (__ZNSt3__27codecvtIcc11__mbstate_tEC2Em = Module["__ZNSt3__27codecvtIcc11__mbstate_tEC2Em"] = Module["asm"]["_ZNSt3__27codecvtIcc11__mbstate_tEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__27codecvtIwc11__mbstate_tEC2Em = Module["__ZNSt3__27codecvtIwc11__mbstate_tEC2Em"] = function() {
                return (__ZNSt3__27codecvtIwc11__mbstate_tEC2Em = Module["__ZNSt3__27codecvtIwc11__mbstate_tEC2Em"] = Module["asm"]["_ZNSt3__27codecvtIwc11__mbstate_tEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__27codecvtIDsc11__mbstate_tEC2Em = Module["__ZNSt3__27codecvtIDsc11__mbstate_tEC2Em"] = function() {
                return (__ZNSt3__27codecvtIDsc11__mbstate_tEC2Em = Module["__ZNSt3__27codecvtIDsc11__mbstate_tEC2Em"] = Module["asm"]["_ZNSt3__27codecvtIDsc11__mbstate_tEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__27codecvtIDic11__mbstate_tEC2Em = Module["__ZNSt3__27codecvtIDic11__mbstate_tEC2Em"] = function() {
                return (__ZNSt3__27codecvtIDic11__mbstate_tEC2Em = Module["__ZNSt3__27codecvtIDic11__mbstate_tEC2Em"] = Module["asm"]["_ZNSt3__27codecvtIDic11__mbstate_tEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__28numpunctIcEC2Em = Module["__ZNSt3__28numpunctIcEC2Em"] = function() {
                return (__ZNSt3__28numpunctIcEC2Em = Module["__ZNSt3__28numpunctIcEC2Em"] = Module["asm"]["_ZNSt3__28numpunctIcEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__28numpunctIwEC2Em = Module["__ZNSt3__28numpunctIwEC2Em"] = function() {
                return (__ZNSt3__28numpunctIwEC2Em = Module["__ZNSt3__28numpunctIwEC2Em"] = Module["asm"]["_ZNSt3__28numpunctIwEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em = Module["__ZNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em"] = function() {
                return (__ZNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em = Module["__ZNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em"] = Module["asm"]["_ZNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em = Module["__ZNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em"] = function() {
                return (__ZNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em = Module["__ZNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em"] = Module["asm"]["_ZNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em = Module["__ZNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em"] = function() {
                return (__ZNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em = Module["__ZNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em"] = Module["asm"]["_ZNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em = Module["__ZNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em"] = function() {
                return (__ZNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em = Module["__ZNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em"] = Module["asm"]["_ZNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__210moneypunctIcLb0EEC2Em = Module["__ZNSt3__210moneypunctIcLb0EEC2Em"] = function() {
                return (__ZNSt3__210moneypunctIcLb0EEC2Em = Module["__ZNSt3__210moneypunctIcLb0EEC2Em"] = Module["asm"]["_ZNSt3__210moneypunctIcLb0EEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__210moneypunctIcLb1EEC2Em = Module["__ZNSt3__210moneypunctIcLb1EEC2Em"] = function() {
                return (__ZNSt3__210moneypunctIcLb1EEC2Em = Module["__ZNSt3__210moneypunctIcLb1EEC2Em"] = Module["asm"]["_ZNSt3__210moneypunctIcLb1EEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__210moneypunctIwLb0EEC2Em = Module["__ZNSt3__210moneypunctIwLb0EEC2Em"] = function() {
                return (__ZNSt3__210moneypunctIwLb0EEC2Em = Module["__ZNSt3__210moneypunctIwLb0EEC2Em"] = Module["asm"]["_ZNSt3__210moneypunctIwLb0EEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__210moneypunctIwLb1EEC2Em = Module["__ZNSt3__210moneypunctIwLb1EEC2Em"] = function() {
                return (__ZNSt3__210moneypunctIwLb1EEC2Em = Module["__ZNSt3__210moneypunctIwLb1EEC2Em"] = Module["asm"]["_ZNSt3__210moneypunctIwLb1EEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em = Module["__ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em"] = function() {
                return (__ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em = Module["__ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em"] = Module["asm"]["_ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em = Module["__ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em"] = function() {
                return (__ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em = Module["__ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em"] = Module["asm"]["_ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em = Module["__ZNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em"] = function() {
                return (__ZNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em = Module["__ZNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em"] = Module["asm"]["_ZNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em = Module["__ZNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em"] = function() {
                return (__ZNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em = Module["__ZNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em"] = Module["asm"]["_ZNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em = Module["__ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em"] = function() {
                return (__ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em = Module["__ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em"] = Module["asm"]["_ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em = Module["__ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em"] = function() {
                return (__ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em = Module["__ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em"] = Module["asm"]["_ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em = Module["__ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em"] = function() {
                return (__ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em = Module["__ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em"] = Module["asm"]["_ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em = Module["__ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em"] = function() {
                return (__ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em = Module["__ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em"] = Module["asm"]["_ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__28messagesIcEC2Em = Module["__ZNSt3__28messagesIcEC2Em"] = function() {
                return (__ZNSt3__28messagesIcEC2Em = Module["__ZNSt3__28messagesIcEC2Em"] = Module["asm"]["_ZNSt3__28messagesIcEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__28messagesIwEC2Em = Module["__ZNSt3__28messagesIwEC2Em"] = function() {
                return (__ZNSt3__28messagesIwEC2Em = Module["__ZNSt3__28messagesIwEC2Em"] = Module["asm"]["_ZNSt3__28messagesIwEC2Em"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__impC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__26locale5__impC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__26locale5__impC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__26locale5__impC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__26locale5__impC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__26locale7classicEv = Module["__ZNSt3__26locale7classicEv"] = function() {
                return (__ZNSt3__26locale7classicEv = Module["__ZNSt3__26locale7classicEv"] = Module["asm"]["_ZNSt3__26locale7classicEv"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEaSERKS6_ = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEaSERKS6_"] = function() {
                return (__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEaSERKS6_ = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEaSERKS6_"] = Module["asm"]["_ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEaSERKS6_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEixEm = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEixEm"] = function() {
                return (__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEixEm = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEixEm"] = Module["asm"]["_ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEixEm"]).apply(null, arguments)
            };
            var __ZNSt3__214collate_bynameIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__214collate_bynameIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__214collate_bynameIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__214collate_bynameIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__214collate_bynameIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_14collate_bynameIcEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_14collate_bynameIcEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_14collate_bynameIcEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_14collate_bynameIcEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_14collate_bynameIcEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__214collate_bynameIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__214collate_bynameIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__214collate_bynameIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__214collate_bynameIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__214collate_bynameIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_14collate_bynameIwEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_14collate_bynameIwEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_14collate_bynameIwEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_14collate_bynameIwEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_14collate_bynameIwEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__212ctype_bynameIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__212ctype_bynameIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__212ctype_bynameIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__212ctype_bynameIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__212ctype_bynameIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_12ctype_bynameIcEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_12ctype_bynameIcEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_12ctype_bynameIcEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_12ctype_bynameIcEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_12ctype_bynameIcEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__212ctype_bynameIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__212ctype_bynameIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__212ctype_bynameIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__212ctype_bynameIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__212ctype_bynameIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_12ctype_bynameIwEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_12ctype_bynameIwEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_12ctype_bynameIwEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_12ctype_bynameIwEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_12ctype_bynameIwEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__214codecvt_bynameIcc11__mbstate_tEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__214codecvt_bynameIcc11__mbstate_tEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__214codecvt_bynameIcc11__mbstate_tEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__214codecvt_bynameIcc11__mbstate_tEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__214codecvt_bynameIcc11__mbstate_tEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_14codecvt_bynameIcc11__mbstate_tEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_14codecvt_bynameIcc11__mbstate_tEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_14codecvt_bynameIcc11__mbstate_tEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_14codecvt_bynameIcc11__mbstate_tEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_14codecvt_bynameIcc11__mbstate_tEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__214codecvt_bynameIwc11__mbstate_tEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__214codecvt_bynameIwc11__mbstate_tEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__214codecvt_bynameIwc11__mbstate_tEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__214codecvt_bynameIwc11__mbstate_tEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__214codecvt_bynameIwc11__mbstate_tEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_14codecvt_bynameIwc11__mbstate_tEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_14codecvt_bynameIwc11__mbstate_tEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_14codecvt_bynameIwc11__mbstate_tEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_14codecvt_bynameIwc11__mbstate_tEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_14codecvt_bynameIwc11__mbstate_tEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__214codecvt_bynameIDsc11__mbstate_tEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__214codecvt_bynameIDsc11__mbstate_tEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__214codecvt_bynameIDsc11__mbstate_tEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__214codecvt_bynameIDsc11__mbstate_tEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__214codecvt_bynameIDsc11__mbstate_tEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_14codecvt_bynameIDsc11__mbstate_tEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_14codecvt_bynameIDsc11__mbstate_tEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_14codecvt_bynameIDsc11__mbstate_tEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_14codecvt_bynameIDsc11__mbstate_tEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_14codecvt_bynameIDsc11__mbstate_tEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__214codecvt_bynameIDic11__mbstate_tEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__214codecvt_bynameIDic11__mbstate_tEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__214codecvt_bynameIDic11__mbstate_tEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__214codecvt_bynameIDic11__mbstate_tEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__214codecvt_bynameIDic11__mbstate_tEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_14codecvt_bynameIDic11__mbstate_tEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_14codecvt_bynameIDic11__mbstate_tEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_14codecvt_bynameIDic11__mbstate_tEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_14codecvt_bynameIDic11__mbstate_tEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_14codecvt_bynameIDic11__mbstate_tEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__215numpunct_bynameIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__215numpunct_bynameIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__215numpunct_bynameIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__215numpunct_bynameIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__215numpunct_bynameIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_15numpunct_bynameIcEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_15numpunct_bynameIcEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_15numpunct_bynameIcEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_15numpunct_bynameIcEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_15numpunct_bynameIcEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__215numpunct_bynameIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__215numpunct_bynameIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__215numpunct_bynameIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__215numpunct_bynameIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__215numpunct_bynameIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_15numpunct_bynameIwEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_15numpunct_bynameIwEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_15numpunct_bynameIwEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_15numpunct_bynameIwEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_15numpunct_bynameIwEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__217moneypunct_bynameIcLb0EEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__217moneypunct_bynameIcLb0EEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__217moneypunct_bynameIcLb0EEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__217moneypunct_bynameIcLb0EEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__217moneypunct_bynameIcLb0EEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_17moneypunct_bynameIcLb0EEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_17moneypunct_bynameIcLb0EEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_17moneypunct_bynameIcLb0EEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_17moneypunct_bynameIcLb0EEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_17moneypunct_bynameIcLb0EEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__217moneypunct_bynameIcLb1EEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__217moneypunct_bynameIcLb1EEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__217moneypunct_bynameIcLb1EEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__217moneypunct_bynameIcLb1EEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__217moneypunct_bynameIcLb1EEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_17moneypunct_bynameIcLb1EEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_17moneypunct_bynameIcLb1EEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_17moneypunct_bynameIcLb1EEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_17moneypunct_bynameIcLb1EEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_17moneypunct_bynameIcLb1EEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__217moneypunct_bynameIwLb0EEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__217moneypunct_bynameIwLb0EEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__217moneypunct_bynameIwLb0EEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__217moneypunct_bynameIwLb0EEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__217moneypunct_bynameIwLb0EEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_17moneypunct_bynameIwLb0EEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_17moneypunct_bynameIwLb0EEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_17moneypunct_bynameIwLb0EEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_17moneypunct_bynameIwLb0EEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_17moneypunct_bynameIwLb0EEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__217moneypunct_bynameIwLb1EEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__217moneypunct_bynameIwLb1EEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__217moneypunct_bynameIwLb1EEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__217moneypunct_bynameIwLb1EEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__217moneypunct_bynameIwLb1EEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_17moneypunct_bynameIwLb1EEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_17moneypunct_bynameIwLb1EEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_17moneypunct_bynameIwLb1EEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_17moneypunct_bynameIwLb1EEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_17moneypunct_bynameIwLb1EEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEC2ERKNS_12basic_stringIcS3_NS_9allocatorIcEEEEm = Module["__ZNSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEC2ERKNS_12basic_stringIcS3_NS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEC2ERKNS_12basic_stringIcS3_NS_9allocatorIcEEEEm = Module["__ZNSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEC2ERKNS_12basic_stringIcS3_NS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEC2ERKNS_12basic_stringIcS3_NS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_15time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_15time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_15time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_15time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_15time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEC2ERKNS_12basic_stringIcNS2_IcEENS_9allocatorIcEEEEm = Module["__ZNSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEC2ERKNS_12basic_stringIcNS2_IcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEC2ERKNS_12basic_stringIcNS2_IcEENS_9allocatorIcEEEEm = Module["__ZNSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEC2ERKNS_12basic_stringIcNS2_IcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEC2ERKNS_12basic_stringIcNS2_IcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_15time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_15time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_15time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_15time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_15time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__215time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEC2ERKNS_12basic_stringIcS3_NS_9allocatorIcEEEEm = Module["__ZNSt3__215time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEC2ERKNS_12basic_stringIcS3_NS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__215time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEC2ERKNS_12basic_stringIcS3_NS_9allocatorIcEEEEm = Module["__ZNSt3__215time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEC2ERKNS_12basic_stringIcS3_NS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__215time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEC2ERKNS_12basic_stringIcS3_NS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_15time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_15time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_15time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_15time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_15time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__215time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEC2ERKNS_12basic_stringIcNS2_IcEENS_9allocatorIcEEEEm = Module["__ZNSt3__215time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEC2ERKNS_12basic_stringIcNS2_IcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__215time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEC2ERKNS_12basic_stringIcNS2_IcEENS_9allocatorIcEEEEm = Module["__ZNSt3__215time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEC2ERKNS_12basic_stringIcNS2_IcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__215time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEC2ERKNS_12basic_stringIcNS2_IcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_15time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_15time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_15time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_15time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_15time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__215messages_bynameIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__215messages_bynameIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__215messages_bynameIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__215messages_bynameIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__215messages_bynameIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_15messages_bynameIcEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_15messages_bynameIcEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_15messages_bynameIcEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_15messages_bynameIcEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_15messages_bynameIcEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__215messages_bynameIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__215messages_bynameIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__215messages_bynameIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__215messages_bynameIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__215messages_bynameIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp7installINS_15messages_bynameIwEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_15messages_bynameIwEEEEvPT_"] = function() {
                return (__ZNSt3__26locale5__imp7installINS_15messages_bynameIwEEEEvPT_ = Module["__ZNSt3__26locale5__imp7installINS_15messages_bynameIwEEEEvPT_"] = Module["asm"]["_ZNSt3__26locale5__imp7installINS_15messages_bynameIwEEEEvPT_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12make_classicEv = Module["__ZNSt3__26locale5__imp12make_classicEv"] = function() {
                return (__ZNSt3__26locale5__imp12make_classicEv = Module["__ZNSt3__26locale5__imp12make_classicEv"] = Module["asm"]["_ZNSt3__26locale5__imp12make_classicEv"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE19__copy_assign_allocERKS6_ = Module["__ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE19__copy_assign_allocERKS6_"] = function() {
                return (__ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE19__copy_assign_allocERKS6_ = Module["__ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE19__copy_assign_allocERKS6_"] = Module["asm"]["_ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE19__copy_assign_allocERKS6_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE6assignIPS3_EENS_9enable_ifIXaasr27__is_cpp17_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_ = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE6assignIPS3_EENS_9enable_ifIXaasr27__is_cpp17_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_"] = function() {
                return (__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE6assignIPS3_EENS_9enable_ifIXaasr27__is_cpp17_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_ = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE6assignIPS3_EENS_9enable_ifIXaasr27__is_cpp17_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_"] = Module["asm"]["_ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE6assignIPS3_EENS_9enable_ifIXaasr27__is_cpp17_forward_iteratorIT_EE5valuesr16is_constructibleIS3_NS_15iterator_traitsISA_E9referenceEEE5valueEvE4typeESA_SA_"]).apply(null, arguments)
            };
            var __ZNSt3__27codecvtIcc11__mbstate_tEC2EPKcm = Module["__ZNSt3__27codecvtIcc11__mbstate_tEC2EPKcm"] = function() {
                return (__ZNSt3__27codecvtIcc11__mbstate_tEC2EPKcm = Module["__ZNSt3__27codecvtIcc11__mbstate_tEC2EPKcm"] = Module["asm"]["_ZNSt3__27codecvtIcc11__mbstate_tEC2EPKcm"]).apply(null, arguments)
            };
            var __ZNSt3__27codecvtIwc11__mbstate_tEC2EPKcm = Module["__ZNSt3__27codecvtIwc11__mbstate_tEC2EPKcm"] = function() {
                return (__ZNSt3__27codecvtIwc11__mbstate_tEC2EPKcm = Module["__ZNSt3__27codecvtIwc11__mbstate_tEC2EPKcm"] = Module["asm"]["_ZNSt3__27codecvtIwc11__mbstate_tEC2EPKcm"]).apply(null, arguments)
            };
            var __ZNSt3__27codecvtIDsc11__mbstate_tEC2EPKcm = Module["__ZNSt3__27codecvtIDsc11__mbstate_tEC2EPKcm"] = function() {
                return (__ZNSt3__27codecvtIDsc11__mbstate_tEC2EPKcm = Module["__ZNSt3__27codecvtIDsc11__mbstate_tEC2EPKcm"] = Module["asm"]["_ZNSt3__27codecvtIDsc11__mbstate_tEC2EPKcm"]).apply(null, arguments)
            };
            var __ZNSt3__27codecvtIDic11__mbstate_tEC2EPKcm = Module["__ZNSt3__27codecvtIDic11__mbstate_tEC2EPKcm"] = function() {
                return (__ZNSt3__27codecvtIDic11__mbstate_tEC2EPKcm = Module["__ZNSt3__27codecvtIDic11__mbstate_tEC2EPKcm"] = Module["asm"]["_ZNSt3__27codecvtIDic11__mbstate_tEC2EPKcm"]).apply(null, arguments)
            };
            var __ZNSt3__217moneypunct_bynameIcLb0EE4initEPKc = Module["__ZNSt3__217moneypunct_bynameIcLb0EE4initEPKc"] = function() {
                return (__ZNSt3__217moneypunct_bynameIcLb0EE4initEPKc = Module["__ZNSt3__217moneypunct_bynameIcLb0EE4initEPKc"] = Module["asm"]["_ZNSt3__217moneypunct_bynameIcLb0EE4initEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__217moneypunct_bynameIcLb1EE4initEPKc = Module["__ZNSt3__217moneypunct_bynameIcLb1EE4initEPKc"] = function() {
                return (__ZNSt3__217moneypunct_bynameIcLb1EE4initEPKc = Module["__ZNSt3__217moneypunct_bynameIcLb1EE4initEPKc"] = Module["asm"]["_ZNSt3__217moneypunct_bynameIcLb1EE4initEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__217moneypunct_bynameIwLb0EE4initEPKc = Module["__ZNSt3__217moneypunct_bynameIwLb0EE4initEPKc"] = function() {
                return (__ZNSt3__217moneypunct_bynameIwLb0EE4initEPKc = Module["__ZNSt3__217moneypunct_bynameIwLb0EE4initEPKc"] = Module["asm"]["_ZNSt3__217moneypunct_bynameIwLb0EE4initEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__217moneypunct_bynameIwLb1EE4initEPKc = Module["__ZNSt3__217moneypunct_bynameIwLb1EE4initEPKc"] = function() {
                return (__ZNSt3__217moneypunct_bynameIwLb1EE4initEPKc = Module["__ZNSt3__217moneypunct_bynameIwLb1EE4initEPKc"] = Module["asm"]["_ZNSt3__217moneypunct_bynameIwLb1EE4initEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__218__time_get_storageIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__218__time_get_storageIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = function() {
                return (__ZNSt3__218__time_get_storageIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__218__time_get_storageIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = Module["asm"]["_ZNSt3__218__time_get_storageIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNSt3__218__time_get_storageIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__218__time_get_storageIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = function() {
                return (__ZNSt3__218__time_get_storageIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__218__time_get_storageIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = Module["asm"]["_ZNSt3__218__time_get_storageIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEC2ERKNS_12basic_stringIcS3_NS_9allocatorIcEEEEm = Module["__ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEC2ERKNS_12basic_stringIcS3_NS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEC2ERKNS_12basic_stringIcS3_NS_9allocatorIcEEEEm = Module["__ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEC2ERKNS_12basic_stringIcS3_NS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEC2ERKNS_12basic_stringIcS3_NS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEC2ERKNS_12basic_stringIcNS2_IcEENS_9allocatorIcEEEEm = Module["__ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEC2ERKNS_12basic_stringIcNS2_IcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEC2ERKNS_12basic_stringIcNS2_IcEENS_9allocatorIcEEEEm = Module["__ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEC2ERKNS_12basic_stringIcNS2_IcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEC2ERKNS_12basic_stringIcNS2_IcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__impC2ERKS1_ = Module["__ZNSt3__26locale5__impC2ERKS1_"] = function() {
                return (__ZNSt3__26locale5__impC2ERKS1_ = Module["__ZNSt3__26locale5__impC2ERKS1_"] = Module["asm"]["_ZNSt3__26locale5__impC2ERKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__impC2ERKS1_RKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEi = Module["__ZNSt3__26locale5__impC2ERKS1_RKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEi"] = function() {
                return (__ZNSt3__26locale5__impC2ERKS1_RKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEi = Module["__ZNSt3__26locale5__impC2ERKS1_RKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEi"] = Module["asm"]["_ZNSt3__26locale5__impC2ERKS1_RKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEi"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__impC2ERKS1_S3_i = Module["__ZNSt3__26locale5__impC2ERKS1_S3_i"] = function() {
                return (__ZNSt3__26locale5__impC2ERKS1_S3_i = Module["__ZNSt3__26locale5__impC2ERKS1_S3_i"] = Module["asm"]["_ZNSt3__26locale5__impC2ERKS1_S3_i"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_7collateIcEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_7collateIcEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_7collateIcEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_7collateIcEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_7collateIcEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_7collateIwEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_7collateIwEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_7collateIwEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_7collateIwEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_7collateIwEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_5ctypeIcEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_5ctypeIcEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_5ctypeIcEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_5ctypeIcEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_5ctypeIcEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_5ctypeIwEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_5ctypeIwEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_5ctypeIwEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_5ctypeIwEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_5ctypeIwEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_7codecvtIcc11__mbstate_tEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_7codecvtIcc11__mbstate_tEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_7codecvtIcc11__mbstate_tEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_7codecvtIcc11__mbstate_tEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_7codecvtIcc11__mbstate_tEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_7codecvtIDsc11__mbstate_tEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_7codecvtIDsc11__mbstate_tEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_7codecvtIDsc11__mbstate_tEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_7codecvtIDsc11__mbstate_tEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_7codecvtIDsc11__mbstate_tEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_7codecvtIDic11__mbstate_tEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_7codecvtIDic11__mbstate_tEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_7codecvtIDic11__mbstate_tEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_7codecvtIDic11__mbstate_tEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_7codecvtIDic11__mbstate_tEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_7codecvtIwc11__mbstate_tEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_7codecvtIwc11__mbstate_tEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_7codecvtIwc11__mbstate_tEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_7codecvtIwc11__mbstate_tEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_7codecvtIwc11__mbstate_tEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_10moneypunctIcLb0EEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_10moneypunctIcLb0EEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_10moneypunctIcLb0EEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_10moneypunctIcLb0EEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_10moneypunctIcLb0EEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_10moneypunctIcLb1EEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_10moneypunctIcLb1EEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_10moneypunctIcLb1EEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_10moneypunctIcLb1EEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_10moneypunctIcLb1EEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_10moneypunctIwLb0EEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_10moneypunctIwLb0EEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_10moneypunctIwLb0EEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_10moneypunctIwLb0EEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_10moneypunctIwLb0EEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_10moneypunctIwLb1EEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_10moneypunctIwLb1EEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_10moneypunctIwLb1EEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_10moneypunctIwLb1EEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_10moneypunctIwLb1EEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_9money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_9money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_9money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_9money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_9money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_9money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_9money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_9money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_9money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_9money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_9money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_9money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_9money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_9money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_9money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_9money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_9money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_9money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_9money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_9money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_8numpunctIcEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_8numpunctIcEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_8numpunctIcEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_8numpunctIcEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_8numpunctIcEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_8numpunctIwEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_8numpunctIwEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_8numpunctIwEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_8numpunctIwEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_8numpunctIwEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_7num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_7num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_7num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_7num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_7num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_7num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_7num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_7num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_7num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_7num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_7num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_7num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_7num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_7num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_7num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_7num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_7num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_7num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_7num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_7num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_8time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_8time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_8time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_8time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_8time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_8time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_8time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_8time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_8time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_8time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_8time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_8time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_8time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_8time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_8time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_8time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_8time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_8time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_8time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_8time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_8messagesIcEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_8messagesIcEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_8messagesIcEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_8messagesIcEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_8messagesIcEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp12install_fromINS_8messagesIwEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_8messagesIwEEEEvRKS1_"] = function() {
                return (__ZNSt3__26locale5__imp12install_fromINS_8messagesIwEEEEvRKS1_ = Module["__ZNSt3__26locale5__imp12install_fromINS_8messagesIwEEEEvRKS1_"] = Module["asm"]["_ZNSt3__26locale5__imp12install_fromINS_8messagesIwEEEEvRKS1_"]).apply(null, arguments)
            };
            var __ZNKSt3__26locale5__imp9use_facetEl = Module["__ZNKSt3__26locale5__imp9use_facetEl"] = function() {
                return (__ZNKSt3__26locale5__imp9use_facetEl = Module["__ZNKSt3__26locale5__imp9use_facetEl"] = Module["asm"]["_ZNKSt3__26locale5__imp9use_facetEl"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__impC2ERKS1_PNS0_5facetEl = Module["__ZNSt3__26locale5__impC2ERKS1_PNS0_5facetEl"] = function() {
                return (__ZNSt3__26locale5__impC2ERKS1_PNS0_5facetEl = Module["__ZNSt3__26locale5__impC2ERKS1_PNS0_5facetEl"] = Module["asm"]["_ZNSt3__26locale5__impC2ERKS1_PNS0_5facetEl"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE6resizeEm = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE6resizeEm"] = function() {
                return (__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE6resizeEm = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE6resizeEm"] = Module["asm"]["_ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE6resizeEm"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__impD2Ev = Module["__ZNSt3__26locale5__impD2Ev"] = function() {
                return (__ZNSt3__26locale5__impD2Ev = Module["__ZNSt3__26locale5__impD2Ev"] = Module["asm"]["_ZNSt3__26locale5__impD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEED2Ev = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEED2Ev"] = function() {
                return (__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEED2Ev = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEED2Ev"] = Module["asm"]["_ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEED2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE17__annotate_deleteEv = Module["__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE17__annotate_deleteEv"] = function() {
                return (__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE17__annotate_deleteEv = Module["__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE17__annotate_deleteEv"] = Module["asm"]["_ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE17__annotate_deleteEv"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEED2Ev = Module["__ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEED2Ev"] = function() {
                return (__ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEED2Ev = Module["__ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEED2Ev"] = Module["asm"]["_ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__impD0Ev = Module["__ZNSt3__26locale5__impD0Ev"] = function() {
                return (__ZNSt3__26locale5__impD0Ev = Module["__ZNSt3__26locale5__impD0Ev"] = Module["asm"]["_ZNSt3__26locale5__impD0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE8__appendEm = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE8__appendEm"] = function() {
                return (__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE8__appendEm = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE8__appendEm"] = Module["asm"]["_ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE8__appendEm"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE17__destruct_at_endEPS3_ = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE17__destruct_at_endEPS3_"] = function() {
                return (__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE17__destruct_at_endEPS3_ = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE17__destruct_at_endEPS3_"] = Module["asm"]["_ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE17__destruct_at_endEPS3_"]).apply(null, arguments)
            };
            var __ZNKSt3__26locale5__imp9has_facetEl = Module["__ZNKSt3__26locale5__imp9has_facetEl"] = function() {
                return (__ZNKSt3__26locale5__imp9has_facetEl = Module["__ZNKSt3__26locale5__imp9has_facetEl"] = Module["asm"]["_ZNKSt3__26locale5__imp9has_facetEl"]).apply(null, arguments)
            };
            var __ZNSt3__216__throw_bad_castEv = Module["__ZNSt3__216__throw_bad_castEv"] = function() {
                return (__ZNSt3__216__throw_bad_castEv = Module["__ZNSt3__216__throw_bad_castEv"] = Module["asm"]["_ZNSt3__216__throw_bad_castEv"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEixEm = Module["__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEixEm"] = function() {
                return (__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEixEm = Module["__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEixEm"] = Module["asm"]["_ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEixEm"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__imp11make_globalEv = Module["__ZNSt3__26locale5__imp11make_globalEv"] = function() {
                return (__ZNSt3__26locale5__imp11make_globalEv = Module["__ZNSt3__26locale5__imp11make_globalEv"] = Module["asm"]["_ZNSt3__26locale5__imp11make_globalEv"]).apply(null, arguments)
            };
            var __ZNSt3__26localeC2ERKS0_ = Module["__ZNSt3__26localeC2ERKS0_"] = function() {
                return (__ZNSt3__26localeC2ERKS0_ = Module["__ZNSt3__26localeC2ERKS0_"] = Module["asm"]["_ZNSt3__26localeC2ERKS0_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale8__globalEv = Module["__ZNSt3__26locale8__globalEv"] = function() {
                return (__ZNSt3__26locale8__globalEv = Module["__ZNSt3__26locale8__globalEv"] = Module["asm"]["_ZNSt3__26locale8__globalEv"]).apply(null, arguments)
            };
            var __ZNSt3__26localeC2Ev = Module["__ZNSt3__26localeC2Ev"] = function() {
                return (__ZNSt3__26localeC2Ev = Module["__ZNSt3__26localeC2Ev"] = Module["asm"]["_ZNSt3__26localeC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__26localeaSERKS0_ = Module["__ZNSt3__26localeaSERKS0_"] = function() {
                return (__ZNSt3__26localeaSERKS0_ = Module["__ZNSt3__26localeaSERKS0_"] = Module["asm"]["_ZNSt3__26localeaSERKS0_"]).apply(null, arguments)
            };
            var __ZNSt3__26localeC2EPKc = Module["__ZNSt3__26localeC2EPKc"] = function() {
                return (__ZNSt3__26localeC2EPKc = Module["__ZNSt3__26localeC2EPKc"] = Module["asm"]["_ZNSt3__26localeC2EPKc"]).apply(null, arguments)
            };
            var __ZNSt3__26localeC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__26localeC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = function() {
                return (__ZNSt3__26localeC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__26localeC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = Module["asm"]["_ZNSt3__26localeC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNSt3__26localeC2ERKS0_PKci = Module["__ZNSt3__26localeC2ERKS0_PKci"] = function() {
                return (__ZNSt3__26localeC2ERKS0_PKci = Module["__ZNSt3__26localeC2ERKS0_PKci"] = Module["asm"]["_ZNSt3__26localeC2ERKS0_PKci"]).apply(null, arguments)
            };
            var __ZNSt3__26localeC2ERKS0_RKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEi = Module["__ZNSt3__26localeC2ERKS0_RKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEi"] = function() {
                return (__ZNSt3__26localeC2ERKS0_RKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEi = Module["__ZNSt3__26localeC2ERKS0_RKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEi"] = Module["asm"]["_ZNSt3__26localeC2ERKS0_RKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEi"]).apply(null, arguments)
            };
            var __ZNSt3__26localeC2ERKS0_S2_i = Module["__ZNSt3__26localeC2ERKS0_S2_i"] = function() {
                return (__ZNSt3__26localeC2ERKS0_S2_i = Module["__ZNSt3__26localeC2ERKS0_S2_i"] = Module["asm"]["_ZNSt3__26localeC2ERKS0_S2_i"]).apply(null, arguments)
            };
            var __ZNKSt3__26locale4nameEv = Module["__ZNKSt3__26locale4nameEv"] = function() {
                return (__ZNKSt3__26locale4nameEv = Module["__ZNKSt3__26locale4nameEv"] = Module["asm"]["_ZNKSt3__26locale4nameEv"]).apply(null, arguments)
            };
            var __ZNKSt3__26locale5__imp4nameEv = Module["__ZNKSt3__26locale5__imp4nameEv"] = function() {
                return (__ZNKSt3__26locale5__imp4nameEv = Module["__ZNKSt3__26locale5__imp4nameEv"] = Module["asm"]["_ZNKSt3__26locale5__imp4nameEv"]).apply(null, arguments)
            };
            var __ZNSt3__26locale14__install_ctorERKS0_PNS0_5facetEl = Module["__ZNSt3__26locale14__install_ctorERKS0_PNS0_5facetEl"] = function() {
                return (__ZNSt3__26locale14__install_ctorERKS0_PNS0_5facetEl = Module["__ZNSt3__26locale14__install_ctorERKS0_PNS0_5facetEl"] = Module["asm"]["_ZNSt3__26locale14__install_ctorERKS0_PNS0_5facetEl"]).apply(null, arguments)
            };
            var __ZNSt3__26locale6globalERKS0_ = Module["__ZNSt3__26locale6globalERKS0_"] = function() {
                return (__ZNSt3__26locale6globalERKS0_ = Module["__ZNSt3__26locale6globalERKS0_"] = Module["asm"]["_ZNSt3__26locale6globalERKS0_"]).apply(null, arguments)
            };
            var __ZNSt3__2neIcNS_11char_traitsIcEENS_9allocatorIcEEEEbRKNS_12basic_stringIT_T0_T1_EEPKS6_ = Module["__ZNSt3__2neIcNS_11char_traitsIcEENS_9allocatorIcEEEEbRKNS_12basic_stringIT_T0_T1_EEPKS6_"] = function() {
                return (__ZNSt3__2neIcNS_11char_traitsIcEENS_9allocatorIcEEEEbRKNS_12basic_stringIT_T0_T1_EEPKS6_ = Module["__ZNSt3__2neIcNS_11char_traitsIcEENS_9allocatorIcEEEEbRKNS_12basic_stringIT_T0_T1_EEPKS6_"] = Module["asm"]["_ZNSt3__2neIcNS_11char_traitsIcEENS_9allocatorIcEEEEbRKNS_12basic_stringIT_T0_T1_EEPKS6_"]).apply(null, arguments)
            };
            var __ZNSt3__2eqIcNS_11char_traitsIcEENS_9allocatorIcEEEEbRKNS_12basic_stringIT_T0_T1_EEPKS6_ = Module["__ZNSt3__2eqIcNS_11char_traitsIcEENS_9allocatorIcEEEEbRKNS_12basic_stringIT_T0_T1_EEPKS6_"] = function() {
                return (__ZNSt3__2eqIcNS_11char_traitsIcEENS_9allocatorIcEEEEbRKNS_12basic_stringIT_T0_T1_EEPKS6_ = Module["__ZNSt3__2eqIcNS_11char_traitsIcEENS_9allocatorIcEEEEbRKNS_12basic_stringIT_T0_T1_EEPKS6_"] = Module["asm"]["_ZNSt3__2eqIcNS_11char_traitsIcEENS_9allocatorIcEEEEbRKNS_12basic_stringIT_T0_T1_EEPKS6_"]).apply(null, arguments)
            };
            var __ZNKSt3__26locale9has_facetERNS0_2idE = Module["__ZNKSt3__26locale9has_facetERNS0_2idE"] = function() {
                return (__ZNKSt3__26locale9has_facetERNS0_2idE = Module["__ZNKSt3__26locale9has_facetERNS0_2idE"] = Module["asm"]["_ZNKSt3__26locale9has_facetERNS0_2idE"]).apply(null, arguments)
            };
            var __ZNSt3__26locale2id6__initEv = Module["__ZNSt3__26locale2id6__initEv"] = function() {
                return (__ZNSt3__26locale2id6__initEv = Module["__ZNSt3__26locale2id6__initEv"] = Module["asm"]["_ZNSt3__26locale2id6__initEv"]).apply(null, arguments)
            };
            var __ZNKSt3__26localeeqERKS0_ = Module["__ZNKSt3__26localeeqERKS0_"] = function() {
                return (__ZNKSt3__26localeeqERKS0_ = Module["__ZNKSt3__26localeeqERKS0_"] = Module["asm"]["_ZNKSt3__26localeeqERKS0_"]).apply(null, arguments)
            };
            var __ZNSt3__2eqINS_9allocatorIcEEEEbRKNS_12basic_stringIcNS_11char_traitsIcEET_EES9_ = Module["__ZNSt3__2eqINS_9allocatorIcEEEEbRKNS_12basic_stringIcNS_11char_traitsIcEET_EES9_"] = function() {
                return (__ZNSt3__2eqINS_9allocatorIcEEEEbRKNS_12basic_stringIcNS_11char_traitsIcEET_EES9_ = Module["__ZNSt3__2eqINS_9allocatorIcEEEEbRKNS_12basic_stringIcNS_11char_traitsIcEET_EES9_"] = Module["asm"]["_ZNSt3__2eqINS_9allocatorIcEEEEbRKNS_12basic_stringIcNS_11char_traitsIcEET_EES9_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5facetD0Ev = Module["__ZNSt3__26locale5facetD0Ev"] = function() {
                return (__ZNSt3__26locale5facetD0Ev = Module["__ZNSt3__26locale5facetD0Ev"] = Module["asm"]["_ZNSt3__26locale5facetD0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5facet16__on_zero_sharedEv = Module["__ZNSt3__26locale5facet16__on_zero_sharedEv"] = function() {
                return (__ZNSt3__26locale5facet16__on_zero_sharedEv = Module["__ZNSt3__26locale5facet16__on_zero_sharedEv"] = Module["asm"]["_ZNSt3__26locale5facet16__on_zero_sharedEv"]).apply(null, arguments)
            };
            var __ZNSt3__221__libcpp_acquire_loadImEET_PKS1_ = Module["__ZNSt3__221__libcpp_acquire_loadImEET_PKS1_"] = function() {
                return (__ZNSt3__221__libcpp_acquire_loadImEET_PKS1_ = Module["__ZNSt3__221__libcpp_acquire_loadImEET_PKS1_"] = Module["asm"]["_ZNSt3__221__libcpp_acquire_loadImEET_PKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__214collate_bynameIcEC2EPKcm = Module["__ZNSt3__214collate_bynameIcEC2EPKcm"] = function() {
                return (__ZNSt3__214collate_bynameIcEC2EPKcm = Module["__ZNSt3__214collate_bynameIcEC2EPKcm"] = Module["asm"]["_ZNSt3__214collate_bynameIcEC2EPKcm"]).apply(null, arguments)
            };
            var __ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_OS9_ = Module["__ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_OS9_"] = function() {
                return (__ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_OS9_ = Module["__ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_OS9_"] = Module["asm"]["_ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEPKS6_OS9_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEEONS_16remove_referenceIT_E4typeEOS9_ = Module["__ZNSt3__24moveIRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEEONS_16remove_referenceIT_E4typeEOS9_"] = function() {
                return (__ZNSt3__24moveIRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEEONS_16remove_referenceIT_E4typeEOS9_ = Module["__ZNSt3__24moveIRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEEONS_16remove_referenceIT_E4typeEOS9_"] = Module["asm"]["_ZNSt3__24moveIRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEEONS_16remove_referenceIT_E4typeEOS9_"]).apply(null, arguments)
            };
            var __ZNSt3__214collate_bynameIcED2Ev = Module["__ZNSt3__214collate_bynameIcED2Ev"] = function() {
                return (__ZNSt3__214collate_bynameIcED2Ev = Module["__ZNSt3__214collate_bynameIcED2Ev"] = Module["asm"]["_ZNSt3__214collate_bynameIcED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214collate_bynameIcED0Ev = Module["__ZNSt3__214collate_bynameIcED0Ev"] = function() {
                return (__ZNSt3__214collate_bynameIcED0Ev = Module["__ZNSt3__214collate_bynameIcED0Ev"] = Module["asm"]["_ZNSt3__214collate_bynameIcED0Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__214collate_bynameIcE10do_compareEPKcS3_S3_S3_ = Module["__ZNKSt3__214collate_bynameIcE10do_compareEPKcS3_S3_S3_"] = function() {
                return (__ZNKSt3__214collate_bynameIcE10do_compareEPKcS3_S3_S3_ = Module["__ZNKSt3__214collate_bynameIcE10do_compareEPKcS3_S3_S3_"] = Module["asm"]["_ZNKSt3__214collate_bynameIcE10do_compareEPKcS3_S3_S3_"]).apply(null, arguments)
            };
            var __ZNKSt3__214collate_bynameIcE12do_transformEPKcS3_ = Module["__ZNKSt3__214collate_bynameIcE12do_transformEPKcS3_"] = function() {
                return (__ZNKSt3__214collate_bynameIcE12do_transformEPKcS3_ = Module["__ZNKSt3__214collate_bynameIcE12do_transformEPKcS3_"] = Module["asm"]["_ZNKSt3__214collate_bynameIcE12do_transformEPKcS3_"]).apply(null, arguments)
            };
            var __ZNSt3__214collate_bynameIwEC2EPKcm = Module["__ZNSt3__214collate_bynameIwEC2EPKcm"] = function() {
                return (__ZNSt3__214collate_bynameIwEC2EPKcm = Module["__ZNSt3__214collate_bynameIwEC2EPKcm"] = Module["asm"]["_ZNSt3__214collate_bynameIwEC2EPKcm"]).apply(null, arguments)
            };
            var __ZNSt3__214collate_bynameIwED2Ev = Module["__ZNSt3__214collate_bynameIwED2Ev"] = function() {
                return (__ZNSt3__214collate_bynameIwED2Ev = Module["__ZNSt3__214collate_bynameIwED2Ev"] = Module["asm"]["_ZNSt3__214collate_bynameIwED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214collate_bynameIwED0Ev = Module["__ZNSt3__214collate_bynameIwED0Ev"] = function() {
                return (__ZNSt3__214collate_bynameIwED0Ev = Module["__ZNSt3__214collate_bynameIwED0Ev"] = Module["asm"]["_ZNSt3__214collate_bynameIwED0Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__214collate_bynameIwE10do_compareEPKwS3_S3_S3_ = Module["__ZNKSt3__214collate_bynameIwE10do_compareEPKwS3_S3_S3_"] = function() {
                return (__ZNKSt3__214collate_bynameIwE10do_compareEPKwS3_S3_S3_ = Module["__ZNKSt3__214collate_bynameIwE10do_compareEPKwS3_S3_S3_"] = Module["asm"]["_ZNKSt3__214collate_bynameIwE10do_compareEPKwS3_S3_S3_"]).apply(null, arguments)
            };
            var __ZNKSt3__214collate_bynameIwE12do_transformEPKwS3_ = Module["__ZNKSt3__214collate_bynameIwE12do_transformEPKwS3_"] = function() {
                return (__ZNKSt3__214collate_bynameIwE12do_transformEPKwS3_ = Module["__ZNKSt3__214collate_bynameIwE12do_transformEPKwS3_"] = Module["asm"]["_ZNKSt3__214collate_bynameIwE12do_transformEPKwS3_"]).apply(null, arguments)
            };
            var __ZNSt3__25ctypeIwED0Ev = Module["__ZNSt3__25ctypeIwED0Ev"] = function() {
                return (__ZNSt3__25ctypeIwED0Ev = Module["__ZNSt3__25ctypeIwED0Ev"] = Module["asm"]["_ZNSt3__25ctypeIwED0Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIwE5do_isEtw = Module["__ZNKSt3__25ctypeIwE5do_isEtw"] = function() {
                return (__ZNKSt3__25ctypeIwE5do_isEtw = Module["__ZNKSt3__25ctypeIwE5do_isEtw"] = Module["asm"]["_ZNKSt3__25ctypeIwE5do_isEtw"]).apply(null, arguments)
            };
            var __ZNSt3__25ctypeIcE13classic_tableEv = Module["__ZNSt3__25ctypeIcE13classic_tableEv"] = function() {
                return (__ZNSt3__25ctypeIcE13classic_tableEv = Module["__ZNSt3__25ctypeIcE13classic_tableEv"] = Module["asm"]["_ZNSt3__25ctypeIcE13classic_tableEv"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIwE5do_isEPKwS3_Pt = Module["__ZNKSt3__25ctypeIwE5do_isEPKwS3_Pt"] = function() {
                return (__ZNKSt3__25ctypeIwE5do_isEPKwS3_Pt = Module["__ZNKSt3__25ctypeIwE5do_isEPKwS3_Pt"] = Module["asm"]["_ZNKSt3__25ctypeIwE5do_isEPKwS3_Pt"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIwE10do_scan_isEtPKwS3_ = Module["__ZNKSt3__25ctypeIwE10do_scan_isEtPKwS3_"] = function() {
                return (__ZNKSt3__25ctypeIwE10do_scan_isEtPKwS3_ = Module["__ZNKSt3__25ctypeIwE10do_scan_isEtPKwS3_"] = Module["asm"]["_ZNKSt3__25ctypeIwE10do_scan_isEtPKwS3_"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIwE11do_scan_notEtPKwS3_ = Module["__ZNKSt3__25ctypeIwE11do_scan_notEtPKwS3_"] = function() {
                return (__ZNKSt3__25ctypeIwE11do_scan_notEtPKwS3_ = Module["__ZNKSt3__25ctypeIwE11do_scan_notEtPKwS3_"] = Module["asm"]["_ZNKSt3__25ctypeIwE11do_scan_notEtPKwS3_"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIwE10do_toupperEw = Module["__ZNKSt3__25ctypeIwE10do_toupperEw"] = function() {
                return (__ZNKSt3__25ctypeIwE10do_toupperEw = Module["__ZNKSt3__25ctypeIwE10do_toupperEw"] = Module["asm"]["_ZNKSt3__25ctypeIwE10do_toupperEw"]).apply(null, arguments)
            };
            var __ZNSt3__25ctypeIcE21__classic_upper_tableEv = Module["__ZNSt3__25ctypeIcE21__classic_upper_tableEv"] = function() {
                return (__ZNSt3__25ctypeIcE21__classic_upper_tableEv = Module["__ZNSt3__25ctypeIcE21__classic_upper_tableEv"] = Module["asm"]["_ZNSt3__25ctypeIcE21__classic_upper_tableEv"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIwE10do_toupperEPwPKw = Module["__ZNKSt3__25ctypeIwE10do_toupperEPwPKw"] = function() {
                return (__ZNKSt3__25ctypeIwE10do_toupperEPwPKw = Module["__ZNKSt3__25ctypeIwE10do_toupperEPwPKw"] = Module["asm"]["_ZNKSt3__25ctypeIwE10do_toupperEPwPKw"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIwE10do_tolowerEw = Module["__ZNKSt3__25ctypeIwE10do_tolowerEw"] = function() {
                return (__ZNKSt3__25ctypeIwE10do_tolowerEw = Module["__ZNKSt3__25ctypeIwE10do_tolowerEw"] = Module["asm"]["_ZNKSt3__25ctypeIwE10do_tolowerEw"]).apply(null, arguments)
            };
            var __ZNSt3__25ctypeIcE21__classic_lower_tableEv = Module["__ZNSt3__25ctypeIcE21__classic_lower_tableEv"] = function() {
                return (__ZNSt3__25ctypeIcE21__classic_lower_tableEv = Module["__ZNSt3__25ctypeIcE21__classic_lower_tableEv"] = Module["asm"]["_ZNSt3__25ctypeIcE21__classic_lower_tableEv"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIwE10do_tolowerEPwPKw = Module["__ZNKSt3__25ctypeIwE10do_tolowerEPwPKw"] = function() {
                return (__ZNKSt3__25ctypeIwE10do_tolowerEPwPKw = Module["__ZNKSt3__25ctypeIwE10do_tolowerEPwPKw"] = Module["asm"]["_ZNKSt3__25ctypeIwE10do_tolowerEPwPKw"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIwE8do_widenEc = Module["__ZNKSt3__25ctypeIwE8do_widenEc"] = function() {
                return (__ZNKSt3__25ctypeIwE8do_widenEc = Module["__ZNKSt3__25ctypeIwE8do_widenEc"] = Module["asm"]["_ZNKSt3__25ctypeIwE8do_widenEc"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIwE8do_widenEPKcS3_Pw = Module["__ZNKSt3__25ctypeIwE8do_widenEPKcS3_Pw"] = function() {
                return (__ZNKSt3__25ctypeIwE8do_widenEPKcS3_Pw = Module["__ZNKSt3__25ctypeIwE8do_widenEPKcS3_Pw"] = Module["asm"]["_ZNKSt3__25ctypeIwE8do_widenEPKcS3_Pw"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIwE9do_narrowEwc = Module["__ZNKSt3__25ctypeIwE9do_narrowEwc"] = function() {
                return (__ZNKSt3__25ctypeIwE9do_narrowEwc = Module["__ZNKSt3__25ctypeIwE9do_narrowEwc"] = Module["asm"]["_ZNKSt3__25ctypeIwE9do_narrowEwc"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIwE9do_narrowEPKwS3_cPc = Module["__ZNKSt3__25ctypeIwE9do_narrowEPKwS3_cPc"] = function() {
                return (__ZNKSt3__25ctypeIwE9do_narrowEPKwS3_cPc = Module["__ZNKSt3__25ctypeIwE9do_narrowEPKwS3_cPc"] = Module["asm"]["_ZNKSt3__25ctypeIwE9do_narrowEPKwS3_cPc"]).apply(null, arguments)
            };
            var __ZNSt3__210ctype_baseC2Ev = Module["__ZNSt3__210ctype_baseC2Ev"] = function() {
                return (__ZNSt3__210ctype_baseC2Ev = Module["__ZNSt3__210ctype_baseC2Ev"] = Module["asm"]["_ZNSt3__210ctype_baseC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__25ctypeIcED2Ev = Module["__ZNSt3__25ctypeIcED2Ev"] = function() {
                return (__ZNSt3__25ctypeIcED2Ev = Module["__ZNSt3__25ctypeIcED2Ev"] = Module["asm"]["_ZNSt3__25ctypeIcED2Ev"]).apply(null, arguments)
            };
            var __ZdaPv = Module["__ZdaPv"] = function() {
                return (__ZdaPv = Module["__ZdaPv"] = Module["asm"]["_ZdaPv"]).apply(null, arguments)
            };
            var __ZNSt3__25ctypeIcED0Ev = Module["__ZNSt3__25ctypeIcED0Ev"] = function() {
                return (__ZNSt3__25ctypeIcED0Ev = Module["__ZNSt3__25ctypeIcED0Ev"] = Module["asm"]["_ZNSt3__25ctypeIcED0Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIcE10do_toupperEc = Module["__ZNKSt3__25ctypeIcE10do_toupperEc"] = function() {
                return (__ZNKSt3__25ctypeIcE10do_toupperEc = Module["__ZNKSt3__25ctypeIcE10do_toupperEc"] = Module["asm"]["_ZNKSt3__25ctypeIcE10do_toupperEc"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIcE10do_toupperEPcPKc = Module["__ZNKSt3__25ctypeIcE10do_toupperEPcPKc"] = function() {
                return (__ZNKSt3__25ctypeIcE10do_toupperEPcPKc = Module["__ZNKSt3__25ctypeIcE10do_toupperEPcPKc"] = Module["asm"]["_ZNKSt3__25ctypeIcE10do_toupperEPcPKc"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIcE10do_tolowerEc = Module["__ZNKSt3__25ctypeIcE10do_tolowerEc"] = function() {
                return (__ZNKSt3__25ctypeIcE10do_tolowerEc = Module["__ZNKSt3__25ctypeIcE10do_tolowerEc"] = Module["asm"]["_ZNKSt3__25ctypeIcE10do_tolowerEc"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIcE10do_tolowerEPcPKc = Module["__ZNKSt3__25ctypeIcE10do_tolowerEPcPKc"] = function() {
                return (__ZNKSt3__25ctypeIcE10do_tolowerEPcPKc = Module["__ZNKSt3__25ctypeIcE10do_tolowerEPcPKc"] = Module["asm"]["_ZNKSt3__25ctypeIcE10do_tolowerEPcPKc"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIcE8do_widenEc = Module["__ZNKSt3__25ctypeIcE8do_widenEc"] = function() {
                return (__ZNKSt3__25ctypeIcE8do_widenEc = Module["__ZNKSt3__25ctypeIcE8do_widenEc"] = Module["asm"]["_ZNKSt3__25ctypeIcE8do_widenEc"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIcE8do_widenEPKcS3_Pc = Module["__ZNKSt3__25ctypeIcE8do_widenEPKcS3_Pc"] = function() {
                return (__ZNKSt3__25ctypeIcE8do_widenEPKcS3_Pc = Module["__ZNKSt3__25ctypeIcE8do_widenEPKcS3_Pc"] = Module["asm"]["_ZNKSt3__25ctypeIcE8do_widenEPKcS3_Pc"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIcE9do_narrowEcc = Module["__ZNKSt3__25ctypeIcE9do_narrowEcc"] = function() {
                return (__ZNKSt3__25ctypeIcE9do_narrowEcc = Module["__ZNKSt3__25ctypeIcE9do_narrowEcc"] = Module["asm"]["_ZNKSt3__25ctypeIcE9do_narrowEcc"]).apply(null, arguments)
            };
            var __ZNKSt3__25ctypeIcE9do_narrowEPKcS3_cPc = Module["__ZNKSt3__25ctypeIcE9do_narrowEPKcS3_cPc"] = function() {
                return (__ZNKSt3__25ctypeIcE9do_narrowEPKcS3_cPc = Module["__ZNKSt3__25ctypeIcE9do_narrowEPKcS3_cPc"] = Module["asm"]["_ZNKSt3__25ctypeIcE9do_narrowEPKcS3_cPc"]).apply(null, arguments)
            };
            var __ZNSt3__212ctype_bynameIcEC2EPKcm = Module["__ZNSt3__212ctype_bynameIcEC2EPKcm"] = function() {
                return (__ZNSt3__212ctype_bynameIcEC2EPKcm = Module["__ZNSt3__212ctype_bynameIcEC2EPKcm"] = Module["asm"]["_ZNSt3__212ctype_bynameIcEC2EPKcm"]).apply(null, arguments)
            };
            var __ZNSt3__212ctype_bynameIcED0Ev = Module["__ZNSt3__212ctype_bynameIcED0Ev"] = function() {
                return (__ZNSt3__212ctype_bynameIcED0Ev = Module["__ZNSt3__212ctype_bynameIcED0Ev"] = Module["asm"]["_ZNSt3__212ctype_bynameIcED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212ctype_bynameIcED2Ev = Module["__ZNSt3__212ctype_bynameIcED2Ev"] = function() {
                return (__ZNSt3__212ctype_bynameIcED2Ev = Module["__ZNSt3__212ctype_bynameIcED2Ev"] = Module["asm"]["_ZNSt3__212ctype_bynameIcED2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__212ctype_bynameIcE10do_toupperEc = Module["__ZNKSt3__212ctype_bynameIcE10do_toupperEc"] = function() {
                return (__ZNKSt3__212ctype_bynameIcE10do_toupperEc = Module["__ZNKSt3__212ctype_bynameIcE10do_toupperEc"] = Module["asm"]["_ZNKSt3__212ctype_bynameIcE10do_toupperEc"]).apply(null, arguments)
            };
            var __ZNKSt3__212ctype_bynameIcE10do_toupperEPcPKc = Module["__ZNKSt3__212ctype_bynameIcE10do_toupperEPcPKc"] = function() {
                return (__ZNKSt3__212ctype_bynameIcE10do_toupperEPcPKc = Module["__ZNKSt3__212ctype_bynameIcE10do_toupperEPcPKc"] = Module["asm"]["_ZNKSt3__212ctype_bynameIcE10do_toupperEPcPKc"]).apply(null, arguments)
            };
            var __ZNKSt3__212ctype_bynameIcE10do_tolowerEc = Module["__ZNKSt3__212ctype_bynameIcE10do_tolowerEc"] = function() {
                return (__ZNKSt3__212ctype_bynameIcE10do_tolowerEc = Module["__ZNKSt3__212ctype_bynameIcE10do_tolowerEc"] = Module["asm"]["_ZNKSt3__212ctype_bynameIcE10do_tolowerEc"]).apply(null, arguments)
            };
            var __ZNKSt3__212ctype_bynameIcE10do_tolowerEPcPKc = Module["__ZNKSt3__212ctype_bynameIcE10do_tolowerEPcPKc"] = function() {
                return (__ZNKSt3__212ctype_bynameIcE10do_tolowerEPcPKc = Module["__ZNKSt3__212ctype_bynameIcE10do_tolowerEPcPKc"] = Module["asm"]["_ZNKSt3__212ctype_bynameIcE10do_tolowerEPcPKc"]).apply(null, arguments)
            };
            var __ZNSt3__212ctype_bynameIwEC2EPKcm = Module["__ZNSt3__212ctype_bynameIwEC2EPKcm"] = function() {
                return (__ZNSt3__212ctype_bynameIwEC2EPKcm = Module["__ZNSt3__212ctype_bynameIwEC2EPKcm"] = Module["asm"]["_ZNSt3__212ctype_bynameIwEC2EPKcm"]).apply(null, arguments)
            };
            var __ZNSt3__212ctype_bynameIwED0Ev = Module["__ZNSt3__212ctype_bynameIwED0Ev"] = function() {
                return (__ZNSt3__212ctype_bynameIwED0Ev = Module["__ZNSt3__212ctype_bynameIwED0Ev"] = Module["asm"]["_ZNSt3__212ctype_bynameIwED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212ctype_bynameIwED2Ev = Module["__ZNSt3__212ctype_bynameIwED2Ev"] = function() {
                return (__ZNSt3__212ctype_bynameIwED2Ev = Module["__ZNSt3__212ctype_bynameIwED2Ev"] = Module["asm"]["_ZNSt3__212ctype_bynameIwED2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__212ctype_bynameIwE5do_isEtw = Module["__ZNKSt3__212ctype_bynameIwE5do_isEtw"] = function() {
                return (__ZNKSt3__212ctype_bynameIwE5do_isEtw = Module["__ZNKSt3__212ctype_bynameIwE5do_isEtw"] = Module["asm"]["_ZNKSt3__212ctype_bynameIwE5do_isEtw"]).apply(null, arguments)
            };
            var __ZNKSt3__212ctype_bynameIwE5do_isEPKwS3_Pt = Module["__ZNKSt3__212ctype_bynameIwE5do_isEPKwS3_Pt"] = function() {
                return (__ZNKSt3__212ctype_bynameIwE5do_isEPKwS3_Pt = Module["__ZNKSt3__212ctype_bynameIwE5do_isEPKwS3_Pt"] = Module["asm"]["_ZNKSt3__212ctype_bynameIwE5do_isEPKwS3_Pt"]).apply(null, arguments)
            };
            var __ZNKSt3__212ctype_bynameIwE10do_scan_isEtPKwS3_ = Module["__ZNKSt3__212ctype_bynameIwE10do_scan_isEtPKwS3_"] = function() {
                return (__ZNKSt3__212ctype_bynameIwE10do_scan_isEtPKwS3_ = Module["__ZNKSt3__212ctype_bynameIwE10do_scan_isEtPKwS3_"] = Module["asm"]["_ZNKSt3__212ctype_bynameIwE10do_scan_isEtPKwS3_"]).apply(null, arguments)
            };
            var __ZNKSt3__212ctype_bynameIwE11do_scan_notEtPKwS3_ = Module["__ZNKSt3__212ctype_bynameIwE11do_scan_notEtPKwS3_"] = function() {
                return (__ZNKSt3__212ctype_bynameIwE11do_scan_notEtPKwS3_ = Module["__ZNKSt3__212ctype_bynameIwE11do_scan_notEtPKwS3_"] = Module["asm"]["_ZNKSt3__212ctype_bynameIwE11do_scan_notEtPKwS3_"]).apply(null, arguments)
            };
            var __ZNKSt3__212ctype_bynameIwE10do_toupperEw = Module["__ZNKSt3__212ctype_bynameIwE10do_toupperEw"] = function() {
                return (__ZNKSt3__212ctype_bynameIwE10do_toupperEw = Module["__ZNKSt3__212ctype_bynameIwE10do_toupperEw"] = Module["asm"]["_ZNKSt3__212ctype_bynameIwE10do_toupperEw"]).apply(null, arguments)
            };
            var __ZNKSt3__212ctype_bynameIwE10do_toupperEPwPKw = Module["__ZNKSt3__212ctype_bynameIwE10do_toupperEPwPKw"] = function() {
                return (__ZNKSt3__212ctype_bynameIwE10do_toupperEPwPKw = Module["__ZNKSt3__212ctype_bynameIwE10do_toupperEPwPKw"] = Module["asm"]["_ZNKSt3__212ctype_bynameIwE10do_toupperEPwPKw"]).apply(null, arguments)
            };
            var __ZNKSt3__212ctype_bynameIwE10do_tolowerEw = Module["__ZNKSt3__212ctype_bynameIwE10do_tolowerEw"] = function() {
                return (__ZNKSt3__212ctype_bynameIwE10do_tolowerEw = Module["__ZNKSt3__212ctype_bynameIwE10do_tolowerEw"] = Module["asm"]["_ZNKSt3__212ctype_bynameIwE10do_tolowerEw"]).apply(null, arguments)
            };
            var __ZNKSt3__212ctype_bynameIwE10do_tolowerEPwPKw = Module["__ZNKSt3__212ctype_bynameIwE10do_tolowerEPwPKw"] = function() {
                return (__ZNKSt3__212ctype_bynameIwE10do_tolowerEPwPKw = Module["__ZNKSt3__212ctype_bynameIwE10do_tolowerEPwPKw"] = Module["asm"]["_ZNKSt3__212ctype_bynameIwE10do_tolowerEPwPKw"]).apply(null, arguments)
            };
            var __ZNKSt3__212ctype_bynameIwE8do_widenEc = Module["__ZNKSt3__212ctype_bynameIwE8do_widenEc"] = function() {
                return (__ZNKSt3__212ctype_bynameIwE8do_widenEc = Module["__ZNKSt3__212ctype_bynameIwE8do_widenEc"] = Module["asm"]["_ZNKSt3__212ctype_bynameIwE8do_widenEc"]).apply(null, arguments)
            };
            var __ZNSt3__216__libcpp_btowc_lEiP15__locale_struct = Module["__ZNSt3__216__libcpp_btowc_lEiP15__locale_struct"] = function() {
                return (__ZNSt3__216__libcpp_btowc_lEiP15__locale_struct = Module["__ZNSt3__216__libcpp_btowc_lEiP15__locale_struct"] = Module["asm"]["_ZNSt3__216__libcpp_btowc_lEiP15__locale_struct"]).apply(null, arguments)
            };
            var __ZNKSt3__212ctype_bynameIwE8do_widenEPKcS3_Pw = Module["__ZNKSt3__212ctype_bynameIwE8do_widenEPKcS3_Pw"] = function() {
                return (__ZNKSt3__212ctype_bynameIwE8do_widenEPKcS3_Pw = Module["__ZNKSt3__212ctype_bynameIwE8do_widenEPKcS3_Pw"] = Module["asm"]["_ZNKSt3__212ctype_bynameIwE8do_widenEPKcS3_Pw"]).apply(null, arguments)
            };
            var __ZNKSt3__212ctype_bynameIwE9do_narrowEwc = Module["__ZNKSt3__212ctype_bynameIwE9do_narrowEwc"] = function() {
                return (__ZNKSt3__212ctype_bynameIwE9do_narrowEwc = Module["__ZNKSt3__212ctype_bynameIwE9do_narrowEwc"] = Module["asm"]["_ZNKSt3__212ctype_bynameIwE9do_narrowEwc"]).apply(null, arguments)
            };
            var __ZNSt3__216__libcpp_wctob_lEjP15__locale_struct = Module["__ZNSt3__216__libcpp_wctob_lEjP15__locale_struct"] = function() {
                return (__ZNSt3__216__libcpp_wctob_lEjP15__locale_struct = Module["__ZNSt3__216__libcpp_wctob_lEjP15__locale_struct"] = Module["asm"]["_ZNSt3__216__libcpp_wctob_lEjP15__locale_struct"]).apply(null, arguments)
            };
            var __ZNKSt3__212ctype_bynameIwE9do_narrowEPKwS3_cPc = Module["__ZNKSt3__212ctype_bynameIwE9do_narrowEPKwS3_cPc"] = function() {
                return (__ZNKSt3__212ctype_bynameIwE9do_narrowEPKwS3_cPc = Module["__ZNKSt3__212ctype_bynameIwE9do_narrowEPKwS3_cPc"] = Module["asm"]["_ZNKSt3__212ctype_bynameIwE9do_narrowEPKwS3_cPc"]).apply(null, arguments)
            };
            var __ZNSt3__27codecvtIcc11__mbstate_tED0Ev = Module["__ZNSt3__27codecvtIcc11__mbstate_tED0Ev"] = function() {
                return (__ZNSt3__27codecvtIcc11__mbstate_tED0Ev = Module["__ZNSt3__27codecvtIcc11__mbstate_tED0Ev"] = Module["asm"]["_ZNSt3__27codecvtIcc11__mbstate_tED0Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIcc11__mbstate_tE6do_outERS1_PKcS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE6do_outERS1_PKcS5_RS5_PcS7_RS7_"] = function() {
                return (__ZNKSt3__27codecvtIcc11__mbstate_tE6do_outERS1_PKcS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE6do_outERS1_PKcS5_RS5_PcS7_RS7_"] = Module["asm"]["_ZNKSt3__27codecvtIcc11__mbstate_tE6do_outERS1_PKcS5_RS5_PcS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIcc11__mbstate_tE5do_inERS1_PKcS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE5do_inERS1_PKcS5_RS5_PcS7_RS7_"] = function() {
                return (__ZNKSt3__27codecvtIcc11__mbstate_tE5do_inERS1_PKcS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE5do_inERS1_PKcS5_RS5_PcS7_RS7_"] = Module["asm"]["_ZNKSt3__27codecvtIcc11__mbstate_tE5do_inERS1_PKcS5_RS5_PcS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIcc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_ = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_"] = function() {
                return (__ZNKSt3__27codecvtIcc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_ = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_"] = Module["asm"]["_ZNKSt3__27codecvtIcc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIcc11__mbstate_tE11do_encodingEv = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE11do_encodingEv"] = function() {
                return (__ZNKSt3__27codecvtIcc11__mbstate_tE11do_encodingEv = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE11do_encodingEv"] = Module["asm"]["_ZNKSt3__27codecvtIcc11__mbstate_tE11do_encodingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIcc11__mbstate_tE16do_always_noconvEv = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE16do_always_noconvEv"] = function() {
                return (__ZNKSt3__27codecvtIcc11__mbstate_tE16do_always_noconvEv = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE16do_always_noconvEv"] = Module["asm"]["_ZNKSt3__27codecvtIcc11__mbstate_tE16do_always_noconvEv"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIcc11__mbstate_tE9do_lengthERS1_PKcS5_m = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE9do_lengthERS1_PKcS5_m"] = function() {
                return (__ZNKSt3__27codecvtIcc11__mbstate_tE9do_lengthERS1_PKcS5_m = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE9do_lengthERS1_PKcS5_m"] = Module["asm"]["_ZNKSt3__27codecvtIcc11__mbstate_tE9do_lengthERS1_PKcS5_m"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIcc11__mbstate_tE13do_max_lengthEv = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE13do_max_lengthEv"] = function() {
                return (__ZNKSt3__27codecvtIcc11__mbstate_tE13do_max_lengthEv = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE13do_max_lengthEv"] = Module["asm"]["_ZNKSt3__27codecvtIcc11__mbstate_tE13do_max_lengthEv"]).apply(null, arguments)
            };
            var __ZNSt3__212codecvt_baseC2Ev = Module["__ZNSt3__212codecvt_baseC2Ev"] = function() {
                return (__ZNSt3__212codecvt_baseC2Ev = Module["__ZNSt3__212codecvt_baseC2Ev"] = Module["asm"]["_ZNSt3__212codecvt_baseC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__27codecvtIwc11__mbstate_tED0Ev = Module["__ZNSt3__27codecvtIwc11__mbstate_tED0Ev"] = function() {
                return (__ZNSt3__27codecvtIwc11__mbstate_tED0Ev = Module["__ZNSt3__27codecvtIwc11__mbstate_tED0Ev"] = Module["asm"]["_ZNSt3__27codecvtIwc11__mbstate_tED0Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIwc11__mbstate_tE6do_outERS1_PKwS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__27codecvtIwc11__mbstate_tE6do_outERS1_PKwS5_RS5_PcS7_RS7_"] = function() {
                return (__ZNKSt3__27codecvtIwc11__mbstate_tE6do_outERS1_PKwS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__27codecvtIwc11__mbstate_tE6do_outERS1_PKwS5_RS5_PcS7_RS7_"] = Module["asm"]["_ZNKSt3__27codecvtIwc11__mbstate_tE6do_outERS1_PKwS5_RS5_PcS7_RS7_"]).apply(null, arguments)
            };
            var __ZNSt3__221__libcpp_wcsnrtombs_lEPcPPKwmmP11__mbstate_tP15__locale_struct = Module["__ZNSt3__221__libcpp_wcsnrtombs_lEPcPPKwmmP11__mbstate_tP15__locale_struct"] = function() {
                return (__ZNSt3__221__libcpp_wcsnrtombs_lEPcPPKwmmP11__mbstate_tP15__locale_struct = Module["__ZNSt3__221__libcpp_wcsnrtombs_lEPcPPKwmmP11__mbstate_tP15__locale_struct"] = Module["asm"]["_ZNSt3__221__libcpp_wcsnrtombs_lEPcPPKwmmP11__mbstate_tP15__locale_struct"]).apply(null, arguments)
            };
            var __ZNSt3__218__libcpp_wcrtomb_lEPcwP11__mbstate_tP15__locale_struct = Module["__ZNSt3__218__libcpp_wcrtomb_lEPcwP11__mbstate_tP15__locale_struct"] = function() {
                return (__ZNSt3__218__libcpp_wcrtomb_lEPcwP11__mbstate_tP15__locale_struct = Module["__ZNSt3__218__libcpp_wcrtomb_lEPcwP11__mbstate_tP15__locale_struct"] = Module["asm"]["_ZNSt3__218__libcpp_wcrtomb_lEPcwP11__mbstate_tP15__locale_struct"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIwc11__mbstate_tE5do_inERS1_PKcS5_RS5_PwS7_RS7_ = Module["__ZNKSt3__27codecvtIwc11__mbstate_tE5do_inERS1_PKcS5_RS5_PwS7_RS7_"] = function() {
                return (__ZNKSt3__27codecvtIwc11__mbstate_tE5do_inERS1_PKcS5_RS5_PwS7_RS7_ = Module["__ZNKSt3__27codecvtIwc11__mbstate_tE5do_inERS1_PKcS5_RS5_PwS7_RS7_"] = Module["asm"]["_ZNKSt3__27codecvtIwc11__mbstate_tE5do_inERS1_PKcS5_RS5_PwS7_RS7_"]).apply(null, arguments)
            };
            var __ZNSt3__221__libcpp_mbsnrtowcs_lEPwPPKcmmP11__mbstate_tP15__locale_struct = Module["__ZNSt3__221__libcpp_mbsnrtowcs_lEPwPPKcmmP11__mbstate_tP15__locale_struct"] = function() {
                return (__ZNSt3__221__libcpp_mbsnrtowcs_lEPwPPKcmmP11__mbstate_tP15__locale_struct = Module["__ZNSt3__221__libcpp_mbsnrtowcs_lEPwPPKcmmP11__mbstate_tP15__locale_struct"] = Module["asm"]["_ZNSt3__221__libcpp_mbsnrtowcs_lEPwPPKcmmP11__mbstate_tP15__locale_struct"]).apply(null, arguments)
            };
            var __ZNSt3__218__libcpp_mbrtowc_lEPwPKcmP11__mbstate_tP15__locale_struct = Module["__ZNSt3__218__libcpp_mbrtowc_lEPwPKcmP11__mbstate_tP15__locale_struct"] = function() {
                return (__ZNSt3__218__libcpp_mbrtowc_lEPwPKcmP11__mbstate_tP15__locale_struct = Module["__ZNSt3__218__libcpp_mbrtowc_lEPwPKcmP11__mbstate_tP15__locale_struct"] = Module["asm"]["_ZNSt3__218__libcpp_mbrtowc_lEPwPKcmP11__mbstate_tP15__locale_struct"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIwc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_ = Module["__ZNKSt3__27codecvtIwc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_"] = function() {
                return (__ZNKSt3__27codecvtIwc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_ = Module["__ZNKSt3__27codecvtIwc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_"] = Module["asm"]["_ZNKSt3__27codecvtIwc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIwc11__mbstate_tE11do_encodingEv = Module["__ZNKSt3__27codecvtIwc11__mbstate_tE11do_encodingEv"] = function() {
                return (__ZNKSt3__27codecvtIwc11__mbstate_tE11do_encodingEv = Module["__ZNKSt3__27codecvtIwc11__mbstate_tE11do_encodingEv"] = Module["asm"]["_ZNKSt3__27codecvtIwc11__mbstate_tE11do_encodingEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__libcpp_mbtowc_lEPwPKcmP15__locale_struct = Module["__ZNSt3__217__libcpp_mbtowc_lEPwPKcmP15__locale_struct"] = function() {
                return (__ZNSt3__217__libcpp_mbtowc_lEPwPKcmP15__locale_struct = Module["__ZNSt3__217__libcpp_mbtowc_lEPwPKcmP15__locale_struct"] = Module["asm"]["_ZNSt3__217__libcpp_mbtowc_lEPwPKcmP15__locale_struct"]).apply(null, arguments)
            };
            var __ZNSt3__221__libcpp_mb_cur_max_lEP15__locale_struct = Module["__ZNSt3__221__libcpp_mb_cur_max_lEP15__locale_struct"] = function() {
                return (__ZNSt3__221__libcpp_mb_cur_max_lEP15__locale_struct = Module["__ZNSt3__221__libcpp_mb_cur_max_lEP15__locale_struct"] = Module["asm"]["_ZNSt3__221__libcpp_mb_cur_max_lEP15__locale_struct"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIwc11__mbstate_tE16do_always_noconvEv = Module["__ZNKSt3__27codecvtIwc11__mbstate_tE16do_always_noconvEv"] = function() {
                return (__ZNKSt3__27codecvtIwc11__mbstate_tE16do_always_noconvEv = Module["__ZNKSt3__27codecvtIwc11__mbstate_tE16do_always_noconvEv"] = Module["asm"]["_ZNKSt3__27codecvtIwc11__mbstate_tE16do_always_noconvEv"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIwc11__mbstate_tE9do_lengthERS1_PKcS5_m = Module["__ZNKSt3__27codecvtIwc11__mbstate_tE9do_lengthERS1_PKcS5_m"] = function() {
                return (__ZNKSt3__27codecvtIwc11__mbstate_tE9do_lengthERS1_PKcS5_m = Module["__ZNKSt3__27codecvtIwc11__mbstate_tE9do_lengthERS1_PKcS5_m"] = Module["asm"]["_ZNKSt3__27codecvtIwc11__mbstate_tE9do_lengthERS1_PKcS5_m"]).apply(null, arguments)
            };
            var __ZNSt3__217__libcpp_mbrlen_lEPKcmP11__mbstate_tP15__locale_struct = Module["__ZNSt3__217__libcpp_mbrlen_lEPKcmP11__mbstate_tP15__locale_struct"] = function() {
                return (__ZNSt3__217__libcpp_mbrlen_lEPKcmP11__mbstate_tP15__locale_struct = Module["__ZNSt3__217__libcpp_mbrlen_lEPKcmP11__mbstate_tP15__locale_struct"] = Module["asm"]["_ZNSt3__217__libcpp_mbrlen_lEPKcmP11__mbstate_tP15__locale_struct"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIwc11__mbstate_tE13do_max_lengthEv = Module["__ZNKSt3__27codecvtIwc11__mbstate_tE13do_max_lengthEv"] = function() {
                return (__ZNKSt3__27codecvtIwc11__mbstate_tE13do_max_lengthEv = Module["__ZNKSt3__27codecvtIwc11__mbstate_tE13do_max_lengthEv"] = Module["asm"]["_ZNKSt3__27codecvtIwc11__mbstate_tE13do_max_lengthEv"]).apply(null, arguments)
            };
            var __ZNSt3__27codecvtIDsc11__mbstate_tED0Ev = Module["__ZNSt3__27codecvtIDsc11__mbstate_tED0Ev"] = function() {
                return (__ZNSt3__27codecvtIDsc11__mbstate_tED0Ev = Module["__ZNSt3__27codecvtIDsc11__mbstate_tED0Ev"] = Module["asm"]["_ZNSt3__27codecvtIDsc11__mbstate_tED0Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIDsc11__mbstate_tE6do_outERS1_PKDsS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__27codecvtIDsc11__mbstate_tE6do_outERS1_PKDsS5_RS5_PcS7_RS7_"] = function() {
                return (__ZNKSt3__27codecvtIDsc11__mbstate_tE6do_outERS1_PKDsS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__27codecvtIDsc11__mbstate_tE6do_outERS1_PKDsS5_RS5_PcS7_RS7_"] = Module["asm"]["_ZNKSt3__27codecvtIDsc11__mbstate_tE6do_outERS1_PKDsS5_RS5_PcS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIDsc11__mbstate_tE5do_inERS1_PKcS5_RS5_PDsS7_RS7_ = Module["__ZNKSt3__27codecvtIDsc11__mbstate_tE5do_inERS1_PKcS5_RS5_PDsS7_RS7_"] = function() {
                return (__ZNKSt3__27codecvtIDsc11__mbstate_tE5do_inERS1_PKcS5_RS5_PDsS7_RS7_ = Module["__ZNKSt3__27codecvtIDsc11__mbstate_tE5do_inERS1_PKcS5_RS5_PDsS7_RS7_"] = Module["asm"]["_ZNKSt3__27codecvtIDsc11__mbstate_tE5do_inERS1_PKcS5_RS5_PDsS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIDsc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_ = Module["__ZNKSt3__27codecvtIDsc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_"] = function() {
                return (__ZNKSt3__27codecvtIDsc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_ = Module["__ZNKSt3__27codecvtIDsc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_"] = Module["asm"]["_ZNKSt3__27codecvtIDsc11__mbstate_tE10do_unshiftERS1_PcS4_RS4_"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIDsc11__mbstate_tE11do_encodingEv = Module["__ZNKSt3__27codecvtIDsc11__mbstate_tE11do_encodingEv"] = function() {
                return (__ZNKSt3__27codecvtIDsc11__mbstate_tE11do_encodingEv = Module["__ZNKSt3__27codecvtIDsc11__mbstate_tE11do_encodingEv"] = Module["asm"]["_ZNKSt3__27codecvtIDsc11__mbstate_tE11do_encodingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIDsc11__mbstate_tE16do_always_noconvEv = Module["__ZNKSt3__27codecvtIDsc11__mbstate_tE16do_always_noconvEv"] = function() {
                return (__ZNKSt3__27codecvtIDsc11__mbstate_tE16do_always_noconvEv = Module["__ZNKSt3__27codecvtIDsc11__mbstate_tE16do_always_noconvEv"] = Module["asm"]["_ZNKSt3__27codecvtIDsc11__mbstate_tE16do_always_noconvEv"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIDsc11__mbstate_tE9do_lengthERS1_PKcS5_m = Module["__ZNKSt3__27codecvtIDsc11__mbstate_tE9do_lengthERS1_PKcS5_m"] = function() {
                return (__ZNKSt3__27codecvtIDsc11__mbstate_tE9do_lengthERS1_PKcS5_m = Module["__ZNKSt3__27codecvtIDsc11__mbstate_tE9do_lengthERS1_PKcS5_m"] = Module["asm"]["_ZNKSt3__27codecvtIDsc11__mbstate_tE9do_lengthERS1_PKcS5_m"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIDsc11__mbstate_tE13do_max_lengthEv = Module["__ZNKSt3__27codecvtIDsc11__mbstate_tE13do_max_lengthEv"] = function() {
                return (__ZNKSt3__27codecvtIDsc11__mbstate_tE13do_max_lengthEv = Module["__ZNKSt3__27codecvtIDsc11__mbstate_tE13do_max_lengthEv"] = Module["asm"]["_ZNKSt3__27codecvtIDsc11__mbstate_tE13do_max_lengthEv"]).apply(null, arguments)
            };
            var __ZNSt3__27codecvtIDic11__mbstate_tED0Ev = Module["__ZNSt3__27codecvtIDic11__mbstate_tED0Ev"] = function() {
                return (__ZNSt3__27codecvtIDic11__mbstate_tED0Ev = Module["__ZNSt3__27codecvtIDic11__mbstate_tED0Ev"] = Module["asm"]["_ZNSt3__27codecvtIDic11__mbstate_tED0Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIDic11__mbstate_tE6do_outERS1_PKDiS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__27codecvtIDic11__mbstate_tE6do_outERS1_PKDiS5_RS5_PcS7_RS7_"] = function() {
                return (__ZNKSt3__27codecvtIDic11__mbstate_tE6do_outERS1_PKDiS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__27codecvtIDic11__mbstate_tE6do_outERS1_PKDiS5_RS5_PcS7_RS7_"] = Module["asm"]["_ZNKSt3__27codecvtIDic11__mbstate_tE6do_outERS1_PKDiS5_RS5_PcS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIDic11__mbstate_tE5do_inERS1_PKcS5_RS5_PDiS7_RS7_ = Module["__ZNKSt3__27codecvtIDic11__mbstate_tE5do_inERS1_PKcS5_RS5_PDiS7_RS7_"] = function() {
                return (__ZNKSt3__27codecvtIDic11__mbstate_tE5do_inERS1_PKcS5_RS5_PDiS7_RS7_ = Module["__ZNKSt3__27codecvtIDic11__mbstate_tE5do_inERS1_PKcS5_RS5_PDiS7_RS7_"] = Module["asm"]["_ZNKSt3__27codecvtIDic11__mbstate_tE5do_inERS1_PKcS5_RS5_PDiS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIDic11__mbstate_tE10do_unshiftERS1_PcS4_RS4_ = Module["__ZNKSt3__27codecvtIDic11__mbstate_tE10do_unshiftERS1_PcS4_RS4_"] = function() {
                return (__ZNKSt3__27codecvtIDic11__mbstate_tE10do_unshiftERS1_PcS4_RS4_ = Module["__ZNKSt3__27codecvtIDic11__mbstate_tE10do_unshiftERS1_PcS4_RS4_"] = Module["asm"]["_ZNKSt3__27codecvtIDic11__mbstate_tE10do_unshiftERS1_PcS4_RS4_"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIDic11__mbstate_tE11do_encodingEv = Module["__ZNKSt3__27codecvtIDic11__mbstate_tE11do_encodingEv"] = function() {
                return (__ZNKSt3__27codecvtIDic11__mbstate_tE11do_encodingEv = Module["__ZNKSt3__27codecvtIDic11__mbstate_tE11do_encodingEv"] = Module["asm"]["_ZNKSt3__27codecvtIDic11__mbstate_tE11do_encodingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIDic11__mbstate_tE16do_always_noconvEv = Module["__ZNKSt3__27codecvtIDic11__mbstate_tE16do_always_noconvEv"] = function() {
                return (__ZNKSt3__27codecvtIDic11__mbstate_tE16do_always_noconvEv = Module["__ZNKSt3__27codecvtIDic11__mbstate_tE16do_always_noconvEv"] = Module["asm"]["_ZNKSt3__27codecvtIDic11__mbstate_tE16do_always_noconvEv"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIDic11__mbstate_tE9do_lengthERS1_PKcS5_m = Module["__ZNKSt3__27codecvtIDic11__mbstate_tE9do_lengthERS1_PKcS5_m"] = function() {
                return (__ZNKSt3__27codecvtIDic11__mbstate_tE9do_lengthERS1_PKcS5_m = Module["__ZNKSt3__27codecvtIDic11__mbstate_tE9do_lengthERS1_PKcS5_m"] = Module["asm"]["_ZNKSt3__27codecvtIDic11__mbstate_tE9do_lengthERS1_PKcS5_m"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIDic11__mbstate_tE13do_max_lengthEv = Module["__ZNKSt3__27codecvtIDic11__mbstate_tE13do_max_lengthEv"] = function() {
                return (__ZNKSt3__27codecvtIDic11__mbstate_tE13do_max_lengthEv = Module["__ZNKSt3__27codecvtIDic11__mbstate_tE13do_max_lengthEv"] = Module["asm"]["_ZNKSt3__27codecvtIDic11__mbstate_tE13do_max_lengthEv"]).apply(null, arguments)
            };
            var __ZNKSt3__214__codecvt_utf8IwE6do_outER11__mbstate_tPKwS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__214__codecvt_utf8IwE6do_outER11__mbstate_tPKwS5_RS5_PcS7_RS7_"] = function() {
                return (__ZNKSt3__214__codecvt_utf8IwE6do_outER11__mbstate_tPKwS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__214__codecvt_utf8IwE6do_outER11__mbstate_tPKwS5_RS5_PcS7_RS7_"] = Module["asm"]["_ZNKSt3__214__codecvt_utf8IwE6do_outER11__mbstate_tPKwS5_RS5_PcS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__214__codecvt_utf8IwE5do_inER11__mbstate_tPKcS5_RS5_PwS7_RS7_ = Module["__ZNKSt3__214__codecvt_utf8IwE5do_inER11__mbstate_tPKcS5_RS5_PwS7_RS7_"] = function() {
                return (__ZNKSt3__214__codecvt_utf8IwE5do_inER11__mbstate_tPKcS5_RS5_PwS7_RS7_ = Module["__ZNKSt3__214__codecvt_utf8IwE5do_inER11__mbstate_tPKcS5_RS5_PwS7_RS7_"] = Module["asm"]["_ZNKSt3__214__codecvt_utf8IwE5do_inER11__mbstate_tPKcS5_RS5_PwS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__214__codecvt_utf8IwE10do_unshiftER11__mbstate_tPcS4_RS4_ = Module["__ZNKSt3__214__codecvt_utf8IwE10do_unshiftER11__mbstate_tPcS4_RS4_"] = function() {
                return (__ZNKSt3__214__codecvt_utf8IwE10do_unshiftER11__mbstate_tPcS4_RS4_ = Module["__ZNKSt3__214__codecvt_utf8IwE10do_unshiftER11__mbstate_tPcS4_RS4_"] = Module["asm"]["_ZNKSt3__214__codecvt_utf8IwE10do_unshiftER11__mbstate_tPcS4_RS4_"]).apply(null, arguments)
            };
            var __ZNKSt3__214__codecvt_utf8IwE11do_encodingEv = Module["__ZNKSt3__214__codecvt_utf8IwE11do_encodingEv"] = function() {
                return (__ZNKSt3__214__codecvt_utf8IwE11do_encodingEv = Module["__ZNKSt3__214__codecvt_utf8IwE11do_encodingEv"] = Module["asm"]["_ZNKSt3__214__codecvt_utf8IwE11do_encodingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__214__codecvt_utf8IwE16do_always_noconvEv = Module["__ZNKSt3__214__codecvt_utf8IwE16do_always_noconvEv"] = function() {
                return (__ZNKSt3__214__codecvt_utf8IwE16do_always_noconvEv = Module["__ZNKSt3__214__codecvt_utf8IwE16do_always_noconvEv"] = Module["asm"]["_ZNKSt3__214__codecvt_utf8IwE16do_always_noconvEv"]).apply(null, arguments)
            };
            var __ZNKSt3__214__codecvt_utf8IwE9do_lengthER11__mbstate_tPKcS5_m = Module["__ZNKSt3__214__codecvt_utf8IwE9do_lengthER11__mbstate_tPKcS5_m"] = function() {
                return (__ZNKSt3__214__codecvt_utf8IwE9do_lengthER11__mbstate_tPKcS5_m = Module["__ZNKSt3__214__codecvt_utf8IwE9do_lengthER11__mbstate_tPKcS5_m"] = Module["asm"]["_ZNKSt3__214__codecvt_utf8IwE9do_lengthER11__mbstate_tPKcS5_m"]).apply(null, arguments)
            };
            var __ZNKSt3__214__codecvt_utf8IwE13do_max_lengthEv = Module["__ZNKSt3__214__codecvt_utf8IwE13do_max_lengthEv"] = function() {
                return (__ZNKSt3__214__codecvt_utf8IwE13do_max_lengthEv = Module["__ZNKSt3__214__codecvt_utf8IwE13do_max_lengthEv"] = Module["asm"]["_ZNKSt3__214__codecvt_utf8IwE13do_max_lengthEv"]).apply(null, arguments)
            };
            var __ZNKSt3__214__codecvt_utf8IDsE6do_outER11__mbstate_tPKDsS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__214__codecvt_utf8IDsE6do_outER11__mbstate_tPKDsS5_RS5_PcS7_RS7_"] = function() {
                return (__ZNKSt3__214__codecvt_utf8IDsE6do_outER11__mbstate_tPKDsS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__214__codecvt_utf8IDsE6do_outER11__mbstate_tPKDsS5_RS5_PcS7_RS7_"] = Module["asm"]["_ZNKSt3__214__codecvt_utf8IDsE6do_outER11__mbstate_tPKDsS5_RS5_PcS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__214__codecvt_utf8IDsE5do_inER11__mbstate_tPKcS5_RS5_PDsS7_RS7_ = Module["__ZNKSt3__214__codecvt_utf8IDsE5do_inER11__mbstate_tPKcS5_RS5_PDsS7_RS7_"] = function() {
                return (__ZNKSt3__214__codecvt_utf8IDsE5do_inER11__mbstate_tPKcS5_RS5_PDsS7_RS7_ = Module["__ZNKSt3__214__codecvt_utf8IDsE5do_inER11__mbstate_tPKcS5_RS5_PDsS7_RS7_"] = Module["asm"]["_ZNKSt3__214__codecvt_utf8IDsE5do_inER11__mbstate_tPKcS5_RS5_PDsS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__214__codecvt_utf8IDsE10do_unshiftER11__mbstate_tPcS4_RS4_ = Module["__ZNKSt3__214__codecvt_utf8IDsE10do_unshiftER11__mbstate_tPcS4_RS4_"] = function() {
                return (__ZNKSt3__214__codecvt_utf8IDsE10do_unshiftER11__mbstate_tPcS4_RS4_ = Module["__ZNKSt3__214__codecvt_utf8IDsE10do_unshiftER11__mbstate_tPcS4_RS4_"] = Module["asm"]["_ZNKSt3__214__codecvt_utf8IDsE10do_unshiftER11__mbstate_tPcS4_RS4_"]).apply(null, arguments)
            };
            var __ZNKSt3__214__codecvt_utf8IDsE11do_encodingEv = Module["__ZNKSt3__214__codecvt_utf8IDsE11do_encodingEv"] = function() {
                return (__ZNKSt3__214__codecvt_utf8IDsE11do_encodingEv = Module["__ZNKSt3__214__codecvt_utf8IDsE11do_encodingEv"] = Module["asm"]["_ZNKSt3__214__codecvt_utf8IDsE11do_encodingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__214__codecvt_utf8IDsE16do_always_noconvEv = Module["__ZNKSt3__214__codecvt_utf8IDsE16do_always_noconvEv"] = function() {
                return (__ZNKSt3__214__codecvt_utf8IDsE16do_always_noconvEv = Module["__ZNKSt3__214__codecvt_utf8IDsE16do_always_noconvEv"] = Module["asm"]["_ZNKSt3__214__codecvt_utf8IDsE16do_always_noconvEv"]).apply(null, arguments)
            };
            var __ZNKSt3__214__codecvt_utf8IDsE9do_lengthER11__mbstate_tPKcS5_m = Module["__ZNKSt3__214__codecvt_utf8IDsE9do_lengthER11__mbstate_tPKcS5_m"] = function() {
                return (__ZNKSt3__214__codecvt_utf8IDsE9do_lengthER11__mbstate_tPKcS5_m = Module["__ZNKSt3__214__codecvt_utf8IDsE9do_lengthER11__mbstate_tPKcS5_m"] = Module["asm"]["_ZNKSt3__214__codecvt_utf8IDsE9do_lengthER11__mbstate_tPKcS5_m"]).apply(null, arguments)
            };
            var __ZNKSt3__214__codecvt_utf8IDsE13do_max_lengthEv = Module["__ZNKSt3__214__codecvt_utf8IDsE13do_max_lengthEv"] = function() {
                return (__ZNKSt3__214__codecvt_utf8IDsE13do_max_lengthEv = Module["__ZNKSt3__214__codecvt_utf8IDsE13do_max_lengthEv"] = Module["asm"]["_ZNKSt3__214__codecvt_utf8IDsE13do_max_lengthEv"]).apply(null, arguments)
            };
            var __ZNKSt3__214__codecvt_utf8IDiE6do_outER11__mbstate_tPKDiS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__214__codecvt_utf8IDiE6do_outER11__mbstate_tPKDiS5_RS5_PcS7_RS7_"] = function() {
                return (__ZNKSt3__214__codecvt_utf8IDiE6do_outER11__mbstate_tPKDiS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__214__codecvt_utf8IDiE6do_outER11__mbstate_tPKDiS5_RS5_PcS7_RS7_"] = Module["asm"]["_ZNKSt3__214__codecvt_utf8IDiE6do_outER11__mbstate_tPKDiS5_RS5_PcS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__214__codecvt_utf8IDiE5do_inER11__mbstate_tPKcS5_RS5_PDiS7_RS7_ = Module["__ZNKSt3__214__codecvt_utf8IDiE5do_inER11__mbstate_tPKcS5_RS5_PDiS7_RS7_"] = function() {
                return (__ZNKSt3__214__codecvt_utf8IDiE5do_inER11__mbstate_tPKcS5_RS5_PDiS7_RS7_ = Module["__ZNKSt3__214__codecvt_utf8IDiE5do_inER11__mbstate_tPKcS5_RS5_PDiS7_RS7_"] = Module["asm"]["_ZNKSt3__214__codecvt_utf8IDiE5do_inER11__mbstate_tPKcS5_RS5_PDiS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__214__codecvt_utf8IDiE10do_unshiftER11__mbstate_tPcS4_RS4_ = Module["__ZNKSt3__214__codecvt_utf8IDiE10do_unshiftER11__mbstate_tPcS4_RS4_"] = function() {
                return (__ZNKSt3__214__codecvt_utf8IDiE10do_unshiftER11__mbstate_tPcS4_RS4_ = Module["__ZNKSt3__214__codecvt_utf8IDiE10do_unshiftER11__mbstate_tPcS4_RS4_"] = Module["asm"]["_ZNKSt3__214__codecvt_utf8IDiE10do_unshiftER11__mbstate_tPcS4_RS4_"]).apply(null, arguments)
            };
            var __ZNKSt3__214__codecvt_utf8IDiE11do_encodingEv = Module["__ZNKSt3__214__codecvt_utf8IDiE11do_encodingEv"] = function() {
                return (__ZNKSt3__214__codecvt_utf8IDiE11do_encodingEv = Module["__ZNKSt3__214__codecvt_utf8IDiE11do_encodingEv"] = Module["asm"]["_ZNKSt3__214__codecvt_utf8IDiE11do_encodingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__214__codecvt_utf8IDiE16do_always_noconvEv = Module["__ZNKSt3__214__codecvt_utf8IDiE16do_always_noconvEv"] = function() {
                return (__ZNKSt3__214__codecvt_utf8IDiE16do_always_noconvEv = Module["__ZNKSt3__214__codecvt_utf8IDiE16do_always_noconvEv"] = Module["asm"]["_ZNKSt3__214__codecvt_utf8IDiE16do_always_noconvEv"]).apply(null, arguments)
            };
            var __ZNKSt3__214__codecvt_utf8IDiE9do_lengthER11__mbstate_tPKcS5_m = Module["__ZNKSt3__214__codecvt_utf8IDiE9do_lengthER11__mbstate_tPKcS5_m"] = function() {
                return (__ZNKSt3__214__codecvt_utf8IDiE9do_lengthER11__mbstate_tPKcS5_m = Module["__ZNKSt3__214__codecvt_utf8IDiE9do_lengthER11__mbstate_tPKcS5_m"] = Module["asm"]["_ZNKSt3__214__codecvt_utf8IDiE9do_lengthER11__mbstate_tPKcS5_m"]).apply(null, arguments)
            };
            var __ZNKSt3__214__codecvt_utf8IDiE13do_max_lengthEv = Module["__ZNKSt3__214__codecvt_utf8IDiE13do_max_lengthEv"] = function() {
                return (__ZNKSt3__214__codecvt_utf8IDiE13do_max_lengthEv = Module["__ZNKSt3__214__codecvt_utf8IDiE13do_max_lengthEv"] = Module["asm"]["_ZNKSt3__214__codecvt_utf8IDiE13do_max_lengthEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IwLb0EE6do_outER11__mbstate_tPKwS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__215__codecvt_utf16IwLb0EE6do_outER11__mbstate_tPKwS5_RS5_PcS7_RS7_"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IwLb0EE6do_outER11__mbstate_tPKwS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__215__codecvt_utf16IwLb0EE6do_outER11__mbstate_tPKwS5_RS5_PcS7_RS7_"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IwLb0EE6do_outER11__mbstate_tPKwS5_RS5_PcS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IwLb0EE5do_inER11__mbstate_tPKcS5_RS5_PwS7_RS7_ = Module["__ZNKSt3__215__codecvt_utf16IwLb0EE5do_inER11__mbstate_tPKcS5_RS5_PwS7_RS7_"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IwLb0EE5do_inER11__mbstate_tPKcS5_RS5_PwS7_RS7_ = Module["__ZNKSt3__215__codecvt_utf16IwLb0EE5do_inER11__mbstate_tPKcS5_RS5_PwS7_RS7_"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IwLb0EE5do_inER11__mbstate_tPKcS5_RS5_PwS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IwLb0EE10do_unshiftER11__mbstate_tPcS4_RS4_ = Module["__ZNKSt3__215__codecvt_utf16IwLb0EE10do_unshiftER11__mbstate_tPcS4_RS4_"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IwLb0EE10do_unshiftER11__mbstate_tPcS4_RS4_ = Module["__ZNKSt3__215__codecvt_utf16IwLb0EE10do_unshiftER11__mbstate_tPcS4_RS4_"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IwLb0EE10do_unshiftER11__mbstate_tPcS4_RS4_"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IwLb0EE11do_encodingEv = Module["__ZNKSt3__215__codecvt_utf16IwLb0EE11do_encodingEv"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IwLb0EE11do_encodingEv = Module["__ZNKSt3__215__codecvt_utf16IwLb0EE11do_encodingEv"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IwLb0EE11do_encodingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IwLb0EE16do_always_noconvEv = Module["__ZNKSt3__215__codecvt_utf16IwLb0EE16do_always_noconvEv"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IwLb0EE16do_always_noconvEv = Module["__ZNKSt3__215__codecvt_utf16IwLb0EE16do_always_noconvEv"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IwLb0EE16do_always_noconvEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IwLb0EE9do_lengthER11__mbstate_tPKcS5_m = Module["__ZNKSt3__215__codecvt_utf16IwLb0EE9do_lengthER11__mbstate_tPKcS5_m"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IwLb0EE9do_lengthER11__mbstate_tPKcS5_m = Module["__ZNKSt3__215__codecvt_utf16IwLb0EE9do_lengthER11__mbstate_tPKcS5_m"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IwLb0EE9do_lengthER11__mbstate_tPKcS5_m"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IwLb0EE13do_max_lengthEv = Module["__ZNKSt3__215__codecvt_utf16IwLb0EE13do_max_lengthEv"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IwLb0EE13do_max_lengthEv = Module["__ZNKSt3__215__codecvt_utf16IwLb0EE13do_max_lengthEv"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IwLb0EE13do_max_lengthEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IwLb1EE6do_outER11__mbstate_tPKwS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__215__codecvt_utf16IwLb1EE6do_outER11__mbstate_tPKwS5_RS5_PcS7_RS7_"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IwLb1EE6do_outER11__mbstate_tPKwS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__215__codecvt_utf16IwLb1EE6do_outER11__mbstate_tPKwS5_RS5_PcS7_RS7_"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IwLb1EE6do_outER11__mbstate_tPKwS5_RS5_PcS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IwLb1EE5do_inER11__mbstate_tPKcS5_RS5_PwS7_RS7_ = Module["__ZNKSt3__215__codecvt_utf16IwLb1EE5do_inER11__mbstate_tPKcS5_RS5_PwS7_RS7_"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IwLb1EE5do_inER11__mbstate_tPKcS5_RS5_PwS7_RS7_ = Module["__ZNKSt3__215__codecvt_utf16IwLb1EE5do_inER11__mbstate_tPKcS5_RS5_PwS7_RS7_"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IwLb1EE5do_inER11__mbstate_tPKcS5_RS5_PwS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IwLb1EE10do_unshiftER11__mbstate_tPcS4_RS4_ = Module["__ZNKSt3__215__codecvt_utf16IwLb1EE10do_unshiftER11__mbstate_tPcS4_RS4_"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IwLb1EE10do_unshiftER11__mbstate_tPcS4_RS4_ = Module["__ZNKSt3__215__codecvt_utf16IwLb1EE10do_unshiftER11__mbstate_tPcS4_RS4_"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IwLb1EE10do_unshiftER11__mbstate_tPcS4_RS4_"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IwLb1EE11do_encodingEv = Module["__ZNKSt3__215__codecvt_utf16IwLb1EE11do_encodingEv"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IwLb1EE11do_encodingEv = Module["__ZNKSt3__215__codecvt_utf16IwLb1EE11do_encodingEv"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IwLb1EE11do_encodingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IwLb1EE16do_always_noconvEv = Module["__ZNKSt3__215__codecvt_utf16IwLb1EE16do_always_noconvEv"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IwLb1EE16do_always_noconvEv = Module["__ZNKSt3__215__codecvt_utf16IwLb1EE16do_always_noconvEv"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IwLb1EE16do_always_noconvEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IwLb1EE9do_lengthER11__mbstate_tPKcS5_m = Module["__ZNKSt3__215__codecvt_utf16IwLb1EE9do_lengthER11__mbstate_tPKcS5_m"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IwLb1EE9do_lengthER11__mbstate_tPKcS5_m = Module["__ZNKSt3__215__codecvt_utf16IwLb1EE9do_lengthER11__mbstate_tPKcS5_m"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IwLb1EE9do_lengthER11__mbstate_tPKcS5_m"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IwLb1EE13do_max_lengthEv = Module["__ZNKSt3__215__codecvt_utf16IwLb1EE13do_max_lengthEv"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IwLb1EE13do_max_lengthEv = Module["__ZNKSt3__215__codecvt_utf16IwLb1EE13do_max_lengthEv"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IwLb1EE13do_max_lengthEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDsLb0EE6do_outER11__mbstate_tPKDsS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__215__codecvt_utf16IDsLb0EE6do_outER11__mbstate_tPKDsS5_RS5_PcS7_RS7_"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDsLb0EE6do_outER11__mbstate_tPKDsS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__215__codecvt_utf16IDsLb0EE6do_outER11__mbstate_tPKDsS5_RS5_PcS7_RS7_"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDsLb0EE6do_outER11__mbstate_tPKDsS5_RS5_PcS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDsLb0EE5do_inER11__mbstate_tPKcS5_RS5_PDsS7_RS7_ = Module["__ZNKSt3__215__codecvt_utf16IDsLb0EE5do_inER11__mbstate_tPKcS5_RS5_PDsS7_RS7_"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDsLb0EE5do_inER11__mbstate_tPKcS5_RS5_PDsS7_RS7_ = Module["__ZNKSt3__215__codecvt_utf16IDsLb0EE5do_inER11__mbstate_tPKcS5_RS5_PDsS7_RS7_"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDsLb0EE5do_inER11__mbstate_tPKcS5_RS5_PDsS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDsLb0EE10do_unshiftER11__mbstate_tPcS4_RS4_ = Module["__ZNKSt3__215__codecvt_utf16IDsLb0EE10do_unshiftER11__mbstate_tPcS4_RS4_"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDsLb0EE10do_unshiftER11__mbstate_tPcS4_RS4_ = Module["__ZNKSt3__215__codecvt_utf16IDsLb0EE10do_unshiftER11__mbstate_tPcS4_RS4_"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDsLb0EE10do_unshiftER11__mbstate_tPcS4_RS4_"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDsLb0EE11do_encodingEv = Module["__ZNKSt3__215__codecvt_utf16IDsLb0EE11do_encodingEv"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDsLb0EE11do_encodingEv = Module["__ZNKSt3__215__codecvt_utf16IDsLb0EE11do_encodingEv"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDsLb0EE11do_encodingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDsLb0EE16do_always_noconvEv = Module["__ZNKSt3__215__codecvt_utf16IDsLb0EE16do_always_noconvEv"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDsLb0EE16do_always_noconvEv = Module["__ZNKSt3__215__codecvt_utf16IDsLb0EE16do_always_noconvEv"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDsLb0EE16do_always_noconvEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDsLb0EE9do_lengthER11__mbstate_tPKcS5_m = Module["__ZNKSt3__215__codecvt_utf16IDsLb0EE9do_lengthER11__mbstate_tPKcS5_m"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDsLb0EE9do_lengthER11__mbstate_tPKcS5_m = Module["__ZNKSt3__215__codecvt_utf16IDsLb0EE9do_lengthER11__mbstate_tPKcS5_m"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDsLb0EE9do_lengthER11__mbstate_tPKcS5_m"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDsLb0EE13do_max_lengthEv = Module["__ZNKSt3__215__codecvt_utf16IDsLb0EE13do_max_lengthEv"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDsLb0EE13do_max_lengthEv = Module["__ZNKSt3__215__codecvt_utf16IDsLb0EE13do_max_lengthEv"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDsLb0EE13do_max_lengthEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDsLb1EE6do_outER11__mbstate_tPKDsS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__215__codecvt_utf16IDsLb1EE6do_outER11__mbstate_tPKDsS5_RS5_PcS7_RS7_"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDsLb1EE6do_outER11__mbstate_tPKDsS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__215__codecvt_utf16IDsLb1EE6do_outER11__mbstate_tPKDsS5_RS5_PcS7_RS7_"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDsLb1EE6do_outER11__mbstate_tPKDsS5_RS5_PcS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDsLb1EE5do_inER11__mbstate_tPKcS5_RS5_PDsS7_RS7_ = Module["__ZNKSt3__215__codecvt_utf16IDsLb1EE5do_inER11__mbstate_tPKcS5_RS5_PDsS7_RS7_"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDsLb1EE5do_inER11__mbstate_tPKcS5_RS5_PDsS7_RS7_ = Module["__ZNKSt3__215__codecvt_utf16IDsLb1EE5do_inER11__mbstate_tPKcS5_RS5_PDsS7_RS7_"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDsLb1EE5do_inER11__mbstate_tPKcS5_RS5_PDsS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDsLb1EE10do_unshiftER11__mbstate_tPcS4_RS4_ = Module["__ZNKSt3__215__codecvt_utf16IDsLb1EE10do_unshiftER11__mbstate_tPcS4_RS4_"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDsLb1EE10do_unshiftER11__mbstate_tPcS4_RS4_ = Module["__ZNKSt3__215__codecvt_utf16IDsLb1EE10do_unshiftER11__mbstate_tPcS4_RS4_"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDsLb1EE10do_unshiftER11__mbstate_tPcS4_RS4_"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDsLb1EE11do_encodingEv = Module["__ZNKSt3__215__codecvt_utf16IDsLb1EE11do_encodingEv"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDsLb1EE11do_encodingEv = Module["__ZNKSt3__215__codecvt_utf16IDsLb1EE11do_encodingEv"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDsLb1EE11do_encodingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDsLb1EE16do_always_noconvEv = Module["__ZNKSt3__215__codecvt_utf16IDsLb1EE16do_always_noconvEv"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDsLb1EE16do_always_noconvEv = Module["__ZNKSt3__215__codecvt_utf16IDsLb1EE16do_always_noconvEv"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDsLb1EE16do_always_noconvEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDsLb1EE9do_lengthER11__mbstate_tPKcS5_m = Module["__ZNKSt3__215__codecvt_utf16IDsLb1EE9do_lengthER11__mbstate_tPKcS5_m"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDsLb1EE9do_lengthER11__mbstate_tPKcS5_m = Module["__ZNKSt3__215__codecvt_utf16IDsLb1EE9do_lengthER11__mbstate_tPKcS5_m"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDsLb1EE9do_lengthER11__mbstate_tPKcS5_m"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDsLb1EE13do_max_lengthEv = Module["__ZNKSt3__215__codecvt_utf16IDsLb1EE13do_max_lengthEv"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDsLb1EE13do_max_lengthEv = Module["__ZNKSt3__215__codecvt_utf16IDsLb1EE13do_max_lengthEv"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDsLb1EE13do_max_lengthEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDiLb0EE6do_outER11__mbstate_tPKDiS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__215__codecvt_utf16IDiLb0EE6do_outER11__mbstate_tPKDiS5_RS5_PcS7_RS7_"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDiLb0EE6do_outER11__mbstate_tPKDiS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__215__codecvt_utf16IDiLb0EE6do_outER11__mbstate_tPKDiS5_RS5_PcS7_RS7_"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDiLb0EE6do_outER11__mbstate_tPKDiS5_RS5_PcS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDiLb0EE5do_inER11__mbstate_tPKcS5_RS5_PDiS7_RS7_ = Module["__ZNKSt3__215__codecvt_utf16IDiLb0EE5do_inER11__mbstate_tPKcS5_RS5_PDiS7_RS7_"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDiLb0EE5do_inER11__mbstate_tPKcS5_RS5_PDiS7_RS7_ = Module["__ZNKSt3__215__codecvt_utf16IDiLb0EE5do_inER11__mbstate_tPKcS5_RS5_PDiS7_RS7_"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDiLb0EE5do_inER11__mbstate_tPKcS5_RS5_PDiS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDiLb0EE10do_unshiftER11__mbstate_tPcS4_RS4_ = Module["__ZNKSt3__215__codecvt_utf16IDiLb0EE10do_unshiftER11__mbstate_tPcS4_RS4_"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDiLb0EE10do_unshiftER11__mbstate_tPcS4_RS4_ = Module["__ZNKSt3__215__codecvt_utf16IDiLb0EE10do_unshiftER11__mbstate_tPcS4_RS4_"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDiLb0EE10do_unshiftER11__mbstate_tPcS4_RS4_"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDiLb0EE11do_encodingEv = Module["__ZNKSt3__215__codecvt_utf16IDiLb0EE11do_encodingEv"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDiLb0EE11do_encodingEv = Module["__ZNKSt3__215__codecvt_utf16IDiLb0EE11do_encodingEv"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDiLb0EE11do_encodingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDiLb0EE16do_always_noconvEv = Module["__ZNKSt3__215__codecvt_utf16IDiLb0EE16do_always_noconvEv"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDiLb0EE16do_always_noconvEv = Module["__ZNKSt3__215__codecvt_utf16IDiLb0EE16do_always_noconvEv"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDiLb0EE16do_always_noconvEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDiLb0EE9do_lengthER11__mbstate_tPKcS5_m = Module["__ZNKSt3__215__codecvt_utf16IDiLb0EE9do_lengthER11__mbstate_tPKcS5_m"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDiLb0EE9do_lengthER11__mbstate_tPKcS5_m = Module["__ZNKSt3__215__codecvt_utf16IDiLb0EE9do_lengthER11__mbstate_tPKcS5_m"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDiLb0EE9do_lengthER11__mbstate_tPKcS5_m"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDiLb0EE13do_max_lengthEv = Module["__ZNKSt3__215__codecvt_utf16IDiLb0EE13do_max_lengthEv"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDiLb0EE13do_max_lengthEv = Module["__ZNKSt3__215__codecvt_utf16IDiLb0EE13do_max_lengthEv"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDiLb0EE13do_max_lengthEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDiLb1EE6do_outER11__mbstate_tPKDiS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__215__codecvt_utf16IDiLb1EE6do_outER11__mbstate_tPKDiS5_RS5_PcS7_RS7_"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDiLb1EE6do_outER11__mbstate_tPKDiS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__215__codecvt_utf16IDiLb1EE6do_outER11__mbstate_tPKDiS5_RS5_PcS7_RS7_"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDiLb1EE6do_outER11__mbstate_tPKDiS5_RS5_PcS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDiLb1EE5do_inER11__mbstate_tPKcS5_RS5_PDiS7_RS7_ = Module["__ZNKSt3__215__codecvt_utf16IDiLb1EE5do_inER11__mbstate_tPKcS5_RS5_PDiS7_RS7_"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDiLb1EE5do_inER11__mbstate_tPKcS5_RS5_PDiS7_RS7_ = Module["__ZNKSt3__215__codecvt_utf16IDiLb1EE5do_inER11__mbstate_tPKcS5_RS5_PDiS7_RS7_"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDiLb1EE5do_inER11__mbstate_tPKcS5_RS5_PDiS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDiLb1EE10do_unshiftER11__mbstate_tPcS4_RS4_ = Module["__ZNKSt3__215__codecvt_utf16IDiLb1EE10do_unshiftER11__mbstate_tPcS4_RS4_"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDiLb1EE10do_unshiftER11__mbstate_tPcS4_RS4_ = Module["__ZNKSt3__215__codecvt_utf16IDiLb1EE10do_unshiftER11__mbstate_tPcS4_RS4_"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDiLb1EE10do_unshiftER11__mbstate_tPcS4_RS4_"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDiLb1EE11do_encodingEv = Module["__ZNKSt3__215__codecvt_utf16IDiLb1EE11do_encodingEv"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDiLb1EE11do_encodingEv = Module["__ZNKSt3__215__codecvt_utf16IDiLb1EE11do_encodingEv"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDiLb1EE11do_encodingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDiLb1EE16do_always_noconvEv = Module["__ZNKSt3__215__codecvt_utf16IDiLb1EE16do_always_noconvEv"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDiLb1EE16do_always_noconvEv = Module["__ZNKSt3__215__codecvt_utf16IDiLb1EE16do_always_noconvEv"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDiLb1EE16do_always_noconvEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDiLb1EE9do_lengthER11__mbstate_tPKcS5_m = Module["__ZNKSt3__215__codecvt_utf16IDiLb1EE9do_lengthER11__mbstate_tPKcS5_m"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDiLb1EE9do_lengthER11__mbstate_tPKcS5_m = Module["__ZNKSt3__215__codecvt_utf16IDiLb1EE9do_lengthER11__mbstate_tPKcS5_m"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDiLb1EE9do_lengthER11__mbstate_tPKcS5_m"]).apply(null, arguments)
            };
            var __ZNKSt3__215__codecvt_utf16IDiLb1EE13do_max_lengthEv = Module["__ZNKSt3__215__codecvt_utf16IDiLb1EE13do_max_lengthEv"] = function() {
                return (__ZNKSt3__215__codecvt_utf16IDiLb1EE13do_max_lengthEv = Module["__ZNKSt3__215__codecvt_utf16IDiLb1EE13do_max_lengthEv"] = Module["asm"]["_ZNKSt3__215__codecvt_utf16IDiLb1EE13do_max_lengthEv"]).apply(null, arguments)
            };
            var __ZNKSt3__220__codecvt_utf8_utf16IwE6do_outER11__mbstate_tPKwS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__220__codecvt_utf8_utf16IwE6do_outER11__mbstate_tPKwS5_RS5_PcS7_RS7_"] = function() {
                return (__ZNKSt3__220__codecvt_utf8_utf16IwE6do_outER11__mbstate_tPKwS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__220__codecvt_utf8_utf16IwE6do_outER11__mbstate_tPKwS5_RS5_PcS7_RS7_"] = Module["asm"]["_ZNKSt3__220__codecvt_utf8_utf16IwE6do_outER11__mbstate_tPKwS5_RS5_PcS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__220__codecvt_utf8_utf16IwE5do_inER11__mbstate_tPKcS5_RS5_PwS7_RS7_ = Module["__ZNKSt3__220__codecvt_utf8_utf16IwE5do_inER11__mbstate_tPKcS5_RS5_PwS7_RS7_"] = function() {
                return (__ZNKSt3__220__codecvt_utf8_utf16IwE5do_inER11__mbstate_tPKcS5_RS5_PwS7_RS7_ = Module["__ZNKSt3__220__codecvt_utf8_utf16IwE5do_inER11__mbstate_tPKcS5_RS5_PwS7_RS7_"] = Module["asm"]["_ZNKSt3__220__codecvt_utf8_utf16IwE5do_inER11__mbstate_tPKcS5_RS5_PwS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__220__codecvt_utf8_utf16IwE10do_unshiftER11__mbstate_tPcS4_RS4_ = Module["__ZNKSt3__220__codecvt_utf8_utf16IwE10do_unshiftER11__mbstate_tPcS4_RS4_"] = function() {
                return (__ZNKSt3__220__codecvt_utf8_utf16IwE10do_unshiftER11__mbstate_tPcS4_RS4_ = Module["__ZNKSt3__220__codecvt_utf8_utf16IwE10do_unshiftER11__mbstate_tPcS4_RS4_"] = Module["asm"]["_ZNKSt3__220__codecvt_utf8_utf16IwE10do_unshiftER11__mbstate_tPcS4_RS4_"]).apply(null, arguments)
            };
            var __ZNKSt3__220__codecvt_utf8_utf16IwE11do_encodingEv = Module["__ZNKSt3__220__codecvt_utf8_utf16IwE11do_encodingEv"] = function() {
                return (__ZNKSt3__220__codecvt_utf8_utf16IwE11do_encodingEv = Module["__ZNKSt3__220__codecvt_utf8_utf16IwE11do_encodingEv"] = Module["asm"]["_ZNKSt3__220__codecvt_utf8_utf16IwE11do_encodingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__220__codecvt_utf8_utf16IwE16do_always_noconvEv = Module["__ZNKSt3__220__codecvt_utf8_utf16IwE16do_always_noconvEv"] = function() {
                return (__ZNKSt3__220__codecvt_utf8_utf16IwE16do_always_noconvEv = Module["__ZNKSt3__220__codecvt_utf8_utf16IwE16do_always_noconvEv"] = Module["asm"]["_ZNKSt3__220__codecvt_utf8_utf16IwE16do_always_noconvEv"]).apply(null, arguments)
            };
            var __ZNKSt3__220__codecvt_utf8_utf16IwE9do_lengthER11__mbstate_tPKcS5_m = Module["__ZNKSt3__220__codecvt_utf8_utf16IwE9do_lengthER11__mbstate_tPKcS5_m"] = function() {
                return (__ZNKSt3__220__codecvt_utf8_utf16IwE9do_lengthER11__mbstate_tPKcS5_m = Module["__ZNKSt3__220__codecvt_utf8_utf16IwE9do_lengthER11__mbstate_tPKcS5_m"] = Module["asm"]["_ZNKSt3__220__codecvt_utf8_utf16IwE9do_lengthER11__mbstate_tPKcS5_m"]).apply(null, arguments)
            };
            var __ZNKSt3__220__codecvt_utf8_utf16IwE13do_max_lengthEv = Module["__ZNKSt3__220__codecvt_utf8_utf16IwE13do_max_lengthEv"] = function() {
                return (__ZNKSt3__220__codecvt_utf8_utf16IwE13do_max_lengthEv = Module["__ZNKSt3__220__codecvt_utf8_utf16IwE13do_max_lengthEv"] = Module["asm"]["_ZNKSt3__220__codecvt_utf8_utf16IwE13do_max_lengthEv"]).apply(null, arguments)
            };
            var __ZNKSt3__220__codecvt_utf8_utf16IDsE6do_outER11__mbstate_tPKDsS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__220__codecvt_utf8_utf16IDsE6do_outER11__mbstate_tPKDsS5_RS5_PcS7_RS7_"] = function() {
                return (__ZNKSt3__220__codecvt_utf8_utf16IDsE6do_outER11__mbstate_tPKDsS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__220__codecvt_utf8_utf16IDsE6do_outER11__mbstate_tPKDsS5_RS5_PcS7_RS7_"] = Module["asm"]["_ZNKSt3__220__codecvt_utf8_utf16IDsE6do_outER11__mbstate_tPKDsS5_RS5_PcS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__220__codecvt_utf8_utf16IDsE5do_inER11__mbstate_tPKcS5_RS5_PDsS7_RS7_ = Module["__ZNKSt3__220__codecvt_utf8_utf16IDsE5do_inER11__mbstate_tPKcS5_RS5_PDsS7_RS7_"] = function() {
                return (__ZNKSt3__220__codecvt_utf8_utf16IDsE5do_inER11__mbstate_tPKcS5_RS5_PDsS7_RS7_ = Module["__ZNKSt3__220__codecvt_utf8_utf16IDsE5do_inER11__mbstate_tPKcS5_RS5_PDsS7_RS7_"] = Module["asm"]["_ZNKSt3__220__codecvt_utf8_utf16IDsE5do_inER11__mbstate_tPKcS5_RS5_PDsS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__220__codecvt_utf8_utf16IDsE10do_unshiftER11__mbstate_tPcS4_RS4_ = Module["__ZNKSt3__220__codecvt_utf8_utf16IDsE10do_unshiftER11__mbstate_tPcS4_RS4_"] = function() {
                return (__ZNKSt3__220__codecvt_utf8_utf16IDsE10do_unshiftER11__mbstate_tPcS4_RS4_ = Module["__ZNKSt3__220__codecvt_utf8_utf16IDsE10do_unshiftER11__mbstate_tPcS4_RS4_"] = Module["asm"]["_ZNKSt3__220__codecvt_utf8_utf16IDsE10do_unshiftER11__mbstate_tPcS4_RS4_"]).apply(null, arguments)
            };
            var __ZNKSt3__220__codecvt_utf8_utf16IDsE11do_encodingEv = Module["__ZNKSt3__220__codecvt_utf8_utf16IDsE11do_encodingEv"] = function() {
                return (__ZNKSt3__220__codecvt_utf8_utf16IDsE11do_encodingEv = Module["__ZNKSt3__220__codecvt_utf8_utf16IDsE11do_encodingEv"] = Module["asm"]["_ZNKSt3__220__codecvt_utf8_utf16IDsE11do_encodingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__220__codecvt_utf8_utf16IDsE16do_always_noconvEv = Module["__ZNKSt3__220__codecvt_utf8_utf16IDsE16do_always_noconvEv"] = function() {
                return (__ZNKSt3__220__codecvt_utf8_utf16IDsE16do_always_noconvEv = Module["__ZNKSt3__220__codecvt_utf8_utf16IDsE16do_always_noconvEv"] = Module["asm"]["_ZNKSt3__220__codecvt_utf8_utf16IDsE16do_always_noconvEv"]).apply(null, arguments)
            };
            var __ZNKSt3__220__codecvt_utf8_utf16IDsE9do_lengthER11__mbstate_tPKcS5_m = Module["__ZNKSt3__220__codecvt_utf8_utf16IDsE9do_lengthER11__mbstate_tPKcS5_m"] = function() {
                return (__ZNKSt3__220__codecvt_utf8_utf16IDsE9do_lengthER11__mbstate_tPKcS5_m = Module["__ZNKSt3__220__codecvt_utf8_utf16IDsE9do_lengthER11__mbstate_tPKcS5_m"] = Module["asm"]["_ZNKSt3__220__codecvt_utf8_utf16IDsE9do_lengthER11__mbstate_tPKcS5_m"]).apply(null, arguments)
            };
            var __ZNKSt3__220__codecvt_utf8_utf16IDsE13do_max_lengthEv = Module["__ZNKSt3__220__codecvt_utf8_utf16IDsE13do_max_lengthEv"] = function() {
                return (__ZNKSt3__220__codecvt_utf8_utf16IDsE13do_max_lengthEv = Module["__ZNKSt3__220__codecvt_utf8_utf16IDsE13do_max_lengthEv"] = Module["asm"]["_ZNKSt3__220__codecvt_utf8_utf16IDsE13do_max_lengthEv"]).apply(null, arguments)
            };
            var __ZNKSt3__220__codecvt_utf8_utf16IDiE6do_outER11__mbstate_tPKDiS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__220__codecvt_utf8_utf16IDiE6do_outER11__mbstate_tPKDiS5_RS5_PcS7_RS7_"] = function() {
                return (__ZNKSt3__220__codecvt_utf8_utf16IDiE6do_outER11__mbstate_tPKDiS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__220__codecvt_utf8_utf16IDiE6do_outER11__mbstate_tPKDiS5_RS5_PcS7_RS7_"] = Module["asm"]["_ZNKSt3__220__codecvt_utf8_utf16IDiE6do_outER11__mbstate_tPKDiS5_RS5_PcS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__220__codecvt_utf8_utf16IDiE5do_inER11__mbstate_tPKcS5_RS5_PDiS7_RS7_ = Module["__ZNKSt3__220__codecvt_utf8_utf16IDiE5do_inER11__mbstate_tPKcS5_RS5_PDiS7_RS7_"] = function() {
                return (__ZNKSt3__220__codecvt_utf8_utf16IDiE5do_inER11__mbstate_tPKcS5_RS5_PDiS7_RS7_ = Module["__ZNKSt3__220__codecvt_utf8_utf16IDiE5do_inER11__mbstate_tPKcS5_RS5_PDiS7_RS7_"] = Module["asm"]["_ZNKSt3__220__codecvt_utf8_utf16IDiE5do_inER11__mbstate_tPKcS5_RS5_PDiS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__220__codecvt_utf8_utf16IDiE10do_unshiftER11__mbstate_tPcS4_RS4_ = Module["__ZNKSt3__220__codecvt_utf8_utf16IDiE10do_unshiftER11__mbstate_tPcS4_RS4_"] = function() {
                return (__ZNKSt3__220__codecvt_utf8_utf16IDiE10do_unshiftER11__mbstate_tPcS4_RS4_ = Module["__ZNKSt3__220__codecvt_utf8_utf16IDiE10do_unshiftER11__mbstate_tPcS4_RS4_"] = Module["asm"]["_ZNKSt3__220__codecvt_utf8_utf16IDiE10do_unshiftER11__mbstate_tPcS4_RS4_"]).apply(null, arguments)
            };
            var __ZNKSt3__220__codecvt_utf8_utf16IDiE11do_encodingEv = Module["__ZNKSt3__220__codecvt_utf8_utf16IDiE11do_encodingEv"] = function() {
                return (__ZNKSt3__220__codecvt_utf8_utf16IDiE11do_encodingEv = Module["__ZNKSt3__220__codecvt_utf8_utf16IDiE11do_encodingEv"] = Module["asm"]["_ZNKSt3__220__codecvt_utf8_utf16IDiE11do_encodingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__220__codecvt_utf8_utf16IDiE16do_always_noconvEv = Module["__ZNKSt3__220__codecvt_utf8_utf16IDiE16do_always_noconvEv"] = function() {
                return (__ZNKSt3__220__codecvt_utf8_utf16IDiE16do_always_noconvEv = Module["__ZNKSt3__220__codecvt_utf8_utf16IDiE16do_always_noconvEv"] = Module["asm"]["_ZNKSt3__220__codecvt_utf8_utf16IDiE16do_always_noconvEv"]).apply(null, arguments)
            };
            var __ZNKSt3__220__codecvt_utf8_utf16IDiE9do_lengthER11__mbstate_tPKcS5_m = Module["__ZNKSt3__220__codecvt_utf8_utf16IDiE9do_lengthER11__mbstate_tPKcS5_m"] = function() {
                return (__ZNKSt3__220__codecvt_utf8_utf16IDiE9do_lengthER11__mbstate_tPKcS5_m = Module["__ZNKSt3__220__codecvt_utf8_utf16IDiE9do_lengthER11__mbstate_tPKcS5_m"] = Module["asm"]["_ZNKSt3__220__codecvt_utf8_utf16IDiE9do_lengthER11__mbstate_tPKcS5_m"]).apply(null, arguments)
            };
            var __ZNKSt3__220__codecvt_utf8_utf16IDiE13do_max_lengthEv = Module["__ZNKSt3__220__codecvt_utf8_utf16IDiE13do_max_lengthEv"] = function() {
                return (__ZNKSt3__220__codecvt_utf8_utf16IDiE13do_max_lengthEv = Module["__ZNKSt3__220__codecvt_utf8_utf16IDiE13do_max_lengthEv"] = Module["asm"]["_ZNKSt3__220__codecvt_utf8_utf16IDiE13do_max_lengthEv"]).apply(null, arguments)
            };
            var __ZNSt3__216__narrow_to_utf8ILm16EED0Ev = Module["__ZNSt3__216__narrow_to_utf8ILm16EED0Ev"] = function() {
                return (__ZNSt3__216__narrow_to_utf8ILm16EED0Ev = Module["__ZNSt3__216__narrow_to_utf8ILm16EED0Ev"] = Module["asm"]["_ZNSt3__216__narrow_to_utf8ILm16EED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__216__narrow_to_utf8ILm32EED0Ev = Module["__ZNSt3__216__narrow_to_utf8ILm32EED0Ev"] = function() {
                return (__ZNSt3__216__narrow_to_utf8ILm32EED0Ev = Module["__ZNSt3__216__narrow_to_utf8ILm32EED0Ev"] = Module["asm"]["_ZNSt3__216__narrow_to_utf8ILm32EED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217__widen_from_utf8ILm16EED0Ev = Module["__ZNSt3__217__widen_from_utf8ILm16EED0Ev"] = function() {
                return (__ZNSt3__217__widen_from_utf8ILm16EED0Ev = Module["__ZNSt3__217__widen_from_utf8ILm16EED0Ev"] = Module["asm"]["_ZNSt3__217__widen_from_utf8ILm16EED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217__widen_from_utf8ILm32EED0Ev = Module["__ZNSt3__217__widen_from_utf8ILm32EED0Ev"] = function() {
                return (__ZNSt3__217__widen_from_utf8ILm32EED0Ev = Module["__ZNSt3__217__widen_from_utf8ILm32EED0Ev"] = Module["asm"]["_ZNSt3__217__widen_from_utf8ILm32EED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28numpunctIcED2Ev = Module["__ZNSt3__28numpunctIcED2Ev"] = function() {
                return (__ZNSt3__28numpunctIcED2Ev = Module["__ZNSt3__28numpunctIcED2Ev"] = Module["asm"]["_ZNSt3__28numpunctIcED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28numpunctIcED0Ev = Module["__ZNSt3__28numpunctIcED0Ev"] = function() {
                return (__ZNSt3__28numpunctIcED0Ev = Module["__ZNSt3__28numpunctIcED0Ev"] = Module["asm"]["_ZNSt3__28numpunctIcED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28numpunctIwED2Ev = Module["__ZNSt3__28numpunctIwED2Ev"] = function() {
                return (__ZNSt3__28numpunctIwED2Ev = Module["__ZNSt3__28numpunctIwED2Ev"] = Module["asm"]["_ZNSt3__28numpunctIwED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28numpunctIwED0Ev = Module["__ZNSt3__28numpunctIwED0Ev"] = function() {
                return (__ZNSt3__28numpunctIwED0Ev = Module["__ZNSt3__28numpunctIwED0Ev"] = Module["asm"]["_ZNSt3__28numpunctIwED0Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__28numpunctIcE16do_decimal_pointEv = Module["__ZNKSt3__28numpunctIcE16do_decimal_pointEv"] = function() {
                return (__ZNKSt3__28numpunctIcE16do_decimal_pointEv = Module["__ZNKSt3__28numpunctIcE16do_decimal_pointEv"] = Module["asm"]["_ZNKSt3__28numpunctIcE16do_decimal_pointEv"]).apply(null, arguments)
            };
            var __ZNKSt3__28numpunctIwE16do_decimal_pointEv = Module["__ZNKSt3__28numpunctIwE16do_decimal_pointEv"] = function() {
                return (__ZNKSt3__28numpunctIwE16do_decimal_pointEv = Module["__ZNKSt3__28numpunctIwE16do_decimal_pointEv"] = Module["asm"]["_ZNKSt3__28numpunctIwE16do_decimal_pointEv"]).apply(null, arguments)
            };
            var __ZNKSt3__28numpunctIcE16do_thousands_sepEv = Module["__ZNKSt3__28numpunctIcE16do_thousands_sepEv"] = function() {
                return (__ZNKSt3__28numpunctIcE16do_thousands_sepEv = Module["__ZNKSt3__28numpunctIcE16do_thousands_sepEv"] = Module["asm"]["_ZNKSt3__28numpunctIcE16do_thousands_sepEv"]).apply(null, arguments)
            };
            var __ZNKSt3__28numpunctIwE16do_thousands_sepEv = Module["__ZNKSt3__28numpunctIwE16do_thousands_sepEv"] = function() {
                return (__ZNKSt3__28numpunctIwE16do_thousands_sepEv = Module["__ZNKSt3__28numpunctIwE16do_thousands_sepEv"] = Module["asm"]["_ZNKSt3__28numpunctIwE16do_thousands_sepEv"]).apply(null, arguments)
            };
            var __ZNKSt3__28numpunctIcE11do_groupingEv = Module["__ZNKSt3__28numpunctIcE11do_groupingEv"] = function() {
                return (__ZNKSt3__28numpunctIcE11do_groupingEv = Module["__ZNKSt3__28numpunctIcE11do_groupingEv"] = Module["asm"]["_ZNKSt3__28numpunctIcE11do_groupingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__28numpunctIwE11do_groupingEv = Module["__ZNKSt3__28numpunctIwE11do_groupingEv"] = function() {
                return (__ZNKSt3__28numpunctIwE11do_groupingEv = Module["__ZNKSt3__28numpunctIwE11do_groupingEv"] = Module["asm"]["_ZNKSt3__28numpunctIwE11do_groupingEv"]).apply(null, arguments)
            };
            var __ZNKSt3__28numpunctIcE11do_truenameEv = Module["__ZNKSt3__28numpunctIcE11do_truenameEv"] = function() {
                return (__ZNKSt3__28numpunctIcE11do_truenameEv = Module["__ZNKSt3__28numpunctIcE11do_truenameEv"] = Module["asm"]["_ZNKSt3__28numpunctIcE11do_truenameEv"]).apply(null, arguments)
            };
            var __ZNKSt3__28numpunctIwE11do_truenameEv = Module["__ZNKSt3__28numpunctIwE11do_truenameEv"] = function() {
                return (__ZNKSt3__28numpunctIwE11do_truenameEv = Module["__ZNKSt3__28numpunctIwE11do_truenameEv"] = Module["asm"]["_ZNKSt3__28numpunctIwE11do_truenameEv"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2IDnEEPKw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2IDnEEPKw"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2IDnEEPKw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2IDnEEPKw"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2IDnEEPKw"]).apply(null, arguments)
            };
            var __ZNKSt3__28numpunctIcE12do_falsenameEv = Module["__ZNKSt3__28numpunctIcE12do_falsenameEv"] = function() {
                return (__ZNKSt3__28numpunctIcE12do_falsenameEv = Module["__ZNKSt3__28numpunctIcE12do_falsenameEv"] = Module["asm"]["_ZNKSt3__28numpunctIcE12do_falsenameEv"]).apply(null, arguments)
            };
            var __ZNKSt3__28numpunctIwE12do_falsenameEv = Module["__ZNKSt3__28numpunctIwE12do_falsenameEv"] = function() {
                return (__ZNKSt3__28numpunctIwE12do_falsenameEv = Module["__ZNKSt3__28numpunctIwE12do_falsenameEv"] = Module["asm"]["_ZNKSt3__28numpunctIwE12do_falsenameEv"]).apply(null, arguments)
            };
            var __ZNSt3__215numpunct_bynameIcEC2EPKcm = Module["__ZNSt3__215numpunct_bynameIcEC2EPKcm"] = function() {
                return (__ZNSt3__215numpunct_bynameIcEC2EPKcm = Module["__ZNSt3__215numpunct_bynameIcEC2EPKcm"] = Module["asm"]["_ZNSt3__215numpunct_bynameIcEC2EPKcm"]).apply(null, arguments)
            };
            var __ZNSt3__215numpunct_bynameIcE6__initEPKc = Module["__ZNSt3__215numpunct_bynameIcE6__initEPKc"] = function() {
                return (__ZNSt3__215numpunct_bynameIcE6__initEPKc = Module["__ZNSt3__215numpunct_bynameIcE6__initEPKc"] = Module["asm"]["_ZNSt3__215numpunct_bynameIcE6__initEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__222__libcpp_unique_localeC2EPKc = Module["__ZNSt3__222__libcpp_unique_localeC2EPKc"] = function() {
                return (__ZNSt3__222__libcpp_unique_localeC2EPKc = Module["__ZNSt3__222__libcpp_unique_localeC2EPKc"] = Module["asm"]["_ZNSt3__222__libcpp_unique_localeC2EPKc"]).apply(null, arguments)
            };
            var __ZNKSt3__222__libcpp_unique_localecvbEv = Module["__ZNKSt3__222__libcpp_unique_localecvbEv"] = function() {
                return (__ZNKSt3__222__libcpp_unique_localecvbEv = Module["__ZNKSt3__222__libcpp_unique_localecvbEv"] = Module["asm"]["_ZNKSt3__222__libcpp_unique_localecvbEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__libcpp_unique_locale3getEv = Module["__ZNSt3__222__libcpp_unique_locale3getEv"] = function() {
                return (__ZNSt3__222__libcpp_unique_locale3getEv = Module["__ZNSt3__222__libcpp_unique_locale3getEv"] = Module["asm"]["_ZNSt3__222__libcpp_unique_locale3getEv"]).apply(null, arguments)
            };
            var __ZNSt3__221__libcpp_localeconv_lEP15__locale_struct = Module["__ZNSt3__221__libcpp_localeconv_lEP15__locale_struct"] = function() {
                return (__ZNSt3__221__libcpp_localeconv_lEP15__locale_struct = Module["__ZNSt3__221__libcpp_localeconv_lEP15__locale_struct"] = Module["asm"]["_ZNSt3__221__libcpp_localeconv_lEP15__locale_struct"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSEPKc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSEPKc"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSEPKc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSEPKc"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEaSEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__222__libcpp_unique_localeD2Ev = Module["__ZNSt3__222__libcpp_unique_localeD2Ev"] = function() {
                return (__ZNSt3__222__libcpp_unique_localeD2Ev = Module["__ZNSt3__222__libcpp_unique_localeD2Ev"] = Module["asm"]["_ZNSt3__222__libcpp_unique_localeD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215numpunct_bynameIcED0Ev = Module["__ZNSt3__215numpunct_bynameIcED0Ev"] = function() {
                return (__ZNSt3__215numpunct_bynameIcED0Ev = Module["__ZNSt3__215numpunct_bynameIcED0Ev"] = Module["asm"]["_ZNSt3__215numpunct_bynameIcED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215numpunct_bynameIwEC2EPKcm = Module["__ZNSt3__215numpunct_bynameIwEC2EPKcm"] = function() {
                return (__ZNSt3__215numpunct_bynameIwEC2EPKcm = Module["__ZNSt3__215numpunct_bynameIwEC2EPKcm"] = Module["asm"]["_ZNSt3__215numpunct_bynameIwEC2EPKcm"]).apply(null, arguments)
            };
            var __ZNSt3__215numpunct_bynameIwE6__initEPKc = Module["__ZNSt3__215numpunct_bynameIwE6__initEPKc"] = function() {
                return (__ZNSt3__215numpunct_bynameIwE6__initEPKc = Module["__ZNSt3__215numpunct_bynameIwE6__initEPKc"] = Module["asm"]["_ZNSt3__215numpunct_bynameIwE6__initEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__215numpunct_bynameIwED0Ev = Module["__ZNSt3__215numpunct_bynameIwED0Ev"] = function() {
                return (__ZNSt3__215numpunct_bynameIwED0Ev = Module["__ZNSt3__215numpunct_bynameIwED0Ev"] = Module["asm"]["_ZNSt3__215numpunct_bynameIwED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29__reverseIPjEEvT_S2_NS_26random_access_iterator_tagE = Module["__ZNSt3__29__reverseIPjEEvT_S2_NS_26random_access_iterator_tagE"] = function() {
                return (__ZNSt3__29__reverseIPjEEvT_S2_NS_26random_access_iterator_tagE = Module["__ZNSt3__29__reverseIPjEEvT_S2_NS_26random_access_iterator_tagE"] = Module["asm"]["_ZNSt3__29__reverseIPjEEvT_S2_NS_26random_access_iterator_tagE"]).apply(null, arguments)
            };
            var __ZNKSt3__220__time_get_c_storageIcE7__weeksEv = Module["__ZNKSt3__220__time_get_c_storageIcE7__weeksEv"] = function() {
                return (__ZNKSt3__220__time_get_c_storageIcE7__weeksEv = Module["__ZNKSt3__220__time_get_c_storageIcE7__weeksEv"] = Module["asm"]["_ZNKSt3__220__time_get_c_storageIcE7__weeksEv"]).apply(null, arguments)
            };
            var __ZNKSt3__220__time_get_c_storageIwE7__weeksEv = Module["__ZNKSt3__220__time_get_c_storageIwE7__weeksEv"] = function() {
                return (__ZNKSt3__220__time_get_c_storageIwE7__weeksEv = Module["__ZNKSt3__220__time_get_c_storageIwE7__weeksEv"] = Module["asm"]["_ZNKSt3__220__time_get_c_storageIwE7__weeksEv"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEaSEPKw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEaSEPKw"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEaSEPKw = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEaSEPKw"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEaSEPKw"]).apply(null, arguments)
            };
            var __ZNKSt3__220__time_get_c_storageIcE8__monthsEv = Module["__ZNKSt3__220__time_get_c_storageIcE8__monthsEv"] = function() {
                return (__ZNKSt3__220__time_get_c_storageIcE8__monthsEv = Module["__ZNKSt3__220__time_get_c_storageIcE8__monthsEv"] = Module["asm"]["_ZNKSt3__220__time_get_c_storageIcE8__monthsEv"]).apply(null, arguments)
            };
            var __ZNKSt3__220__time_get_c_storageIwE8__monthsEv = Module["__ZNKSt3__220__time_get_c_storageIwE8__monthsEv"] = function() {
                return (__ZNKSt3__220__time_get_c_storageIwE8__monthsEv = Module["__ZNKSt3__220__time_get_c_storageIwE8__monthsEv"] = Module["asm"]["_ZNKSt3__220__time_get_c_storageIwE8__monthsEv"]).apply(null, arguments)
            };
            var __ZNKSt3__220__time_get_c_storageIcE7__am_pmEv = Module["__ZNKSt3__220__time_get_c_storageIcE7__am_pmEv"] = function() {
                return (__ZNKSt3__220__time_get_c_storageIcE7__am_pmEv = Module["__ZNKSt3__220__time_get_c_storageIcE7__am_pmEv"] = Module["asm"]["_ZNKSt3__220__time_get_c_storageIcE7__am_pmEv"]).apply(null, arguments)
            };
            var __ZNKSt3__220__time_get_c_storageIwE7__am_pmEv = Module["__ZNKSt3__220__time_get_c_storageIwE7__am_pmEv"] = function() {
                return (__ZNKSt3__220__time_get_c_storageIwE7__am_pmEv = Module["__ZNKSt3__220__time_get_c_storageIwE7__am_pmEv"] = Module["asm"]["_ZNKSt3__220__time_get_c_storageIwE7__am_pmEv"]).apply(null, arguments)
            };
            var __ZNKSt3__220__time_get_c_storageIcE3__xEv = Module["__ZNKSt3__220__time_get_c_storageIcE3__xEv"] = function() {
                return (__ZNKSt3__220__time_get_c_storageIcE3__xEv = Module["__ZNKSt3__220__time_get_c_storageIcE3__xEv"] = Module["asm"]["_ZNKSt3__220__time_get_c_storageIcE3__xEv"]).apply(null, arguments)
            };
            var __ZNKSt3__220__time_get_c_storageIwE3__xEv = Module["__ZNKSt3__220__time_get_c_storageIwE3__xEv"] = function() {
                return (__ZNKSt3__220__time_get_c_storageIwE3__xEv = Module["__ZNKSt3__220__time_get_c_storageIwE3__xEv"] = Module["asm"]["_ZNKSt3__220__time_get_c_storageIwE3__xEv"]).apply(null, arguments)
            };
            var __ZNKSt3__220__time_get_c_storageIcE3__XEv = Module["__ZNKSt3__220__time_get_c_storageIcE3__XEv"] = function() {
                return (__ZNKSt3__220__time_get_c_storageIcE3__XEv = Module["__ZNKSt3__220__time_get_c_storageIcE3__XEv"] = Module["asm"]["_ZNKSt3__220__time_get_c_storageIcE3__XEv"]).apply(null, arguments)
            };
            var __ZNKSt3__220__time_get_c_storageIwE3__XEv = Module["__ZNKSt3__220__time_get_c_storageIwE3__XEv"] = function() {
                return (__ZNKSt3__220__time_get_c_storageIwE3__XEv = Module["__ZNKSt3__220__time_get_c_storageIwE3__XEv"] = Module["asm"]["_ZNKSt3__220__time_get_c_storageIwE3__XEv"]).apply(null, arguments)
            };
            var __ZNKSt3__220__time_get_c_storageIcE3__cEv = Module["__ZNKSt3__220__time_get_c_storageIcE3__cEv"] = function() {
                return (__ZNKSt3__220__time_get_c_storageIcE3__cEv = Module["__ZNKSt3__220__time_get_c_storageIcE3__cEv"] = Module["asm"]["_ZNKSt3__220__time_get_c_storageIcE3__cEv"]).apply(null, arguments)
            };
            var __ZNKSt3__220__time_get_c_storageIwE3__cEv = Module["__ZNKSt3__220__time_get_c_storageIwE3__cEv"] = function() {
                return (__ZNKSt3__220__time_get_c_storageIwE3__cEv = Module["__ZNKSt3__220__time_get_c_storageIwE3__cEv"] = Module["asm"]["_ZNKSt3__220__time_get_c_storageIwE3__cEv"]).apply(null, arguments)
            };
            var __ZNKSt3__220__time_get_c_storageIcE3__rEv = Module["__ZNKSt3__220__time_get_c_storageIcE3__rEv"] = function() {
                return (__ZNKSt3__220__time_get_c_storageIcE3__rEv = Module["__ZNKSt3__220__time_get_c_storageIcE3__rEv"] = Module["asm"]["_ZNKSt3__220__time_get_c_storageIcE3__rEv"]).apply(null, arguments)
            };
            var __ZNKSt3__220__time_get_c_storageIwE3__rEv = Module["__ZNKSt3__220__time_get_c_storageIwE3__rEv"] = function() {
                return (__ZNKSt3__220__time_get_c_storageIwE3__rEv = Module["__ZNKSt3__220__time_get_c_storageIwE3__rEv"] = Module["asm"]["_ZNKSt3__220__time_get_c_storageIwE3__rEv"]).apply(null, arguments)
            };
            var __ZNSt3__210__time_getC2EPKc = Module["__ZNSt3__210__time_getC2EPKc"] = function() {
                return (__ZNSt3__210__time_getC2EPKc = Module["__ZNSt3__210__time_getC2EPKc"] = Module["asm"]["_ZNSt3__210__time_getC2EPKc"]).apply(null, arguments)
            };
            var __ZNSt3__210__time_getC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__210__time_getC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = function() {
                return (__ZNSt3__210__time_getC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__210__time_getC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = Module["asm"]["_ZNSt3__210__time_getC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNSt3__210__time_getD2Ev = Module["__ZNSt3__210__time_getD2Ev"] = function() {
                return (__ZNSt3__210__time_getD2Ev = Module["__ZNSt3__210__time_getD2Ev"] = Module["asm"]["_ZNSt3__210__time_getD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__218__time_get_storageIcE9__analyzeEcRKNS_5ctypeIcEE = Module["__ZNSt3__218__time_get_storageIcE9__analyzeEcRKNS_5ctypeIcEE"] = function() {
                return (__ZNSt3__218__time_get_storageIcE9__analyzeEcRKNS_5ctypeIcEE = Module["__ZNSt3__218__time_get_storageIcE9__analyzeEcRKNS_5ctypeIcEE"] = Module["asm"]["_ZNSt3__218__time_get_storageIcE9__analyzeEcRKNS_5ctypeIcEE"]).apply(null, arguments)
            };
            var __ZNSt3__214__scan_keywordIPcPNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_5ctypeIcEEEET0_RT_SC_SB_SB_RKT1_Rjb = Module["__ZNSt3__214__scan_keywordIPcPNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_5ctypeIcEEEET0_RT_SC_SB_SB_RKT1_Rjb"] = function() {
                return (__ZNSt3__214__scan_keywordIPcPNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_5ctypeIcEEEET0_RT_SC_SB_SB_RKT1_Rjb = Module["__ZNSt3__214__scan_keywordIPcPNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_5ctypeIcEEEET0_RT_SC_SB_SB_RKT1_Rjb"] = Module["asm"]["_ZNSt3__214__scan_keywordIPcPNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_5ctypeIcEEEET0_RT_SC_SB_SB_RKT1_Rjb"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4backEv = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4backEv"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4backEv = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4backEv"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4backEv"]).apply(null, arguments)
            };
            var __ZNSt3__220__get_up_to_n_digitsIcPcEEiRT0_S2_RjRKNS_5ctypeIT_EEi = Module["__ZNSt3__220__get_up_to_n_digitsIcPcEEiRT0_S2_RjRKNS_5ctypeIT_EEi"] = function() {
                return (__ZNSt3__220__get_up_to_n_digitsIcPcEEiRT0_S2_RjRKNS_5ctypeIT_EEi = Module["__ZNSt3__220__get_up_to_n_digitsIcPcEEiRT0_S2_RjRKNS_5ctypeIT_EEi"] = Module["asm"]["_ZNSt3__220__get_up_to_n_digitsIcPcEEiRT0_S2_RjRKNS_5ctypeIT_EEi"]).apply(null, arguments)
            };
            var __ZNSt3__28distanceIPNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_ = Module["__ZNSt3__28distanceIPNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_"] = function() {
                return (__ZNSt3__28distanceIPNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_ = Module["__ZNSt3__28distanceIPNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_"] = Module["asm"]["_ZNSt3__28distanceIPNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_"]).apply(null, arguments)
            };
            var __ZNSt3__218__time_get_storageIwE9__analyzeEcRKNS_5ctypeIwEE = Module["__ZNSt3__218__time_get_storageIwE9__analyzeEcRKNS_5ctypeIwEE"] = function() {
                return (__ZNSt3__218__time_get_storageIwE9__analyzeEcRKNS_5ctypeIwEE = Module["__ZNSt3__218__time_get_storageIwE9__analyzeEcRKNS_5ctypeIwEE"] = Module["asm"]["_ZNSt3__218__time_get_storageIwE9__analyzeEcRKNS_5ctypeIwEE"]).apply(null, arguments)
            };
            var __ZNSt3__214__scan_keywordIPwPNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEENS_5ctypeIwEEEET0_RT_SC_SB_SB_RKT1_Rjb = Module["__ZNSt3__214__scan_keywordIPwPNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEENS_5ctypeIwEEEET0_RT_SC_SB_SB_RKT1_Rjb"] = function() {
                return (__ZNSt3__214__scan_keywordIPwPNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEENS_5ctypeIwEEEET0_RT_SC_SB_SB_RKT1_Rjb = Module["__ZNSt3__214__scan_keywordIPwPNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEENS_5ctypeIwEEEET0_RT_SC_SB_SB_RKT1_Rjb"] = Module["asm"]["_ZNSt3__214__scan_keywordIPwPNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEENS_5ctypeIwEEEET0_RT_SC_SB_SB_RKT1_Rjb"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4backEv = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4backEv"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4backEv = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4backEv"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4backEv"]).apply(null, arguments)
            };
            var __ZNSt3__220__get_up_to_n_digitsIwPwEEiRT0_S2_RjRKNS_5ctypeIT_EEi = Module["__ZNSt3__220__get_up_to_n_digitsIwPwEEiRT0_S2_RjRKNS_5ctypeIT_EEi"] = function() {
                return (__ZNSt3__220__get_up_to_n_digitsIwPwEEiRT0_S2_RjRKNS_5ctypeIT_EEi = Module["__ZNSt3__220__get_up_to_n_digitsIwPwEEiRT0_S2_RjRKNS_5ctypeIT_EEi"] = Module["asm"]["_ZNSt3__220__get_up_to_n_digitsIwPwEEiRT0_S2_RjRKNS_5ctypeIT_EEi"]).apply(null, arguments)
            };
            var __ZNSt3__28distanceIPNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_ = Module["__ZNSt3__28distanceIPNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_"] = function() {
                return (__ZNSt3__28distanceIPNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_ = Module["__ZNSt3__28distanceIPNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_"] = Module["asm"]["_ZNSt3__28distanceIPNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_"]).apply(null, arguments)
            };
            var __ZNSt3__218__time_get_storageIcE4initERKNS_5ctypeIcEE = Module["__ZNSt3__218__time_get_storageIcE4initERKNS_5ctypeIcEE"] = function() {
                return (__ZNSt3__218__time_get_storageIcE4initERKNS_5ctypeIcEE = Module["__ZNSt3__218__time_get_storageIcE4initERKNS_5ctypeIcEE"] = Module["asm"]["_ZNSt3__218__time_get_storageIcE4initERKNS_5ctypeIcEE"]).apply(null, arguments)
            };
            var __ZNSt3__218__time_get_storageIwE4initERKNS_5ctypeIwEE = Module["__ZNSt3__218__time_get_storageIwE4initERKNS_5ctypeIwEE"] = function() {
                return (__ZNSt3__218__time_get_storageIwE4initERKNS_5ctypeIwEE = Module["__ZNSt3__218__time_get_storageIwE4initERKNS_5ctypeIwEE"] = Module["asm"]["_ZNSt3__218__time_get_storageIwE4initERKNS_5ctypeIwEE"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignIPwEENS_9enable_ifIXaasr27__is_cpp17_forward_iteratorIT_EE5valuesr38__libcpp_string_gets_noexcept_iteratorIS9_EE5valueERS5_E4typeES9_S9_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignIPwEENS_9enable_ifIXaasr27__is_cpp17_forward_iteratorIT_EE5valuesr38__libcpp_string_gets_noexcept_iteratorIS9_EE5valueERS5_E4typeES9_S9_"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignIPwEENS_9enable_ifIXaasr27__is_cpp17_forward_iteratorIT_EE5valuesr38__libcpp_string_gets_noexcept_iteratorIS9_EE5valueERS5_E4typeES9_S9_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignIPwEENS_9enable_ifIXaasr27__is_cpp17_forward_iteratorIT_EE5valuesr38__libcpp_string_gets_noexcept_iteratorIS9_EE5valueERS5_E4typeES9_S9_"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6assignIPwEENS_9enable_ifIXaasr27__is_cpp17_forward_iteratorIT_EE5valuesr38__libcpp_string_gets_noexcept_iteratorIS9_EE5valueERS5_E4typeES9_S9_"]).apply(null, arguments)
            };
            var __ZNSt3__28distanceIPwEENS_15iterator_traitsIT_E15difference_typeES3_S3_ = Module["__ZNSt3__28distanceIPwEENS_15iterator_traitsIT_E15difference_typeES3_S3_"] = function() {
                return (__ZNSt3__28distanceIPwEENS_15iterator_traitsIT_E15difference_typeES3_S3_ = Module["__ZNSt3__28distanceIPwEENS_15iterator_traitsIT_E15difference_typeES3_S3_"] = Module["asm"]["_ZNSt3__28distanceIPwEENS_15iterator_traitsIT_E15difference_typeES3_S3_"]).apply(null, arguments)
            };
            var __ZNSt3__218__time_get_storageIcEC2EPKc = Module["__ZNSt3__218__time_get_storageIcEC2EPKc"] = function() {
                return (__ZNSt3__218__time_get_storageIcEC2EPKc = Module["__ZNSt3__218__time_get_storageIcEC2EPKc"] = Module["asm"]["_ZNSt3__218__time_get_storageIcEC2EPKc"]).apply(null, arguments)
            };
            var __ZNSt3__215__time_get_tempIcEC2EPKc = Module["__ZNSt3__215__time_get_tempIcEC2EPKc"] = function() {
                return (__ZNSt3__215__time_get_tempIcEC2EPKc = Module["__ZNSt3__215__time_get_tempIcEC2EPKc"] = Module["asm"]["_ZNSt3__215__time_get_tempIcEC2EPKc"]).apply(null, arguments)
            };
            var __ZNSt3__215__time_get_tempIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__215__time_get_tempIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = function() {
                return (__ZNSt3__215__time_get_tempIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__215__time_get_tempIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = Module["asm"]["_ZNSt3__215__time_get_tempIcEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNSt3__218__time_get_storageIwEC2EPKc = Module["__ZNSt3__218__time_get_storageIwEC2EPKc"] = function() {
                return (__ZNSt3__218__time_get_storageIwEC2EPKc = Module["__ZNSt3__218__time_get_storageIwEC2EPKc"] = Module["asm"]["_ZNSt3__218__time_get_storageIwEC2EPKc"]).apply(null, arguments)
            };
            var __ZNSt3__215__time_get_tempIwEC2EPKc = Module["__ZNSt3__215__time_get_tempIwEC2EPKc"] = function() {
                return (__ZNSt3__215__time_get_tempIwEC2EPKc = Module["__ZNSt3__215__time_get_tempIwEC2EPKc"] = Module["asm"]["_ZNSt3__215__time_get_tempIwEC2EPKc"]).apply(null, arguments)
            };
            var __ZNSt3__215__time_get_tempIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__215__time_get_tempIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = function() {
                return (__ZNSt3__215__time_get_tempIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__215__time_get_tempIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = Module["asm"]["_ZNSt3__215__time_get_tempIwEC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNKSt3__218__time_get_storageIcE15__do_date_orderEv = Module["__ZNKSt3__218__time_get_storageIcE15__do_date_orderEv"] = function() {
                return (__ZNKSt3__218__time_get_storageIcE15__do_date_orderEv = Module["__ZNKSt3__218__time_get_storageIcE15__do_date_orderEv"] = Module["asm"]["_ZNKSt3__218__time_get_storageIcE15__do_date_orderEv"]).apply(null, arguments)
            };
            var __ZNKSt3__218__time_get_storageIwE15__do_date_orderEv = Module["__ZNKSt3__218__time_get_storageIwE15__do_date_orderEv"] = function() {
                return (__ZNKSt3__218__time_get_storageIwE15__do_date_orderEv = Module["__ZNKSt3__218__time_get_storageIwE15__do_date_orderEv"] = Module["asm"]["_ZNKSt3__218__time_get_storageIwE15__do_date_orderEv"]).apply(null, arguments)
            };
            var __ZNSt3__210__time_putC2EPKc = Module["__ZNSt3__210__time_putC2EPKc"] = function() {
                return (__ZNSt3__210__time_putC2EPKc = Module["__ZNSt3__210__time_putC2EPKc"] = Module["asm"]["_ZNSt3__210__time_putC2EPKc"]).apply(null, arguments)
            };
            var __ZNSt3__210__time_putC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__210__time_putC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = function() {
                return (__ZNSt3__210__time_putC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__210__time_putC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = Module["asm"]["_ZNSt3__210__time_putC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNSt3__210__time_putD2Ev = Module["__ZNSt3__210__time_putD2Ev"] = function() {
                return (__ZNSt3__210__time_putD2Ev = Module["__ZNSt3__210__time_putD2Ev"] = Module["asm"]["_ZNSt3__210__time_putD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRcEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRcEEONS_16remove_referenceIT_E4typeEOS3_"] = function() {
                return (__ZNSt3__24moveIRcEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRcEEONS_16remove_referenceIT_E4typeEOS3_"] = Module["asm"]["_ZNSt3__24moveIRcEEONS_16remove_referenceIT_E4typeEOS3_"]).apply(null, arguments)
            };
            var __ZNSt3__26rotateINS_11__wrap_iterIPcEEEET_S4_S4_S4_ = Module["__ZNSt3__26rotateINS_11__wrap_iterIPcEEEET_S4_S4_S4_"] = function() {
                return (__ZNSt3__26rotateINS_11__wrap_iterIPcEEEET_S4_S4_S4_ = Module["__ZNSt3__26rotateINS_11__wrap_iterIPcEEEET_S4_S4_S4_"] = Module["asm"]["_ZNSt3__26rotateINS_11__wrap_iterIPcEEEET_S4_S4_S4_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5eraseENS_11__wrap_iterIPKcEE = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5eraseENS_11__wrap_iterIPKcEE"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5eraseENS_11__wrap_iterIPKcEE = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5eraseENS_11__wrap_iterIPKcEE"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE5eraseENS_11__wrap_iterIPKcEE"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE8pop_backEv = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE8pop_backEv"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE8pop_backEv = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE8pop_backEv"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE8pop_backEv"]).apply(null, arguments)
            };
            var __ZNSt3__26rotateINS_11__wrap_iterIPwEEEET_S4_S4_S4_ = Module["__ZNSt3__26rotateINS_11__wrap_iterIPwEEEET_S4_S4_S4_"] = function() {
                return (__ZNSt3__26rotateINS_11__wrap_iterIPwEEEET_S4_S4_S4_ = Module["__ZNSt3__26rotateINS_11__wrap_iterIPwEEEET_S4_S4_S4_"] = Module["asm"]["_ZNSt3__26rotateINS_11__wrap_iterIPwEEEET_S4_S4_S4_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5eraseENS_11__wrap_iterIPKwEE = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5eraseENS_11__wrap_iterIPKwEE"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5eraseENS_11__wrap_iterIPKwEE = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5eraseENS_11__wrap_iterIPKwEE"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE5eraseENS_11__wrap_iterIPKwEE"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE8pop_backEv = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE8pop_backEv"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE8pop_backEv = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE8pop_backEv"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE8pop_backEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__codecvt_utf8IwED0Ev = Module["__ZNSt3__214__codecvt_utf8IwED0Ev"] = function() {
                return (__ZNSt3__214__codecvt_utf8IwED0Ev = Module["__ZNSt3__214__codecvt_utf8IwED0Ev"] = Module["asm"]["_ZNSt3__214__codecvt_utf8IwED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214__codecvt_utf8IDsED0Ev = Module["__ZNSt3__214__codecvt_utf8IDsED0Ev"] = function() {
                return (__ZNSt3__214__codecvt_utf8IDsED0Ev = Module["__ZNSt3__214__codecvt_utf8IDsED0Ev"] = Module["asm"]["_ZNSt3__214__codecvt_utf8IDsED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214__codecvt_utf8IDiED0Ev = Module["__ZNSt3__214__codecvt_utf8IDiED0Ev"] = function() {
                return (__ZNSt3__214__codecvt_utf8IDiED0Ev = Module["__ZNSt3__214__codecvt_utf8IDiED0Ev"] = Module["asm"]["_ZNSt3__214__codecvt_utf8IDiED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215__codecvt_utf16IwLb0EED0Ev = Module["__ZNSt3__215__codecvt_utf16IwLb0EED0Ev"] = function() {
                return (__ZNSt3__215__codecvt_utf16IwLb0EED0Ev = Module["__ZNSt3__215__codecvt_utf16IwLb0EED0Ev"] = Module["asm"]["_ZNSt3__215__codecvt_utf16IwLb0EED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215__codecvt_utf16IwLb1EED0Ev = Module["__ZNSt3__215__codecvt_utf16IwLb1EED0Ev"] = function() {
                return (__ZNSt3__215__codecvt_utf16IwLb1EED0Ev = Module["__ZNSt3__215__codecvt_utf16IwLb1EED0Ev"] = Module["asm"]["_ZNSt3__215__codecvt_utf16IwLb1EED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215__codecvt_utf16IDsLb0EED0Ev = Module["__ZNSt3__215__codecvt_utf16IDsLb0EED0Ev"] = function() {
                return (__ZNSt3__215__codecvt_utf16IDsLb0EED0Ev = Module["__ZNSt3__215__codecvt_utf16IDsLb0EED0Ev"] = Module["asm"]["_ZNSt3__215__codecvt_utf16IDsLb0EED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215__codecvt_utf16IDsLb1EED0Ev = Module["__ZNSt3__215__codecvt_utf16IDsLb1EED0Ev"] = function() {
                return (__ZNSt3__215__codecvt_utf16IDsLb1EED0Ev = Module["__ZNSt3__215__codecvt_utf16IDsLb1EED0Ev"] = Module["asm"]["_ZNSt3__215__codecvt_utf16IDsLb1EED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215__codecvt_utf16IDiLb0EED0Ev = Module["__ZNSt3__215__codecvt_utf16IDiLb0EED0Ev"] = function() {
                return (__ZNSt3__215__codecvt_utf16IDiLb0EED0Ev = Module["__ZNSt3__215__codecvt_utf16IDiLb0EED0Ev"] = Module["asm"]["_ZNSt3__215__codecvt_utf16IDiLb0EED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215__codecvt_utf16IDiLb1EED0Ev = Module["__ZNSt3__215__codecvt_utf16IDiLb1EED0Ev"] = function() {
                return (__ZNSt3__215__codecvt_utf16IDiLb1EED0Ev = Module["__ZNSt3__215__codecvt_utf16IDiLb1EED0Ev"] = Module["asm"]["_ZNSt3__215__codecvt_utf16IDiLb1EED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__220__codecvt_utf8_utf16IwED0Ev = Module["__ZNSt3__220__codecvt_utf8_utf16IwED0Ev"] = function() {
                return (__ZNSt3__220__codecvt_utf8_utf16IwED0Ev = Module["__ZNSt3__220__codecvt_utf8_utf16IwED0Ev"] = Module["asm"]["_ZNSt3__220__codecvt_utf8_utf16IwED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__220__codecvt_utf8_utf16IDiED0Ev = Module["__ZNSt3__220__codecvt_utf8_utf16IDiED0Ev"] = function() {
                return (__ZNSt3__220__codecvt_utf8_utf16IDiED0Ev = Module["__ZNSt3__220__codecvt_utf8_utf16IDiED0Ev"] = Module["asm"]["_ZNSt3__220__codecvt_utf8_utf16IDiED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__220__codecvt_utf8_utf16IDsED0Ev = Module["__ZNSt3__220__codecvt_utf8_utf16IDsED0Ev"] = function() {
                return (__ZNSt3__220__codecvt_utf8_utf16IDsED0Ev = Module["__ZNSt3__220__codecvt_utf8_utf16IDsED0Ev"] = Module["asm"]["_ZNSt3__220__codecvt_utf8_utf16IDsED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev = Module["__ZNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev"] = function() {
                return (__ZNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev = Module["__ZNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev"] = Module["asm"]["_ZNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev = Module["__ZNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev"] = function() {
                return (__ZNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev = Module["__ZNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev"] = Module["asm"]["_ZNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev = Module["__ZNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev"] = function() {
                return (__ZNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev = Module["__ZNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev"] = Module["asm"]["_ZNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev = Module["__ZNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev"] = function() {
                return (__ZNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev = Module["__ZNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev"] = Module["asm"]["_ZNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev = Module["__ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev"] = function() {
                return (__ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev = Module["__ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev"] = Module["asm"]["_ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__220__time_get_c_storageIcED2Ev = Module["__ZNSt3__220__time_get_c_storageIcED2Ev"] = function() {
                return (__ZNSt3__220__time_get_c_storageIcED2Ev = Module["__ZNSt3__220__time_get_c_storageIcED2Ev"] = Module["asm"]["_ZNSt3__220__time_get_c_storageIcED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev = Module["__ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev"] = function() {
                return (__ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev = Module["__ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev"] = Module["asm"]["_ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev = Module["__ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev"] = function() {
                return (__ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev = Module["__ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev"] = Module["asm"]["_ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__220__time_get_c_storageIwED2Ev = Module["__ZNSt3__220__time_get_c_storageIwED2Ev"] = function() {
                return (__ZNSt3__220__time_get_c_storageIwED2Ev = Module["__ZNSt3__220__time_get_c_storageIwED2Ev"] = Module["asm"]["_ZNSt3__220__time_get_c_storageIwED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev = Module["__ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev"] = function() {
                return (__ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev = Module["__ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev"] = Module["asm"]["_ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev = Module["__ZNSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev"] = function() {
                return (__ZNSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev = Module["__ZNSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev"] = Module["asm"]["_ZNSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__218__time_get_storageIcED2Ev = Module["__ZNSt3__218__time_get_storageIcED2Ev"] = function() {
                return (__ZNSt3__218__time_get_storageIcED2Ev = Module["__ZNSt3__218__time_get_storageIcED2Ev"] = Module["asm"]["_ZNSt3__218__time_get_storageIcED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev = Module["__ZNSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev"] = function() {
                return (__ZNSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev = Module["__ZNSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev"] = Module["asm"]["_ZNSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13do_date_orderEv = Module["__ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13do_date_orderEv"] = function() {
                return (__ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13do_date_orderEv = Module["__ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13do_date_orderEv"] = Module["asm"]["_ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE13do_date_orderEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE7__weeksEv = Module["__ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE7__weeksEv"] = function() {
                return (__ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE7__weeksEv = Module["__ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE7__weeksEv"] = Module["asm"]["_ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE7__weeksEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE8__monthsEv = Module["__ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE8__monthsEv"] = function() {
                return (__ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE8__monthsEv = Module["__ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE8__monthsEv"] = Module["asm"]["_ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE8__monthsEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE7__am_pmEv = Module["__ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE7__am_pmEv"] = function() {
                return (__ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE7__am_pmEv = Module["__ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE7__am_pmEv"] = Module["asm"]["_ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE7__am_pmEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__cEv = Module["__ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__cEv"] = function() {
                return (__ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__cEv = Module["__ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__cEv"] = Module["asm"]["_ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__cEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__rEv = Module["__ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__rEv"] = function() {
                return (__ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__rEv = Module["__ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__rEv"] = Module["asm"]["_ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__rEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__xEv = Module["__ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__xEv"] = function() {
                return (__ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__xEv = Module["__ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__xEv"] = Module["asm"]["_ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__xEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__XEv = Module["__ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__XEv"] = function() {
                return (__ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__XEv = Module["__ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__XEv"] = Module["asm"]["_ZNKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__XEv"]).apply(null, arguments)
            };
            var __ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE7__weeksEv = Module["__ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE7__weeksEv"] = function() {
                return (__ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE7__weeksEv = Module["__ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE7__weeksEv"] = Module["asm"]["_ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE7__weeksEv"]).apply(null, arguments)
            };
            var __ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE8__monthsEv = Module["__ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE8__monthsEv"] = function() {
                return (__ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE8__monthsEv = Module["__ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE8__monthsEv"] = Module["asm"]["_ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE8__monthsEv"]).apply(null, arguments)
            };
            var __ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE7__am_pmEv = Module["__ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE7__am_pmEv"] = function() {
                return (__ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE7__am_pmEv = Module["__ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE7__am_pmEv"] = Module["asm"]["_ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE7__am_pmEv"]).apply(null, arguments)
            };
            var __ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__cEv = Module["__ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__cEv"] = function() {
                return (__ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__cEv = Module["__ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__cEv"] = Module["asm"]["_ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__cEv"]).apply(null, arguments)
            };
            var __ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__rEv = Module["__ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__rEv"] = function() {
                return (__ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__rEv = Module["__ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__rEv"] = Module["asm"]["_ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__rEv"]).apply(null, arguments)
            };
            var __ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__xEv = Module["__ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__xEv"] = function() {
                return (__ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__xEv = Module["__ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__xEv"] = Module["asm"]["_ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__xEv"]).apply(null, arguments)
            };
            var __ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__XEv = Module["__ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__XEv"] = function() {
                return (__ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__XEv = Module["__ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__XEv"] = Module["asm"]["_ZThn8_NKSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3__XEv"]).apply(null, arguments)
            };
            var __ZNSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev = Module["__ZNSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev"] = function() {
                return (__ZNSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev = Module["__ZNSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev"] = Module["asm"]["_ZNSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__218__time_get_storageIwED2Ev = Module["__ZNSt3__218__time_get_storageIwED2Ev"] = function() {
                return (__ZNSt3__218__time_get_storageIwED2Ev = Module["__ZNSt3__218__time_get_storageIwED2Ev"] = Module["asm"]["_ZNSt3__218__time_get_storageIwED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev = Module["__ZNSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev"] = function() {
                return (__ZNSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev = Module["__ZNSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev"] = Module["asm"]["_ZNSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13do_date_orderEv = Module["__ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13do_date_orderEv"] = function() {
                return (__ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13do_date_orderEv = Module["__ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13do_date_orderEv"] = Module["asm"]["_ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE13do_date_orderEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE7__weeksEv = Module["__ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE7__weeksEv"] = function() {
                return (__ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE7__weeksEv = Module["__ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE7__weeksEv"] = Module["asm"]["_ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE7__weeksEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE8__monthsEv = Module["__ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE8__monthsEv"] = function() {
                return (__ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE8__monthsEv = Module["__ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE8__monthsEv"] = Module["asm"]["_ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE8__monthsEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE7__am_pmEv = Module["__ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE7__am_pmEv"] = function() {
                return (__ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE7__am_pmEv = Module["__ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE7__am_pmEv"] = Module["asm"]["_ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE7__am_pmEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__cEv = Module["__ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__cEv"] = function() {
                return (__ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__cEv = Module["__ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__cEv"] = Module["asm"]["_ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__cEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__rEv = Module["__ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__rEv"] = function() {
                return (__ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__rEv = Module["__ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__rEv"] = Module["asm"]["_ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__rEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__xEv = Module["__ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__xEv"] = function() {
                return (__ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__xEv = Module["__ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__xEv"] = Module["asm"]["_ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__xEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__XEv = Module["__ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__XEv"] = function() {
                return (__ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__XEv = Module["__ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__XEv"] = Module["asm"]["_ZNKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__XEv"]).apply(null, arguments)
            };
            var __ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE7__weeksEv = Module["__ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE7__weeksEv"] = function() {
                return (__ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE7__weeksEv = Module["__ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE7__weeksEv"] = Module["asm"]["_ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE7__weeksEv"]).apply(null, arguments)
            };
            var __ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE8__monthsEv = Module["__ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE8__monthsEv"] = function() {
                return (__ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE8__monthsEv = Module["__ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE8__monthsEv"] = Module["asm"]["_ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE8__monthsEv"]).apply(null, arguments)
            };
            var __ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE7__am_pmEv = Module["__ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE7__am_pmEv"] = function() {
                return (__ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE7__am_pmEv = Module["__ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE7__am_pmEv"] = Module["asm"]["_ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE7__am_pmEv"]).apply(null, arguments)
            };
            var __ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__cEv = Module["__ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__cEv"] = function() {
                return (__ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__cEv = Module["__ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__cEv"] = Module["asm"]["_ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__cEv"]).apply(null, arguments)
            };
            var __ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__rEv = Module["__ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__rEv"] = function() {
                return (__ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__rEv = Module["__ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__rEv"] = Module["asm"]["_ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__rEv"]).apply(null, arguments)
            };
            var __ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__xEv = Module["__ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__xEv"] = function() {
                return (__ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__xEv = Module["__ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__xEv"] = Module["asm"]["_ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__xEv"]).apply(null, arguments)
            };
            var __ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__XEv = Module["__ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__XEv"] = function() {
                return (__ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__XEv = Module["__ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__XEv"] = Module["asm"]["_ZThn8_NKSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3__XEv"]).apply(null, arguments)
            };
            var __ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev = Module["__ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev"] = function() {
                return (__ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev = Module["__ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev"] = Module["asm"]["_ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev = Module["__ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev"] = function() {
                return (__ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev = Module["__ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev"] = Module["asm"]["_ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev = Module["__ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev"] = function() {
                return (__ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev = Module["__ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev"] = Module["asm"]["_ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev = Module["__ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev"] = function() {
                return (__ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev = Module["__ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev"] = Module["asm"]["_ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev = Module["__ZNSt3__215time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev"] = function() {
                return (__ZNSt3__215time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev = Module["__ZNSt3__215time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev"] = Module["asm"]["_ZNSt3__215time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev = Module["__ZNSt3__215time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev"] = function() {
                return (__ZNSt3__215time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev = Module["__ZNSt3__215time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev"] = Module["asm"]["_ZNSt3__215time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__210moneypunctIcLb0EED0Ev = Module["__ZNSt3__210moneypunctIcLb0EED0Ev"] = function() {
                return (__ZNSt3__210moneypunctIcLb0EED0Ev = Module["__ZNSt3__210moneypunctIcLb0EED0Ev"] = Module["asm"]["_ZNSt3__210moneypunctIcLb0EED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__210moneypunctIcLb1EED0Ev = Module["__ZNSt3__210moneypunctIcLb1EED0Ev"] = function() {
                return (__ZNSt3__210moneypunctIcLb1EED0Ev = Module["__ZNSt3__210moneypunctIcLb1EED0Ev"] = Module["asm"]["_ZNSt3__210moneypunctIcLb1EED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__210moneypunctIwLb0EED0Ev = Module["__ZNSt3__210moneypunctIwLb0EED0Ev"] = function() {
                return (__ZNSt3__210moneypunctIwLb0EED0Ev = Module["__ZNSt3__210moneypunctIwLb0EED0Ev"] = Module["asm"]["_ZNSt3__210moneypunctIwLb0EED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__210moneypunctIwLb1EED0Ev = Module["__ZNSt3__210moneypunctIwLb1EED0Ev"] = function() {
                return (__ZNSt3__210moneypunctIwLb1EED0Ev = Module["__ZNSt3__210moneypunctIwLb1EED0Ev"] = Module["asm"]["_ZNSt3__210moneypunctIwLb1EED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217moneypunct_bynameIcLb0EED2Ev = Module["__ZNSt3__217moneypunct_bynameIcLb0EED2Ev"] = function() {
                return (__ZNSt3__217moneypunct_bynameIcLb0EED2Ev = Module["__ZNSt3__217moneypunct_bynameIcLb0EED2Ev"] = Module["asm"]["_ZNSt3__217moneypunct_bynameIcLb0EED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217moneypunct_bynameIcLb0EED0Ev = Module["__ZNSt3__217moneypunct_bynameIcLb0EED0Ev"] = function() {
                return (__ZNSt3__217moneypunct_bynameIcLb0EED0Ev = Module["__ZNSt3__217moneypunct_bynameIcLb0EED0Ev"] = Module["asm"]["_ZNSt3__217moneypunct_bynameIcLb0EED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217moneypunct_bynameIcLb1EED2Ev = Module["__ZNSt3__217moneypunct_bynameIcLb1EED2Ev"] = function() {
                return (__ZNSt3__217moneypunct_bynameIcLb1EED2Ev = Module["__ZNSt3__217moneypunct_bynameIcLb1EED2Ev"] = Module["asm"]["_ZNSt3__217moneypunct_bynameIcLb1EED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217moneypunct_bynameIcLb1EED0Ev = Module["__ZNSt3__217moneypunct_bynameIcLb1EED0Ev"] = function() {
                return (__ZNSt3__217moneypunct_bynameIcLb1EED0Ev = Module["__ZNSt3__217moneypunct_bynameIcLb1EED0Ev"] = Module["asm"]["_ZNSt3__217moneypunct_bynameIcLb1EED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217moneypunct_bynameIwLb0EED2Ev = Module["__ZNSt3__217moneypunct_bynameIwLb0EED2Ev"] = function() {
                return (__ZNSt3__217moneypunct_bynameIwLb0EED2Ev = Module["__ZNSt3__217moneypunct_bynameIwLb0EED2Ev"] = Module["asm"]["_ZNSt3__217moneypunct_bynameIwLb0EED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217moneypunct_bynameIwLb0EED0Ev = Module["__ZNSt3__217moneypunct_bynameIwLb0EED0Ev"] = function() {
                return (__ZNSt3__217moneypunct_bynameIwLb0EED0Ev = Module["__ZNSt3__217moneypunct_bynameIwLb0EED0Ev"] = Module["asm"]["_ZNSt3__217moneypunct_bynameIwLb0EED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217moneypunct_bynameIwLb1EED2Ev = Module["__ZNSt3__217moneypunct_bynameIwLb1EED2Ev"] = function() {
                return (__ZNSt3__217moneypunct_bynameIwLb1EED2Ev = Module["__ZNSt3__217moneypunct_bynameIwLb1EED2Ev"] = Module["asm"]["_ZNSt3__217moneypunct_bynameIwLb1EED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217moneypunct_bynameIwLb1EED0Ev = Module["__ZNSt3__217moneypunct_bynameIwLb1EED0Ev"] = function() {
                return (__ZNSt3__217moneypunct_bynameIwLb1EED0Ev = Module["__ZNSt3__217moneypunct_bynameIwLb1EED0Ev"] = Module["asm"]["_ZNSt3__217moneypunct_bynameIwLb1EED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev = Module["__ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev"] = function() {
                return (__ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev = Module["__ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev"] = Module["asm"]["_ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev = Module["__ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev"] = function() {
                return (__ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev = Module["__ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev"] = Module["asm"]["_ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev = Module["__ZNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev"] = function() {
                return (__ZNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev = Module["__ZNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev"] = Module["asm"]["_ZNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev = Module["__ZNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev"] = function() {
                return (__ZNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev = Module["__ZNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev"] = Module["asm"]["_ZNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28messagesIcED0Ev = Module["__ZNSt3__28messagesIcED0Ev"] = function() {
                return (__ZNSt3__28messagesIcED0Ev = Module["__ZNSt3__28messagesIcED0Ev"] = Module["asm"]["_ZNSt3__28messagesIcED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28messagesIwED0Ev = Module["__ZNSt3__28messagesIwED0Ev"] = function() {
                return (__ZNSt3__28messagesIwED0Ev = Module["__ZNSt3__28messagesIwED0Ev"] = Module["asm"]["_ZNSt3__28messagesIwED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215messages_bynameIcED0Ev = Module["__ZNSt3__215messages_bynameIcED0Ev"] = function() {
                return (__ZNSt3__215messages_bynameIcED0Ev = Module["__ZNSt3__215messages_bynameIcED0Ev"] = Module["asm"]["_ZNSt3__215messages_bynameIcED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215messages_bynameIwED0Ev = Module["__ZNSt3__215messages_bynameIwED0Ev"] = function() {
                return (__ZNSt3__215messages_bynameIwED0Ev = Module["__ZNSt3__215messages_bynameIwED0Ev"] = Module["asm"]["_ZNSt3__215messages_bynameIwED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__220__vector_base_commonILb1EEC2Ev = Module["__ZNSt3__220__vector_base_commonILb1EEC2Ev"] = function() {
                return (__ZNSt3__220__vector_base_commonILb1EEC2Ev = Module["__ZNSt3__220__vector_base_commonILb1EEC2Ev"] = Module["asm"]["_ZNSt3__220__vector_base_commonILb1EEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEC2IDnNS_18__default_init_tagEEEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEC2IDnNS_18__default_init_tagEEEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIPPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEC2IDnNS_18__default_init_tagEEEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEC2IDnNS_18__default_init_tagEEEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIPPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEEC2IDnNS_18__default_init_tagEEEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE8max_sizeEv = Module["__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE8max_sizeEv"] = function() {
                return (__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE8max_sizeEv = Module["__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE8max_sizeEv"] = Module["asm"]["_ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE8max_sizeEv"]).apply(null, arguments)
            };
            var __ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv = Module["__ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv"] = function() {
                return (__ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv = Module["__ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv"] = Module["asm"]["_ZNKSt3__220__vector_base_commonILb1EE20__throw_length_errorEv"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE7__allocEv = Module["__ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE7__allocEv"] = function() {
                return (__ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE7__allocEv = Module["__ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE7__allocEv"] = Module["asm"]["_ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE7__allocEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE8allocateERS5_m = Module["__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE8allocateERS5_m"] = function() {
                return (__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE8allocateERS5_m = Module["__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE8allocateERS5_m"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE8allocateERS5_m"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE9__end_capEv = Module["__ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE9__end_capEv"] = function() {
                return (__ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE9__end_capEv = Module["__ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE9__end_capEv"] = Module["asm"]["_ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE9__end_capEv"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE14__annotate_newEm = Module["__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE14__annotate_newEm"] = function() {
                return (__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE14__annotate_newEm = Module["__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE14__annotate_newEm"] = Module["asm"]["_ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE14__annotate_newEm"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE21_ConstructTransactionC2ERS6_m = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE21_ConstructTransactionC2ERS6_m"] = function() {
                return (__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE21_ConstructTransactionC2ERS6_m = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE21_ConstructTransactionC2ERS6_m"] = Module["asm"]["_ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE21_ConstructTransactionC2ERS6_m"]).apply(null, arguments)
            };
            var __ZNSt3__212__to_addressIPNS_6locale5facetEEEPT_S5_ = Module["__ZNSt3__212__to_addressIPNS_6locale5facetEEEPT_S5_"] = function() {
                return (__ZNSt3__212__to_addressIPNS_6locale5facetEEEPT_S5_ = Module["__ZNSt3__212__to_addressIPNS_6locale5facetEEEPT_S5_"] = Module["asm"]["_ZNSt3__212__to_addressIPNS_6locale5facetEEEPT_S5_"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE9constructIS4_JEEEvRS5_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE9constructIS4_JEEEvRS5_PT_DpOT0_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE9constructIS4_JEEEvRS5_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE9constructIS4_JEEEvRS5_PT_DpOT0_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE9constructIS4_JEEEvRS5_PT_DpOT0_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE21_ConstructTransactionD2Ev = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE21_ConstructTransactionD2Ev"] = function() {
                return (__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE21_ConstructTransactionD2Ev = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE21_ConstructTransactionD2Ev"] = Module["asm"]["_ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE21_ConstructTransactionD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIDnEEOT_RNS_16remove_referenceIS1_E4typeE = Module["__ZNSt3__27forwardIDnEEOT_RNS_16remove_referenceIS1_E4typeE"] = function() {
                return (__ZNSt3__27forwardIDnEEOT_RNS_16remove_referenceIS1_E4typeE = Module["__ZNSt3__27forwardIDnEEOT_RNS_16remove_referenceIS1_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIDnEEOT_RNS_16remove_referenceIS1_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPPNS_6locale5facetELi0ELb0EEC2IDnvEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPPNS_6locale5facetELi0ELb0EEC2IDnvEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPPNS_6locale5facetELi0ELb0EEC2IDnvEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPPNS_6locale5facetELi0ELb0EEC2IDnvEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPPNS_6locale5facetELi0ELb0EEC2IDnvEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_15__sso_allocatorIPNS_6locale5facetELm28EEELi1ELb0EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_15__sso_allocatorIPNS_6locale5facetELm28EEELi1ELb0EEC2ENS_18__default_init_tagE"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_15__sso_allocatorIPNS_6locale5facetELm28EEELi1ELb0EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_15__sso_allocatorIPNS_6locale5facetELm28EEELi1ELb0EEC2ENS_18__default_init_tagE"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_15__sso_allocatorIPNS_6locale5facetELm28EEELi1ELb0EEC2ENS_18__default_init_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__215__sso_allocatorIPNS_6locale5facetELm28EEC2Ev = Module["__ZNSt3__215__sso_allocatorIPNS_6locale5facetELm28EEC2Ev"] = function() {
                return (__ZNSt3__215__sso_allocatorIPNS_6locale5facetELm28EEC2Ev = Module["__ZNSt3__215__sso_allocatorIPNS_6locale5facetELm28EEC2Ev"] = Module["asm"]["_ZNSt3__215__sso_allocatorIPNS_6locale5facetELm28EEC2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE7__allocEv = Module["__ZNKSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE7__allocEv"] = function() {
                return (__ZNKSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE7__allocEv = Module["__ZNKSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE7__allocEv"] = Module["asm"]["_ZNKSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE7__allocEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE8max_sizeERKS5_ = Module["__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE8max_sizeERKS5_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE8max_sizeERKS5_ = Module["__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE8max_sizeERKS5_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE8max_sizeERKS5_"]).apply(null, arguments)
            };
            var __ZNSt3__214numeric_limitsIlE3maxEv = Module["__ZNSt3__214numeric_limitsIlE3maxEv"] = function() {
                return (__ZNSt3__214numeric_limitsIlE3maxEv = Module["__ZNSt3__214numeric_limitsIlE3maxEv"] = Module["asm"]["_ZNSt3__214numeric_limitsIlE3maxEv"]).apply(null, arguments)
            };
            var __ZNSt3__215__sso_allocatorIPNS_6locale5facetELm28EE8allocateEmPKv = Module["__ZNSt3__215__sso_allocatorIPNS_6locale5facetELm28EE8allocateEmPKv"] = function() {
                return (__ZNSt3__215__sso_allocatorIPNS_6locale5facetELm28EE8allocateEmPKv = Module["__ZNSt3__215__sso_allocatorIPNS_6locale5facetELm28EE8allocateEmPKv"] = Module["asm"]["_ZNSt3__215__sso_allocatorIPNS_6locale5facetELm28EE8allocateEmPKv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE6secondEv = Module["__ZNSt3__217__compressed_pairIPPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE6secondEv = Module["__ZNSt3__217__compressed_pairIPPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE5firstEv = Module["__ZNSt3__217__compressed_pairIPPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE5firstEv = Module["__ZNSt3__217__compressed_pairIPPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE5firstEv"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE4dataEv = Module["__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE4dataEv"] = function() {
                return (__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE4dataEv = Module["__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE4dataEv"] = Module["asm"]["_ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE4dataEv"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE8capacityEv = Module["__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE8capacityEv"] = function() {
                return (__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE8capacityEv = Module["__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE8capacityEv"] = Module["asm"]["_ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE8capacityEv"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE31__annotate_contiguous_containerEPKvS8_S8_S8_ = Module["__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE31__annotate_contiguous_containerEPKvS8_S8_S8_"] = function() {
                return (__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE31__annotate_contiguous_containerEPKvS8_S8_S8_ = Module["__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE31__annotate_contiguous_containerEPKvS8_S8_S8_"] = Module["asm"]["_ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE31__annotate_contiguous_containerEPKvS8_S8_S8_"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE10__max_sizeENS_17integral_constantIbLb1EEERKS5_ = Module["__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE10__max_sizeENS_17integral_constantIbLb1EEERKS5_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE10__max_sizeENS_17integral_constantIbLb1EEERKS5_ = Module["__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE10__max_sizeENS_17integral_constantIbLb1EEERKS5_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE10__max_sizeENS_17integral_constantIbLb1EEERKS5_"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE6secondEv = Module["__ZNKSt3__217__compressed_pairIPPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE6secondEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE6secondEv = Module["__ZNKSt3__217__compressed_pairIPPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE6secondEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__223__libcpp_numeric_limitsIlLb1EE3maxEv = Module["__ZNSt3__223__libcpp_numeric_limitsIlLb1EE3maxEv"] = function() {
                return (__ZNSt3__223__libcpp_numeric_limitsIlLb1EE3maxEv = Module["__ZNSt3__223__libcpp_numeric_limitsIlLb1EE3maxEv"] = Module["asm"]["_ZNSt3__223__libcpp_numeric_limitsIlLb1EE3maxEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215__sso_allocatorIPNS_6locale5facetELm28EE8max_sizeEv = Module["__ZNKSt3__215__sso_allocatorIPNS_6locale5facetELm28EE8max_sizeEv"] = function() {
                return (__ZNKSt3__215__sso_allocatorIPNS_6locale5facetELm28EE8max_sizeEv = Module["__ZNKSt3__215__sso_allocatorIPNS_6locale5facetELm28EE8max_sizeEv"] = Module["asm"]["_ZNKSt3__215__sso_allocatorIPNS_6locale5facetELm28EE8max_sizeEv"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemINS_15__sso_allocatorIPNS_6locale5facetELm28EEELi1ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemINS_15__sso_allocatorIPNS_6locale5facetELm28EEELi1ELb0EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemINS_15__sso_allocatorIPNS_6locale5facetELm28EEELi1ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemINS_15__sso_allocatorIPNS_6locale5facetELm28EEELi1ELb0EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemINS_15__sso_allocatorIPNS_6locale5facetELm28EEELi1ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_15__sso_allocatorIPNS_6locale5facetELm28EEELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_15__sso_allocatorIPNS_6locale5facetELm28EEELi1ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_15__sso_allocatorIPNS_6locale5facetELm28EEELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_15__sso_allocatorIPNS_6locale5facetELm28EEELi1ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_15__sso_allocatorIPNS_6locale5facetELm28EEELi1ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPPNS_6locale5facetELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPPNS_6locale5facetELi0ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPPNS_6locale5facetELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPPNS_6locale5facetELi0ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPPNS_6locale5facetELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNKSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE8capacityEv = Module["__ZNKSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE8capacityEv"] = function() {
                return (__ZNKSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE8capacityEv = Module["__ZNKSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE8capacityEv"] = Module["asm"]["_ZNKSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE8capacityEv"]).apply(null, arguments)
            };
            var __ZNKSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE9__end_capEv = Module["__ZNKSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE9__end_capEv"] = function() {
                return (__ZNKSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE9__end_capEv = Module["__ZNKSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE9__end_capEv"] = Module["asm"]["_ZNKSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE9__end_capEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE5firstEv"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemIPPNS_6locale5facetELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPPNS_6locale5facetELi0ELb0EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemIPPNS_6locale5facetELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPPNS_6locale5facetELi0ELb0EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemIPPNS_6locale5facetELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE11__constructIS4_JEEEvNS_17integral_constantIbLb0EEERS5_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE11__constructIS4_JEEEvNS_17integral_constantIbLb0EEERS5_PT_DpOT0_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE11__constructIS4_JEEEvNS_17integral_constantIbLb0EEERS5_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE11__constructIS4_JEEEvNS_17integral_constantIbLb0EEERS5_PT_DpOT0_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE11__constructIS4_JEEEvNS_17integral_constantIbLb0EEERS5_PT_DpOT0_"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE10deallocateERS5_PS4_m = Module["__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE10deallocateERS5_PS4_m"] = function() {
                return (__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE10deallocateERS5_PS4_m = Module["__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE10deallocateERS5_PS4_m"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE10deallocateERS5_PS4_m"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE17__destruct_at_endEPS3_ = Module["__ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE17__destruct_at_endEPS3_"] = function() {
                return (__ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE17__destruct_at_endEPS3_ = Module["__ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE17__destruct_at_endEPS3_"] = Module["asm"]["_ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE17__destruct_at_endEPS3_"]).apply(null, arguments)
            };
            var __ZNSt3__215__sso_allocatorIPNS_6locale5facetELm28EE10deallocateEPS3_m = Module["__ZNSt3__215__sso_allocatorIPNS_6locale5facetELm28EE10deallocateEPS3_m"] = function() {
                return (__ZNSt3__215__sso_allocatorIPNS_6locale5facetELm28EE10deallocateEPS3_m = Module["__ZNSt3__215__sso_allocatorIPNS_6locale5facetELm28EE10deallocateEPS3_m"] = Module["asm"]["_ZNSt3__215__sso_allocatorIPNS_6locale5facetELm28EE10deallocateEPS3_m"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE7destroyIS4_EEvRS5_PT_ = Module["__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE7destroyIS4_EEvRS5_PT_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE7destroyIS4_EEvRS5_PT_ = Module["__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE7destroyIS4_EEvRS5_PT_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE7destroyIS4_EEvRS5_PT_"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE9__destroyIS4_EEvNS_17integral_constantIbLb0EEERS5_PT_ = Module["__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE9__destroyIS4_EEvNS_17integral_constantIbLb0EEERS5_PT_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE9__destroyIS4_EEvNS_17integral_constantIbLb0EEERS5_PT_ = Module["__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE9__destroyIS4_EEvNS_17integral_constantIbLb0EEERS5_PT_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE9__destroyIS4_EEvNS_17integral_constantIbLb0EEERS5_PT_"]).apply(null, arguments)
            };
            var __ZNSt3__210money_baseC2Ev = Module["__ZNSt3__210money_baseC2Ev"] = function() {
                return (__ZNSt3__210money_baseC2Ev = Module["__ZNSt3__210money_baseC2Ev"] = Module["asm"]["_ZNSt3__210money_baseC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__211__money_getIcEC2Ev = Module["__ZNSt3__211__money_getIcEC2Ev"] = function() {
                return (__ZNSt3__211__money_getIcEC2Ev = Module["__ZNSt3__211__money_getIcEC2Ev"] = Module["asm"]["_ZNSt3__211__money_getIcEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__211__money_getIwEC2Ev = Module["__ZNSt3__211__money_getIwEC2Ev"] = function() {
                return (__ZNSt3__211__money_getIwEC2Ev = Module["__ZNSt3__211__money_getIwEC2Ev"] = Module["asm"]["_ZNSt3__211__money_getIwEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__211__money_putIcEC2Ev = Module["__ZNSt3__211__money_putIcEC2Ev"] = function() {
                return (__ZNSt3__211__money_putIcEC2Ev = Module["__ZNSt3__211__money_putIcEC2Ev"] = Module["asm"]["_ZNSt3__211__money_putIcEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__211__money_putIwEC2Ev = Module["__ZNSt3__211__money_putIwEC2Ev"] = function() {
                return (__ZNSt3__211__money_putIwEC2Ev = Module["__ZNSt3__211__money_putIwEC2Ev"] = Module["asm"]["_ZNSt3__211__money_putIwEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__220__time_get_c_storageIcEC2Ev = Module["__ZNSt3__220__time_get_c_storageIcEC2Ev"] = function() {
                return (__ZNSt3__220__time_get_c_storageIcEC2Ev = Module["__ZNSt3__220__time_get_c_storageIcEC2Ev"] = Module["asm"]["_ZNSt3__220__time_get_c_storageIcEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__220__time_get_c_storageIwEC2Ev = Module["__ZNSt3__220__time_get_c_storageIwEC2Ev"] = function() {
                return (__ZNSt3__220__time_get_c_storageIwEC2Ev = Module["__ZNSt3__220__time_get_c_storageIwEC2Ev"] = Module["asm"]["_ZNSt3__220__time_get_c_storageIwEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__210__time_putC2Ev = Module["__ZNSt3__210__time_putC2Ev"] = function() {
                return (__ZNSt3__210__time_putC2Ev = Module["__ZNSt3__210__time_putC2Ev"] = Module["asm"]["_ZNSt3__210__time_putC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213messages_baseC2Ev = Module["__ZNSt3__213messages_baseC2Ev"] = function() {
                return (__ZNSt3__213messages_baseC2Ev = Module["__ZNSt3__213messages_baseC2Ev"] = Module["asm"]["_ZNSt3__213messages_baseC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE19__copy_assign_allocERKS6_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE19__copy_assign_allocERKS6_NS_17integral_constantIbLb0EEE"] = function() {
                return (__ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE19__copy_assign_allocERKS6_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE19__copy_assign_allocERKS6_NS_17integral_constantIbLb0EEE"] = Module["asm"]["_ZNSt3__213__vector_baseIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE19__copy_assign_allocERKS6_NS_17integral_constantIbLb0EEE"]).apply(null, arguments)
            };
            var __ZNSt3__28distanceIPPNS_6locale5facetEEENS_15iterator_traitsIT_E15difference_typeES6_S6_ = Module["__ZNSt3__28distanceIPPNS_6locale5facetEEENS_15iterator_traitsIT_E15difference_typeES6_S6_"] = function() {
                return (__ZNSt3__28distanceIPPNS_6locale5facetEEENS_15iterator_traitsIT_E15difference_typeES6_S6_ = Module["__ZNSt3__28distanceIPPNS_6locale5facetEEENS_15iterator_traitsIT_E15difference_typeES6_S6_"] = Module["asm"]["_ZNSt3__28distanceIPPNS_6locale5facetEEENS_15iterator_traitsIT_E15difference_typeES6_S6_"]).apply(null, arguments)
            };
            var __ZNSt3__27advanceIPPNS_6locale5facetEEEvRT_NS_15iterator_traitsIS5_E15difference_typeE = Module["__ZNSt3__27advanceIPPNS_6locale5facetEEEvRT_NS_15iterator_traitsIS5_E15difference_typeE"] = function() {
                return (__ZNSt3__27advanceIPPNS_6locale5facetEEEvRT_NS_15iterator_traitsIS5_E15difference_typeE = Module["__ZNSt3__27advanceIPPNS_6locale5facetEEEvRT_NS_15iterator_traitsIS5_E15difference_typeE"] = Module["asm"]["_ZNSt3__27advanceIPPNS_6locale5facetEEEvRT_NS_15iterator_traitsIS5_E15difference_typeE"]).apply(null, arguments)
            };
            var __ZNSt3__24copyIPPNS_6locale5facetES4_EET0_T_S6_S5_ = Module["__ZNSt3__24copyIPPNS_6locale5facetES4_EET0_T_S6_S5_"] = function() {
                return (__ZNSt3__24copyIPPNS_6locale5facetES4_EET0_T_S6_S5_ = Module["__ZNSt3__24copyIPPNS_6locale5facetES4_EET0_T_S6_S5_"] = Module["asm"]["_ZNSt3__24copyIPPNS_6locale5facetES4_EET0_T_S6_S5_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE18__construct_at_endIPS3_EENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeESA_SA_m = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE18__construct_at_endIPS3_EENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeESA_SA_m"] = function() {
                return (__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE18__construct_at_endIPS3_EENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeESA_SA_m = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE18__construct_at_endIPS3_EENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeESA_SA_m"] = Module["asm"]["_ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE18__construct_at_endIPS3_EENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeESA_SA_m"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE13__vdeallocateEv = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE13__vdeallocateEv"] = function() {
                return (__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE13__vdeallocateEv = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE13__vdeallocateEv"] = Module["asm"]["_ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE13__vdeallocateEv"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE11__recommendEm = Module["__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE11__recommendEm"] = function() {
                return (__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE11__recommendEm = Module["__ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE11__recommendEm"] = Module["asm"]["_ZNKSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE11__recommendEm"]).apply(null, arguments)
            };
            var __ZNSt3__210__distanceIPPNS_6locale5facetEEENS_15iterator_traitsIT_E15difference_typeES6_S6_NS_26random_access_iterator_tagE = Module["__ZNSt3__210__distanceIPPNS_6locale5facetEEENS_15iterator_traitsIT_E15difference_typeES6_S6_NS_26random_access_iterator_tagE"] = function() {
                return (__ZNSt3__210__distanceIPPNS_6locale5facetEEENS_15iterator_traitsIT_E15difference_typeES6_S6_NS_26random_access_iterator_tagE = Module["__ZNSt3__210__distanceIPPNS_6locale5facetEEENS_15iterator_traitsIT_E15difference_typeES6_S6_NS_26random_access_iterator_tagE"] = Module["asm"]["_ZNSt3__210__distanceIPPNS_6locale5facetEEENS_15iterator_traitsIT_E15difference_typeES6_S6_NS_26random_access_iterator_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__29__advanceIPPNS_6locale5facetEEEvRT_NS_15iterator_traitsIS5_E15difference_typeENS_26random_access_iterator_tagE = Module["__ZNSt3__29__advanceIPPNS_6locale5facetEEEvRT_NS_15iterator_traitsIS5_E15difference_typeENS_26random_access_iterator_tagE"] = function() {
                return (__ZNSt3__29__advanceIPPNS_6locale5facetEEEvRT_NS_15iterator_traitsIS5_E15difference_typeENS_26random_access_iterator_tagE = Module["__ZNSt3__29__advanceIPPNS_6locale5facetEEEvRT_NS_15iterator_traitsIS5_E15difference_typeENS_26random_access_iterator_tagE"] = Module["asm"]["_ZNSt3__29__advanceIPPNS_6locale5facetEEEvRT_NS_15iterator_traitsIS5_E15difference_typeENS_26random_access_iterator_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__213__unwrap_iterIPPNS_6locale5facetEEET_S5_ = Module["__ZNSt3__213__unwrap_iterIPPNS_6locale5facetEEET_S5_"] = function() {
                return (__ZNSt3__213__unwrap_iterIPPNS_6locale5facetEEET_S5_ = Module["__ZNSt3__213__unwrap_iterIPPNS_6locale5facetEEET_S5_"] = Module["asm"]["_ZNSt3__213__unwrap_iterIPPNS_6locale5facetEEET_S5_"]).apply(null, arguments)
            };
            var __ZNSt3__26__copyIPNS_6locale5facetES3_EENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS9_EE5valueEPS9_E4typeEPS6_SD_SA_ = Module["__ZNSt3__26__copyIPNS_6locale5facetES3_EENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS9_EE5valueEPS9_E4typeEPS6_SD_SA_"] = function() {
                return (__ZNSt3__26__copyIPNS_6locale5facetES3_EENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS9_EE5valueEPS9_E4typeEPS6_SD_SA_ = Module["__ZNSt3__26__copyIPNS_6locale5facetES3_EENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS9_EE5valueEPS9_E4typeEPS6_SD_SA_"] = Module["asm"]["_ZNSt3__26__copyIPNS_6locale5facetES3_EENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS9_EE5valueEPS9_E4typeEPS6_SD_SA_"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE25__construct_range_forwardIS4_S4_S4_S4_EENS_9enable_ifIXaaaasr31is_trivially_move_constructibleIT0_EE5valuesr7is_sameIT1_T2_EE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr15__has_constructIS5_PS9_RT_EE5valueEvE4typeERS5_PSF_SK_RSE_ = Module["__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE25__construct_range_forwardIS4_S4_S4_S4_EENS_9enable_ifIXaaaasr31is_trivially_move_constructibleIT0_EE5valuesr7is_sameIT1_T2_EE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr15__has_constructIS5_PS9_RT_EE5valueEvE4typeERS5_PSF_SK_RSE_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE25__construct_range_forwardIS4_S4_S4_S4_EENS_9enable_ifIXaaaasr31is_trivially_move_constructibleIT0_EE5valuesr7is_sameIT1_T2_EE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr15__has_constructIS5_PS9_RT_EE5valueEvE4typeERS5_PSF_SK_RSE_ = Module["__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE25__construct_range_forwardIS4_S4_S4_S4_EENS_9enable_ifIXaaaasr31is_trivially_move_constructibleIT0_EE5valuesr7is_sameIT1_T2_EE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr15__has_constructIS5_PS9_RT_EE5valueEvE4typeERS5_PSF_SK_RSE_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE25__construct_range_forwardIS4_S4_S4_S4_EENS_9enable_ifIXaaaasr31is_trivially_move_constructibleIT0_EE5valuesr7is_sameIT1_T2_EE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr15__has_constructIS5_PS9_RT_EE5valueEvE4typeERS5_PSF_SK_RSE_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE27__invalidate_iterators_pastEPS3_ = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE27__invalidate_iterators_pastEPS3_"] = function() {
                return (__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE27__invalidate_iterators_pastEPS3_ = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE27__invalidate_iterators_pastEPS3_"] = Module["asm"]["_ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE27__invalidate_iterators_pastEPS3_"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRPNS_6locale5facetEEEOT_RNS_16remove_referenceIS5_E4typeE = Module["__ZNSt3__27forwardIRPNS_6locale5facetEEEOT_RNS_16remove_referenceIS5_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRPNS_6locale5facetEEEOT_RNS_16remove_referenceIS5_E4typeE = Module["__ZNSt3__27forwardIRPNS_6locale5facetEEEOT_RNS_16remove_referenceIS5_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRPNS_6locale5facetEEEOT_RNS_16remove_referenceIS5_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPNS_6locale5facetELi0ELb0EEC2IRS3_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPNS_6locale5facetELi0ELb0EEC2IRS3_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPNS_6locale5facetELi0ELb0EEC2IRS3_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPNS_6locale5facetELi0ELb0EEC2IRS3_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPNS_6locale5facetELi0ELb0EEC2IRS3_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPNS_6locale5facetELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPNS_6locale5facetELi0ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPNS_6locale5facetELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPNS_6locale5facetELi0ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPNS_6locale5facetELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemIPNS_6locale5facetELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPNS_6locale5facetELi0ELb0EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemIPNS_6locale5facetELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPNS_6locale5facetELi0ELb0EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemIPNS_6locale5facetELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEEC2EmmS6_ = Module["__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEEC2EmmS6_"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEEC2EmmS6_ = Module["__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEEC2EmmS6_"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEEC2EmmS6_"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE18__construct_at_endEm = Module["__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE18__construct_at_endEm"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE18__construct_at_endEm = Module["__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE18__construct_at_endEm"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE18__construct_at_endEm"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE"] = function() {
                return (__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE = Module["__ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE"] = Module["asm"]["_ZNSt3__26vectorIPNS_6locale5facetENS_15__sso_allocatorIS3_Lm28EEEE26__swap_out_circular_bufferERNS_14__split_bufferIS3_RS5_EE"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEED2Ev = Module["__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEED2Ev"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEED2Ev = Module["__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEED2Ev"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEEC2IDnS7_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEEC2IDnS7_EEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIPPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEEC2IDnS7_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEEC2IDnS7_EEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIPPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEEC2IDnS7_EEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE7__allocEv = Module["__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE7__allocEv"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE7__allocEv = Module["__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE7__allocEv"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE7__allocEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE9__end_capEv = Module["__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE9__end_capEv"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE9__end_capEv = Module["__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE9__end_capEv"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE9__end_capEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE21_ConstructTransactionC2EPPS3_m = Module["__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE21_ConstructTransactionC2EPPS3_m"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE21_ConstructTransactionC2EPPS3_m = Module["__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE21_ConstructTransactionC2EPPS3_m"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE21_ConstructTransactionC2EPPS3_m"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE21_ConstructTransactionD2Ev = Module["__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE21_ConstructTransactionD2Ev"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE21_ConstructTransactionD2Ev = Module["__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE21_ConstructTransactionD2Ev"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE21_ConstructTransactionD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE46__construct_backward_with_exception_guaranteesIS4_EENS_9enable_ifIXaaooL_ZNS_17integral_constantIbLb0EE5valueEEntsr15__has_constructIS5_PT_SB_EE5valuesr31is_trivially_move_constructibleISB_EE5valueEvE4typeERS5_SC_SC_RSC_ = Module["__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE46__construct_backward_with_exception_guaranteesIS4_EENS_9enable_ifIXaaooL_ZNS_17integral_constantIbLb0EE5valueEEntsr15__has_constructIS5_PT_SB_EE5valuesr31is_trivially_move_constructibleISB_EE5valueEvE4typeERS5_SC_SC_RSC_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE46__construct_backward_with_exception_guaranteesIS4_EENS_9enable_ifIXaaooL_ZNS_17integral_constantIbLb0EE5valueEEntsr15__has_constructIS5_PT_SB_EE5valuesr31is_trivially_move_constructibleISB_EE5valueEvE4typeERS5_SC_SC_RSC_ = Module["__ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE46__construct_backward_with_exception_guaranteesIS4_EENS_9enable_ifIXaaooL_ZNS_17integral_constantIbLb0EE5valueEEntsr15__has_constructIS5_PT_SB_EE5valuesr31is_trivially_move_constructibleISB_EE5valueEvE4typeERS5_SC_SC_RSC_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_15__sso_allocatorIPNS_6locale5facetELm28EEEE46__construct_backward_with_exception_guaranteesIS4_EENS_9enable_ifIXaaooL_ZNS_17integral_constantIbLb0EE5valueEEntsr15__has_constructIS5_PT_SB_EE5valuesr31is_trivially_move_constructibleISB_EE5valueEvE4typeERS5_SC_SC_RSC_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIPPNS_6locale5facetEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS6_EE5valueEvE4typeERS6_S9_ = Module["__ZNSt3__24swapIPPNS_6locale5facetEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS6_EE5valueEvE4typeERS6_S9_"] = function() {
                return (__ZNSt3__24swapIPPNS_6locale5facetEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS6_EE5valueEvE4typeERS6_S9_ = Module["__ZNSt3__24swapIPPNS_6locale5facetEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS6_EE5valueEvE4typeERS6_S9_"] = Module["asm"]["_ZNSt3__24swapIPPNS_6locale5facetEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS6_EE5valueEvE4typeERS6_S9_"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE5clearEv = Module["__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE5clearEv"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE5clearEv = Module["__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE5clearEv"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE5clearEv"]).apply(null, arguments)
            };
            var __ZNKSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE8capacityEv = Module["__ZNKSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE8capacityEv"] = function() {
                return (__ZNKSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE8capacityEv = Module["__ZNKSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE8capacityEv"] = Module["asm"]["_ZNKSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE8capacityEv"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRNS_15__sso_allocatorIPNS_6locale5facetELm28EEEEEOT_RNS_16remove_referenceIS7_E4typeE = Module["__ZNSt3__27forwardIRNS_15__sso_allocatorIPNS_6locale5facetELm28EEEEEOT_RNS_16remove_referenceIS7_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRNS_15__sso_allocatorIPNS_6locale5facetELm28EEEEEOT_RNS_16remove_referenceIS7_E4typeE = Module["__ZNSt3__27forwardIRNS_15__sso_allocatorIPNS_6locale5facetELm28EEEEEOT_RNS_16remove_referenceIS7_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRNS_15__sso_allocatorIPNS_6locale5facetELm28EEEEEOT_RNS_16remove_referenceIS7_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIRNS_15__sso_allocatorIPNS_6locale5facetELm28EEELi1ELb0EEC2IS6_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIRNS_15__sso_allocatorIPNS_6locale5facetELm28EEELi1ELb0EEC2IS6_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIRNS_15__sso_allocatorIPNS_6locale5facetELm28EEELi1ELb0EEC2IS6_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIRNS_15__sso_allocatorIPNS_6locale5facetELm28EEELi1ELb0EEC2IS6_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIRNS_15__sso_allocatorIPNS_6locale5facetELm28EEELi1ELb0EEC2IS6_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE6secondEv = Module["__ZNSt3__217__compressed_pairIPPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE6secondEv = Module["__ZNSt3__217__compressed_pairIPPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE5firstEv = Module["__ZNSt3__217__compressed_pairIPPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE5firstEv = Module["__ZNSt3__217__compressed_pairIPPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIRNS_15__sso_allocatorIPNS_6locale5facetELm28EEELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIRNS_15__sso_allocatorIPNS_6locale5facetELm28EEELi1ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIRNS_15__sso_allocatorIPNS_6locale5facetELm28EEELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIRNS_15__sso_allocatorIPNS_6locale5facetELm28EEELi1ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIRNS_15__sso_allocatorIPNS_6locale5facetELm28EEELi1ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRPPNS_6locale5facetEEEONS_16remove_referenceIT_E4typeEOS7_ = Module["__ZNSt3__24moveIRPPNS_6locale5facetEEEONS_16remove_referenceIT_E4typeEOS7_"] = function() {
                return (__ZNSt3__24moveIRPPNS_6locale5facetEEEONS_16remove_referenceIT_E4typeEOS7_ = Module["__ZNSt3__24moveIRPPNS_6locale5facetEEEONS_16remove_referenceIT_E4typeEOS7_"] = Module["asm"]["_ZNSt3__24moveIRPPNS_6locale5facetEEEONS_16remove_referenceIT_E4typeEOS7_"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE17__destruct_at_endEPS3_ = Module["__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE17__destruct_at_endEPS3_"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE17__destruct_at_endEPS3_ = Module["__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE17__destruct_at_endEPS3_"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE17__destruct_at_endEPS3_"]).apply(null, arguments)
            };
            var __ZNKSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE9__end_capEv = Module["__ZNKSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE9__end_capEv"] = function() {
                return (__ZNKSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE9__end_capEv = Module["__ZNKSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE9__end_capEv"] = Module["asm"]["_ZNKSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE9__end_capEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE17__destruct_at_endEPS3_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE17__destruct_at_endEPS3_NS_17integral_constantIbLb0EEE"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE17__destruct_at_endEPS3_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE17__destruct_at_endEPS3_NS_17integral_constantIbLb0EEE"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE17__destruct_at_endEPS3_NS_17integral_constantIbLb0EEE"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPPNS_6locale5facetERNS_15__sso_allocatorIS3_Lm28EEEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__28distanceIPKcEENS_15iterator_traitsIT_E15difference_typeES4_S4_ = Module["__ZNSt3__28distanceIPKcEENS_15iterator_traitsIT_E15difference_typeES4_S4_"] = function() {
                return (__ZNSt3__28distanceIPKcEENS_15iterator_traitsIT_E15difference_typeES4_S4_ = Module["__ZNSt3__28distanceIPKcEENS_15iterator_traitsIT_E15difference_typeES4_S4_"] = Module["asm"]["_ZNSt3__28distanceIPKcEENS_15iterator_traitsIT_E15difference_typeES4_S4_"]).apply(null, arguments)
            };
            var __ZNSt3__210__distanceIPKcEENS_15iterator_traitsIT_E15difference_typeES4_S4_NS_26random_access_iterator_tagE = Module["__ZNSt3__210__distanceIPKcEENS_15iterator_traitsIT_E15difference_typeES4_S4_NS_26random_access_iterator_tagE"] = function() {
                return (__ZNSt3__210__distanceIPKcEENS_15iterator_traitsIT_E15difference_typeES4_S4_NS_26random_access_iterator_tagE = Module["__ZNSt3__210__distanceIPKcEENS_15iterator_traitsIT_E15difference_typeES4_S4_NS_26random_access_iterator_tagE"] = Module["asm"]["_ZNSt3__210__distanceIPKcEENS_15iterator_traitsIT_E15difference_typeES4_S4_NS_26random_access_iterator_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__28distanceIPKwEENS_15iterator_traitsIT_E15difference_typeES4_S4_ = Module["__ZNSt3__28distanceIPKwEENS_15iterator_traitsIT_E15difference_typeES4_S4_"] = function() {
                return (__ZNSt3__28distanceIPKwEENS_15iterator_traitsIT_E15difference_typeES4_S4_ = Module["__ZNSt3__28distanceIPKwEENS_15iterator_traitsIT_E15difference_typeES4_S4_"] = Module["asm"]["_ZNSt3__28distanceIPKwEENS_15iterator_traitsIT_E15difference_typeES4_S4_"]).apply(null, arguments)
            };
            var __ZNSt3__210__distanceIPKwEENS_15iterator_traitsIT_E15difference_typeES4_S4_NS_26random_access_iterator_tagE = Module["__ZNSt3__210__distanceIPKwEENS_15iterator_traitsIT_E15difference_typeES4_S4_NS_26random_access_iterator_tagE"] = function() {
                return (__ZNSt3__210__distanceIPKwEENS_15iterator_traitsIT_E15difference_typeES4_S4_NS_26random_access_iterator_tagE = Module["__ZNSt3__210__distanceIPKwEENS_15iterator_traitsIT_E15difference_typeES4_S4_NS_26random_access_iterator_tagE"] = Module["asm"]["_ZNSt3__210__distanceIPKwEENS_15iterator_traitsIT_E15difference_typeES4_S4_NS_26random_access_iterator_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__29iter_swapIPjS1_EEvT_T0_ = Module["__ZNSt3__29iter_swapIPjS1_EEvT_T0_"] = function() {
                return (__ZNSt3__29iter_swapIPjS1_EEvT_T0_ = Module["__ZNSt3__29iter_swapIPjS1_EEvT_T0_"] = Module["asm"]["_ZNSt3__29iter_swapIPjS1_EEvT_T0_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIjEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIjEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = function() {
                return (__ZNSt3__24swapIjEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIjEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = Module["asm"]["_ZNSt3__24swapIjEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRjEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRjEEONS_16remove_referenceIT_E4typeEOS3_"] = function() {
                return (__ZNSt3__24moveIRjEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRjEEONS_16remove_referenceIT_E4typeEOS3_"] = Module["asm"]["_ZNSt3__24moveIRjEEONS_16remove_referenceIT_E4typeEOS3_"]).apply(null, arguments)
            };
            var __ZNSt3__210__distanceIPNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_NS_26random_access_iterator_tagE = Module["__ZNSt3__210__distanceIPNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_NS_26random_access_iterator_tagE"] = function() {
                return (__ZNSt3__210__distanceIPNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_NS_26random_access_iterator_tagE = Module["__ZNSt3__210__distanceIPNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_NS_26random_access_iterator_tagE"] = Module["asm"]["_ZNSt3__210__distanceIPNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_NS_26random_access_iterator_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPhPFvPvEEC2IRS1_S4_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPhPFvPvEEC2IRS1_S4_EEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIPhPFvPvEEC2IRS1_S4_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPhPFvPvEEC2IRS1_S4_EEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIPhPFvPvEEC2IRS1_S4_EEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPhPFvPvEE5firstEv = Module["__ZNSt3__217__compressed_pairIPhPFvPvEE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPhPFvPvEE5firstEv = Module["__ZNSt3__217__compressed_pairIPhPFvPvEE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPhPFvPvEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPhPFvPvEE6secondEv = Module["__ZNSt3__217__compressed_pairIPhPFvPvEE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPhPFvPvEE6secondEv = Module["__ZNSt3__217__compressed_pairIPhPFvPvEE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPhPFvPvEE6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRPhEEOT_RNS_16remove_referenceIS3_E4typeE = Module["__ZNSt3__27forwardIRPhEEOT_RNS_16remove_referenceIS3_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRPhEEOT_RNS_16remove_referenceIS3_E4typeE = Module["__ZNSt3__27forwardIRPhEEOT_RNS_16remove_referenceIS3_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRPhEEOT_RNS_16remove_referenceIS3_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPhLi0ELb0EEC2IRS1_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPhLi0ELb0EEC2IRS1_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPhLi0ELb0EEC2IRS1_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPhLi0ELb0EEC2IRS1_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPhLi0ELb0EEC2IRS1_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIPFvPvEEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIPFvPvEEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIPFvPvEEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIPFvPvEEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIPFvPvEEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPFvPvELi1ELb0EEC2IS3_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPFvPvELi1ELb0EEC2IS3_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPFvPvELi1ELb0EEC2IS3_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPFvPvELi1ELb0EEC2IS3_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPFvPvELi1ELb0EEC2IS3_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPhLi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPhLi0ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPhLi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPhLi0ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPhLi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPFvPvELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPFvPvELi1ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPFvPvELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPFvPvELi1ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPFvPvELi1ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__210__distanceIPNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_NS_26random_access_iterator_tagE = Module["__ZNSt3__210__distanceIPNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_NS_26random_access_iterator_tagE"] = function() {
                return (__ZNSt3__210__distanceIPNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_NS_26random_access_iterator_tagE = Module["__ZNSt3__210__distanceIPNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_NS_26random_access_iterator_tagE"] = Module["asm"]["_ZNSt3__210__distanceIPNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_NS_26random_access_iterator_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__move_assign_allocERS5_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__move_assign_allocERS5_"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__move_assign_allocERS5_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__move_assign_allocERS5_"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__move_assign_allocERS5_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__move_assign_allocERS5_NS_17integral_constantIbLb1EEE = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__move_assign_allocERS5_NS_17integral_constantIbLb1EEE"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__move_assign_allocERS5_NS_17integral_constantIbLb1EEE = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__move_assign_allocERS5_NS_17integral_constantIbLb1EEE"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE19__move_assign_allocERS5_NS_17integral_constantIbLb1EEE"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRNS_9allocatorIcEEEEONS_16remove_referenceIT_E4typeEOS5_ = Module["__ZNSt3__24moveIRNS_9allocatorIcEEEEONS_16remove_referenceIT_E4typeEOS5_"] = function() {
                return (__ZNSt3__24moveIRNS_9allocatorIcEEEEONS_16remove_referenceIT_E4typeEOS5_ = Module["__ZNSt3__24moveIRNS_9allocatorIcEEEEONS_16remove_referenceIT_E4typeEOS5_"] = Module["asm"]["_ZNSt3__24moveIRNS_9allocatorIcEEEEONS_16remove_referenceIT_E4typeEOS5_"]).apply(null, arguments)
            };
            var __ZNSt3__210__distanceIPwEENS_15iterator_traitsIT_E15difference_typeES3_S3_NS_26random_access_iterator_tagE = Module["__ZNSt3__210__distanceIPwEENS_15iterator_traitsIT_E15difference_typeES3_S3_NS_26random_access_iterator_tagE"] = function() {
                return (__ZNSt3__210__distanceIPwEENS_15iterator_traitsIT_E15difference_typeES3_S3_NS_26random_access_iterator_tagE = Module["__ZNSt3__210__distanceIPwEENS_15iterator_traitsIT_E15difference_typeES3_S3_NS_26random_access_iterator_tagE"] = Module["asm"]["_ZNSt3__210__distanceIPwEENS_15iterator_traitsIT_E15difference_typeES3_S3_NS_26random_access_iterator_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__move_assign_allocERS5_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__move_assign_allocERS5_"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__move_assign_allocERS5_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__move_assign_allocERS5_"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__move_assign_allocERS5_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__move_assign_allocERS5_NS_17integral_constantIbLb1EEE = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__move_assign_allocERS5_NS_17integral_constantIbLb1EEE"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__move_assign_allocERS5_NS_17integral_constantIbLb1EEE = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__move_assign_allocERS5_NS_17integral_constantIbLb1EEE"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE19__move_assign_allocERS5_NS_17integral_constantIbLb1EEE"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRNS_9allocatorIwEEEEONS_16remove_referenceIT_E4typeEOS5_ = Module["__ZNSt3__24moveIRNS_9allocatorIwEEEEONS_16remove_referenceIT_E4typeEOS5_"] = function() {
                return (__ZNSt3__24moveIRNS_9allocatorIwEEEEONS_16remove_referenceIT_E4typeEOS5_ = Module["__ZNSt3__24moveIRNS_9allocatorIwEEEEONS_16remove_referenceIT_E4typeEOS5_"] = Module["asm"]["_ZNSt3__24moveIRNS_9allocatorIwEEEEONS_16remove_referenceIT_E4typeEOS5_"]).apply(null, arguments)
            };
            var __ZNSt3__215__time_get_tempIcED0Ev = Module["__ZNSt3__215__time_get_tempIcED0Ev"] = function() {
                return (__ZNSt3__215__time_get_tempIcED0Ev = Module["__ZNSt3__215__time_get_tempIcED0Ev"] = Module["asm"]["_ZNSt3__215__time_get_tempIcED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215__time_get_tempIwED0Ev = Module["__ZNSt3__215__time_get_tempIwED0Ev"] = function() {
                return (__ZNSt3__215__time_get_tempIwED0Ev = Module["__ZNSt3__215__time_get_tempIwED0Ev"] = Module["asm"]["_ZNSt3__215__time_get_tempIwED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28__rotateINS_11__wrap_iterIPcEEEET_S4_S4_S4_NS_26random_access_iterator_tagE = Module["__ZNSt3__28__rotateINS_11__wrap_iterIPcEEEET_S4_S4_S4_NS_26random_access_iterator_tagE"] = function() {
                return (__ZNSt3__28__rotateINS_11__wrap_iterIPcEEEET_S4_S4_S4_NS_26random_access_iterator_tagE = Module["__ZNSt3__28__rotateINS_11__wrap_iterIPcEEEET_S4_S4_S4_NS_26random_access_iterator_tagE"] = Module["asm"]["_ZNSt3__28__rotateINS_11__wrap_iterIPcEEEET_S4_S4_S4_NS_26random_access_iterator_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__24nextINS_11__wrap_iterIPcEEEENS_9enable_ifIXsr25__is_cpp17_input_iteratorIT_EE5valueES5_E4typeES5_NS_15iterator_traitsIS5_E15difference_typeE = Module["__ZNSt3__24nextINS_11__wrap_iterIPcEEEENS_9enable_ifIXsr25__is_cpp17_input_iteratorIT_EE5valueES5_E4typeES5_NS_15iterator_traitsIS5_E15difference_typeE"] = function() {
                return (__ZNSt3__24nextINS_11__wrap_iterIPcEEEENS_9enable_ifIXsr25__is_cpp17_input_iteratorIT_EE5valueES5_E4typeES5_NS_15iterator_traitsIS5_E15difference_typeE = Module["__ZNSt3__24nextINS_11__wrap_iterIPcEEEENS_9enable_ifIXsr25__is_cpp17_input_iteratorIT_EE5valueES5_E4typeES5_NS_15iterator_traitsIS5_E15difference_typeE"] = Module["asm"]["_ZNSt3__24nextINS_11__wrap_iterIPcEEEENS_9enable_ifIXsr25__is_cpp17_input_iteratorIT_EE5valueES5_E4typeES5_NS_15iterator_traitsIS5_E15difference_typeE"]).apply(null, arguments)
            };
            var __ZNSt3__213__rotate_leftINS_11__wrap_iterIPcEEEET_S4_S4_ = Module["__ZNSt3__213__rotate_leftINS_11__wrap_iterIPcEEEET_S4_S4_"] = function() {
                return (__ZNSt3__213__rotate_leftINS_11__wrap_iterIPcEEEET_S4_S4_ = Module["__ZNSt3__213__rotate_leftINS_11__wrap_iterIPcEEEET_S4_S4_"] = Module["asm"]["_ZNSt3__213__rotate_leftINS_11__wrap_iterIPcEEEET_S4_S4_"]).apply(null, arguments)
            };
            var __ZNSt3__214__rotate_rightINS_11__wrap_iterIPcEEEET_S4_S4_ = Module["__ZNSt3__214__rotate_rightINS_11__wrap_iterIPcEEEET_S4_S4_"] = function() {
                return (__ZNSt3__214__rotate_rightINS_11__wrap_iterIPcEEEET_S4_S4_ = Module["__ZNSt3__214__rotate_rightINS_11__wrap_iterIPcEEEET_S4_S4_"] = Module["asm"]["_ZNSt3__214__rotate_rightINS_11__wrap_iterIPcEEEET_S4_S4_"]).apply(null, arguments)
            };
            var __ZNSt3__212__rotate_gcdINS_11__wrap_iterIPcEEEET_S4_S4_S4_ = Module["__ZNSt3__212__rotate_gcdINS_11__wrap_iterIPcEEEET_S4_S4_S4_"] = function() {
                return (__ZNSt3__212__rotate_gcdINS_11__wrap_iterIPcEEEET_S4_S4_S4_ = Module["__ZNSt3__212__rotate_gcdINS_11__wrap_iterIPcEEEET_S4_S4_S4_"] = Module["asm"]["_ZNSt3__212__rotate_gcdINS_11__wrap_iterIPcEEEET_S4_S4_S4_"]).apply(null, arguments)
            };
            var __ZNSt3__27advanceINS_11__wrap_iterIPcEEEEvRT_NS_15iterator_traitsIS4_E15difference_typeE = Module["__ZNSt3__27advanceINS_11__wrap_iterIPcEEEEvRT_NS_15iterator_traitsIS4_E15difference_typeE"] = function() {
                return (__ZNSt3__27advanceINS_11__wrap_iterIPcEEEEvRT_NS_15iterator_traitsIS4_E15difference_typeE = Module["__ZNSt3__27advanceINS_11__wrap_iterIPcEEEEvRT_NS_15iterator_traitsIS4_E15difference_typeE"] = Module["asm"]["_ZNSt3__27advanceINS_11__wrap_iterIPcEEEEvRT_NS_15iterator_traitsIS4_E15difference_typeE"]).apply(null, arguments)
            };
            var __ZNSt3__24moveINS_11__wrap_iterIPcEES3_EET0_T_S5_S4_ = Module["__ZNSt3__24moveINS_11__wrap_iterIPcEES3_EET0_T_S5_S4_"] = function() {
                return (__ZNSt3__24moveINS_11__wrap_iterIPcEES3_EET0_T_S5_S4_ = Module["__ZNSt3__24moveINS_11__wrap_iterIPcEES3_EET0_T_S5_S4_"] = Module["asm"]["_ZNSt3__24moveINS_11__wrap_iterIPcEES3_EET0_T_S5_S4_"]).apply(null, arguments)
            };
            var __ZNSt3__24prevINS_11__wrap_iterIPcEEEENS_9enable_ifIXsr25__is_cpp17_input_iteratorIT_EE5valueES5_E4typeES5_NS_15iterator_traitsIS5_E15difference_typeE = Module["__ZNSt3__24prevINS_11__wrap_iterIPcEEEENS_9enable_ifIXsr25__is_cpp17_input_iteratorIT_EE5valueES5_E4typeES5_NS_15iterator_traitsIS5_E15difference_typeE"] = function() {
                return (__ZNSt3__24prevINS_11__wrap_iterIPcEEEENS_9enable_ifIXsr25__is_cpp17_input_iteratorIT_EE5valueES5_E4typeES5_NS_15iterator_traitsIS5_E15difference_typeE = Module["__ZNSt3__24prevINS_11__wrap_iterIPcEEEENS_9enable_ifIXsr25__is_cpp17_input_iteratorIT_EE5valueES5_E4typeES5_NS_15iterator_traitsIS5_E15difference_typeE"] = Module["asm"]["_ZNSt3__24prevINS_11__wrap_iterIPcEEEENS_9enable_ifIXsr25__is_cpp17_input_iteratorIT_EE5valueES5_E4typeES5_NS_15iterator_traitsIS5_E15difference_typeE"]).apply(null, arguments)
            };
            var __ZNSt3__213move_backwardINS_11__wrap_iterIPcEES3_EET0_T_S5_S4_ = Module["__ZNSt3__213move_backwardINS_11__wrap_iterIPcEES3_EET0_T_S5_S4_"] = function() {
                return (__ZNSt3__213move_backwardINS_11__wrap_iterIPcEES3_EET0_T_S5_S4_ = Module["__ZNSt3__213move_backwardINS_11__wrap_iterIPcEES3_EET0_T_S5_S4_"] = Module["asm"]["_ZNSt3__213move_backwardINS_11__wrap_iterIPcEES3_EET0_T_S5_S4_"]).apply(null, arguments)
            };
            var __ZNSt3__2miIPcS1_EEDTmicldtfp_4baseEcldtfp0_4baseEERKNS_11__wrap_iterIT_EERKNS3_IT0_EE = Module["__ZNSt3__2miIPcS1_EEDTmicldtfp_4baseEcldtfp0_4baseEERKNS_11__wrap_iterIT_EERKNS3_IT0_EE"] = function() {
                return (__ZNSt3__2miIPcS1_EEDTmicldtfp_4baseEcldtfp0_4baseEERKNS_11__wrap_iterIT_EERKNS3_IT0_EE = Module["__ZNSt3__2miIPcS1_EEDTmicldtfp_4baseEcldtfp0_4baseEERKNS_11__wrap_iterIT_EERKNS3_IT0_EE"] = Module["asm"]["_ZNSt3__2miIPcS1_EEDTmicldtfp_4baseEcldtfp0_4baseEERKNS_11__wrap_iterIT_EERKNS3_IT0_EE"]).apply(null, arguments)
            };
            var __ZNSt3__211swap_rangesINS_11__wrap_iterIPcEES3_EET0_T_S5_S4_ = Module["__ZNSt3__211swap_rangesINS_11__wrap_iterIPcEES3_EET0_T_S5_S4_"] = function() {
                return (__ZNSt3__211swap_rangesINS_11__wrap_iterIPcEES3_EET0_T_S5_S4_ = Module["__ZNSt3__211swap_rangesINS_11__wrap_iterIPcEES3_EET0_T_S5_S4_"] = Module["asm"]["_ZNSt3__211swap_rangesINS_11__wrap_iterIPcEES3_EET0_T_S5_S4_"]).apply(null, arguments)
            };
            var __ZNSt3__210__algo_gcdIlEET_S1_S1_ = Module["__ZNSt3__210__algo_gcdIlEET_S1_S1_"] = function() {
                return (__ZNSt3__210__algo_gcdIlEET_S1_S1_ = Module["__ZNSt3__210__algo_gcdIlEET_S1_S1_"] = Module["asm"]["_ZNSt3__210__algo_gcdIlEET_S1_S1_"]).apply(null, arguments)
            };
            var __ZNSt3__211__wrap_iterIPcEmmEv = Module["__ZNSt3__211__wrap_iterIPcEmmEv"] = function() {
                return (__ZNSt3__211__wrap_iterIPcEmmEv = Module["__ZNSt3__211__wrap_iterIPcEmmEv"] = Module["asm"]["_ZNSt3__211__wrap_iterIPcEmmEv"]).apply(null, arguments)
            };
            var __ZNSt3__29__advanceINS_11__wrap_iterIPcEEEEvRT_NS_15iterator_traitsIS4_E15difference_typeENS_26random_access_iterator_tagE = Module["__ZNSt3__29__advanceINS_11__wrap_iterIPcEEEEvRT_NS_15iterator_traitsIS4_E15difference_typeENS_26random_access_iterator_tagE"] = function() {
                return (__ZNSt3__29__advanceINS_11__wrap_iterIPcEEEEvRT_NS_15iterator_traitsIS4_E15difference_typeENS_26random_access_iterator_tagE = Module["__ZNSt3__29__advanceINS_11__wrap_iterIPcEEEEvRT_NS_15iterator_traitsIS4_E15difference_typeENS_26random_access_iterator_tagE"] = Module["asm"]["_ZNSt3__29__advanceINS_11__wrap_iterIPcEEEEvRT_NS_15iterator_traitsIS4_E15difference_typeENS_26random_access_iterator_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__213__unwrap_iterIcEENS_9enable_ifIXsr28is_trivially_copy_assignableIT_EE5valueEPS2_E4typeENS_11__wrap_iterIS3_EE = Module["__ZNSt3__213__unwrap_iterIcEENS_9enable_ifIXsr28is_trivially_copy_assignableIT_EE5valueEPS2_E4typeENS_11__wrap_iterIS3_EE"] = function() {
                return (__ZNSt3__213__unwrap_iterIcEENS_9enable_ifIXsr28is_trivially_copy_assignableIT_EE5valueEPS2_E4typeENS_11__wrap_iterIS3_EE = Module["__ZNSt3__213__unwrap_iterIcEENS_9enable_ifIXsr28is_trivially_copy_assignableIT_EE5valueEPS2_E4typeENS_11__wrap_iterIS3_EE"] = Module["asm"]["_ZNSt3__213__unwrap_iterIcEENS_9enable_ifIXsr28is_trivially_copy_assignableIT_EE5valueEPS2_E4typeENS_11__wrap_iterIS3_EE"]).apply(null, arguments)
            };
            var __ZNSt3__26__moveIccEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS6_EE5valueEPS6_E4typeEPS3_SA_S7_ = Module["__ZNSt3__26__moveIccEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS6_EE5valueEPS6_E4typeEPS3_SA_S7_"] = function() {
                return (__ZNSt3__26__moveIccEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS6_EE5valueEPS6_E4typeEPS3_SA_S7_ = Module["__ZNSt3__26__moveIccEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS6_EE5valueEPS6_E4typeEPS3_SA_S7_"] = Module["asm"]["_ZNSt3__26__moveIccEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS6_EE5valueEPS6_E4typeEPS3_SA_S7_"]).apply(null, arguments)
            };
            var __ZNSt3__215__move_backwardIccEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS6_EE5valueEPS6_E4typeEPS3_SA_S7_ = Module["__ZNSt3__215__move_backwardIccEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS6_EE5valueEPS6_E4typeEPS3_SA_S7_"] = function() {
                return (__ZNSt3__215__move_backwardIccEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS6_EE5valueEPS6_E4typeEPS3_SA_S7_ = Module["__ZNSt3__215__move_backwardIccEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS6_EE5valueEPS6_E4typeEPS3_SA_S7_"] = Module["asm"]["_ZNSt3__215__move_backwardIccEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS6_EE5valueEPS6_E4typeEPS3_SA_S7_"]).apply(null, arguments)
            };
            var __ZNSt3__28__rotateINS_11__wrap_iterIPwEEEET_S4_S4_S4_NS_26random_access_iterator_tagE = Module["__ZNSt3__28__rotateINS_11__wrap_iterIPwEEEET_S4_S4_S4_NS_26random_access_iterator_tagE"] = function() {
                return (__ZNSt3__28__rotateINS_11__wrap_iterIPwEEEET_S4_S4_S4_NS_26random_access_iterator_tagE = Module["__ZNSt3__28__rotateINS_11__wrap_iterIPwEEEET_S4_S4_S4_NS_26random_access_iterator_tagE"] = Module["asm"]["_ZNSt3__28__rotateINS_11__wrap_iterIPwEEEET_S4_S4_S4_NS_26random_access_iterator_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__24nextINS_11__wrap_iterIPwEEEENS_9enable_ifIXsr25__is_cpp17_input_iteratorIT_EE5valueES5_E4typeES5_NS_15iterator_traitsIS5_E15difference_typeE = Module["__ZNSt3__24nextINS_11__wrap_iterIPwEEEENS_9enable_ifIXsr25__is_cpp17_input_iteratorIT_EE5valueES5_E4typeES5_NS_15iterator_traitsIS5_E15difference_typeE"] = function() {
                return (__ZNSt3__24nextINS_11__wrap_iterIPwEEEENS_9enable_ifIXsr25__is_cpp17_input_iteratorIT_EE5valueES5_E4typeES5_NS_15iterator_traitsIS5_E15difference_typeE = Module["__ZNSt3__24nextINS_11__wrap_iterIPwEEEENS_9enable_ifIXsr25__is_cpp17_input_iteratorIT_EE5valueES5_E4typeES5_NS_15iterator_traitsIS5_E15difference_typeE"] = Module["asm"]["_ZNSt3__24nextINS_11__wrap_iterIPwEEEENS_9enable_ifIXsr25__is_cpp17_input_iteratorIT_EE5valueES5_E4typeES5_NS_15iterator_traitsIS5_E15difference_typeE"]).apply(null, arguments)
            };
            var __ZNSt3__213__rotate_leftINS_11__wrap_iterIPwEEEET_S4_S4_ = Module["__ZNSt3__213__rotate_leftINS_11__wrap_iterIPwEEEET_S4_S4_"] = function() {
                return (__ZNSt3__213__rotate_leftINS_11__wrap_iterIPwEEEET_S4_S4_ = Module["__ZNSt3__213__rotate_leftINS_11__wrap_iterIPwEEEET_S4_S4_"] = Module["asm"]["_ZNSt3__213__rotate_leftINS_11__wrap_iterIPwEEEET_S4_S4_"]).apply(null, arguments)
            };
            var __ZNSt3__214__rotate_rightINS_11__wrap_iterIPwEEEET_S4_S4_ = Module["__ZNSt3__214__rotate_rightINS_11__wrap_iterIPwEEEET_S4_S4_"] = function() {
                return (__ZNSt3__214__rotate_rightINS_11__wrap_iterIPwEEEET_S4_S4_ = Module["__ZNSt3__214__rotate_rightINS_11__wrap_iterIPwEEEET_S4_S4_"] = Module["asm"]["_ZNSt3__214__rotate_rightINS_11__wrap_iterIPwEEEET_S4_S4_"]).apply(null, arguments)
            };
            var __ZNSt3__212__rotate_gcdINS_11__wrap_iterIPwEEEET_S4_S4_S4_ = Module["__ZNSt3__212__rotate_gcdINS_11__wrap_iterIPwEEEET_S4_S4_S4_"] = function() {
                return (__ZNSt3__212__rotate_gcdINS_11__wrap_iterIPwEEEET_S4_S4_S4_ = Module["__ZNSt3__212__rotate_gcdINS_11__wrap_iterIPwEEEET_S4_S4_S4_"] = Module["asm"]["_ZNSt3__212__rotate_gcdINS_11__wrap_iterIPwEEEET_S4_S4_S4_"]).apply(null, arguments)
            };
            var __ZNSt3__27advanceINS_11__wrap_iterIPwEEEEvRT_NS_15iterator_traitsIS4_E15difference_typeE = Module["__ZNSt3__27advanceINS_11__wrap_iterIPwEEEEvRT_NS_15iterator_traitsIS4_E15difference_typeE"] = function() {
                return (__ZNSt3__27advanceINS_11__wrap_iterIPwEEEEvRT_NS_15iterator_traitsIS4_E15difference_typeE = Module["__ZNSt3__27advanceINS_11__wrap_iterIPwEEEEvRT_NS_15iterator_traitsIS4_E15difference_typeE"] = Module["asm"]["_ZNSt3__27advanceINS_11__wrap_iterIPwEEEEvRT_NS_15iterator_traitsIS4_E15difference_typeE"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRwEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRwEEONS_16remove_referenceIT_E4typeEOS3_"] = function() {
                return (__ZNSt3__24moveIRwEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRwEEONS_16remove_referenceIT_E4typeEOS3_"] = Module["asm"]["_ZNSt3__24moveIRwEEONS_16remove_referenceIT_E4typeEOS3_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveINS_11__wrap_iterIPwEES3_EET0_T_S5_S4_ = Module["__ZNSt3__24moveINS_11__wrap_iterIPwEES3_EET0_T_S5_S4_"] = function() {
                return (__ZNSt3__24moveINS_11__wrap_iterIPwEES3_EET0_T_S5_S4_ = Module["__ZNSt3__24moveINS_11__wrap_iterIPwEES3_EET0_T_S5_S4_"] = Module["asm"]["_ZNSt3__24moveINS_11__wrap_iterIPwEES3_EET0_T_S5_S4_"]).apply(null, arguments)
            };
            var __ZNSt3__24prevINS_11__wrap_iterIPwEEEENS_9enable_ifIXsr25__is_cpp17_input_iteratorIT_EE5valueES5_E4typeES5_NS_15iterator_traitsIS5_E15difference_typeE = Module["__ZNSt3__24prevINS_11__wrap_iterIPwEEEENS_9enable_ifIXsr25__is_cpp17_input_iteratorIT_EE5valueES5_E4typeES5_NS_15iterator_traitsIS5_E15difference_typeE"] = function() {
                return (__ZNSt3__24prevINS_11__wrap_iterIPwEEEENS_9enable_ifIXsr25__is_cpp17_input_iteratorIT_EE5valueES5_E4typeES5_NS_15iterator_traitsIS5_E15difference_typeE = Module["__ZNSt3__24prevINS_11__wrap_iterIPwEEEENS_9enable_ifIXsr25__is_cpp17_input_iteratorIT_EE5valueES5_E4typeES5_NS_15iterator_traitsIS5_E15difference_typeE"] = Module["asm"]["_ZNSt3__24prevINS_11__wrap_iterIPwEEEENS_9enable_ifIXsr25__is_cpp17_input_iteratorIT_EE5valueES5_E4typeES5_NS_15iterator_traitsIS5_E15difference_typeE"]).apply(null, arguments)
            };
            var __ZNSt3__213move_backwardINS_11__wrap_iterIPwEES3_EET0_T_S5_S4_ = Module["__ZNSt3__213move_backwardINS_11__wrap_iterIPwEES3_EET0_T_S5_S4_"] = function() {
                return (__ZNSt3__213move_backwardINS_11__wrap_iterIPwEES3_EET0_T_S5_S4_ = Module["__ZNSt3__213move_backwardINS_11__wrap_iterIPwEES3_EET0_T_S5_S4_"] = Module["asm"]["_ZNSt3__213move_backwardINS_11__wrap_iterIPwEES3_EET0_T_S5_S4_"]).apply(null, arguments)
            };
            var __ZNSt3__2miIPwS1_EEDTmicldtfp_4baseEcldtfp0_4baseEERKNS_11__wrap_iterIT_EERKNS3_IT0_EE = Module["__ZNSt3__2miIPwS1_EEDTmicldtfp_4baseEcldtfp0_4baseEERKNS_11__wrap_iterIT_EERKNS3_IT0_EE"] = function() {
                return (__ZNSt3__2miIPwS1_EEDTmicldtfp_4baseEcldtfp0_4baseEERKNS_11__wrap_iterIT_EERKNS3_IT0_EE = Module["__ZNSt3__2miIPwS1_EEDTmicldtfp_4baseEcldtfp0_4baseEERKNS_11__wrap_iterIT_EERKNS3_IT0_EE"] = Module["asm"]["_ZNSt3__2miIPwS1_EEDTmicldtfp_4baseEcldtfp0_4baseEERKNS_11__wrap_iterIT_EERKNS3_IT0_EE"]).apply(null, arguments)
            };
            var __ZNSt3__211swap_rangesINS_11__wrap_iterIPwEES3_EET0_T_S5_S4_ = Module["__ZNSt3__211swap_rangesINS_11__wrap_iterIPwEES3_EET0_T_S5_S4_"] = function() {
                return (__ZNSt3__211swap_rangesINS_11__wrap_iterIPwEES3_EET0_T_S5_S4_ = Module["__ZNSt3__211swap_rangesINS_11__wrap_iterIPwEES3_EET0_T_S5_S4_"] = Module["asm"]["_ZNSt3__211swap_rangesINS_11__wrap_iterIPwEES3_EET0_T_S5_S4_"]).apply(null, arguments)
            };
            var __ZNSt3__211__wrap_iterIPwEmmEv = Module["__ZNSt3__211__wrap_iterIPwEmmEv"] = function() {
                return (__ZNSt3__211__wrap_iterIPwEmmEv = Module["__ZNSt3__211__wrap_iterIPwEmmEv"] = Module["asm"]["_ZNSt3__211__wrap_iterIPwEmmEv"]).apply(null, arguments)
            };
            var __ZNSt3__29__advanceINS_11__wrap_iterIPwEEEEvRT_NS_15iterator_traitsIS4_E15difference_typeENS_26random_access_iterator_tagE = Module["__ZNSt3__29__advanceINS_11__wrap_iterIPwEEEEvRT_NS_15iterator_traitsIS4_E15difference_typeENS_26random_access_iterator_tagE"] = function() {
                return (__ZNSt3__29__advanceINS_11__wrap_iterIPwEEEEvRT_NS_15iterator_traitsIS4_E15difference_typeENS_26random_access_iterator_tagE = Module["__ZNSt3__29__advanceINS_11__wrap_iterIPwEEEEvRT_NS_15iterator_traitsIS4_E15difference_typeENS_26random_access_iterator_tagE"] = Module["asm"]["_ZNSt3__29__advanceINS_11__wrap_iterIPwEEEEvRT_NS_15iterator_traitsIS4_E15difference_typeENS_26random_access_iterator_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__213__unwrap_iterIwEENS_9enable_ifIXsr28is_trivially_copy_assignableIT_EE5valueEPS2_E4typeENS_11__wrap_iterIS3_EE = Module["__ZNSt3__213__unwrap_iterIwEENS_9enable_ifIXsr28is_trivially_copy_assignableIT_EE5valueEPS2_E4typeENS_11__wrap_iterIS3_EE"] = function() {
                return (__ZNSt3__213__unwrap_iterIwEENS_9enable_ifIXsr28is_trivially_copy_assignableIT_EE5valueEPS2_E4typeENS_11__wrap_iterIS3_EE = Module["__ZNSt3__213__unwrap_iterIwEENS_9enable_ifIXsr28is_trivially_copy_assignableIT_EE5valueEPS2_E4typeENS_11__wrap_iterIS3_EE"] = Module["asm"]["_ZNSt3__213__unwrap_iterIwEENS_9enable_ifIXsr28is_trivially_copy_assignableIT_EE5valueEPS2_E4typeENS_11__wrap_iterIS3_EE"]).apply(null, arguments)
            };
            var __ZNSt3__26__moveIwwEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS6_EE5valueEPS6_E4typeEPS3_SA_S7_ = Module["__ZNSt3__26__moveIwwEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS6_EE5valueEPS6_E4typeEPS3_SA_S7_"] = function() {
                return (__ZNSt3__26__moveIwwEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS6_EE5valueEPS6_E4typeEPS3_SA_S7_ = Module["__ZNSt3__26__moveIwwEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS6_EE5valueEPS6_E4typeEPS3_SA_S7_"] = Module["asm"]["_ZNSt3__26__moveIwwEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS6_EE5valueEPS6_E4typeEPS3_SA_S7_"]).apply(null, arguments)
            };
            var __ZNSt3__215__move_backwardIwwEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS6_EE5valueEPS6_E4typeEPS3_SA_S7_ = Module["__ZNSt3__215__move_backwardIwwEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS6_EE5valueEPS6_E4typeEPS3_SA_S7_"] = function() {
                return (__ZNSt3__215__move_backwardIwwEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS6_EE5valueEPS6_E4typeEPS3_SA_S7_ = Module["__ZNSt3__215__move_backwardIwwEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS6_EE5valueEPS6_E4typeEPS3_SA_S7_"] = Module["asm"]["_ZNSt3__215__move_backwardIwwEENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableIS6_EE5valueEPS6_E4typeEPS3_SA_S7_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIwEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIwEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = function() {
                return (__ZNSt3__24swapIwEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIwEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = Module["asm"]["_ZNSt3__24swapIwEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"]).apply(null, arguments)
            };
            var __ZNSt3__210__distanceIPKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_15iterator_traitsIT_E15difference_typeESA_SA_NS_26random_access_iterator_tagE = Module["__ZNSt3__210__distanceIPKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_15iterator_traitsIT_E15difference_typeESA_SA_NS_26random_access_iterator_tagE"] = function() {
                return (__ZNSt3__210__distanceIPKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_15iterator_traitsIT_E15difference_typeESA_SA_NS_26random_access_iterator_tagE = Module["__ZNSt3__210__distanceIPKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_15iterator_traitsIT_E15difference_typeESA_SA_NS_26random_access_iterator_tagE"] = Module["asm"]["_ZNSt3__210__distanceIPKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEENS_15iterator_traitsIT_E15difference_typeESA_SA_NS_26random_access_iterator_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__214numeric_limitsIlE3minEv = Module["__ZNSt3__214numeric_limitsIlE3minEv"] = function() {
                return (__ZNSt3__214numeric_limitsIlE3minEv = Module["__ZNSt3__214numeric_limitsIlE3minEv"] = Module["asm"]["_ZNSt3__214numeric_limitsIlE3minEv"]).apply(null, arguments)
            };
            var __ZNSt3__223__libcpp_numeric_limitsIlLb1EE3minEv = Module["__ZNSt3__223__libcpp_numeric_limitsIlLb1EE3minEv"] = function() {
                return (__ZNSt3__223__libcpp_numeric_limitsIlLb1EE3minEv = Module["__ZNSt3__223__libcpp_numeric_limitsIlLb1EE3minEv"] = Module["asm"]["_ZNSt3__223__libcpp_numeric_limitsIlLb1EE3minEv"]).apply(null, arguments)
            };
            var __ZNSt3__214numeric_limitsIxE3minEv = Module["__ZNSt3__214numeric_limitsIxE3minEv"] = function() {
                return (__ZNSt3__214numeric_limitsIxE3minEv = Module["__ZNSt3__214numeric_limitsIxE3minEv"] = Module["asm"]["_ZNSt3__214numeric_limitsIxE3minEv"]).apply(null, arguments)
            };
            var __ZNSt3__214numeric_limitsIxE3maxEv = Module["__ZNSt3__214numeric_limitsIxE3maxEv"] = function() {
                return (__ZNSt3__214numeric_limitsIxE3maxEv = Module["__ZNSt3__214numeric_limitsIxE3maxEv"] = Module["asm"]["_ZNSt3__214numeric_limitsIxE3maxEv"]).apply(null, arguments)
            };
            var __ZNSt3__223__libcpp_numeric_limitsIxLb1EE3minEv = Module["__ZNSt3__223__libcpp_numeric_limitsIxLb1EE3minEv"] = function() {
                return (__ZNSt3__223__libcpp_numeric_limitsIxLb1EE3minEv = Module["__ZNSt3__223__libcpp_numeric_limitsIxLb1EE3minEv"] = Module["asm"]["_ZNSt3__223__libcpp_numeric_limitsIxLb1EE3minEv"]).apply(null, arguments)
            };
            var __ZNSt3__223__libcpp_numeric_limitsIxLb1EE3maxEv = Module["__ZNSt3__223__libcpp_numeric_limitsIxLb1EE3maxEv"] = function() {
                return (__ZNSt3__223__libcpp_numeric_limitsIxLb1EE3maxEv = Module["__ZNSt3__223__libcpp_numeric_limitsIxLb1EE3maxEv"] = Module["asm"]["_ZNSt3__223__libcpp_numeric_limitsIxLb1EE3maxEv"]).apply(null, arguments)
            };
            var __ZNSt3__214numeric_limitsItE3maxEv = Module["__ZNSt3__214numeric_limitsItE3maxEv"] = function() {
                return (__ZNSt3__214numeric_limitsItE3maxEv = Module["__ZNSt3__214numeric_limitsItE3maxEv"] = Module["asm"]["_ZNSt3__214numeric_limitsItE3maxEv"]).apply(null, arguments)
            };
            var __ZNSt3__223__libcpp_numeric_limitsItLb1EE3maxEv = Module["__ZNSt3__223__libcpp_numeric_limitsItLb1EE3maxEv"] = function() {
                return (__ZNSt3__223__libcpp_numeric_limitsItLb1EE3maxEv = Module["__ZNSt3__223__libcpp_numeric_limitsItLb1EE3maxEv"] = Module["asm"]["_ZNSt3__223__libcpp_numeric_limitsItLb1EE3maxEv"]).apply(null, arguments)
            };
            var __ZNSt3__214numeric_limitsIyE3maxEv = Module["__ZNSt3__214numeric_limitsIyE3maxEv"] = function() {
                return (__ZNSt3__214numeric_limitsIyE3maxEv = Module["__ZNSt3__214numeric_limitsIyE3maxEv"] = Module["asm"]["_ZNSt3__214numeric_limitsIyE3maxEv"]).apply(null, arguments)
            };
            var __ZNSt3__223__libcpp_numeric_limitsIyLb1EE3maxEv = Module["__ZNSt3__223__libcpp_numeric_limitsIyLb1EE3maxEv"] = function() {
                return (__ZNSt3__223__libcpp_numeric_limitsIyLb1EE3maxEv = Module["__ZNSt3__223__libcpp_numeric_limitsIyLb1EE3maxEv"] = Module["asm"]["_ZNSt3__223__libcpp_numeric_limitsIyLb1EE3maxEv"]).apply(null, arguments)
            };
            var __ZNSt3__211__do_strtodIfEET_PKcPPc = Module["__ZNSt3__211__do_strtodIfEET_PKcPPc"] = function() {
                return (__ZNSt3__211__do_strtodIfEET_PKcPPc = Module["__ZNSt3__211__do_strtodIfEET_PKcPPc"] = Module["asm"]["_ZNSt3__211__do_strtodIfEET_PKcPPc"]).apply(null, arguments)
            };
            var __ZNSt3__211__do_strtodIdEET_PKcPPc = Module["__ZNSt3__211__do_strtodIdEET_PKcPPc"] = function() {
                return (__ZNSt3__211__do_strtodIdEET_PKcPPc = Module["__ZNSt3__211__do_strtodIdEET_PKcPPc"] = Module["asm"]["_ZNSt3__211__do_strtodIdEET_PKcPPc"]).apply(null, arguments)
            };
            var __ZNSt3__211__do_strtodIeEET_PKcPPc = Module["__ZNSt3__211__do_strtodIeEET_PKcPPc"] = function() {
                return (__ZNSt3__211__do_strtodIeEET_PKcPPc = Module["__ZNSt3__211__do_strtodIeEET_PKcPPc"] = Module["asm"]["_ZNSt3__211__do_strtodIeEET_PKcPPc"]).apply(null, arguments)
            };
            var __ZNKSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEE14__test_for_eofEv = Module["__ZNKSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEE14__test_for_eofEv"] = function() {
                return (__ZNKSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEE14__test_for_eofEv = Module["__ZNKSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEE14__test_for_eofEv"] = Module["asm"]["_ZNKSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEE14__test_for_eofEv"]).apply(null, arguments)
            };
            var __ZNSt3__210__distanceIPKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEEENS_15iterator_traitsIT_E15difference_typeESA_SA_NS_26random_access_iterator_tagE = Module["__ZNSt3__210__distanceIPKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEEENS_15iterator_traitsIT_E15difference_typeESA_SA_NS_26random_access_iterator_tagE"] = function() {
                return (__ZNSt3__210__distanceIPKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEEENS_15iterator_traitsIT_E15difference_typeESA_SA_NS_26random_access_iterator_tagE = Module["__ZNSt3__210__distanceIPKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEEENS_15iterator_traitsIT_E15difference_typeESA_SA_NS_26random_access_iterator_tagE"] = Module["asm"]["_ZNSt3__210__distanceIPKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEEENS_15iterator_traitsIT_E15difference_typeESA_SA_NS_26random_access_iterator_tagE"]).apply(null, arguments)
            };
            var __ZNKSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEE14__test_for_eofEv = Module["__ZNKSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEE14__test_for_eofEv"] = function() {
                return (__ZNKSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEE14__test_for_eofEv = Module["__ZNKSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEE14__test_for_eofEv"] = Module["asm"]["_ZNKSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEE14__test_for_eofEv"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIwE11to_int_typeEw = Module["__ZNSt3__211char_traitsIwE11to_int_typeEw"] = function() {
                return (__ZNSt3__211char_traitsIwE11to_int_typeEw = Module["__ZNSt3__211char_traitsIwE11to_int_typeEw"] = Module["asm"]["_ZNSt3__211char_traitsIwE11to_int_typeEw"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRPcEEOT_RNS_16remove_referenceIS3_E4typeE = Module["__ZNSt3__27forwardIRPcEEOT_RNS_16remove_referenceIS3_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRPcEEOT_RNS_16remove_referenceIS3_E4typeE = Module["__ZNSt3__27forwardIRPcEEOT_RNS_16remove_referenceIS3_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRPcEEOT_RNS_16remove_referenceIS3_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPcLi0ELb0EEC2IRS1_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPcLi0ELb0EEC2IRS1_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPcLi0ELb0EEC2IRS1_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPcLi0ELb0EEC2IRS1_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPcLi0ELb0EEC2IRS1_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPcLi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPcLi0ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPcLi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPcLi0ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPcLi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRPwEEOT_RNS_16remove_referenceIS3_E4typeE = Module["__ZNSt3__27forwardIRPwEEOT_RNS_16remove_referenceIS3_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRPwEEOT_RNS_16remove_referenceIS3_E4typeE = Module["__ZNSt3__27forwardIRPwEEOT_RNS_16remove_referenceIS3_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRPwEEOT_RNS_16remove_referenceIS3_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPwLi0ELb0EEC2IRS1_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPwLi0ELb0EEC2IRS1_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPwLi0ELb0EEC2IRS1_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPwLi0ELb0EEC2IRS1_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPwLi0ELb0EEC2IRS1_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPwLi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPwLi0ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPwLi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPwLi0ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPwLi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__29iter_swapIPcS1_EEvT_T0_ = Module["__ZNSt3__29iter_swapIPcS1_EEvT_T0_"] = function() {
                return (__ZNSt3__29iter_swapIPcS1_EEvT_T0_ = Module["__ZNSt3__29iter_swapIPcS1_EEvT_T0_"] = Module["asm"]["_ZNSt3__29iter_swapIPcS1_EEvT_T0_"]).apply(null, arguments)
            };
            var __ZNSt3__29iter_swapIPwS1_EEvT_T0_ = Module["__ZNSt3__29iter_swapIPwS1_EEvT_T0_"] = function() {
                return (__ZNSt3__29iter_swapIPwS1_EEvT_T0_ = Module["__ZNSt3__29iter_swapIPwS1_EEvT_T0_"] = Module["asm"]["_ZNSt3__29iter_swapIPwS1_EEvT_T0_"]).apply(null, arguments)
            };
            var __ZNSt3__216__copy_constexprIPcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEET0_T_S7_S6_ = Module["__ZNSt3__216__copy_constexprIPcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEET0_T_S7_S6_"] = function() {
                return (__ZNSt3__216__copy_constexprIPcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEET0_T_S7_S6_ = Module["__ZNSt3__216__copy_constexprIPcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEET0_T_S7_S6_"] = Module["asm"]["_ZNSt3__216__copy_constexprIPcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEET0_T_S7_S6_"]).apply(null, arguments)
            };
            var __ZNSt3__216__copy_constexprIPwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEET0_T_S7_S6_ = Module["__ZNSt3__216__copy_constexprIPwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEET0_T_S7_S6_"] = function() {
                return (__ZNSt3__216__copy_constexprIPwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEET0_T_S7_S6_ = Module["__ZNSt3__216__copy_constexprIPwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEET0_T_S7_S6_"] = Module["asm"]["_ZNSt3__216__copy_constexprIPwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEET0_T_S7_S6_"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemIPcLi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPcLi0ELb0EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemIPcLi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPcLi0ELb0EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemIPcLi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__ptr_in_rangeIcEEbPKT_S3_S3_ = Module["__ZNSt3__214__ptr_in_rangeIcEEbPKT_S3_S3_"] = function() {
                return (__ZNSt3__214__ptr_in_rangeIcEEbPKT_S3_S3_ = Module["__ZNSt3__214__ptr_in_rangeIcEEbPKT_S3_S3_"] = Module["asm"]["_ZNSt3__214__ptr_in_rangeIcEEbPKT_S3_S3_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2IPcvEET_S8_RKS4_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2IPcvEET_S8_RKS4_"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2IPcvEET_S8_RKS4_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2IPcvEET_S8_RKS4_"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2IPcvEET_S8_RKS4_"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRPjEEOT_RNS_16remove_referenceIS3_E4typeE = Module["__ZNSt3__27forwardIRPjEEOT_RNS_16remove_referenceIS3_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRPjEEOT_RNS_16remove_referenceIS3_E4typeE = Module["__ZNSt3__27forwardIRPjEEOT_RNS_16remove_referenceIS3_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRPjEEOT_RNS_16remove_referenceIS3_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPjLi0ELb0EEC2IRS1_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPjLi0ELb0EEC2IRS1_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPjLi0ELb0EEC2IRS1_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPjLi0ELb0EEC2IRS1_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPjLi0ELb0EEC2IRS1_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPjPFvPvEE5firstEv = Module["__ZNSt3__217__compressed_pairIPjPFvPvEE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPjPFvPvEE5firstEv = Module["__ZNSt3__217__compressed_pairIPjPFvPvEE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPjPFvPvEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPjPFvPvEE6secondEv = Module["__ZNSt3__217__compressed_pairIPjPFvPvEE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPjPFvPvEE6secondEv = Module["__ZNSt3__217__compressed_pairIPjPFvPvEE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPjPFvPvEE6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPjLi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPjLi0ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPjLi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPjLi0ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPjLi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemIPjLi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPjLi0ELb0EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemIPjLi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPjLi0ELb0EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemIPjLi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210__equal_toIccEclERKcS3_ = Module["__ZNKSt3__210__equal_toIccEclERKcS3_"] = function() {
                return (__ZNKSt3__210__equal_toIccEclERKcS3_ = Module["__ZNKSt3__210__equal_toIccEclERKcS3_"] = Module["asm"]["_ZNKSt3__210__equal_toIccEclERKcS3_"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemIPwLi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPwLi0ELb0EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemIPwLi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPwLi0ELb0EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemIPwLi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__ptr_in_rangeIwEEbPKT_S3_S3_ = Module["__ZNSt3__214__ptr_in_rangeIwEEbPKT_S3_S3_"] = function() {
                return (__ZNSt3__214__ptr_in_rangeIwEEbPKT_S3_S3_ = Module["__ZNSt3__214__ptr_in_rangeIwEEbPKT_S3_S3_"] = Module["asm"]["_ZNSt3__214__ptr_in_rangeIwEEbPKT_S3_S3_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2IPwvEET_S8_RKS4_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2IPwvEET_S8_RKS4_"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2IPwvEET_S8_RKS4_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2IPwvEET_S8_RKS4_"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEC2IPwvEET_S8_RKS4_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initIPwEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeES9_S9_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initIPwEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeES9_S9_"] = function() {
                return (__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initIPwEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeES9_S9_ = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initIPwEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeES9_S9_"] = Module["asm"]["_ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE6__initIPwEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeES9_S9_"]).apply(null, arguments)
            };
            var __ZNKSt3__210__equal_toIwwEclERKwS3_ = Module["__ZNKSt3__210__equal_toIwwEclERKwS3_"] = function() {
                return (__ZNKSt3__210__equal_toIwwEclERKwS3_ = Module["__ZNKSt3__210__equal_toIwwEclERKwS3_"] = Module["asm"]["_ZNKSt3__210__equal_toIwwEclERKwS3_"]).apply(null, arguments)
            };
            var __ZNSt3__27collateIcED1Ev = Module["__ZNSt3__27collateIcED1Ev"] = function() {
                return (__ZNSt3__27collateIcED1Ev = Module["__ZNSt3__27collateIcED1Ev"] = Module["asm"]["_ZNSt3__27collateIcED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__27collateIwED1Ev = Module["__ZNSt3__27collateIwED1Ev"] = function() {
                return (__ZNSt3__27collateIwED1Ev = Module["__ZNSt3__27collateIwED1Ev"] = Module["asm"]["_ZNSt3__27collateIwED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214codecvt_bynameIcc11__mbstate_tED1Ev = Module["__ZNSt3__214codecvt_bynameIcc11__mbstate_tED1Ev"] = function() {
                return (__ZNSt3__214codecvt_bynameIcc11__mbstate_tED1Ev = Module["__ZNSt3__214codecvt_bynameIcc11__mbstate_tED1Ev"] = Module["asm"]["_ZNSt3__214codecvt_bynameIcc11__mbstate_tED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214codecvt_bynameIwc11__mbstate_tED1Ev = Module["__ZNSt3__214codecvt_bynameIwc11__mbstate_tED1Ev"] = function() {
                return (__ZNSt3__214codecvt_bynameIwc11__mbstate_tED1Ev = Module["__ZNSt3__214codecvt_bynameIwc11__mbstate_tED1Ev"] = Module["asm"]["_ZNSt3__214codecvt_bynameIwc11__mbstate_tED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214codecvt_bynameIDsc11__mbstate_tED1Ev = Module["__ZNSt3__214codecvt_bynameIDsc11__mbstate_tED1Ev"] = function() {
                return (__ZNSt3__214codecvt_bynameIDsc11__mbstate_tED1Ev = Module["__ZNSt3__214codecvt_bynameIDsc11__mbstate_tED1Ev"] = Module["asm"]["_ZNSt3__214codecvt_bynameIDsc11__mbstate_tED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214codecvt_bynameIDic11__mbstate_tED1Ev = Module["__ZNSt3__214codecvt_bynameIDic11__mbstate_tED1Ev"] = function() {
                return (__ZNSt3__214codecvt_bynameIDic11__mbstate_tED1Ev = Module["__ZNSt3__214codecvt_bynameIDic11__mbstate_tED1Ev"] = Module["asm"]["_ZNSt3__214codecvt_bynameIDic11__mbstate_tED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__impC1Em = Module["__ZNSt3__26locale5__impC1Em"] = function() {
                return (__ZNSt3__26locale5__impC1Em = Module["__ZNSt3__26locale5__impC1Em"] = Module["asm"]["_ZNSt3__26locale5__impC1Em"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__impC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__26locale5__impC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__26locale5__impC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__26locale5__impC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__26locale5__impC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__impC1ERKS1_ = Module["__ZNSt3__26locale5__impC1ERKS1_"] = function() {
                return (__ZNSt3__26locale5__impC1ERKS1_ = Module["__ZNSt3__26locale5__impC1ERKS1_"] = Module["asm"]["_ZNSt3__26locale5__impC1ERKS1_"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__impC1ERKS1_RKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEi = Module["__ZNSt3__26locale5__impC1ERKS1_RKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEi"] = function() {
                return (__ZNSt3__26locale5__impC1ERKS1_RKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEi = Module["__ZNSt3__26locale5__impC1ERKS1_RKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEi"] = Module["asm"]["_ZNSt3__26locale5__impC1ERKS1_RKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEi"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__impC1ERKS1_S3_i = Module["__ZNSt3__26locale5__impC1ERKS1_S3_i"] = function() {
                return (__ZNSt3__26locale5__impC1ERKS1_S3_i = Module["__ZNSt3__26locale5__impC1ERKS1_S3_i"] = Module["asm"]["_ZNSt3__26locale5__impC1ERKS1_S3_i"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__impC1ERKS1_PNS0_5facetEl = Module["__ZNSt3__26locale5__impC1ERKS1_PNS0_5facetEl"] = function() {
                return (__ZNSt3__26locale5__impC1ERKS1_PNS0_5facetEl = Module["__ZNSt3__26locale5__impC1ERKS1_PNS0_5facetEl"] = Module["asm"]["_ZNSt3__26locale5__impC1ERKS1_PNS0_5facetEl"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5__impD1Ev = Module["__ZNSt3__26locale5__impD1Ev"] = function() {
                return (__ZNSt3__26locale5__impD1Ev = Module["__ZNSt3__26locale5__impD1Ev"] = Module["asm"]["_ZNSt3__26locale5__impD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__26localeC1Ev = Module["__ZNSt3__26localeC1Ev"] = function() {
                return (__ZNSt3__26localeC1Ev = Module["__ZNSt3__26localeC1Ev"] = Module["asm"]["_ZNSt3__26localeC1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__26localeC1ERKS0_ = Module["__ZNSt3__26localeC1ERKS0_"] = function() {
                return (__ZNSt3__26localeC1ERKS0_ = Module["__ZNSt3__26localeC1ERKS0_"] = Module["asm"]["_ZNSt3__26localeC1ERKS0_"]).apply(null, arguments)
            };
            var __ZNSt3__26localeD1Ev = Module["__ZNSt3__26localeD1Ev"] = function() {
                return (__ZNSt3__26localeD1Ev = Module["__ZNSt3__26localeD1Ev"] = Module["asm"]["_ZNSt3__26localeD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__26localeC1EPKc = Module["__ZNSt3__26localeC1EPKc"] = function() {
                return (__ZNSt3__26localeC1EPKc = Module["__ZNSt3__26localeC1EPKc"] = Module["asm"]["_ZNSt3__26localeC1EPKc"]).apply(null, arguments)
            };
            var __ZNSt3__26localeC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__26localeC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = function() {
                return (__ZNSt3__26localeC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__26localeC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = Module["asm"]["_ZNSt3__26localeC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNSt3__26localeC1ERKS0_PKci = Module["__ZNSt3__26localeC1ERKS0_PKci"] = function() {
                return (__ZNSt3__26localeC1ERKS0_PKci = Module["__ZNSt3__26localeC1ERKS0_PKci"] = Module["asm"]["_ZNSt3__26localeC1ERKS0_PKci"]).apply(null, arguments)
            };
            var __ZNSt3__26localeC1ERKS0_RKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEi = Module["__ZNSt3__26localeC1ERKS0_RKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEi"] = function() {
                return (__ZNSt3__26localeC1ERKS0_RKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEi = Module["__ZNSt3__26localeC1ERKS0_RKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEi"] = Module["asm"]["_ZNSt3__26localeC1ERKS0_RKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEi"]).apply(null, arguments)
            };
            var __ZNSt3__26localeC1ERKS0_S2_i = Module["__ZNSt3__26localeC1ERKS0_S2_i"] = function() {
                return (__ZNSt3__26localeC1ERKS0_S2_i = Module["__ZNSt3__26localeC1ERKS0_S2_i"] = Module["asm"]["_ZNSt3__26localeC1ERKS0_S2_i"]).apply(null, arguments)
            };
            var __ZNSt3__26locale5facetD1Ev = Module["__ZNSt3__26locale5facetD1Ev"] = function() {
                return (__ZNSt3__26locale5facetD1Ev = Module["__ZNSt3__26locale5facetD1Ev"] = Module["asm"]["_ZNSt3__26locale5facetD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214collate_bynameIcEC1EPKcm = Module["__ZNSt3__214collate_bynameIcEC1EPKcm"] = function() {
                return (__ZNSt3__214collate_bynameIcEC1EPKcm = Module["__ZNSt3__214collate_bynameIcEC1EPKcm"] = Module["asm"]["_ZNSt3__214collate_bynameIcEC1EPKcm"]).apply(null, arguments)
            };
            var __ZNSt3__214collate_bynameIcEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__214collate_bynameIcEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__214collate_bynameIcEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__214collate_bynameIcEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__214collate_bynameIcEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__214collate_bynameIcED1Ev = Module["__ZNSt3__214collate_bynameIcED1Ev"] = function() {
                return (__ZNSt3__214collate_bynameIcED1Ev = Module["__ZNSt3__214collate_bynameIcED1Ev"] = Module["asm"]["_ZNSt3__214collate_bynameIcED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214collate_bynameIwEC1EPKcm = Module["__ZNSt3__214collate_bynameIwEC1EPKcm"] = function() {
                return (__ZNSt3__214collate_bynameIwEC1EPKcm = Module["__ZNSt3__214collate_bynameIwEC1EPKcm"] = Module["asm"]["_ZNSt3__214collate_bynameIwEC1EPKcm"]).apply(null, arguments)
            };
            var __ZNSt3__214collate_bynameIwEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__214collate_bynameIwEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__214collate_bynameIwEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__214collate_bynameIwEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__214collate_bynameIwEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__214collate_bynameIwED1Ev = Module["__ZNSt3__214collate_bynameIwED1Ev"] = function() {
                return (__ZNSt3__214collate_bynameIwED1Ev = Module["__ZNSt3__214collate_bynameIwED1Ev"] = Module["asm"]["_ZNSt3__214collate_bynameIwED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__25ctypeIwED2Ev = Module["__ZNSt3__25ctypeIwED2Ev"] = function() {
                return (__ZNSt3__25ctypeIwED2Ev = Module["__ZNSt3__25ctypeIwED2Ev"] = Module["asm"]["_ZNSt3__25ctypeIwED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__25ctypeIwED1Ev = Module["__ZNSt3__25ctypeIwED1Ev"] = function() {
                return (__ZNSt3__25ctypeIwED1Ev = Module["__ZNSt3__25ctypeIwED1Ev"] = Module["asm"]["_ZNSt3__25ctypeIwED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__25ctypeIcEC1EPKtbm = Module["__ZNSt3__25ctypeIcEC1EPKtbm"] = function() {
                return (__ZNSt3__25ctypeIcEC1EPKtbm = Module["__ZNSt3__25ctypeIcEC1EPKtbm"] = Module["asm"]["_ZNSt3__25ctypeIcEC1EPKtbm"]).apply(null, arguments)
            };
            var __ZNSt3__25ctypeIcED1Ev = Module["__ZNSt3__25ctypeIcED1Ev"] = function() {
                return (__ZNSt3__25ctypeIcED1Ev = Module["__ZNSt3__25ctypeIcED1Ev"] = Module["asm"]["_ZNSt3__25ctypeIcED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212ctype_bynameIcEC1EPKcm = Module["__ZNSt3__212ctype_bynameIcEC1EPKcm"] = function() {
                return (__ZNSt3__212ctype_bynameIcEC1EPKcm = Module["__ZNSt3__212ctype_bynameIcEC1EPKcm"] = Module["asm"]["_ZNSt3__212ctype_bynameIcEC1EPKcm"]).apply(null, arguments)
            };
            var __ZNSt3__212ctype_bynameIcEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__212ctype_bynameIcEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__212ctype_bynameIcEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__212ctype_bynameIcEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__212ctype_bynameIcEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__212ctype_bynameIcED1Ev = Module["__ZNSt3__212ctype_bynameIcED1Ev"] = function() {
                return (__ZNSt3__212ctype_bynameIcED1Ev = Module["__ZNSt3__212ctype_bynameIcED1Ev"] = Module["asm"]["_ZNSt3__212ctype_bynameIcED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212ctype_bynameIwEC1EPKcm = Module["__ZNSt3__212ctype_bynameIwEC1EPKcm"] = function() {
                return (__ZNSt3__212ctype_bynameIwEC1EPKcm = Module["__ZNSt3__212ctype_bynameIwEC1EPKcm"] = Module["asm"]["_ZNSt3__212ctype_bynameIwEC1EPKcm"]).apply(null, arguments)
            };
            var __ZNSt3__212ctype_bynameIwEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__212ctype_bynameIwEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__212ctype_bynameIwEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__212ctype_bynameIwEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__212ctype_bynameIwEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__212ctype_bynameIwED1Ev = Module["__ZNSt3__212ctype_bynameIwED1Ev"] = function() {
                return (__ZNSt3__212ctype_bynameIwED1Ev = Module["__ZNSt3__212ctype_bynameIwED1Ev"] = Module["asm"]["_ZNSt3__212ctype_bynameIwED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__27codecvtIcc11__mbstate_tED2Ev = Module["__ZNSt3__27codecvtIcc11__mbstate_tED2Ev"] = function() {
                return (__ZNSt3__27codecvtIcc11__mbstate_tED2Ev = Module["__ZNSt3__27codecvtIcc11__mbstate_tED2Ev"] = Module["asm"]["_ZNSt3__27codecvtIcc11__mbstate_tED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__27codecvtIcc11__mbstate_tED1Ev = Module["__ZNSt3__27codecvtIcc11__mbstate_tED1Ev"] = function() {
                return (__ZNSt3__27codecvtIcc11__mbstate_tED1Ev = Module["__ZNSt3__27codecvtIcc11__mbstate_tED1Ev"] = Module["asm"]["_ZNSt3__27codecvtIcc11__mbstate_tED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__27codecvtIwc11__mbstate_tEC1Em = Module["__ZNSt3__27codecvtIwc11__mbstate_tEC1Em"] = function() {
                return (__ZNSt3__27codecvtIwc11__mbstate_tEC1Em = Module["__ZNSt3__27codecvtIwc11__mbstate_tEC1Em"] = Module["asm"]["_ZNSt3__27codecvtIwc11__mbstate_tEC1Em"]).apply(null, arguments)
            };
            var __ZNSt3__27codecvtIwc11__mbstate_tEC1EPKcm = Module["__ZNSt3__27codecvtIwc11__mbstate_tEC1EPKcm"] = function() {
                return (__ZNSt3__27codecvtIwc11__mbstate_tEC1EPKcm = Module["__ZNSt3__27codecvtIwc11__mbstate_tEC1EPKcm"] = Module["asm"]["_ZNSt3__27codecvtIwc11__mbstate_tEC1EPKcm"]).apply(null, arguments)
            };
            var __ZNSt3__27codecvtIwc11__mbstate_tED1Ev = Module["__ZNSt3__27codecvtIwc11__mbstate_tED1Ev"] = function() {
                return (__ZNSt3__27codecvtIwc11__mbstate_tED1Ev = Module["__ZNSt3__27codecvtIwc11__mbstate_tED1Ev"] = Module["asm"]["_ZNSt3__27codecvtIwc11__mbstate_tED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__27codecvtIDsc11__mbstate_tED2Ev = Module["__ZNSt3__27codecvtIDsc11__mbstate_tED2Ev"] = function() {
                return (__ZNSt3__27codecvtIDsc11__mbstate_tED2Ev = Module["__ZNSt3__27codecvtIDsc11__mbstate_tED2Ev"] = Module["asm"]["_ZNSt3__27codecvtIDsc11__mbstate_tED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__27codecvtIDsc11__mbstate_tED1Ev = Module["__ZNSt3__27codecvtIDsc11__mbstate_tED1Ev"] = function() {
                return (__ZNSt3__27codecvtIDsc11__mbstate_tED1Ev = Module["__ZNSt3__27codecvtIDsc11__mbstate_tED1Ev"] = Module["asm"]["_ZNSt3__27codecvtIDsc11__mbstate_tED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__27codecvtIDic11__mbstate_tED2Ev = Module["__ZNSt3__27codecvtIDic11__mbstate_tED2Ev"] = function() {
                return (__ZNSt3__27codecvtIDic11__mbstate_tED2Ev = Module["__ZNSt3__27codecvtIDic11__mbstate_tED2Ev"] = Module["asm"]["_ZNSt3__27codecvtIDic11__mbstate_tED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__27codecvtIDic11__mbstate_tED1Ev = Module["__ZNSt3__27codecvtIDic11__mbstate_tED1Ev"] = function() {
                return (__ZNSt3__27codecvtIDic11__mbstate_tED1Ev = Module["__ZNSt3__27codecvtIDic11__mbstate_tED1Ev"] = Module["asm"]["_ZNSt3__27codecvtIDic11__mbstate_tED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__216__narrow_to_utf8ILm16EED2Ev = Module["__ZNSt3__216__narrow_to_utf8ILm16EED2Ev"] = function() {
                return (__ZNSt3__216__narrow_to_utf8ILm16EED2Ev = Module["__ZNSt3__216__narrow_to_utf8ILm16EED2Ev"] = Module["asm"]["_ZNSt3__216__narrow_to_utf8ILm16EED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__216__narrow_to_utf8ILm16EED1Ev = Module["__ZNSt3__216__narrow_to_utf8ILm16EED1Ev"] = function() {
                return (__ZNSt3__216__narrow_to_utf8ILm16EED1Ev = Module["__ZNSt3__216__narrow_to_utf8ILm16EED1Ev"] = Module["asm"]["_ZNSt3__216__narrow_to_utf8ILm16EED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__216__narrow_to_utf8ILm32EED2Ev = Module["__ZNSt3__216__narrow_to_utf8ILm32EED2Ev"] = function() {
                return (__ZNSt3__216__narrow_to_utf8ILm32EED2Ev = Module["__ZNSt3__216__narrow_to_utf8ILm32EED2Ev"] = Module["asm"]["_ZNSt3__216__narrow_to_utf8ILm32EED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__216__narrow_to_utf8ILm32EED1Ev = Module["__ZNSt3__216__narrow_to_utf8ILm32EED1Ev"] = function() {
                return (__ZNSt3__216__narrow_to_utf8ILm32EED1Ev = Module["__ZNSt3__216__narrow_to_utf8ILm32EED1Ev"] = Module["asm"]["_ZNSt3__216__narrow_to_utf8ILm32EED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217__widen_from_utf8ILm16EED2Ev = Module["__ZNSt3__217__widen_from_utf8ILm16EED2Ev"] = function() {
                return (__ZNSt3__217__widen_from_utf8ILm16EED2Ev = Module["__ZNSt3__217__widen_from_utf8ILm16EED2Ev"] = Module["asm"]["_ZNSt3__217__widen_from_utf8ILm16EED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217__widen_from_utf8ILm16EED1Ev = Module["__ZNSt3__217__widen_from_utf8ILm16EED1Ev"] = function() {
                return (__ZNSt3__217__widen_from_utf8ILm16EED1Ev = Module["__ZNSt3__217__widen_from_utf8ILm16EED1Ev"] = Module["asm"]["_ZNSt3__217__widen_from_utf8ILm16EED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217__widen_from_utf8ILm32EED2Ev = Module["__ZNSt3__217__widen_from_utf8ILm32EED2Ev"] = function() {
                return (__ZNSt3__217__widen_from_utf8ILm32EED2Ev = Module["__ZNSt3__217__widen_from_utf8ILm32EED2Ev"] = Module["asm"]["_ZNSt3__217__widen_from_utf8ILm32EED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217__widen_from_utf8ILm32EED1Ev = Module["__ZNSt3__217__widen_from_utf8ILm32EED1Ev"] = function() {
                return (__ZNSt3__217__widen_from_utf8ILm32EED1Ev = Module["__ZNSt3__217__widen_from_utf8ILm32EED1Ev"] = Module["asm"]["_ZNSt3__217__widen_from_utf8ILm32EED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28numpunctIcEC1Em = Module["__ZNSt3__28numpunctIcEC1Em"] = function() {
                return (__ZNSt3__28numpunctIcEC1Em = Module["__ZNSt3__28numpunctIcEC1Em"] = Module["asm"]["_ZNSt3__28numpunctIcEC1Em"]).apply(null, arguments)
            };
            var __ZNSt3__28numpunctIwEC1Em = Module["__ZNSt3__28numpunctIwEC1Em"] = function() {
                return (__ZNSt3__28numpunctIwEC1Em = Module["__ZNSt3__28numpunctIwEC1Em"] = Module["asm"]["_ZNSt3__28numpunctIwEC1Em"]).apply(null, arguments)
            };
            var __ZNSt3__28numpunctIcED1Ev = Module["__ZNSt3__28numpunctIcED1Ev"] = function() {
                return (__ZNSt3__28numpunctIcED1Ev = Module["__ZNSt3__28numpunctIcED1Ev"] = Module["asm"]["_ZNSt3__28numpunctIcED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28numpunctIwED1Ev = Module["__ZNSt3__28numpunctIwED1Ev"] = function() {
                return (__ZNSt3__28numpunctIwED1Ev = Module["__ZNSt3__28numpunctIwED1Ev"] = Module["asm"]["_ZNSt3__28numpunctIwED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215numpunct_bynameIcEC1EPKcm = Module["__ZNSt3__215numpunct_bynameIcEC1EPKcm"] = function() {
                return (__ZNSt3__215numpunct_bynameIcEC1EPKcm = Module["__ZNSt3__215numpunct_bynameIcEC1EPKcm"] = Module["asm"]["_ZNSt3__215numpunct_bynameIcEC1EPKcm"]).apply(null, arguments)
            };
            var __ZNSt3__215numpunct_bynameIcEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__215numpunct_bynameIcEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__215numpunct_bynameIcEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__215numpunct_bynameIcEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__215numpunct_bynameIcEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__215numpunct_bynameIcED2Ev = Module["__ZNSt3__215numpunct_bynameIcED2Ev"] = function() {
                return (__ZNSt3__215numpunct_bynameIcED2Ev = Module["__ZNSt3__215numpunct_bynameIcED2Ev"] = Module["asm"]["_ZNSt3__215numpunct_bynameIcED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215numpunct_bynameIcED1Ev = Module["__ZNSt3__215numpunct_bynameIcED1Ev"] = function() {
                return (__ZNSt3__215numpunct_bynameIcED1Ev = Module["__ZNSt3__215numpunct_bynameIcED1Ev"] = Module["asm"]["_ZNSt3__215numpunct_bynameIcED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215numpunct_bynameIwEC1EPKcm = Module["__ZNSt3__215numpunct_bynameIwEC1EPKcm"] = function() {
                return (__ZNSt3__215numpunct_bynameIwEC1EPKcm = Module["__ZNSt3__215numpunct_bynameIwEC1EPKcm"] = Module["asm"]["_ZNSt3__215numpunct_bynameIwEC1EPKcm"]).apply(null, arguments)
            };
            var __ZNSt3__215numpunct_bynameIwEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__215numpunct_bynameIwEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = function() {
                return (__ZNSt3__215numpunct_bynameIwEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm = Module["__ZNSt3__215numpunct_bynameIwEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"] = Module["asm"]["_ZNSt3__215numpunct_bynameIwEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEm"]).apply(null, arguments)
            };
            var __ZNSt3__215numpunct_bynameIwED2Ev = Module["__ZNSt3__215numpunct_bynameIwED2Ev"] = function() {
                return (__ZNSt3__215numpunct_bynameIwED2Ev = Module["__ZNSt3__215numpunct_bynameIwED2Ev"] = Module["asm"]["_ZNSt3__215numpunct_bynameIwED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215numpunct_bynameIwED1Ev = Module["__ZNSt3__215numpunct_bynameIwED1Ev"] = function() {
                return (__ZNSt3__215numpunct_bynameIwED1Ev = Module["__ZNSt3__215numpunct_bynameIwED1Ev"] = Module["asm"]["_ZNSt3__215numpunct_bynameIwED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__210__time_getC1EPKc = Module["__ZNSt3__210__time_getC1EPKc"] = function() {
                return (__ZNSt3__210__time_getC1EPKc = Module["__ZNSt3__210__time_getC1EPKc"] = Module["asm"]["_ZNSt3__210__time_getC1EPKc"]).apply(null, arguments)
            };
            var __ZNSt3__210__time_getC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__210__time_getC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = function() {
                return (__ZNSt3__210__time_getC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__210__time_getC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = Module["asm"]["_ZNSt3__210__time_getC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNSt3__210__time_getD1Ev = Module["__ZNSt3__210__time_getD1Ev"] = function() {
                return (__ZNSt3__210__time_getD1Ev = Module["__ZNSt3__210__time_getD1Ev"] = Module["asm"]["_ZNSt3__210__time_getD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__218__time_get_storageIcEC1EPKc = Module["__ZNSt3__218__time_get_storageIcEC1EPKc"] = function() {
                return (__ZNSt3__218__time_get_storageIcEC1EPKc = Module["__ZNSt3__218__time_get_storageIcEC1EPKc"] = Module["asm"]["_ZNSt3__218__time_get_storageIcEC1EPKc"]).apply(null, arguments)
            };
            var __ZNSt3__218__time_get_storageIcEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__218__time_get_storageIcEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = function() {
                return (__ZNSt3__218__time_get_storageIcEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__218__time_get_storageIcEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = Module["asm"]["_ZNSt3__218__time_get_storageIcEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNSt3__218__time_get_storageIwEC1EPKc = Module["__ZNSt3__218__time_get_storageIwEC1EPKc"] = function() {
                return (__ZNSt3__218__time_get_storageIwEC1EPKc = Module["__ZNSt3__218__time_get_storageIwEC1EPKc"] = Module["asm"]["_ZNSt3__218__time_get_storageIwEC1EPKc"]).apply(null, arguments)
            };
            var __ZNSt3__218__time_get_storageIwEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__218__time_get_storageIwEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = function() {
                return (__ZNSt3__218__time_get_storageIwEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__218__time_get_storageIwEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = Module["asm"]["_ZNSt3__218__time_get_storageIwEC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNSt3__210__time_putC1EPKc = Module["__ZNSt3__210__time_putC1EPKc"] = function() {
                return (__ZNSt3__210__time_putC1EPKc = Module["__ZNSt3__210__time_putC1EPKc"] = Module["asm"]["_ZNSt3__210__time_putC1EPKc"]).apply(null, arguments)
            };
            var __ZNSt3__210__time_putC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__210__time_putC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = function() {
                return (__ZNSt3__210__time_putC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__210__time_putC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = Module["asm"]["_ZNSt3__210__time_putC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNSt3__210__time_putD1Ev = Module["__ZNSt3__210__time_putD1Ev"] = function() {
                return (__ZNSt3__210__time_putD1Ev = Module["__ZNSt3__210__time_putD1Ev"] = Module["asm"]["_ZNSt3__210__time_putD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214error_categoryD0Ev = Module["__ZNSt3__214error_categoryD0Ev"] = function() {
                return (__ZNSt3__214error_categoryD0Ev = Module["__ZNSt3__214error_categoryD0Ev"] = Module["asm"]["_ZNSt3__214error_categoryD0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215error_conditionC2EiRKNS_14error_categoryE = Module["__ZNSt3__215error_conditionC2EiRKNS_14error_categoryE"] = function() {
                return (__ZNSt3__215error_conditionC2EiRKNS_14error_categoryE = Module["__ZNSt3__215error_conditionC2EiRKNS_14error_categoryE"] = Module["asm"]["_ZNSt3__215error_conditionC2EiRKNS_14error_categoryE"]).apply(null, arguments)
            };
            var __ZNSt3__2eqERKNS_15error_conditionES2_ = Module["__ZNSt3__2eqERKNS_15error_conditionES2_"] = function() {
                return (__ZNSt3__2eqERKNS_15error_conditionES2_ = Module["__ZNSt3__2eqERKNS_15error_conditionES2_"] = Module["asm"]["_ZNSt3__2eqERKNS_15error_conditionES2_"]).apply(null, arguments)
            };
            var __ZNKSt3__215error_condition8categoryEv = Module["__ZNKSt3__215error_condition8categoryEv"] = function() {
                return (__ZNKSt3__215error_condition8categoryEv = Module["__ZNKSt3__215error_condition8categoryEv"] = Module["asm"]["_ZNKSt3__215error_condition8categoryEv"]).apply(null, arguments)
            };
            var __ZNKSt3__214error_categoryeqERKS0_ = Module["__ZNKSt3__214error_categoryeqERKS0_"] = function() {
                return (__ZNKSt3__214error_categoryeqERKS0_ = Module["__ZNKSt3__214error_categoryeqERKS0_"] = Module["asm"]["_ZNKSt3__214error_categoryeqERKS0_"]).apply(null, arguments)
            };
            var __ZNKSt3__215error_condition5valueEv = Module["__ZNKSt3__215error_condition5valueEv"] = function() {
                return (__ZNKSt3__215error_condition5valueEv = Module["__ZNKSt3__215error_condition5valueEv"] = Module["asm"]["_ZNKSt3__215error_condition5valueEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210error_code8categoryEv = Module["__ZNKSt3__210error_code8categoryEv"] = function() {
                return (__ZNKSt3__210error_code8categoryEv = Module["__ZNKSt3__210error_code8categoryEv"] = Module["asm"]["_ZNKSt3__210error_code8categoryEv"]).apply(null, arguments)
            };
            var __ZNKSt3__210error_code5valueEv = Module["__ZNKSt3__210error_code5valueEv"] = function() {
                return (__ZNKSt3__210error_code5valueEv = Module["__ZNKSt3__210error_code5valueEv"] = Module["asm"]["_ZNKSt3__210error_code5valueEv"]).apply(null, arguments)
            };
            var __ZNKSt3__212__do_message7messageEi = Module["__ZNKSt3__212__do_message7messageEi"] = function() {
                return (__ZNKSt3__212__do_message7messageEi = Module["__ZNKSt3__212__do_message7messageEi"] = Module["asm"]["_ZNKSt3__212__do_message7messageEi"]).apply(null, arguments)
            };
            var __ZNKSt3__224__generic_error_category4nameEv = Module["__ZNKSt3__224__generic_error_category4nameEv"] = function() {
                return (__ZNKSt3__224__generic_error_category4nameEv = Module["__ZNKSt3__224__generic_error_category4nameEv"] = Module["asm"]["_ZNKSt3__224__generic_error_category4nameEv"]).apply(null, arguments)
            };
            var __ZNKSt3__224__generic_error_category7messageEi = Module["__ZNKSt3__224__generic_error_category7messageEi"] = function() {
                return (__ZNKSt3__224__generic_error_category7messageEi = Module["__ZNKSt3__224__generic_error_category7messageEi"] = Module["asm"]["_ZNKSt3__224__generic_error_category7messageEi"]).apply(null, arguments)
            };
            var __ZNSt3__216generic_categoryEv = Module["__ZNSt3__216generic_categoryEv"] = function() {
                return (__ZNSt3__216generic_categoryEv = Module["__ZNSt3__216generic_categoryEv"] = Module["asm"]["_ZNSt3__216generic_categoryEv"]).apply(null, arguments)
            };
            var __ZNKSt3__223__system_error_category4nameEv = Module["__ZNKSt3__223__system_error_category4nameEv"] = function() {
                return (__ZNKSt3__223__system_error_category4nameEv = Module["__ZNKSt3__223__system_error_category4nameEv"] = Module["asm"]["_ZNKSt3__223__system_error_category4nameEv"]).apply(null, arguments)
            };
            var __ZNKSt3__223__system_error_category7messageEi = Module["__ZNKSt3__223__system_error_category7messageEi"] = function() {
                return (__ZNKSt3__223__system_error_category7messageEi = Module["__ZNKSt3__223__system_error_category7messageEi"] = Module["asm"]["_ZNKSt3__223__system_error_category7messageEi"]).apply(null, arguments)
            };
            var __ZNKSt3__223__system_error_category23default_error_conditionEi = Module["__ZNKSt3__223__system_error_category23default_error_conditionEi"] = function() {
                return (__ZNKSt3__223__system_error_category23default_error_conditionEi = Module["__ZNKSt3__223__system_error_category23default_error_conditionEi"] = Module["asm"]["_ZNKSt3__223__system_error_category23default_error_conditionEi"]).apply(null, arguments)
            };
            var __ZNSt3__215system_categoryEv = Module["__ZNSt3__215system_categoryEv"] = function() {
                return (__ZNSt3__215system_categoryEv = Module["__ZNSt3__215system_categoryEv"] = Module["asm"]["_ZNSt3__215system_categoryEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215error_condition7messageEv = Module["__ZNKSt3__215error_condition7messageEv"] = function() {
                return (__ZNKSt3__215error_condition7messageEv = Module["__ZNKSt3__215error_condition7messageEv"] = Module["asm"]["_ZNKSt3__215error_condition7messageEv"]).apply(null, arguments)
            };
            var __ZNSt3__212system_error6__initERKNS_10error_codeENS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__212system_error6__initERKNS_10error_codeENS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = function() {
                return (__ZNSt3__212system_error6__initERKNS_10error_codeENS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__212system_error6__initERKNS_10error_codeENS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = Module["asm"]["_ZNSt3__212system_error6__initERKNS_10error_codeENS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNKSt3__210error_codecvbEv = Module["__ZNKSt3__210error_codecvbEv"] = function() {
                return (__ZNKSt3__210error_codecvbEv = Module["__ZNKSt3__210error_codecvbEv"] = Module["asm"]["_ZNKSt3__210error_codecvbEv"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEpLEPKc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEpLEPKc"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEpLEPKc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEpLEPKc"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEpLEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEpLERKS5_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEpLERKS5_"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEpLERKS5_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEpLERKS5_"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEpLERKS5_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendERKS5_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendERKS5_"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendERKS5_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendERKS5_"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6appendERKS5_"]).apply(null, arguments)
            };
            var __ZNSt3__212system_errorC2ENS_10error_codeERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__212system_errorC2ENS_10error_codeERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = function() {
                return (__ZNSt3__212system_errorC2ENS_10error_codeERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__212system_errorC2ENS_10error_codeERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = Module["asm"]["_ZNSt3__212system_errorC2ENS_10error_codeERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNSt3__212system_errorC2ENS_10error_codeEPKc = Module["__ZNSt3__212system_errorC2ENS_10error_codeEPKc"] = function() {
                return (__ZNSt3__212system_errorC2ENS_10error_codeEPKc = Module["__ZNSt3__212system_errorC2ENS_10error_codeEPKc"] = Module["asm"]["_ZNSt3__212system_errorC2ENS_10error_codeEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__212system_errorC2ENS_10error_codeE = Module["__ZNSt3__212system_errorC2ENS_10error_codeE"] = function() {
                return (__ZNSt3__212system_errorC2ENS_10error_codeE = Module["__ZNSt3__212system_errorC2ENS_10error_codeE"] = Module["asm"]["_ZNSt3__212system_errorC2ENS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__212system_errorC2EiRKNS_14error_categoryERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__212system_errorC2EiRKNS_14error_categoryERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = function() {
                return (__ZNSt3__212system_errorC2EiRKNS_14error_categoryERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__212system_errorC2EiRKNS_14error_categoryERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = Module["asm"]["_ZNSt3__212system_errorC2EiRKNS_14error_categoryERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNSt3__210error_codeC2EiRKNS_14error_categoryE = Module["__ZNSt3__210error_codeC2EiRKNS_14error_categoryE"] = function() {
                return (__ZNSt3__210error_codeC2EiRKNS_14error_categoryE = Module["__ZNSt3__210error_codeC2EiRKNS_14error_categoryE"] = Module["asm"]["_ZNSt3__210error_codeC2EiRKNS_14error_categoryE"]).apply(null, arguments)
            };
            var __ZNSt3__212system_errorC2EiRKNS_14error_categoryEPKc = Module["__ZNSt3__212system_errorC2EiRKNS_14error_categoryEPKc"] = function() {
                return (__ZNSt3__212system_errorC2EiRKNS_14error_categoryEPKc = Module["__ZNSt3__212system_errorC2EiRKNS_14error_categoryEPKc"] = Module["asm"]["_ZNSt3__212system_errorC2EiRKNS_14error_categoryEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__212system_errorC2EiRKNS_14error_categoryE = Module["__ZNSt3__212system_errorC2EiRKNS_14error_categoryE"] = function() {
                return (__ZNSt3__212system_errorC2EiRKNS_14error_categoryE = Module["__ZNSt3__212system_errorC2EiRKNS_14error_categoryE"] = Module["asm"]["_ZNSt3__212system_errorC2EiRKNS_14error_categoryE"]).apply(null, arguments)
            };
            var __ZNSt3__212system_errorD2Ev = Module["__ZNSt3__212system_errorD2Ev"] = function() {
                return (__ZNSt3__212system_errorD2Ev = Module["__ZNSt3__212system_errorD2Ev"] = Module["asm"]["_ZNSt3__212system_errorD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212system_errorD0Ev = Module["__ZNSt3__212system_errorD0Ev"] = function() {
                return (__ZNSt3__212system_errorD0Ev = Module["__ZNSt3__212system_errorD0Ev"] = Module["asm"]["_ZNSt3__212system_errorD0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212__do_messageD0Ev = Module["__ZNSt3__212__do_messageD0Ev"] = function() {
                return (__ZNSt3__212__do_messageD0Ev = Module["__ZNSt3__212__do_messageD0Ev"] = Module["asm"]["_ZNSt3__212__do_messageD0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__224__generic_error_categoryD0Ev = Module["__ZNSt3__224__generic_error_categoryD0Ev"] = function() {
                return (__ZNSt3__224__generic_error_categoryD0Ev = Module["__ZNSt3__224__generic_error_categoryD0Ev"] = Module["asm"]["_ZNSt3__224__generic_error_categoryD0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__223__system_error_categoryD0Ev = Module["__ZNSt3__223__system_error_categoryD0Ev"] = function() {
                return (__ZNSt3__223__system_error_categoryD0Ev = Module["__ZNSt3__223__system_error_categoryD0Ev"] = Module["asm"]["_ZNSt3__223__system_error_categoryD0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214error_categoryD1Ev = Module["__ZNSt3__214error_categoryD1Ev"] = function() {
                return (__ZNSt3__214error_categoryD1Ev = Module["__ZNSt3__214error_categoryD1Ev"] = Module["asm"]["_ZNSt3__214error_categoryD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212system_errorC1ENS_10error_codeERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__212system_errorC1ENS_10error_codeERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = function() {
                return (__ZNSt3__212system_errorC1ENS_10error_codeERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__212system_errorC1ENS_10error_codeERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = Module["asm"]["_ZNSt3__212system_errorC1ENS_10error_codeERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNSt3__212system_errorC1ENS_10error_codeEPKc = Module["__ZNSt3__212system_errorC1ENS_10error_codeEPKc"] = function() {
                return (__ZNSt3__212system_errorC1ENS_10error_codeEPKc = Module["__ZNSt3__212system_errorC1ENS_10error_codeEPKc"] = Module["asm"]["_ZNSt3__212system_errorC1ENS_10error_codeEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__212system_errorC1ENS_10error_codeE = Module["__ZNSt3__212system_errorC1ENS_10error_codeE"] = function() {
                return (__ZNSt3__212system_errorC1ENS_10error_codeE = Module["__ZNSt3__212system_errorC1ENS_10error_codeE"] = Module["asm"]["_ZNSt3__212system_errorC1ENS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__212system_errorC1EiRKNS_14error_categoryERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__212system_errorC1EiRKNS_14error_categoryERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = function() {
                return (__ZNSt3__212system_errorC1EiRKNS_14error_categoryERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__212system_errorC1EiRKNS_14error_categoryERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = Module["asm"]["_ZNSt3__212system_errorC1EiRKNS_14error_categoryERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNSt3__212system_errorC1EiRKNS_14error_categoryEPKc = Module["__ZNSt3__212system_errorC1EiRKNS_14error_categoryEPKc"] = function() {
                return (__ZNSt3__212system_errorC1EiRKNS_14error_categoryEPKc = Module["__ZNSt3__212system_errorC1EiRKNS_14error_categoryEPKc"] = Module["asm"]["_ZNSt3__212system_errorC1EiRKNS_14error_categoryEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__212system_errorC1EiRKNS_14error_categoryE = Module["__ZNSt3__212system_errorC1EiRKNS_14error_categoryE"] = function() {
                return (__ZNSt3__212system_errorC1EiRKNS_14error_categoryE = Module["__ZNSt3__212system_errorC1EiRKNS_14error_categoryE"] = Module["asm"]["_ZNSt3__212system_errorC1EiRKNS_14error_categoryE"]).apply(null, arguments)
            };
            var __ZNSt3__212system_errorD1Ev = Module["__ZNSt3__212system_errorD1Ev"] = function() {
                return (__ZNSt3__212system_errorD1Ev = Module["__ZNSt3__212system_errorD1Ev"] = Module["asm"]["_ZNSt3__212system_errorD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambufC2El = Module["__ZNSt3__212strstreambufC2El"] = function() {
                return (__ZNSt3__212strstreambufC2El = Module["__ZNSt3__212strstreambufC2El"] = Module["asm"]["_ZNSt3__212strstreambufC2El"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2Ev = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2Ev"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2Ev = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2Ev"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambufC2EPFPvmEPFvS1_E = Module["__ZNSt3__212strstreambufC2EPFPvmEPFvS1_E"] = function() {
                return (__ZNSt3__212strstreambufC2EPFPvmEPFvS1_E = Module["__ZNSt3__212strstreambufC2EPFPvmEPFvS1_E"] = Module["asm"]["_ZNSt3__212strstreambufC2EPFPvmEPFvS1_E"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambuf6__initEPclS1_ = Module["__ZNSt3__212strstreambuf6__initEPclS1_"] = function() {
                return (__ZNSt3__212strstreambuf6__initEPclS1_ = Module["__ZNSt3__212strstreambuf6__initEPclS1_"] = Module["asm"]["_ZNSt3__212strstreambuf6__initEPclS1_"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE4setgEPcS4_S4_ = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE4setgEPcS4_S4_"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE4setgEPcS4_S4_ = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE4setgEPcS4_S4_"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE4setgEPcS4_S4_"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE4setpEPcS4_ = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE4setpEPcS4_"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE4setpEPcS4_ = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE4setpEPcS4_"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE4setpEPcS4_"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambufC2EPclS1_ = Module["__ZNSt3__212strstreambufC2EPclS1_"] = function() {
                return (__ZNSt3__212strstreambufC2EPclS1_ = Module["__ZNSt3__212strstreambufC2EPclS1_"] = Module["asm"]["_ZNSt3__212strstreambufC2EPclS1_"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambufC2EPKcl = Module["__ZNSt3__212strstreambufC2EPKcl"] = function() {
                return (__ZNSt3__212strstreambufC2EPKcl = Module["__ZNSt3__212strstreambufC2EPKcl"] = Module["asm"]["_ZNSt3__212strstreambufC2EPKcl"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambufC2EPalS1_ = Module["__ZNSt3__212strstreambufC2EPalS1_"] = function() {
                return (__ZNSt3__212strstreambufC2EPalS1_ = Module["__ZNSt3__212strstreambufC2EPalS1_"] = Module["asm"]["_ZNSt3__212strstreambufC2EPalS1_"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambufC2EPKal = Module["__ZNSt3__212strstreambufC2EPKal"] = function() {
                return (__ZNSt3__212strstreambufC2EPKal = Module["__ZNSt3__212strstreambufC2EPKal"] = Module["asm"]["_ZNSt3__212strstreambufC2EPKal"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambufC2EPhlS1_ = Module["__ZNSt3__212strstreambufC2EPhlS1_"] = function() {
                return (__ZNSt3__212strstreambufC2EPhlS1_ = Module["__ZNSt3__212strstreambufC2EPhlS1_"] = Module["asm"]["_ZNSt3__212strstreambufC2EPhlS1_"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambufC2EPKhl = Module["__ZNSt3__212strstreambufC2EPKhl"] = function() {
                return (__ZNSt3__212strstreambufC2EPKhl = Module["__ZNSt3__212strstreambufC2EPKhl"] = Module["asm"]["_ZNSt3__212strstreambufC2EPKhl"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambufD2Ev = Module["__ZNSt3__212strstreambufD2Ev"] = function() {
                return (__ZNSt3__212strstreambufD2Ev = Module["__ZNSt3__212strstreambufD2Ev"] = Module["asm"]["_ZNSt3__212strstreambufD2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE5ebackEv = Module["__ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE5ebackEv"] = function() {
                return (__ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE5ebackEv = Module["__ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE5ebackEv"] = Module["asm"]["_ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE5ebackEv"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED2Ev = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED2Ev"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED2Ev = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED2Ev"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambufD0Ev = Module["__ZNSt3__212strstreambufD0Ev"] = function() {
                return (__ZNSt3__212strstreambufD0Ev = Module["__ZNSt3__212strstreambufD0Ev"] = Module["asm"]["_ZNSt3__212strstreambufD0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambuf4swapERS0_ = Module["__ZNSt3__212strstreambuf4swapERS0_"] = function() {
                return (__ZNSt3__212strstreambuf4swapERS0_ = Module["__ZNSt3__212strstreambuf4swapERS0_"] = Module["asm"]["_ZNSt3__212strstreambuf4swapERS0_"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE4swapERS3_ = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE4swapERS3_"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE4swapERS3_ = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE4swapERS3_"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE4swapERS3_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIlEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIlEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = function() {
                return (__ZNSt3__24swapIlEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIlEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = Module["asm"]["_ZNSt3__24swapIlEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIPFPvmEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS5_EE5valueEvE4typeERS5_S8_ = Module["__ZNSt3__24swapIPFPvmEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS5_EE5valueEvE4typeERS5_S8_"] = function() {
                return (__ZNSt3__24swapIPFPvmEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS5_EE5valueEvE4typeERS5_S8_ = Module["__ZNSt3__24swapIPFPvmEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS5_EE5valueEvE4typeERS5_S8_"] = Module["asm"]["_ZNSt3__24swapIPFPvmEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS5_EE5valueEvE4typeERS5_S8_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIPFvPvEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS5_EE5valueEvE4typeERS5_S8_ = Module["__ZNSt3__24swapIPFvPvEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS5_EE5valueEvE4typeERS5_S8_"] = function() {
                return (__ZNSt3__24swapIPFvPvEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS5_EE5valueEvE4typeERS5_S8_ = Module["__ZNSt3__24swapIPFvPvEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS5_EE5valueEvE4typeERS5_S8_"] = Module["asm"]["_ZNSt3__24swapIPFvPvEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS5_EE5valueEvE4typeERS5_S8_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRlEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRlEEONS_16remove_referenceIT_E4typeEOS3_"] = function() {
                return (__ZNSt3__24moveIRlEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRlEEONS_16remove_referenceIT_E4typeEOS3_"] = Module["asm"]["_ZNSt3__24moveIRlEEONS_16remove_referenceIT_E4typeEOS3_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRPFPvmEEEONS_16remove_referenceIT_E4typeEOS6_ = Module["__ZNSt3__24moveIRPFPvmEEEONS_16remove_referenceIT_E4typeEOS6_"] = function() {
                return (__ZNSt3__24moveIRPFPvmEEEONS_16remove_referenceIT_E4typeEOS6_ = Module["__ZNSt3__24moveIRPFPvmEEEONS_16remove_referenceIT_E4typeEOS6_"] = Module["asm"]["_ZNSt3__24moveIRPFPvmEEEONS_16remove_referenceIT_E4typeEOS6_"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambuf6freezeEb = Module["__ZNSt3__212strstreambuf6freezeEb"] = function() {
                return (__ZNSt3__212strstreambuf6freezeEb = Module["__ZNSt3__212strstreambuf6freezeEb"] = Module["asm"]["_ZNSt3__212strstreambuf6freezeEb"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambuf3strEv = Module["__ZNSt3__212strstreambuf3strEv"] = function() {
                return (__ZNSt3__212strstreambuf3strEv = Module["__ZNSt3__212strstreambuf3strEv"] = Module["asm"]["_ZNSt3__212strstreambuf3strEv"]).apply(null, arguments)
            };
            var __ZNKSt3__212strstreambuf6pcountEv = Module["__ZNKSt3__212strstreambuf6pcountEv"] = function() {
                return (__ZNKSt3__212strstreambuf6pcountEv = Module["__ZNKSt3__212strstreambuf6pcountEv"] = Module["asm"]["_ZNKSt3__212strstreambuf6pcountEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE4pptrEv = Module["__ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE4pptrEv"] = function() {
                return (__ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE4pptrEv = Module["__ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE4pptrEv"] = Module["asm"]["_ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE4pptrEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE5pbaseEv = Module["__ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE5pbaseEv"] = function() {
                return (__ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE5pbaseEv = Module["__ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE5pbaseEv"] = Module["asm"]["_ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE5pbaseEv"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambuf8overflowEi = Module["__ZNSt3__212strstreambuf8overflowEi"] = function() {
                return (__ZNSt3__212strstreambuf8overflowEi = Module["__ZNSt3__212strstreambuf8overflowEi"] = Module["asm"]["_ZNSt3__212strstreambuf8overflowEi"]).apply(null, arguments)
            };
            var __ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE5epptrEv = Module["__ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE5epptrEv"] = function() {
                return (__ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE5epptrEv = Module["__ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE5epptrEv"] = Module["asm"]["_ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE5epptrEv"]).apply(null, arguments)
            };
            var __ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE5egptrEv = Module["__ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE5egptrEv"] = function() {
                return (__ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE5egptrEv = Module["__ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE5egptrEv"] = Module["asm"]["_ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE5egptrEv"]).apply(null, arguments)
            };
            var __Znam = Module["__Znam"] = function() {
                return (__Znam = Module["__Znam"] = Module["asm"]["_Znam"]).apply(null, arguments)
            };
            var __ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE4gptrEv = Module["__ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE4gptrEv"] = function() {
                return (__ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE4gptrEv = Module["__ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE4gptrEv"] = Module["asm"]["_ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE4gptrEv"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7__pbumpEl = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7__pbumpEl"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7__pbumpEl = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7__pbumpEl"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7__pbumpEl"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5pbumpEi = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5pbumpEi"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5pbumpEi = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5pbumpEi"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5pbumpEi"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambuf9pbackfailEi = Module["__ZNSt3__212strstreambuf9pbackfailEi"] = function() {
                return (__ZNSt3__212strstreambuf9pbackfailEi = Module["__ZNSt3__212strstreambuf9pbackfailEi"] = Module["asm"]["_ZNSt3__212strstreambuf9pbackfailEi"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5gbumpEi = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5gbumpEi"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5gbumpEi = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5gbumpEi"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5gbumpEi"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambuf9underflowEv = Module["__ZNSt3__212strstreambuf9underflowEv"] = function() {
                return (__ZNSt3__212strstreambuf9underflowEv = Module["__ZNSt3__212strstreambuf9underflowEv"] = Module["asm"]["_ZNSt3__212strstreambuf9underflowEv"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambuf7seekoffExNS_8ios_base7seekdirEj = Module["__ZNSt3__212strstreambuf7seekoffExNS_8ios_base7seekdirEj"] = function() {
                return (__ZNSt3__212strstreambuf7seekoffExNS_8ios_base7seekdirEj = Module["__ZNSt3__212strstreambuf7seekoffExNS_8ios_base7seekdirEj"] = Module["asm"]["_ZNSt3__212strstreambuf7seekoffExNS_8ios_base7seekdirEj"]).apply(null, arguments)
            };
            var __ZNSt3__23maxIPcEERKT_S4_S4_ = Module["__ZNSt3__23maxIPcEERKT_S4_S4_"] = function() {
                return (__ZNSt3__23maxIPcEERKT_S4_S4_ = Module["__ZNSt3__23maxIPcEERKT_S4_S4_"] = Module["asm"]["_ZNSt3__23maxIPcEERKT_S4_S4_"]).apply(null, arguments)
            };
            var __ZNSt3__23minIPcEERKT_S4_S4_ = Module["__ZNSt3__23minIPcEERKT_S4_S4_"] = function() {
                return (__ZNSt3__23minIPcEERKT_S4_S4_ = Module["__ZNSt3__23minIPcEERKT_S4_S4_"] = Module["asm"]["_ZNSt3__23minIPcEERKT_S4_S4_"]).apply(null, arguments)
            };
            var __ZNSt3__24fposI11__mbstate_tEC2Ex = Module["__ZNSt3__24fposI11__mbstate_tEC2Ex"] = function() {
                return (__ZNSt3__24fposI11__mbstate_tEC2Ex = Module["__ZNSt3__24fposI11__mbstate_tEC2Ex"] = Module["asm"]["_ZNSt3__24fposI11__mbstate_tEC2Ex"]).apply(null, arguments)
            };
            var __ZNSt3__23maxIPcNS_6__lessIS1_S1_EEEERKT_S6_S6_T0_ = Module["__ZNSt3__23maxIPcNS_6__lessIS1_S1_EEEERKT_S6_S6_T0_"] = function() {
                return (__ZNSt3__23maxIPcNS_6__lessIS1_S1_EEEERKT_S6_S6_T0_ = Module["__ZNSt3__23maxIPcNS_6__lessIS1_S1_EEEERKT_S6_S6_T0_"] = Module["asm"]["_ZNSt3__23maxIPcNS_6__lessIS1_S1_EEEERKT_S6_S6_T0_"]).apply(null, arguments)
            };
            var __ZNSt3__23minIPcNS_6__lessIS1_S1_EEEERKT_S6_S6_T0_ = Module["__ZNSt3__23minIPcNS_6__lessIS1_S1_EEEERKT_S6_S6_T0_"] = function() {
                return (__ZNSt3__23minIPcNS_6__lessIS1_S1_EEEERKT_S6_S6_T0_ = Module["__ZNSt3__23minIPcNS_6__lessIS1_S1_EEEERKT_S6_S6_T0_"] = Module["asm"]["_ZNSt3__23minIPcNS_6__lessIS1_S1_EEEERKT_S6_S6_T0_"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambuf7seekposENS_4fposI11__mbstate_tEEj = Module["__ZNSt3__212strstreambuf7seekposENS_4fposI11__mbstate_tEEj"] = function() {
                return (__ZNSt3__212strstreambuf7seekposENS_4fposI11__mbstate_tEEj = Module["__ZNSt3__212strstreambuf7seekposENS_4fposI11__mbstate_tEEj"] = Module["asm"]["_ZNSt3__212strstreambuf7seekposENS_4fposI11__mbstate_tEEj"]).apply(null, arguments)
            };
            var __ZNKSt3__24fposI11__mbstate_tEcvxEv = Module["__ZNKSt3__24fposI11__mbstate_tEcvxEv"] = function() {
                return (__ZNKSt3__24fposI11__mbstate_tEcvxEv = Module["__ZNKSt3__24fposI11__mbstate_tEcvxEv"] = Module["asm"]["_ZNKSt3__24fposI11__mbstate_tEcvxEv"]).apply(null, arguments)
            };
            var __ZNSt3__210istrstreamD2Ev = Module["__ZNSt3__210istrstreamD2Ev"] = function() {
                return (__ZNSt3__210istrstreamD2Ev = Module["__ZNSt3__210istrstreamD2Ev"] = Module["asm"]["_ZNSt3__210istrstreamD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED2Ev = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED2Ev"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED2Ev = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED2Ev"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__210istrstreamD1Ev = Module["__ZNSt3__210istrstreamD1Ev"] = function() {
                return (__ZNSt3__210istrstreamD1Ev = Module["__ZNSt3__210istrstreamD1Ev"] = Module["asm"]["_ZNSt3__210istrstreamD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29basic_iosIcNS_11char_traitsIcEEED2Ev = Module["__ZNSt3__29basic_iosIcNS_11char_traitsIcEEED2Ev"] = function() {
                return (__ZNSt3__29basic_iosIcNS_11char_traitsIcEEED2Ev = Module["__ZNSt3__29basic_iosIcNS_11char_traitsIcEEED2Ev"] = Module["asm"]["_ZNSt3__29basic_iosIcNS_11char_traitsIcEEED2Ev"]).apply(null, arguments)
            };
            var __ZTv0_n12_NSt3__210istrstreamD1Ev = Module["__ZTv0_n12_NSt3__210istrstreamD1Ev"] = function() {
                return (__ZTv0_n12_NSt3__210istrstreamD1Ev = Module["__ZTv0_n12_NSt3__210istrstreamD1Ev"] = Module["asm"]["_ZTv0_n12_NSt3__210istrstreamD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__210istrstreamD0Ev = Module["__ZNSt3__210istrstreamD0Ev"] = function() {
                return (__ZNSt3__210istrstreamD0Ev = Module["__ZNSt3__210istrstreamD0Ev"] = Module["asm"]["_ZNSt3__210istrstreamD0Ev"]).apply(null, arguments)
            };
            var __ZTv0_n12_NSt3__210istrstreamD0Ev = Module["__ZTv0_n12_NSt3__210istrstreamD0Ev"] = function() {
                return (__ZTv0_n12_NSt3__210istrstreamD0Ev = Module["__ZTv0_n12_NSt3__210istrstreamD0Ev"] = Module["asm"]["_ZTv0_n12_NSt3__210istrstreamD0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__210ostrstreamD2Ev = Module["__ZNSt3__210ostrstreamD2Ev"] = function() {
                return (__ZNSt3__210ostrstreamD2Ev = Module["__ZNSt3__210ostrstreamD2Ev"] = Module["asm"]["_ZNSt3__210ostrstreamD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED2Ev = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED2Ev"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED2Ev = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED2Ev"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__210ostrstreamD1Ev = Module["__ZNSt3__210ostrstreamD1Ev"] = function() {
                return (__ZNSt3__210ostrstreamD1Ev = Module["__ZNSt3__210ostrstreamD1Ev"] = Module["asm"]["_ZNSt3__210ostrstreamD1Ev"]).apply(null, arguments)
            };
            var __ZTv0_n12_NSt3__210ostrstreamD1Ev = Module["__ZTv0_n12_NSt3__210ostrstreamD1Ev"] = function() {
                return (__ZTv0_n12_NSt3__210ostrstreamD1Ev = Module["__ZTv0_n12_NSt3__210ostrstreamD1Ev"] = Module["asm"]["_ZTv0_n12_NSt3__210ostrstreamD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__210ostrstreamD0Ev = Module["__ZNSt3__210ostrstreamD0Ev"] = function() {
                return (__ZNSt3__210ostrstreamD0Ev = Module["__ZNSt3__210ostrstreamD0Ev"] = Module["asm"]["_ZNSt3__210ostrstreamD0Ev"]).apply(null, arguments)
            };
            var __ZTv0_n12_NSt3__210ostrstreamD0Ev = Module["__ZTv0_n12_NSt3__210ostrstreamD0Ev"] = function() {
                return (__ZTv0_n12_NSt3__210ostrstreamD0Ev = Module["__ZTv0_n12_NSt3__210ostrstreamD0Ev"] = Module["asm"]["_ZTv0_n12_NSt3__210ostrstreamD0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29strstreamD2Ev = Module["__ZNSt3__29strstreamD2Ev"] = function() {
                return (__ZNSt3__29strstreamD2Ev = Module["__ZNSt3__29strstreamD2Ev"] = Module["asm"]["_ZNSt3__29strstreamD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED2Ev = Module["__ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED2Ev"] = function() {
                return (__ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED2Ev = Module["__ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED2Ev"] = Module["asm"]["_ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29strstreamD1Ev = Module["__ZNSt3__29strstreamD1Ev"] = function() {
                return (__ZNSt3__29strstreamD1Ev = Module["__ZNSt3__29strstreamD1Ev"] = Module["asm"]["_ZNSt3__29strstreamD1Ev"]).apply(null, arguments)
            };
            var __ZThn8_NSt3__29strstreamD1Ev = Module["__ZThn8_NSt3__29strstreamD1Ev"] = function() {
                return (__ZThn8_NSt3__29strstreamD1Ev = Module["__ZThn8_NSt3__29strstreamD1Ev"] = Module["asm"]["_ZThn8_NSt3__29strstreamD1Ev"]).apply(null, arguments)
            };
            var __ZTv0_n12_NSt3__29strstreamD1Ev = Module["__ZTv0_n12_NSt3__29strstreamD1Ev"] = function() {
                return (__ZTv0_n12_NSt3__29strstreamD1Ev = Module["__ZTv0_n12_NSt3__29strstreamD1Ev"] = Module["asm"]["_ZTv0_n12_NSt3__29strstreamD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29strstreamD0Ev = Module["__ZNSt3__29strstreamD0Ev"] = function() {
                return (__ZNSt3__29strstreamD0Ev = Module["__ZNSt3__29strstreamD0Ev"] = Module["asm"]["_ZNSt3__29strstreamD0Ev"]).apply(null, arguments)
            };
            var __ZThn8_NSt3__29strstreamD0Ev = Module["__ZThn8_NSt3__29strstreamD0Ev"] = function() {
                return (__ZThn8_NSt3__29strstreamD0Ev = Module["__ZThn8_NSt3__29strstreamD0Ev"] = Module["asm"]["_ZThn8_NSt3__29strstreamD0Ev"]).apply(null, arguments)
            };
            var __ZTv0_n12_NSt3__29strstreamD0Ev = Module["__ZTv0_n12_NSt3__29strstreamD0Ev"] = function() {
                return (__ZTv0_n12_NSt3__29strstreamD0Ev = Module["__ZTv0_n12_NSt3__29strstreamD0Ev"] = Module["asm"]["_ZTv0_n12_NSt3__29strstreamD0Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__26__lessIPcS1_EclERKS1_S4_ = Module["__ZNKSt3__26__lessIPcS1_EclERKS1_S4_"] = function() {
                return (__ZNKSt3__26__lessIPcS1_EclERKS1_S4_ = Module["__ZNKSt3__26__lessIPcS1_EclERKS1_S4_"] = Module["asm"]["_ZNKSt3__26__lessIPcS1_EclERKS1_S4_"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5imbueERKNS_6localeE = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5imbueERKNS_6localeE"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5imbueERKNS_6localeE = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5imbueERKNS_6localeE"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5imbueERKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6setbufEPcl = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6setbufEPcl"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6setbufEPcl = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6setbufEPcl"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6setbufEPcl"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE4syncEv = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE4syncEv"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE4syncEv = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE4syncEv"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE4syncEv"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9showmanycEv = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9showmanycEv"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9showmanycEv = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9showmanycEv"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9showmanycEv"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6xsgetnEPcl = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6xsgetnEPcl"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6xsgetnEPcl = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6xsgetnEPcl"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6xsgetnEPcl"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5uflowEv = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5uflowEv"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5uflowEv = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5uflowEv"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5uflowEv"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6xsputnEPKcl = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6xsputnEPKcl"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6xsputnEPKcl = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6xsputnEPKcl"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE6xsputnEPKcl"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED1Ev = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED1Ev"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED1Ev = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED1Ev"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED0Ev = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED0Ev"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED0Ev = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED0Ev"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEED0Ev"]).apply(null, arguments)
            };
            var __ZTv0_n12_NSt3__213basic_istreamIcNS_11char_traitsIcEEED1Ev = Module["__ZTv0_n12_NSt3__213basic_istreamIcNS_11char_traitsIcEEED1Ev"] = function() {
                return (__ZTv0_n12_NSt3__213basic_istreamIcNS_11char_traitsIcEEED1Ev = Module["__ZTv0_n12_NSt3__213basic_istreamIcNS_11char_traitsIcEEED1Ev"] = Module["asm"]["_ZTv0_n12_NSt3__213basic_istreamIcNS_11char_traitsIcEEED1Ev"]).apply(null, arguments)
            };
            var __ZTv0_n12_NSt3__213basic_istreamIcNS_11char_traitsIcEEED0Ev = Module["__ZTv0_n12_NSt3__213basic_istreamIcNS_11char_traitsIcEEED0Ev"] = function() {
                return (__ZTv0_n12_NSt3__213basic_istreamIcNS_11char_traitsIcEEED0Ev = Module["__ZTv0_n12_NSt3__213basic_istreamIcNS_11char_traitsIcEEED0Ev"] = Module["asm"]["_ZTv0_n12_NSt3__213basic_istreamIcNS_11char_traitsIcEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED1Ev = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED1Ev"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED1Ev = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED1Ev"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED0Ev = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED0Ev"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED0Ev = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED0Ev"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEED0Ev"]).apply(null, arguments)
            };
            var __ZTv0_n12_NSt3__213basic_ostreamIcNS_11char_traitsIcEEED1Ev = Module["__ZTv0_n12_NSt3__213basic_ostreamIcNS_11char_traitsIcEEED1Ev"] = function() {
                return (__ZTv0_n12_NSt3__213basic_ostreamIcNS_11char_traitsIcEEED1Ev = Module["__ZTv0_n12_NSt3__213basic_ostreamIcNS_11char_traitsIcEEED1Ev"] = Module["asm"]["_ZTv0_n12_NSt3__213basic_ostreamIcNS_11char_traitsIcEEED1Ev"]).apply(null, arguments)
            };
            var __ZTv0_n12_NSt3__213basic_ostreamIcNS_11char_traitsIcEEED0Ev = Module["__ZTv0_n12_NSt3__213basic_ostreamIcNS_11char_traitsIcEEED0Ev"] = function() {
                return (__ZTv0_n12_NSt3__213basic_ostreamIcNS_11char_traitsIcEEED0Ev = Module["__ZTv0_n12_NSt3__213basic_ostreamIcNS_11char_traitsIcEEED0Ev"] = Module["asm"]["_ZTv0_n12_NSt3__213basic_ostreamIcNS_11char_traitsIcEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev = Module["__ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev"] = function() {
                return (__ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev = Module["__ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev"] = Module["asm"]["_ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev = Module["__ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev"] = function() {
                return (__ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev = Module["__ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev"] = Module["asm"]["_ZNSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev"]).apply(null, arguments)
            };
            var __ZThn8_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev = Module["__ZThn8_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev"] = function() {
                return (__ZThn8_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev = Module["__ZThn8_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev"] = Module["asm"]["_ZThn8_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev"]).apply(null, arguments)
            };
            var __ZThn8_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev = Module["__ZThn8_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev"] = function() {
                return (__ZThn8_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev = Module["__ZThn8_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev"] = Module["asm"]["_ZThn8_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev"]).apply(null, arguments)
            };
            var __ZTv0_n12_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev = Module["__ZTv0_n12_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev"] = function() {
                return (__ZTv0_n12_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev = Module["__ZTv0_n12_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev"] = Module["asm"]["_ZTv0_n12_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED1Ev"]).apply(null, arguments)
            };
            var __ZTv0_n12_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev = Module["__ZTv0_n12_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev"] = function() {
                return (__ZTv0_n12_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev = Module["__ZTv0_n12_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev"] = Module["asm"]["_ZTv0_n12_NSt3__214basic_iostreamIcNS_11char_traitsIcEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambufC1El = Module["__ZNSt3__212strstreambufC1El"] = function() {
                return (__ZNSt3__212strstreambufC1El = Module["__ZNSt3__212strstreambufC1El"] = Module["asm"]["_ZNSt3__212strstreambufC1El"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambufC1EPFPvmEPFvS1_E = Module["__ZNSt3__212strstreambufC1EPFPvmEPFvS1_E"] = function() {
                return (__ZNSt3__212strstreambufC1EPFPvmEPFvS1_E = Module["__ZNSt3__212strstreambufC1EPFPvmEPFvS1_E"] = Module["asm"]["_ZNSt3__212strstreambufC1EPFPvmEPFvS1_E"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambufC1EPclS1_ = Module["__ZNSt3__212strstreambufC1EPclS1_"] = function() {
                return (__ZNSt3__212strstreambufC1EPclS1_ = Module["__ZNSt3__212strstreambufC1EPclS1_"] = Module["asm"]["_ZNSt3__212strstreambufC1EPclS1_"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambufC1EPKcl = Module["__ZNSt3__212strstreambufC1EPKcl"] = function() {
                return (__ZNSt3__212strstreambufC1EPKcl = Module["__ZNSt3__212strstreambufC1EPKcl"] = Module["asm"]["_ZNSt3__212strstreambufC1EPKcl"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambufC1EPalS1_ = Module["__ZNSt3__212strstreambufC1EPalS1_"] = function() {
                return (__ZNSt3__212strstreambufC1EPalS1_ = Module["__ZNSt3__212strstreambufC1EPalS1_"] = Module["asm"]["_ZNSt3__212strstreambufC1EPalS1_"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambufC1EPKal = Module["__ZNSt3__212strstreambufC1EPKal"] = function() {
                return (__ZNSt3__212strstreambufC1EPKal = Module["__ZNSt3__212strstreambufC1EPKal"] = Module["asm"]["_ZNSt3__212strstreambufC1EPKal"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambufC1EPhlS1_ = Module["__ZNSt3__212strstreambufC1EPhlS1_"] = function() {
                return (__ZNSt3__212strstreambufC1EPhlS1_ = Module["__ZNSt3__212strstreambufC1EPhlS1_"] = Module["asm"]["_ZNSt3__212strstreambufC1EPhlS1_"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambufC1EPKhl = Module["__ZNSt3__212strstreambufC1EPKhl"] = function() {
                return (__ZNSt3__212strstreambufC1EPKhl = Module["__ZNSt3__212strstreambufC1EPKhl"] = Module["asm"]["_ZNSt3__212strstreambufC1EPKhl"]).apply(null, arguments)
            };
            var __ZNSt3__212strstreambufD1Ev = Module["__ZNSt3__212strstreambufD1Ev"] = function() {
                return (__ZNSt3__212strstreambufD1Ev = Module["__ZNSt3__212strstreambufD1Ev"] = Module["asm"]["_ZNSt3__212strstreambufD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__223__libcpp_condvar_signalEP14pthread_cond_t = Module["__ZNSt3__223__libcpp_condvar_signalEP14pthread_cond_t"] = function() {
                return (__ZNSt3__223__libcpp_condvar_signalEP14pthread_cond_t = Module["__ZNSt3__223__libcpp_condvar_signalEP14pthread_cond_t"] = Module["asm"]["_ZNSt3__223__libcpp_condvar_signalEP14pthread_cond_t"]).apply(null, arguments)
            };
            var __ZNKSt3__211unique_lockINS_5mutexEE5mutexEv = Module["__ZNKSt3__211unique_lockINS_5mutexEE5mutexEv"] = function() {
                return (__ZNKSt3__211unique_lockINS_5mutexEE5mutexEv = Module["__ZNKSt3__211unique_lockINS_5mutexEE5mutexEv"] = Module["asm"]["_ZNKSt3__211unique_lockINS_5mutexEE5mutexEv"]).apply(null, arguments)
            };
            var __ZNSt3__25mutex13native_handleEv = Module["__ZNSt3__25mutex13native_handleEv"] = function() {
                return (__ZNSt3__25mutex13native_handleEv = Module["__ZNSt3__25mutex13native_handleEv"] = Module["asm"]["_ZNSt3__25mutex13native_handleEv"]).apply(null, arguments)
            };
            var __ZNSt3__218condition_variable15__do_timed_waitERNS_11unique_lockINS_5mutexEEENS_6chrono10time_pointINS5_12system_clockENS5_8durationIxNS_5ratioILx1ELx1000000000EEEEEEE = Module["__ZNSt3__218condition_variable15__do_timed_waitERNS_11unique_lockINS_5mutexEEENS_6chrono10time_pointINS5_12system_clockENS5_8durationIxNS_5ratioILx1ELx1000000000EEEEEEE"] = function() {
                return (__ZNSt3__218condition_variable15__do_timed_waitERNS_11unique_lockINS_5mutexEEENS_6chrono10time_pointINS5_12system_clockENS5_8durationIxNS_5ratioILx1ELx1000000000EEEEEEE = Module["__ZNSt3__218condition_variable15__do_timed_waitERNS_11unique_lockINS_5mutexEEENS_6chrono10time_pointINS5_12system_clockENS5_8durationIxNS_5ratioILx1ELx1000000000EEEEEEE"] = Module["asm"]["_ZNSt3__218condition_variable15__do_timed_waitERNS_11unique_lockINS_5mutexEEENS_6chrono10time_pointINS5_12system_clockENS5_8durationIxNS_5ratioILx1ELx1000000000EEEEEEE"]).apply(null, arguments)
            };
            var __ZNKSt3__26chrono10time_pointINS0_12system_clockENS0_8durationIxNS_5ratioILx1ELx1000000000EEEEEE16time_since_epochEv = Module["__ZNKSt3__26chrono10time_pointINS0_12system_clockENS0_8durationIxNS_5ratioILx1ELx1000000000EEEEEE16time_since_epochEv"] = function() {
                return (__ZNKSt3__26chrono10time_pointINS0_12system_clockENS0_8durationIxNS_5ratioILx1ELx1000000000EEEEEE16time_since_epochEv = Module["__ZNKSt3__26chrono10time_pointINS0_12system_clockENS0_8durationIxNS_5ratioILx1ELx1000000000EEEEEE16time_since_epochEv"] = Module["asm"]["_ZNKSt3__26chrono10time_pointINS0_12system_clockENS0_8durationIxNS_5ratioILx1ELx1000000000EEEEEE16time_since_epochEv"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEEC2IxEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEEC2IxEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"] = function() {
                return (__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEEC2IxEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEEC2IxEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"] = Module["asm"]["_ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEEC2IxEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__26chronogtIxNS_5ratioILx1ELx1000000000EEExS3_EEbRKNS0_8durationIT_T0_EERKNS4_IT1_T2_EE = Module["__ZNSt3__26chronogtIxNS_5ratioILx1ELx1000000000EEExS3_EEbRKNS0_8durationIT_T0_EERKNS4_IT1_T2_EE"] = function() {
                return (__ZNSt3__26chronogtIxNS_5ratioILx1ELx1000000000EEExS3_EEbRKNS0_8durationIT_T0_EERKNS4_IT1_T2_EE = Module["__ZNSt3__26chronogtIxNS_5ratioILx1ELx1000000000EEExS3_EEbRKNS0_8durationIT_T0_EERKNS4_IT1_T2_EE"] = Module["asm"]["_ZNSt3__26chronogtIxNS_5ratioILx1ELx1000000000EEExS3_EEbRKNS0_8durationIT_T0_EERKNS4_IT1_T2_EE"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEExNS3_ILx1ELx1000000000EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE = Module["__ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEExNS3_ILx1ELx1000000000EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"] = function() {
                return (__ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEExNS3_ILx1ELx1000000000EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE = Module["__ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEExNS3_ILx1ELx1000000000EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"] = Module["asm"]["_ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEExNS3_ILx1ELx1000000000EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"]).apply(null, arguments)
            };
            var __ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1EEEE5countEv = Module["__ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1EEEE5countEv"] = function() {
                return (__ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1EEEE5countEv = Module["__ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1EEEE5countEv"] = Module["asm"]["_ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1EEEE5countEv"]).apply(null, arguments)
            };
            var __ZNSt3__26chronomiIxNS_5ratioILx1ELx1000000000EEExNS2_ILx1ELx1EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_ = Module["__ZNSt3__26chronomiIxNS_5ratioILx1ELx1000000000EEExNS2_ILx1ELx1EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"] = function() {
                return (__ZNSt3__26chronomiIxNS_5ratioILx1ELx1000000000EEExNS2_ILx1ELx1EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_ = Module["__ZNSt3__26chronomiIxNS_5ratioILx1ELx1000000000EEExNS2_ILx1ELx1EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"] = Module["asm"]["_ZNSt3__26chronomiIxNS_5ratioILx1ELx1000000000EEExNS2_ILx1ELx1EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"]).apply(null, arguments)
            };
            var __ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEE5countEv = Module["__ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEE5countEv"] = function() {
                return (__ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEE5countEv = Module["__ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEE5countEv"] = Module["asm"]["_ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEE5countEv"]).apply(null, arguments)
            };
            var __ZNSt3__226__libcpp_condvar_timedwaitEP14pthread_cond_tP15pthread_mutex_tP8timespec = Module["__ZNSt3__226__libcpp_condvar_timedwaitEP14pthread_cond_tP15pthread_mutex_tP8timespec"] = function() {
                return (__ZNSt3__226__libcpp_condvar_timedwaitEP14pthread_cond_tP15pthread_mutex_tP8timespec = Module["__ZNSt3__226__libcpp_condvar_timedwaitEP14pthread_cond_tP15pthread_mutex_tP8timespec"] = Module["asm"]["_ZNSt3__226__libcpp_condvar_timedwaitEP14pthread_cond_tP15pthread_mutex_tP8timespec"]).apply(null, arguments)
            };
            var __ZNSt3__26chronoltIxNS_5ratioILx1ELx1000000000EEExS3_EEbRKNS0_8durationIT_T0_EERKNS4_IT1_T2_EE = Module["__ZNSt3__26chronoltIxNS_5ratioILx1ELx1000000000EEExS3_EEbRKNS0_8durationIT_T0_EERKNS4_IT1_T2_EE"] = function() {
                return (__ZNSt3__26chronoltIxNS_5ratioILx1ELx1000000000EEExS3_EEbRKNS0_8durationIT_T0_EERKNS4_IT1_T2_EE = Module["__ZNSt3__26chronoltIxNS_5ratioILx1ELx1000000000EEExS3_EEbRKNS0_8durationIT_T0_EERKNS4_IT1_T2_EE"] = Module["asm"]["_ZNSt3__26chronoltIxNS_5ratioILx1ELx1000000000EEExS3_EEbRKNS0_8durationIT_T0_EERKNS4_IT1_T2_EE"]).apply(null, arguments)
            };
            var __ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1000000000EEEEENS2_IxNS3_ILx1ELx1EEEEES4_Lb1ELb0EEclERKS5_ = Module["__ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1000000000EEEEENS2_IxNS3_ILx1ELx1EEEEES4_Lb1ELb0EEclERKS5_"] = function() {
                return (__ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1000000000EEEEENS2_IxNS3_ILx1ELx1EEEEES4_Lb1ELb0EEclERKS5_ = Module["__ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1000000000EEEEENS2_IxNS3_ILx1ELx1EEEEES4_Lb1ELb0EEclERKS5_"] = Module["asm"]["_ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1000000000EEEEENS2_IxNS3_ILx1ELx1EEEEES4_Lb1ELb0EEclERKS5_"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEEC2IxNS2_ILx1ELx1EEEEERKNS1_IT_T0_EEPNS_9enable_ifIXaasr13__no_overflowIS8_S3_EE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEaaeqsr13__no_overflowIS8_S3_E4typeE3denLi1Entsr23treat_as_floating_pointIS7_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEEC2IxNS2_ILx1ELx1EEEEERKNS1_IT_T0_EEPNS_9enable_ifIXaasr13__no_overflowIS8_S3_EE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEaaeqsr13__no_overflowIS8_S3_E4typeE3denLi1Entsr23treat_as_floating_pointIS7_EE5valueEvE4typeE"] = function() {
                return (__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEEC2IxNS2_ILx1ELx1EEEEERKNS1_IT_T0_EEPNS_9enable_ifIXaasr13__no_overflowIS8_S3_EE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEaaeqsr13__no_overflowIS8_S3_E4typeE3denLi1Entsr23treat_as_floating_pointIS7_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEEC2IxNS2_ILx1ELx1EEEEERKNS1_IT_T0_EEPNS_9enable_ifIXaasr13__no_overflowIS8_S3_EE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEaaeqsr13__no_overflowIS8_S3_E4typeE3denLi1Entsr23treat_as_floating_pointIS7_EE5valueEvE4typeE"] = Module["asm"]["_ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEEC2IxNS2_ILx1ELx1EEEEERKNS1_IT_T0_EEPNS_9enable_ifIXaasr13__no_overflowIS8_S3_EE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEaaeqsr13__no_overflowIS8_S3_E4typeE3denLi1Entsr23treat_as_floating_pointIS7_EE5valueEvE4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__225notify_all_at_thread_exitERNS_18condition_variableENS_11unique_lockINS_5mutexEEE = Module["__ZNSt3__225notify_all_at_thread_exitERNS_18condition_variableENS_11unique_lockINS_5mutexEEE"] = function() {
                return (__ZNSt3__225notify_all_at_thread_exitERNS_18condition_variableENS_11unique_lockINS_5mutexEEE = Module["__ZNSt3__225notify_all_at_thread_exitERNS_18condition_variableENS_11unique_lockINS_5mutexEEE"] = Module["asm"]["_ZNSt3__225notify_all_at_thread_exitERNS_18condition_variableENS_11unique_lockINS_5mutexEEE"]).apply(null, arguments)
            };
            var __ZNSt3__215__thread_structC1Ev = Module["__ZNSt3__215__thread_structC1Ev"] = function() {
                return (__ZNSt3__215__thread_structC1Ev = Module["__ZNSt3__215__thread_structC1Ev"] = Module["asm"]["_ZNSt3__215__thread_structC1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__221__thread_specific_ptrINS_15__thread_structEE11set_pointerEPS1_ = Module["__ZNSt3__221__thread_specific_ptrINS_15__thread_structEE11set_pointerEPS1_"] = function() {
                return (__ZNSt3__221__thread_specific_ptrINS_15__thread_structEE11set_pointerEPS1_ = Module["__ZNSt3__221__thread_specific_ptrINS_15__thread_structEE11set_pointerEPS1_"] = Module["asm"]["_ZNSt3__221__thread_specific_ptrINS_15__thread_structEE11set_pointerEPS1_"]).apply(null, arguments)
            };
            var __ZNSt3__211unique_lockINS_5mutexEE7releaseEv = Module["__ZNSt3__211unique_lockINS_5mutexEE7releaseEv"] = function() {
                return (__ZNSt3__211unique_lockINS_5mutexEE7releaseEv = Module["__ZNSt3__211unique_lockINS_5mutexEE7releaseEv"] = Module["asm"]["_ZNSt3__211unique_lockINS_5mutexEE7releaseEv"]).apply(null, arguments)
            };
            var __ZNSt3__215__thread_struct25notify_all_at_thread_exitEPNS_18condition_variableEPNS_5mutexE = Module["__ZNSt3__215__thread_struct25notify_all_at_thread_exitEPNS_18condition_variableEPNS_5mutexE"] = function() {
                return (__ZNSt3__215__thread_struct25notify_all_at_thread_exitEPNS_18condition_variableEPNS_5mutexE = Module["__ZNSt3__215__thread_struct25notify_all_at_thread_exitEPNS_18condition_variableEPNS_5mutexE"] = Module["asm"]["_ZNSt3__215__thread_struct25notify_all_at_thread_exitEPNS_18condition_variableEPNS_5mutexE"]).apply(null, arguments)
            };
            var __ZNSt3__216__libcpp_tls_setEjPv = Module["__ZNSt3__216__libcpp_tls_setEjPv"] = function() {
                return (__ZNSt3__216__libcpp_tls_setEjPv = Module["__ZNSt3__216__libcpp_tls_setEjPv"] = Module["asm"]["_ZNSt3__216__libcpp_tls_setEjPv"]).apply(null, arguments)
            };
            var __ZNKSt3__26chrono13__duration_ltINS0_8durationIxNS_5ratioILx1ELx1000000000EEEEES5_EclERKS5_S8_ = Module["__ZNKSt3__26chrono13__duration_ltINS0_8durationIxNS_5ratioILx1ELx1000000000EEEEES5_EclERKS5_S8_"] = function() {
                return (__ZNKSt3__26chrono13__duration_ltINS0_8durationIxNS_5ratioILx1ELx1000000000EEEEES5_EclERKS5_S8_ = Module["__ZNKSt3__26chrono13__duration_ltINS0_8durationIxNS_5ratioILx1ELx1000000000EEEEES5_EclERKS5_S8_"] = Module["asm"]["_ZNKSt3__26chrono13__duration_ltINS0_8durationIxNS_5ratioILx1ELx1000000000EEEEES5_EclERKS5_S8_"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1EEEEC2IxEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1EEEEC2IxEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"] = function() {
                return (__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1EEEEC2IxEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1EEEEC2IxEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"] = Module["asm"]["_ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1EEEEC2IxEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1000000000EEEEExNS3_ILx1ELx1EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE = Module["__ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1000000000EEEEExNS3_ILx1ELx1EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"] = function() {
                return (__ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1000000000EEEEExNS3_ILx1ELx1EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE = Module["__ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1000000000EEEEExNS3_ILx1ELx1EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"] = Module["asm"]["_ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1000000000EEEEExNS3_ILx1ELx1EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"]).apply(null, arguments)
            };
            var __ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEENS2_IxNS3_ILx1ELx1000000000EEEEENS3_ILx1000000000ELx1EEELb0ELb1EEclERKS5_ = Module["__ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEENS2_IxNS3_ILx1ELx1000000000EEEEENS3_ILx1000000000ELx1EEELb0ELb1EEclERKS5_"] = function() {
                return (__ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEENS2_IxNS3_ILx1ELx1000000000EEEEENS3_ILx1000000000ELx1EEELb0ELb1EEclERKS5_ = Module["__ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEENS2_IxNS3_ILx1ELx1000000000EEEEENS3_ILx1000000000ELx1EEELb0ELb1EEclERKS5_"] = Module["asm"]["_ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEENS2_IxNS3_ILx1ELx1000000000EEEEENS3_ILx1000000000ELx1EEELb0ELb1EEclERKS5_"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base4InitC2Ev = Module["__ZNSt3__28ios_base4InitC2Ev"] = function() {
                return (__ZNSt3__28ios_base4InitC2Ev = Module["__ZNSt3__28ios_base4InitC2Ev"] = Module["asm"]["_ZNSt3__28ios_base4InitC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29DoIOSInitC2Ev = Module["__ZNSt3__29DoIOSInitC2Ev"] = function() {
                return (__ZNSt3__29DoIOSInitC2Ev = Module["__ZNSt3__29DoIOSInitC2Ev"] = Module["asm"]["_ZNSt3__29DoIOSInitC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__210__stdinbufIcEC2EP8_IO_FILEP11__mbstate_t = Module["__ZNSt3__210__stdinbufIcEC2EP8_IO_FILEP11__mbstate_t"] = function() {
                return (__ZNSt3__210__stdinbufIcEC2EP8_IO_FILEP11__mbstate_t = Module["__ZNSt3__210__stdinbufIcEC2EP8_IO_FILEP11__mbstate_t"] = Module["asm"]["_ZNSt3__210__stdinbufIcEC2EP8_IO_FILEP11__mbstate_t"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEEC1EPNS_15basic_streambufIcS2_EE = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEEC1EPNS_15basic_streambufIcS2_EE"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEEC1EPNS_15basic_streambufIcS2_EE = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEEC1EPNS_15basic_streambufIcS2_EE"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEEC1EPNS_15basic_streambufIcS2_EE"]).apply(null, arguments)
            };
            var __ZNSt3__210__stdinbufIwEC2EP8_IO_FILEP11__mbstate_t = Module["__ZNSt3__210__stdinbufIwEC2EP8_IO_FILEP11__mbstate_t"] = function() {
                return (__ZNSt3__210__stdinbufIwEC2EP8_IO_FILEP11__mbstate_t = Module["__ZNSt3__210__stdinbufIwEC2EP8_IO_FILEP11__mbstate_t"] = Module["asm"]["_ZNSt3__210__stdinbufIwEC2EP8_IO_FILEP11__mbstate_t"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEEC1EPNS_15basic_streambufIwS2_EE = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEEC1EPNS_15basic_streambufIwS2_EE"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEEC1EPNS_15basic_streambufIwS2_EE = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEEC1EPNS_15basic_streambufIwS2_EE"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEEC1EPNS_15basic_streambufIwS2_EE"]).apply(null, arguments)
            };
            var __ZNSt3__211__stdoutbufIcEC2EP8_IO_FILEP11__mbstate_t = Module["__ZNSt3__211__stdoutbufIcEC2EP8_IO_FILEP11__mbstate_t"] = function() {
                return (__ZNSt3__211__stdoutbufIcEC2EP8_IO_FILEP11__mbstate_t = Module["__ZNSt3__211__stdoutbufIcEC2EP8_IO_FILEP11__mbstate_t"] = Module["asm"]["_ZNSt3__211__stdoutbufIcEC2EP8_IO_FILEP11__mbstate_t"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEEC1EPNS_15basic_streambufIcS2_EE = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEEC1EPNS_15basic_streambufIcS2_EE"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEEC1EPNS_15basic_streambufIcS2_EE = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEEC1EPNS_15basic_streambufIcS2_EE"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEEC1EPNS_15basic_streambufIcS2_EE"]).apply(null, arguments)
            };
            var __ZNSt3__211__stdoutbufIwEC2EP8_IO_FILEP11__mbstate_t = Module["__ZNSt3__211__stdoutbufIwEC2EP8_IO_FILEP11__mbstate_t"] = function() {
                return (__ZNSt3__211__stdoutbufIwEC2EP8_IO_FILEP11__mbstate_t = Module["__ZNSt3__211__stdoutbufIwEC2EP8_IO_FILEP11__mbstate_t"] = Module["asm"]["_ZNSt3__211__stdoutbufIwEC2EP8_IO_FILEP11__mbstate_t"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEEC1EPNS_15basic_streambufIwS2_EE = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEEC1EPNS_15basic_streambufIwS2_EE"] = function() {
                return (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEEC1EPNS_15basic_streambufIwS2_EE = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEEC1EPNS_15basic_streambufIwS2_EE"] = Module["asm"]["_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEEC1EPNS_15basic_streambufIwS2_EE"]).apply(null, arguments)
            };
            var __ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE5rdbufEv = Module["__ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE5rdbufEv"] = function() {
                return (__ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE5rdbufEv = Module["__ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE5rdbufEv"] = Module["asm"]["_ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE5rdbufEv"]).apply(null, arguments)
            };
            var __ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE5rdbufEv = Module["__ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE5rdbufEv"] = function() {
                return (__ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE5rdbufEv = Module["__ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE5rdbufEv"] = Module["asm"]["_ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE5rdbufEv"]).apply(null, arguments)
            };
            var __ZNSt3__29basic_iosIcNS_11char_traitsIcEEE3tieEPNS_13basic_ostreamIcS2_EE = Module["__ZNSt3__29basic_iosIcNS_11char_traitsIcEEE3tieEPNS_13basic_ostreamIcS2_EE"] = function() {
                return (__ZNSt3__29basic_iosIcNS_11char_traitsIcEEE3tieEPNS_13basic_ostreamIcS2_EE = Module["__ZNSt3__29basic_iosIcNS_11char_traitsIcEEE3tieEPNS_13basic_ostreamIcS2_EE"] = Module["asm"]["_ZNSt3__29basic_iosIcNS_11char_traitsIcEEE3tieEPNS_13basic_ostreamIcS2_EE"]).apply(null, arguments)
            };
            var __ZNSt3__29basic_iosIwNS_11char_traitsIwEEE3tieEPNS_13basic_ostreamIwS2_EE = Module["__ZNSt3__29basic_iosIwNS_11char_traitsIwEEE3tieEPNS_13basic_ostreamIwS2_EE"] = function() {
                return (__ZNSt3__29basic_iosIwNS_11char_traitsIwEEE3tieEPNS_13basic_ostreamIwS2_EE = Module["__ZNSt3__29basic_iosIwNS_11char_traitsIwEEE3tieEPNS_13basic_ostreamIwS2_EE"] = Module["asm"]["_ZNSt3__29basic_iosIwNS_11char_traitsIwEEE3tieEPNS_13basic_ostreamIwS2_EE"]).apply(null, arguments)
            };
            var __ZNSt3__27unitbufERNS_8ios_baseE = Module["__ZNSt3__27unitbufERNS_8ios_baseE"] = function() {
                return (__ZNSt3__27unitbufERNS_8ios_baseE = Module["__ZNSt3__27unitbufERNS_8ios_baseE"] = Module["asm"]["_ZNSt3__27unitbufERNS_8ios_baseE"]).apply(null, arguments)
            };
            var __ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE6getlocEv = Module["__ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE6getlocEv"] = function() {
                return (__ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE6getlocEv = Module["__ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE6getlocEv"] = Module["asm"]["_ZNKSt3__215basic_streambufIcNS_11char_traitsIcEEE6getlocEv"]).apply(null, arguments)
            };
            var __ZNSt3__29basic_iosIcNS_11char_traitsIcEEEC2Ev = Module["__ZNSt3__29basic_iosIcNS_11char_traitsIcEEEC2Ev"] = function() {
                return (__ZNSt3__29basic_iosIcNS_11char_traitsIcEEEC2Ev = Module["__ZNSt3__29basic_iosIcNS_11char_traitsIcEEEC2Ev"] = Module["asm"]["_ZNSt3__29basic_iosIcNS_11char_traitsIcEEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29basic_iosIcNS_11char_traitsIcEEE4initEPNS_15basic_streambufIcS2_EE = Module["__ZNSt3__29basic_iosIcNS_11char_traitsIcEEE4initEPNS_15basic_streambufIcS2_EE"] = function() {
                return (__ZNSt3__29basic_iosIcNS_11char_traitsIcEEE4initEPNS_15basic_streambufIcS2_EE = Module["__ZNSt3__29basic_iosIcNS_11char_traitsIcEEE4initEPNS_15basic_streambufIcS2_EE"] = Module["asm"]["_ZNSt3__29basic_iosIcNS_11char_traitsIcEEE4initEPNS_15basic_streambufIcS2_EE"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC2Ev = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC2Ev"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC2Ev = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC2Ev"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__215basic_streambufIwNS_11char_traitsIwEEE6getlocEv = Module["__ZNKSt3__215basic_streambufIwNS_11char_traitsIwEEE6getlocEv"] = function() {
                return (__ZNKSt3__215basic_streambufIwNS_11char_traitsIwEEE6getlocEv = Module["__ZNKSt3__215basic_streambufIwNS_11char_traitsIwEEE6getlocEv"] = Module["asm"]["_ZNKSt3__215basic_streambufIwNS_11char_traitsIwEEE6getlocEv"]).apply(null, arguments)
            };
            var __ZNSt3__29basic_iosIwNS_11char_traitsIwEEEC2Ev = Module["__ZNSt3__29basic_iosIwNS_11char_traitsIwEEEC2Ev"] = function() {
                return (__ZNSt3__29basic_iosIwNS_11char_traitsIwEEEC2Ev = Module["__ZNSt3__29basic_iosIwNS_11char_traitsIwEEEC2Ev"] = Module["asm"]["_ZNSt3__29basic_iosIwNS_11char_traitsIwEEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29basic_iosIwNS_11char_traitsIwEEE4initEPNS_15basic_streambufIwS2_EE = Module["__ZNSt3__29basic_iosIwNS_11char_traitsIwEEE4initEPNS_15basic_streambufIwS2_EE"] = function() {
                return (__ZNSt3__29basic_iosIwNS_11char_traitsIwEEE4initEPNS_15basic_streambufIwS2_EE = Module["__ZNSt3__29basic_iosIwNS_11char_traitsIwEEE4initEPNS_15basic_streambufIwS2_EE"] = Module["asm"]["_ZNSt3__29basic_iosIwNS_11char_traitsIwEEE4initEPNS_15basic_streambufIwS2_EE"]).apply(null, arguments)
            };
            var __ZNSt3__29use_facetINS_7codecvtIcc11__mbstate_tEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_7codecvtIcc11__mbstate_tEEEERKT_RKNS_6localeE"] = function() {
                return (__ZNSt3__29use_facetINS_7codecvtIcc11__mbstate_tEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_7codecvtIcc11__mbstate_tEEEERKT_RKNS_6localeE"] = Module["asm"]["_ZNSt3__29use_facetINS_7codecvtIcc11__mbstate_tEEEERKT_RKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIcc11__mbstate_tE13always_noconvEv = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE13always_noconvEv"] = function() {
                return (__ZNKSt3__27codecvtIcc11__mbstate_tE13always_noconvEv = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE13always_noconvEv"] = Module["asm"]["_ZNKSt3__27codecvtIcc11__mbstate_tE13always_noconvEv"]).apply(null, arguments)
            };
            var __ZNSt3__29use_facetINS_7codecvtIwc11__mbstate_tEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_7codecvtIwc11__mbstate_tEEEERKT_RKNS_6localeE"] = function() {
                return (__ZNSt3__29use_facetINS_7codecvtIwc11__mbstate_tEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_7codecvtIwc11__mbstate_tEEEERKT_RKNS_6localeE"] = Module["asm"]["_ZNSt3__29use_facetINS_7codecvtIwc11__mbstate_tEEEERKT_RKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIwc11__mbstate_tE13always_noconvEv = Module["__ZNKSt3__27codecvtIwc11__mbstate_tE13always_noconvEv"] = function() {
                return (__ZNKSt3__27codecvtIwc11__mbstate_tE13always_noconvEv = Module["__ZNKSt3__27codecvtIwc11__mbstate_tE13always_noconvEv"] = Module["asm"]["_ZNKSt3__27codecvtIwc11__mbstate_tE13always_noconvEv"]).apply(null, arguments)
            };
            var __ZNKSt3__28ios_base5rdbufEv = Module["__ZNKSt3__28ios_base5rdbufEv"] = function() {
                return (__ZNKSt3__28ios_base5rdbufEv = Module["__ZNKSt3__28ios_base5rdbufEv"] = Module["asm"]["_ZNKSt3__28ios_base5rdbufEv"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base4setfEj = Module["__ZNSt3__28ios_base4setfEj"] = function() {
                return (__ZNSt3__28ios_base4setfEj = Module["__ZNSt3__28ios_base4setfEj"] = Module["asm"]["_ZNSt3__28ios_base4setfEj"]).apply(null, arguments)
            };
            var __ZNSt3__29DoIOSInitD2Ev = Module["__ZNSt3__29DoIOSInitD2Ev"] = function() {
                return (__ZNSt3__29DoIOSInitD2Ev = Module["__ZNSt3__29DoIOSInitD2Ev"] = Module["asm"]["_ZNSt3__29DoIOSInitD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5flushEv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE5flushEv = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE5flushEv"] = function() {
                return (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE5flushEv = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE5flushEv"] = Module["asm"]["_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE5flushEv"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base4InitD2Ev = Module["__ZNSt3__28ios_base4InitD2Ev"] = function() {
                return (__ZNSt3__28ios_base4InitD2Ev = Module["__ZNSt3__28ios_base4InitD2Ev"] = Module["asm"]["_ZNSt3__28ios_base4InitD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__210__stdinbufIcED0Ev = Module["__ZNSt3__210__stdinbufIcED0Ev"] = function() {
                return (__ZNSt3__210__stdinbufIcED0Ev = Module["__ZNSt3__210__stdinbufIcED0Ev"] = Module["asm"]["_ZNSt3__210__stdinbufIcED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__210__stdinbufIcE5imbueERKNS_6localeE = Module["__ZNSt3__210__stdinbufIcE5imbueERKNS_6localeE"] = function() {
                return (__ZNSt3__210__stdinbufIcE5imbueERKNS_6localeE = Module["__ZNSt3__210__stdinbufIcE5imbueERKNS_6localeE"] = Module["asm"]["_ZNSt3__210__stdinbufIcE5imbueERKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIcc11__mbstate_tE8encodingEv = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE8encodingEv"] = function() {
                return (__ZNKSt3__27codecvtIcc11__mbstate_tE8encodingEv = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE8encodingEv"] = Module["asm"]["_ZNKSt3__27codecvtIcc11__mbstate_tE8encodingEv"]).apply(null, arguments)
            };
            var __ZNSt3__210__stdinbufIcE9underflowEv = Module["__ZNSt3__210__stdinbufIcE9underflowEv"] = function() {
                return (__ZNSt3__210__stdinbufIcE9underflowEv = Module["__ZNSt3__210__stdinbufIcE9underflowEv"] = Module["asm"]["_ZNSt3__210__stdinbufIcE9underflowEv"]).apply(null, arguments)
            };
            var __ZNSt3__210__stdinbufIcE9__getcharEb = Module["__ZNSt3__210__stdinbufIcE9__getcharEb"] = function() {
                return (__ZNSt3__210__stdinbufIcE9__getcharEb = Module["__ZNSt3__210__stdinbufIcE9__getcharEb"] = Module["asm"]["_ZNSt3__210__stdinbufIcE9__getcharEb"]).apply(null, arguments)
            };
            var __ZNSt3__210__stdinbufIcE5uflowEv = Module["__ZNSt3__210__stdinbufIcE5uflowEv"] = function() {
                return (__ZNSt3__210__stdinbufIcE5uflowEv = Module["__ZNSt3__210__stdinbufIcE5uflowEv"] = Module["asm"]["_ZNSt3__210__stdinbufIcE5uflowEv"]).apply(null, arguments)
            };
            var __ZNSt3__210__stdinbufIcE9pbackfailEi = Module["__ZNSt3__210__stdinbufIcE9pbackfailEi"] = function() {
                return (__ZNSt3__210__stdinbufIcE9pbackfailEi = Module["__ZNSt3__210__stdinbufIcE9pbackfailEi"] = Module["asm"]["_ZNSt3__210__stdinbufIcE9pbackfailEi"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIcE12to_char_typeEi = Module["__ZNSt3__211char_traitsIcE12to_char_typeEi"] = function() {
                return (__ZNSt3__211char_traitsIcE12to_char_typeEi = Module["__ZNSt3__211char_traitsIcE12to_char_typeEi"] = Module["asm"]["_ZNSt3__211char_traitsIcE12to_char_typeEi"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIcc11__mbstate_tE3outERS1_PKcS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE3outERS1_PKcS5_RS5_PcS7_RS7_"] = function() {
                return (__ZNKSt3__27codecvtIcc11__mbstate_tE3outERS1_PKcS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE3outERS1_PKcS5_RS5_PcS7_RS7_"] = Module["asm"]["_ZNKSt3__27codecvtIcc11__mbstate_tE3outERS1_PKcS5_RS5_PcS7_RS7_"]).apply(null, arguments)
            };
            var __ZNSt3__23maxIiEERKT_S3_S3_ = Module["__ZNSt3__23maxIiEERKT_S3_S3_"] = function() {
                return (__ZNSt3__23maxIiEERKT_S3_S3_ = Module["__ZNSt3__23maxIiEERKT_S3_S3_"] = Module["asm"]["_ZNSt3__23maxIiEERKT_S3_S3_"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIcc11__mbstate_tE2inERS1_PKcS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE2inERS1_PKcS5_RS5_PcS7_RS7_"] = function() {
                return (__ZNKSt3__27codecvtIcc11__mbstate_tE2inERS1_PKcS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE2inERS1_PKcS5_RS5_PcS7_RS7_"] = Module["asm"]["_ZNKSt3__27codecvtIcc11__mbstate_tE2inERS1_PKcS5_RS5_PcS7_RS7_"]).apply(null, arguments)
            };
            var __ZNSt3__23maxIiNS_6__lessIiiEEEERKT_S5_S5_T0_ = Module["__ZNSt3__23maxIiNS_6__lessIiiEEEERKT_S5_S5_T0_"] = function() {
                return (__ZNSt3__23maxIiNS_6__lessIiiEEEERKT_S5_S5_T0_ = Module["__ZNSt3__23maxIiNS_6__lessIiiEEEERKT_S5_S5_T0_"] = Module["asm"]["_ZNSt3__23maxIiNS_6__lessIiiEEEERKT_S5_S5_T0_"]).apply(null, arguments)
            };
            var __ZNKSt3__26__lessIiiEclERKiS3_ = Module["__ZNKSt3__26__lessIiiEclERKiS3_"] = function() {
                return (__ZNKSt3__26__lessIiiEclERKiS3_ = Module["__ZNKSt3__26__lessIiiEclERKiS3_"] = Module["asm"]["_ZNKSt3__26__lessIiiEclERKiS3_"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_baseC2Ev = Module["__ZNSt3__28ios_baseC2Ev"] = function() {
                return (__ZNSt3__28ios_baseC2Ev = Module["__ZNSt3__28ios_baseC2Ev"] = Module["asm"]["_ZNSt3__28ios_baseC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base4initEPv = Module["__ZNSt3__28ios_base4initEPv"] = function() {
                return (__ZNSt3__28ios_base4initEPv = Module["__ZNSt3__28ios_base4initEPv"] = Module["asm"]["_ZNSt3__28ios_base4initEPv"]).apply(null, arguments)
            };
            var __ZNSt3__210__stdinbufIwED0Ev = Module["__ZNSt3__210__stdinbufIwED0Ev"] = function() {
                return (__ZNSt3__210__stdinbufIwED0Ev = Module["__ZNSt3__210__stdinbufIwED0Ev"] = Module["asm"]["_ZNSt3__210__stdinbufIwED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED2Ev = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED2Ev"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED2Ev = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED2Ev"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__210__stdinbufIwE5imbueERKNS_6localeE = Module["__ZNSt3__210__stdinbufIwE5imbueERKNS_6localeE"] = function() {
                return (__ZNSt3__210__stdinbufIwE5imbueERKNS_6localeE = Module["__ZNSt3__210__stdinbufIwE5imbueERKNS_6localeE"] = Module["asm"]["_ZNSt3__210__stdinbufIwE5imbueERKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIwc11__mbstate_tE8encodingEv = Module["__ZNKSt3__27codecvtIwc11__mbstate_tE8encodingEv"] = function() {
                return (__ZNKSt3__27codecvtIwc11__mbstate_tE8encodingEv = Module["__ZNKSt3__27codecvtIwc11__mbstate_tE8encodingEv"] = Module["asm"]["_ZNKSt3__27codecvtIwc11__mbstate_tE8encodingEv"]).apply(null, arguments)
            };
            var __ZNSt3__210__stdinbufIwE9underflowEv = Module["__ZNSt3__210__stdinbufIwE9underflowEv"] = function() {
                return (__ZNSt3__210__stdinbufIwE9underflowEv = Module["__ZNSt3__210__stdinbufIwE9underflowEv"] = Module["asm"]["_ZNSt3__210__stdinbufIwE9underflowEv"]).apply(null, arguments)
            };
            var __ZNSt3__210__stdinbufIwE9__getcharEb = Module["__ZNSt3__210__stdinbufIwE9__getcharEb"] = function() {
                return (__ZNSt3__210__stdinbufIwE9__getcharEb = Module["__ZNSt3__210__stdinbufIwE9__getcharEb"] = Module["asm"]["_ZNSt3__210__stdinbufIwE9__getcharEb"]).apply(null, arguments)
            };
            var __ZNSt3__210__stdinbufIwE5uflowEv = Module["__ZNSt3__210__stdinbufIwE5uflowEv"] = function() {
                return (__ZNSt3__210__stdinbufIwE5uflowEv = Module["__ZNSt3__210__stdinbufIwE5uflowEv"] = Module["asm"]["_ZNSt3__210__stdinbufIwE5uflowEv"]).apply(null, arguments)
            };
            var __ZNSt3__210__stdinbufIwE9pbackfailEj = Module["__ZNSt3__210__stdinbufIwE9pbackfailEj"] = function() {
                return (__ZNSt3__210__stdinbufIwE9pbackfailEj = Module["__ZNSt3__210__stdinbufIwE9pbackfailEj"] = Module["asm"]["_ZNSt3__210__stdinbufIwE9pbackfailEj"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIwE12to_char_typeEj = Module["__ZNSt3__211char_traitsIwE12to_char_typeEj"] = function() {
                return (__ZNSt3__211char_traitsIwE12to_char_typeEj = Module["__ZNSt3__211char_traitsIwE12to_char_typeEj"] = Module["asm"]["_ZNSt3__211char_traitsIwE12to_char_typeEj"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIwc11__mbstate_tE3outERS1_PKwS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__27codecvtIwc11__mbstate_tE3outERS1_PKwS5_RS5_PcS7_RS7_"] = function() {
                return (__ZNKSt3__27codecvtIwc11__mbstate_tE3outERS1_PKwS5_RS5_PcS7_RS7_ = Module["__ZNKSt3__27codecvtIwc11__mbstate_tE3outERS1_PKwS5_RS5_PcS7_RS7_"] = Module["asm"]["_ZNKSt3__27codecvtIwc11__mbstate_tE3outERS1_PKwS5_RS5_PcS7_RS7_"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIwc11__mbstate_tE2inERS1_PKcS5_RS5_PwS7_RS7_ = Module["__ZNKSt3__27codecvtIwc11__mbstate_tE2inERS1_PKcS5_RS5_PwS7_RS7_"] = function() {
                return (__ZNKSt3__27codecvtIwc11__mbstate_tE2inERS1_PKcS5_RS5_PwS7_RS7_ = Module["__ZNKSt3__27codecvtIwc11__mbstate_tE2inERS1_PKcS5_RS5_PwS7_RS7_"] = Module["asm"]["_ZNKSt3__27codecvtIwc11__mbstate_tE2inERS1_PKcS5_RS5_PwS7_RS7_"]).apply(null, arguments)
            };
            var __ZNSt3__211__stdoutbufIcED0Ev = Module["__ZNSt3__211__stdoutbufIcED0Ev"] = function() {
                return (__ZNSt3__211__stdoutbufIcED0Ev = Module["__ZNSt3__211__stdoutbufIcED0Ev"] = Module["asm"]["_ZNSt3__211__stdoutbufIcED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__211__stdoutbufIcE5imbueERKNS_6localeE = Module["__ZNSt3__211__stdoutbufIcE5imbueERKNS_6localeE"] = function() {
                return (__ZNSt3__211__stdoutbufIcE5imbueERKNS_6localeE = Module["__ZNSt3__211__stdoutbufIcE5imbueERKNS_6localeE"] = Module["asm"]["_ZNSt3__211__stdoutbufIcE5imbueERKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNSt3__211__stdoutbufIcE4syncEv = Module["__ZNSt3__211__stdoutbufIcE4syncEv"] = function() {
                return (__ZNSt3__211__stdoutbufIcE4syncEv = Module["__ZNSt3__211__stdoutbufIcE4syncEv"] = Module["asm"]["_ZNSt3__211__stdoutbufIcE4syncEv"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIcc11__mbstate_tE7unshiftERS1_PcS4_RS4_ = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE7unshiftERS1_PcS4_RS4_"] = function() {
                return (__ZNKSt3__27codecvtIcc11__mbstate_tE7unshiftERS1_PcS4_RS4_ = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE7unshiftERS1_PcS4_RS4_"] = Module["asm"]["_ZNKSt3__27codecvtIcc11__mbstate_tE7unshiftERS1_PcS4_RS4_"]).apply(null, arguments)
            };
            var __ZNSt3__211__stdoutbufIcE6xsputnEPKcl = Module["__ZNSt3__211__stdoutbufIcE6xsputnEPKcl"] = function() {
                return (__ZNSt3__211__stdoutbufIcE6xsputnEPKcl = Module["__ZNSt3__211__stdoutbufIcE6xsputnEPKcl"] = Module["asm"]["_ZNSt3__211__stdoutbufIcE6xsputnEPKcl"]).apply(null, arguments)
            };
            var __ZNSt3__211__stdoutbufIcE8overflowEi = Module["__ZNSt3__211__stdoutbufIcE8overflowEi"] = function() {
                return (__ZNSt3__211__stdoutbufIcE8overflowEi = Module["__ZNSt3__211__stdoutbufIcE8overflowEi"] = Module["asm"]["_ZNSt3__211__stdoutbufIcE8overflowEi"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIcE7not_eofEi = Module["__ZNSt3__211char_traitsIcE7not_eofEi"] = function() {
                return (__ZNSt3__211char_traitsIcE7not_eofEi = Module["__ZNSt3__211char_traitsIcE7not_eofEi"] = Module["asm"]["_ZNSt3__211char_traitsIcE7not_eofEi"]).apply(null, arguments)
            };
            var __ZNSt3__211__stdoutbufIwED0Ev = Module["__ZNSt3__211__stdoutbufIwED0Ev"] = function() {
                return (__ZNSt3__211__stdoutbufIwED0Ev = Module["__ZNSt3__211__stdoutbufIwED0Ev"] = Module["asm"]["_ZNSt3__211__stdoutbufIwED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__211__stdoutbufIwE5imbueERKNS_6localeE = Module["__ZNSt3__211__stdoutbufIwE5imbueERKNS_6localeE"] = function() {
                return (__ZNSt3__211__stdoutbufIwE5imbueERKNS_6localeE = Module["__ZNSt3__211__stdoutbufIwE5imbueERKNS_6localeE"] = Module["asm"]["_ZNSt3__211__stdoutbufIwE5imbueERKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNSt3__211__stdoutbufIwE4syncEv = Module["__ZNSt3__211__stdoutbufIwE4syncEv"] = function() {
                return (__ZNSt3__211__stdoutbufIwE4syncEv = Module["__ZNSt3__211__stdoutbufIwE4syncEv"] = Module["asm"]["_ZNSt3__211__stdoutbufIwE4syncEv"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIwc11__mbstate_tE7unshiftERS1_PcS4_RS4_ = Module["__ZNKSt3__27codecvtIwc11__mbstate_tE7unshiftERS1_PcS4_RS4_"] = function() {
                return (__ZNKSt3__27codecvtIwc11__mbstate_tE7unshiftERS1_PcS4_RS4_ = Module["__ZNKSt3__27codecvtIwc11__mbstate_tE7unshiftERS1_PcS4_RS4_"] = Module["asm"]["_ZNKSt3__27codecvtIwc11__mbstate_tE7unshiftERS1_PcS4_RS4_"]).apply(null, arguments)
            };
            var __ZNSt3__211__stdoutbufIwE6xsputnEPKwl = Module["__ZNSt3__211__stdoutbufIwE6xsputnEPKwl"] = function() {
                return (__ZNSt3__211__stdoutbufIwE6xsputnEPKwl = Module["__ZNSt3__211__stdoutbufIwE6xsputnEPKwl"] = Module["asm"]["_ZNSt3__211__stdoutbufIwE6xsputnEPKwl"]).apply(null, arguments)
            };
            var __ZNSt3__211__stdoutbufIwE8overflowEj = Module["__ZNSt3__211__stdoutbufIwE8overflowEj"] = function() {
                return (__ZNSt3__211__stdoutbufIwE8overflowEj = Module["__ZNSt3__211__stdoutbufIwE8overflowEj"] = Module["asm"]["_ZNSt3__211__stdoutbufIwE8overflowEj"]).apply(null, arguments)
            };
            var __ZNSt3__211char_traitsIwE7not_eofEj = Module["__ZNSt3__211char_traitsIwE7not_eofEj"] = function() {
                return (__ZNSt3__211char_traitsIwE7not_eofEj = Module["__ZNSt3__211char_traitsIwE7not_eofEj"] = Module["asm"]["_ZNSt3__211char_traitsIwE7not_eofEj"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7seekposENS_4fposI11__mbstate_tEEj = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7seekposENS_4fposI11__mbstate_tEEj"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7seekposENS_4fposI11__mbstate_tEEj = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7seekposENS_4fposI11__mbstate_tEEj"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7seekposENS_4fposI11__mbstate_tEEj"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE8overflowEi = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE8overflowEi"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE8overflowEi = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE8overflowEi"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE8overflowEi"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6setbufEPwl = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6setbufEPwl"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6setbufEPwl = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6setbufEPwl"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6setbufEPwl"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7seekoffExNS_8ios_base7seekdirEj = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7seekoffExNS_8ios_base7seekdirEj"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7seekoffExNS_8ios_base7seekdirEj = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7seekoffExNS_8ios_base7seekdirEj"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7seekoffExNS_8ios_base7seekdirEj"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7seekposENS_4fposI11__mbstate_tEEj = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7seekposENS_4fposI11__mbstate_tEEj"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7seekposENS_4fposI11__mbstate_tEEj = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7seekposENS_4fposI11__mbstate_tEEj"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7seekposENS_4fposI11__mbstate_tEEj"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE4syncEv = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE4syncEv"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE4syncEv = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE4syncEv"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE4syncEv"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9showmanycEv = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9showmanycEv"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9showmanycEv = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9showmanycEv"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9showmanycEv"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6xsgetnEPwl = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6xsgetnEPwl"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6xsgetnEPwl = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6xsgetnEPwl"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6xsgetnEPwl"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6xsputnEPKwl = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6xsputnEPKwl"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6xsputnEPKwl = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6xsputnEPKwl"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE6xsputnEPKwl"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE8overflowEj = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE8overflowEj"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE8overflowEj = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE8overflowEj"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE8overflowEj"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9underflowEv = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9underflowEv"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9underflowEv = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9underflowEv"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9underflowEv"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9pbackfailEi = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9pbackfailEi"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9pbackfailEi = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9pbackfailEi"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9pbackfailEi"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9underflowEv = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9underflowEv"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9underflowEv = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9underflowEv"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9underflowEv"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5uflowEv = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5uflowEv"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5uflowEv = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5uflowEv"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5uflowEv"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9pbackfailEj = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9pbackfailEj"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9pbackfailEj = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9pbackfailEj"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9pbackfailEj"]).apply(null, arguments)
            };
            var __ZNSt3__29DoIOSInitC1Ev = Module["__ZNSt3__29DoIOSInitC1Ev"] = function() {
                return (__ZNSt3__29DoIOSInitC1Ev = Module["__ZNSt3__29DoIOSInitC1Ev"] = Module["asm"]["_ZNSt3__29DoIOSInitC1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29DoIOSInitD1Ev = Module["__ZNSt3__29DoIOSInitD1Ev"] = function() {
                return (__ZNSt3__29DoIOSInitD1Ev = Module["__ZNSt3__29DoIOSInitD1Ev"] = Module["asm"]["_ZNSt3__29DoIOSInitD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base4InitC1Ev = Module["__ZNSt3__28ios_base4InitC1Ev"] = function() {
                return (__ZNSt3__28ios_base4InitC1Ev = Module["__ZNSt3__28ios_base4InitC1Ev"] = Module["asm"]["_ZNSt3__28ios_base4InitC1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base4InitD1Ev = Module["__ZNSt3__28ios_base4InitD1Ev"] = function() {
                return (__ZNSt3__28ios_base4InitD1Ev = Module["__ZNSt3__28ios_base4InitD1Ev"] = Module["asm"]["_ZNSt3__28ios_base4InitD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213random_deviceC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__213random_deviceC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = function() {
                return (__ZNSt3__213random_deviceC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__213random_deviceC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = Module["asm"]["_ZNSt3__213random_deviceC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNSt3__213random_deviceD2Ev = Module["__ZNSt3__213random_deviceD2Ev"] = function() {
                return (__ZNSt3__213random_deviceD2Ev = Module["__ZNSt3__213random_deviceD2Ev"] = Module["asm"]["_ZNSt3__213random_deviceD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213random_deviceclEv = Module["__ZNSt3__213random_deviceclEv"] = function() {
                return (__ZNSt3__213random_deviceclEv = Module["__ZNSt3__213random_deviceclEv"] = Module["asm"]["_ZNSt3__213random_deviceclEv"]).apply(null, arguments)
            };
            var __ZNKSt3__213random_device7entropyEv = Module["__ZNKSt3__213random_device7entropyEv"] = function() {
                return (__ZNKSt3__213random_device7entropyEv = Module["__ZNKSt3__213random_device7entropyEv"] = Module["asm"]["_ZNKSt3__213random_device7entropyEv"]).apply(null, arguments)
            };
            var __ZNSt3__213random_deviceC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__213random_deviceC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = function() {
                return (__ZNSt3__213random_deviceC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE = Module["__ZNSt3__213random_deviceC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"] = Module["asm"]["_ZNSt3__213random_deviceC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEE"]).apply(null, arguments)
            };
            var __ZNSt3__213random_deviceD1Ev = Module["__ZNSt3__213random_deviceD1Ev"] = function() {
                return (__ZNSt3__213random_deviceD1Ev = Module["__ZNSt3__213random_deviceD1Ev"] = Module["asm"]["_ZNSt3__213random_deviceD1Ev"]).apply(null, arguments)
            };
            var __ZSt15get_new_handlerv = Module["__ZSt15get_new_handlerv"] = function() {
                return (__ZSt15get_new_handlerv = Module["__ZSt15get_new_handlerv"] = Module["asm"]["_ZSt15get_new_handlerv"]).apply(null, arguments)
            };
            var __ZnwmRKSt9nothrow_t = Module["__ZnwmRKSt9nothrow_t"] = function() {
                return (__ZnwmRKSt9nothrow_t = Module["__ZnwmRKSt9nothrow_t"] = Module["asm"]["_ZnwmRKSt9nothrow_t"]).apply(null, arguments)
            };
            var __ZnamRKSt9nothrow_t = Module["__ZnamRKSt9nothrow_t"] = function() {
                return (__ZnamRKSt9nothrow_t = Module["__ZnamRKSt9nothrow_t"] = Module["asm"]["_ZnamRKSt9nothrow_t"]).apply(null, arguments)
            };
            var __ZdlPvRKSt9nothrow_t = Module["__ZdlPvRKSt9nothrow_t"] = function() {
                return (__ZdlPvRKSt9nothrow_t = Module["__ZdlPvRKSt9nothrow_t"] = Module["asm"]["_ZdlPvRKSt9nothrow_t"]).apply(null, arguments)
            };
            var __ZdlPvm = Module["__ZdlPvm"] = function() {
                return (__ZdlPvm = Module["__ZdlPvm"] = Module["asm"]["_ZdlPvm"]).apply(null, arguments)
            };
            var __ZdaPvRKSt9nothrow_t = Module["__ZdaPvRKSt9nothrow_t"] = function() {
                return (__ZdaPvRKSt9nothrow_t = Module["__ZdaPvRKSt9nothrow_t"] = Module["asm"]["_ZdaPvRKSt9nothrow_t"]).apply(null, arguments)
            };
            var __ZdaPvm = Module["__ZdaPvm"] = function() {
                return (__ZdaPvm = Module["__ZdaPvm"] = Module["asm"]["_ZdaPvm"]).apply(null, arguments)
            };
            var __ZnwmSt11align_val_t = Module["__ZnwmSt11align_val_t"] = function() {
                return (__ZnwmSt11align_val_t = Module["__ZnwmSt11align_val_t"] = Module["asm"]["_ZnwmSt11align_val_t"]).apply(null, arguments)
            };
            var __ZnwmSt11align_val_tRKSt9nothrow_t = Module["__ZnwmSt11align_val_tRKSt9nothrow_t"] = function() {
                return (__ZnwmSt11align_val_tRKSt9nothrow_t = Module["__ZnwmSt11align_val_tRKSt9nothrow_t"] = Module["asm"]["_ZnwmSt11align_val_tRKSt9nothrow_t"]).apply(null, arguments)
            };
            var __ZnamSt11align_val_t = Module["__ZnamSt11align_val_t"] = function() {
                return (__ZnamSt11align_val_t = Module["__ZnamSt11align_val_t"] = Module["asm"]["_ZnamSt11align_val_t"]).apply(null, arguments)
            };
            var __ZnamSt11align_val_tRKSt9nothrow_t = Module["__ZnamSt11align_val_tRKSt9nothrow_t"] = function() {
                return (__ZnamSt11align_val_tRKSt9nothrow_t = Module["__ZnamSt11align_val_tRKSt9nothrow_t"] = Module["asm"]["_ZnamSt11align_val_tRKSt9nothrow_t"]).apply(null, arguments)
            };
            var __ZdlPvSt11align_val_t = Module["__ZdlPvSt11align_val_t"] = function() {
                return (__ZdlPvSt11align_val_t = Module["__ZdlPvSt11align_val_t"] = Module["asm"]["_ZdlPvSt11align_val_t"]).apply(null, arguments)
            };
            var __ZdlPvSt11align_val_tRKSt9nothrow_t = Module["__ZdlPvSt11align_val_tRKSt9nothrow_t"] = function() {
                return (__ZdlPvSt11align_val_tRKSt9nothrow_t = Module["__ZdlPvSt11align_val_tRKSt9nothrow_t"] = Module["asm"]["_ZdlPvSt11align_val_tRKSt9nothrow_t"]).apply(null, arguments)
            };
            var __ZdlPvmSt11align_val_t = Module["__ZdlPvmSt11align_val_t"] = function() {
                return (__ZdlPvmSt11align_val_t = Module["__ZdlPvmSt11align_val_t"] = Module["asm"]["_ZdlPvmSt11align_val_t"]).apply(null, arguments)
            };
            var __ZdaPvSt11align_val_t = Module["__ZdaPvSt11align_val_t"] = function() {
                return (__ZdaPvSt11align_val_t = Module["__ZdaPvSt11align_val_t"] = Module["asm"]["_ZdaPvSt11align_val_t"]).apply(null, arguments)
            };
            var __ZdaPvSt11align_val_tRKSt9nothrow_t = Module["__ZdaPvSt11align_val_tRKSt9nothrow_t"] = function() {
                return (__ZdaPvSt11align_val_tRKSt9nothrow_t = Module["__ZdaPvSt11align_val_tRKSt9nothrow_t"] = Module["asm"]["_ZdaPvSt11align_val_tRKSt9nothrow_t"]).apply(null, arguments)
            };
            var __ZdaPvmSt11align_val_t = Module["__ZdaPvmSt11align_val_t"] = function() {
                return (__ZdaPvmSt11align_val_t = Module["__ZdaPvmSt11align_val_t"] = Module["asm"]["_ZdaPvmSt11align_val_t"]).apply(null, arguments)
            };
            var __ZNSt3__26threadD2Ev = Module["__ZNSt3__26threadD2Ev"] = function() {
                return (__ZNSt3__26threadD2Ev = Module["__ZNSt3__26threadD2Ev"] = Module["asm"]["_ZNSt3__26threadD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__222__libcpp_thread_isnullEPKm = Module["__ZNSt3__222__libcpp_thread_isnullEPKm"] = function() {
                return (__ZNSt3__222__libcpp_thread_isnullEPKm = Module["__ZNSt3__222__libcpp_thread_isnullEPKm"] = Module["asm"]["_ZNSt3__222__libcpp_thread_isnullEPKm"]).apply(null, arguments)
            };
            var __ZNSt3__26thread4joinEv = Module["__ZNSt3__26thread4joinEv"] = function() {
                return (__ZNSt3__26thread4joinEv = Module["__ZNSt3__26thread4joinEv"] = Module["asm"]["_ZNSt3__26thread4joinEv"]).apply(null, arguments)
            };
            var __ZNSt3__220__libcpp_thread_joinEPm = Module["__ZNSt3__220__libcpp_thread_joinEPm"] = function() {
                return (__ZNSt3__220__libcpp_thread_joinEPm = Module["__ZNSt3__220__libcpp_thread_joinEPm"] = Module["asm"]["_ZNSt3__220__libcpp_thread_joinEPm"]).apply(null, arguments)
            };
            var __ZNSt3__26thread6detachEv = Module["__ZNSt3__26thread6detachEv"] = function() {
                return (__ZNSt3__26thread6detachEv = Module["__ZNSt3__26thread6detachEv"] = Module["asm"]["_ZNSt3__26thread6detachEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__libcpp_thread_detachEPm = Module["__ZNSt3__222__libcpp_thread_detachEPm"] = function() {
                return (__ZNSt3__222__libcpp_thread_detachEPm = Module["__ZNSt3__222__libcpp_thread_detachEPm"] = Module["asm"]["_ZNSt3__222__libcpp_thread_detachEPm"]).apply(null, arguments)
            };
            var __ZNSt3__26thread20hardware_concurrencyEv = Module["__ZNSt3__26thread20hardware_concurrencyEv"] = function() {
                return (__ZNSt3__26thread20hardware_concurrencyEv = Module["__ZNSt3__26thread20hardware_concurrencyEv"] = Module["asm"]["_ZNSt3__26thread20hardware_concurrencyEv"]).apply(null, arguments)
            };
            var __ZNSt3__211this_thread9sleep_forERKNS_6chrono8durationIxNS_5ratioILx1ELx1000000000EEEEE = Module["__ZNSt3__211this_thread9sleep_forERKNS_6chrono8durationIxNS_5ratioILx1ELx1000000000EEEEE"] = function() {
                return (__ZNSt3__211this_thread9sleep_forERKNS_6chrono8durationIxNS_5ratioILx1ELx1000000000EEEEE = Module["__ZNSt3__211this_thread9sleep_forERKNS_6chrono8durationIxNS_5ratioILx1ELx1000000000EEEEE"] = Module["asm"]["_ZNSt3__211this_thread9sleep_forERKNS_6chrono8durationIxNS_5ratioILx1ELx1000000000EEEEE"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEE4zeroEv = Module["__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEE4zeroEv"] = function() {
                return (__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEE4zeroEv = Module["__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEE4zeroEv"] = Module["asm"]["_ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEE4zeroEv"]).apply(null, arguments)
            };
            var __ZNSt3__225__libcpp_thread_sleep_forERKNS_6chrono8durationIxNS_5ratioILx1ELx1000000000EEEEE = Module["__ZNSt3__225__libcpp_thread_sleep_forERKNS_6chrono8durationIxNS_5ratioILx1ELx1000000000EEEEE"] = function() {
                return (__ZNSt3__225__libcpp_thread_sleep_forERKNS_6chrono8durationIxNS_5ratioILx1ELx1000000000EEEEE = Module["__ZNSt3__225__libcpp_thread_sleep_forERKNS_6chrono8durationIxNS_5ratioILx1ELx1000000000EEEEE"] = Module["asm"]["_ZNSt3__225__libcpp_thread_sleep_forERKNS_6chrono8durationIxNS_5ratioILx1ELx1000000000EEEEE"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono15duration_valuesIxE4zeroEv = Module["__ZNSt3__26chrono15duration_valuesIxE4zeroEv"] = function() {
                return (__ZNSt3__26chrono15duration_valuesIxE4zeroEv = Module["__ZNSt3__26chrono15duration_valuesIxE4zeroEv"] = Module["asm"]["_ZNSt3__26chrono15duration_valuesIxE4zeroEv"]).apply(null, arguments)
            };
            var __ZNSt3__215__thread_detail21__convert_to_timespecERKNS_6chrono8durationIxNS_5ratioILx1ELx1000000000EEEEE = Module["__ZNSt3__215__thread_detail21__convert_to_timespecERKNS_6chrono8durationIxNS_5ratioILx1ELx1000000000EEEEE"] = function() {
                return (__ZNSt3__215__thread_detail21__convert_to_timespecERKNS_6chrono8durationIxNS_5ratioILx1ELx1000000000EEEEE = Module["__ZNSt3__215__thread_detail21__convert_to_timespecERKNS_6chrono8durationIxNS_5ratioILx1ELx1000000000EEEEE"] = Module["asm"]["_ZNSt3__215__thread_detail21__convert_to_timespecERKNS_6chrono8durationIxNS_5ratioILx1ELx1000000000EEEEE"]).apply(null, arguments)
            };
            var __ZNSt3__221__thread_specific_ptrINS_15__thread_structEEC2Ev = Module["__ZNSt3__221__thread_specific_ptrINS_15__thread_structEEC2Ev"] = function() {
                return (__ZNSt3__221__thread_specific_ptrINS_15__thread_structEEC2Ev = Module["__ZNSt3__221__thread_specific_ptrINS_15__thread_structEEC2Ev"] = Module["asm"]["_ZNSt3__221__thread_specific_ptrINS_15__thread_structEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__221__thread_specific_ptrINS_15__thread_structEE16__at_thread_exitEPv = Module["__ZNSt3__221__thread_specific_ptrINS_15__thread_structEE16__at_thread_exitEPv"] = function() {
                return (__ZNSt3__221__thread_specific_ptrINS_15__thread_structEE16__at_thread_exitEPv = Module["__ZNSt3__221__thread_specific_ptrINS_15__thread_structEE16__at_thread_exitEPv"] = Module["asm"]["_ZNSt3__221__thread_specific_ptrINS_15__thread_structEE16__at_thread_exitEPv"]).apply(null, arguments)
            };
            var __ZNSt3__219__libcpp_tls_createEPjPFvPvE = Module["__ZNSt3__219__libcpp_tls_createEPjPFvPvE"] = function() {
                return (__ZNSt3__219__libcpp_tls_createEPjPFvPvE = Module["__ZNSt3__219__libcpp_tls_createEPjPFvPvE"] = Module["asm"]["_ZNSt3__219__libcpp_tls_createEPjPFvPvE"]).apply(null, arguments)
            };
            var __ZNSt3__221__thread_specific_ptrINS_15__thread_structEED2Ev = Module["__ZNSt3__221__thread_specific_ptrINS_15__thread_structEED2Ev"] = function() {
                return (__ZNSt3__221__thread_specific_ptrINS_15__thread_structEED2Ev = Module["__ZNSt3__221__thread_specific_ptrINS_15__thread_structEED2Ev"] = Module["asm"]["_ZNSt3__221__thread_specific_ptrINS_15__thread_structEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__219__thread_struct_impD2Ev = Module["__ZNSt3__219__thread_struct_impD2Ev"] = function() {
                return (__ZNSt3__219__thread_struct_impD2Ev = Module["__ZNSt3__219__thread_struct_impD2Ev"] = Module["asm"]["_ZNSt3__219__thread_struct_impD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE5beginEv = Module["__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE5beginEv"] = function() {
                return (__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE5beginEv = Module["__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE5beginEv"] = Module["asm"]["_ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE5beginEv"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE3endEv = Module["__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE3endEv"] = function() {
                return (__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE3endEv = Module["__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE3endEv"] = Module["asm"]["_ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE3endEv"]).apply(null, arguments)
            };
            var __ZNSt3__2neIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEbRKNS_11__wrap_iterIT_EESC_ = Module["__ZNSt3__2neIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEbRKNS_11__wrap_iterIT_EESC_"] = function() {
                return (__ZNSt3__2neIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEbRKNS_11__wrap_iterIT_EESC_ = Module["__ZNSt3__2neIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEbRKNS_11__wrap_iterIT_EESC_"] = Module["asm"]["_ZNSt3__2neIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEbRKNS_11__wrap_iterIT_EESC_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE5beginEv = Module["__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE5beginEv"] = function() {
                return (__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE5beginEv = Module["__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE5beginEv"] = Module["asm"]["_ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE5beginEv"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE3endEv = Module["__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE3endEv"] = function() {
                return (__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE3endEv = Module["__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE3endEv"] = Module["asm"]["_ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE3endEv"]).apply(null, arguments)
            };
            var __ZNSt3__2neIPPNS_17__assoc_sub_stateEEEbRKNS_11__wrap_iterIT_EES8_ = Module["__ZNSt3__2neIPPNS_17__assoc_sub_stateEEEbRKNS_11__wrap_iterIT_EES8_"] = function() {
                return (__ZNSt3__2neIPPNS_17__assoc_sub_stateEEEbRKNS_11__wrap_iterIT_EES8_ = Module["__ZNSt3__2neIPPNS_17__assoc_sub_stateEEEbRKNS_11__wrap_iterIT_EES8_"] = Module["asm"]["_ZNSt3__2neIPPNS_17__assoc_sub_stateEEEbRKNS_11__wrap_iterIT_EES8_"]).apply(null, arguments)
            };
            var __ZNKSt3__211__wrap_iterIPPNS_17__assoc_sub_stateEEdeEv = Module["__ZNKSt3__211__wrap_iterIPPNS_17__assoc_sub_stateEEdeEv"] = function() {
                return (__ZNKSt3__211__wrap_iterIPPNS_17__assoc_sub_stateEEdeEv = Module["__ZNKSt3__211__wrap_iterIPPNS_17__assoc_sub_stateEEdeEv"] = Module["asm"]["_ZNKSt3__211__wrap_iterIPPNS_17__assoc_sub_stateEEdeEv"]).apply(null, arguments)
            };
            var __ZNSt3__211__wrap_iterIPPNS_17__assoc_sub_stateEEppEv = Module["__ZNSt3__211__wrap_iterIPPNS_17__assoc_sub_stateEEppEv"] = function() {
                return (__ZNSt3__211__wrap_iterIPPNS_17__assoc_sub_stateEEppEv = Module["__ZNSt3__211__wrap_iterIPPNS_17__assoc_sub_stateEEppEv"] = Module["asm"]["_ZNSt3__211__wrap_iterIPPNS_17__assoc_sub_stateEEppEv"]).apply(null, arguments)
            };
            var __ZNKSt3__211__wrap_iterIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEptEv = Module["__ZNKSt3__211__wrap_iterIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEptEv"] = function() {
                return (__ZNKSt3__211__wrap_iterIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEptEv = Module["__ZNKSt3__211__wrap_iterIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEptEv"] = Module["asm"]["_ZNKSt3__211__wrap_iterIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEptEv"]).apply(null, arguments)
            };
            var __ZNSt3__211__wrap_iterIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEppEv = Module["__ZNSt3__211__wrap_iterIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEppEv"] = function() {
                return (__ZNSt3__211__wrap_iterIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEppEv = Module["__ZNSt3__211__wrap_iterIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEppEv"] = Module["asm"]["_ZNSt3__211__wrap_iterIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEppEv"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEED2Ev = Module["__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEED2Ev"] = function() {
                return (__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEED2Ev = Module["__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEED2Ev"] = Module["asm"]["_ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEED2Ev = Module["__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEED2Ev"] = function() {
                return (__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEED2Ev = Module["__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEED2Ev"] = Module["asm"]["_ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE11__make_iterEPS6_ = Module["__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE11__make_iterEPS6_"] = function() {
                return (__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE11__make_iterEPS6_ = Module["__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE11__make_iterEPS6_"] = Module["asm"]["_ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE11__make_iterEPS6_"]).apply(null, arguments)
            };
            var __ZNSt3__2eqIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEES7_EEbRKNS_11__wrap_iterIT_EERKNS8_IT0_EE = Module["__ZNSt3__2eqIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEES7_EEbRKNS_11__wrap_iterIT_EERKNS8_IT0_EE"] = function() {
                return (__ZNSt3__2eqIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEES7_EEbRKNS_11__wrap_iterIT_EERKNS8_IT0_EE = Module["__ZNSt3__2eqIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEES7_EEbRKNS_11__wrap_iterIT_EERKNS8_IT0_EE"] = Module["asm"]["_ZNSt3__2eqIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEES7_EEbRKNS_11__wrap_iterIT_EERKNS8_IT0_EE"]).apply(null, arguments)
            };
            var __ZNSt3__29addressofINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEPT_RS7_ = Module["__ZNSt3__29addressofINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEPT_RS7_"] = function() {
                return (__ZNSt3__29addressofINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEPT_RS7_ = Module["__ZNSt3__29addressofINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEPT_RS7_"] = Module["asm"]["_ZNSt3__29addressofINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEPT_RS7_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE11__make_iterEPS2_ = Module["__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE11__make_iterEPS2_"] = function() {
                return (__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE11__make_iterEPS2_ = Module["__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE11__make_iterEPS2_"] = Module["asm"]["_ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE11__make_iterEPS2_"]).apply(null, arguments)
            };
            var __ZNSt3__2eqIPPNS_17__assoc_sub_stateES3_EEbRKNS_11__wrap_iterIT_EERKNS4_IT0_EE = Module["__ZNSt3__2eqIPPNS_17__assoc_sub_stateES3_EEbRKNS_11__wrap_iterIT_EERKNS4_IT0_EE"] = function() {
                return (__ZNSt3__2eqIPPNS_17__assoc_sub_stateES3_EEbRKNS_11__wrap_iterIT_EERKNS4_IT0_EE = Module["__ZNSt3__2eqIPPNS_17__assoc_sub_stateES3_EEbRKNS_11__wrap_iterIT_EERKNS4_IT0_EE"] = Module["asm"]["_ZNSt3__2eqIPPNS_17__assoc_sub_stateES3_EEbRKNS_11__wrap_iterIT_EERKNS4_IT0_EE"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE17__annotate_deleteEv = Module["__ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE17__annotate_deleteEv"] = function() {
                return (__ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE17__annotate_deleteEv = Module["__ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE17__annotate_deleteEv"] = Module["asm"]["_ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE17__annotate_deleteEv"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEED2Ev = Module["__ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEED2Ev"] = function() {
                return (__ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEED2Ev = Module["__ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEED2Ev"] = Module["asm"]["_ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEED2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE17__annotate_deleteEv = Module["__ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE17__annotate_deleteEv"] = function() {
                return (__ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE17__annotate_deleteEv = Module["__ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE17__annotate_deleteEv"] = Module["asm"]["_ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE17__annotate_deleteEv"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEED2Ev = Module["__ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEED2Ev"] = function() {
                return (__ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEED2Ev = Module["__ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEED2Ev"] = Module["asm"]["_ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__219__thread_struct_imp25notify_all_at_thread_exitEPNS_18condition_variableEPNS_5mutexE = Module["__ZNSt3__219__thread_struct_imp25notify_all_at_thread_exitEPNS_18condition_variableEPNS_5mutexE"] = function() {
                return (__ZNSt3__219__thread_struct_imp25notify_all_at_thread_exitEPNS_18condition_variableEPNS_5mutexE = Module["__ZNSt3__219__thread_struct_imp25notify_all_at_thread_exitEPNS_18condition_variableEPNS_5mutexE"] = Module["asm"]["_ZNSt3__219__thread_struct_imp25notify_all_at_thread_exitEPNS_18condition_variableEPNS_5mutexE"]).apply(null, arguments)
            };
            var __ZNSt3__24pairIPNS_18condition_variableEPNS_5mutexEEC2IRS2_RS4_Lb0EEEOT_OT0_ = Module["__ZNSt3__24pairIPNS_18condition_variableEPNS_5mutexEEC2IRS2_RS4_Lb0EEEOT_OT0_"] = function() {
                return (__ZNSt3__24pairIPNS_18condition_variableEPNS_5mutexEEC2IRS2_RS4_Lb0EEEOT_OT0_ = Module["__ZNSt3__24pairIPNS_18condition_variableEPNS_5mutexEEC2IRS2_RS4_Lb0EEEOT_OT0_"] = Module["asm"]["_ZNSt3__24pairIPNS_18condition_variableEPNS_5mutexEEC2IRS2_RS4_Lb0EEEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE9push_backEOS6_ = Module["__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE9push_backEOS6_"] = function() {
                return (__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE9push_backEOS6_ = Module["__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE9push_backEOS6_"] = Module["asm"]["_ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE9push_backEOS6_"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE9__end_capEv = Module["__ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE9__end_capEv"] = function() {
                return (__ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE9__end_capEv = Module["__ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE9__end_capEv"] = Module["asm"]["_ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE9__end_capEv"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEONS_16remove_referenceIT_E4typeEOS9_ = Module["__ZNSt3__24moveIRNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEONS_16remove_referenceIT_E4typeEOS9_"] = function() {
                return (__ZNSt3__24moveIRNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEONS_16remove_referenceIT_E4typeEOS9_ = Module["__ZNSt3__24moveIRNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEONS_16remove_referenceIT_E4typeEOS9_"] = Module["asm"]["_ZNSt3__24moveIRNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEONS_16remove_referenceIT_E4typeEOS9_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE22__construct_one_at_endIJS6_EEEvDpOT_ = Module["__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE22__construct_one_at_endIJS6_EEEvDpOT_"] = function() {
                return (__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE22__construct_one_at_endIJS6_EEEvDpOT_ = Module["__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE22__construct_one_at_endIJS6_EEEvDpOT_"] = Module["asm"]["_ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE22__construct_one_at_endIJS6_EEEvDpOT_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE21__push_back_slow_pathIS6_EEvOT_ = Module["__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE21__push_back_slow_pathIS6_EEvOT_"] = function() {
                return (__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE21__push_back_slow_pathIS6_EEvOT_ = Module["__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE21__push_back_slow_pathIS6_EEvOT_"] = Module["asm"]["_ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE21__push_back_slow_pathIS6_EEvOT_"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRPNS_18condition_variableEEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRPNS_18condition_variableEEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRPNS_18condition_variableEEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRPNS_18condition_variableEEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRPNS_18condition_variableEEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRPNS_5mutexEEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRPNS_5mutexEEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRPNS_5mutexEEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRPNS_5mutexEEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRPNS_5mutexEEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__219__thread_struct_imp27__make_ready_at_thread_exitEPNS_17__assoc_sub_stateE = Module["__ZNSt3__219__thread_struct_imp27__make_ready_at_thread_exitEPNS_17__assoc_sub_stateE"] = function() {
                return (__ZNSt3__219__thread_struct_imp27__make_ready_at_thread_exitEPNS_17__assoc_sub_stateE = Module["__ZNSt3__219__thread_struct_imp27__make_ready_at_thread_exitEPNS_17__assoc_sub_stateE"] = Module["asm"]["_ZNSt3__219__thread_struct_imp27__make_ready_at_thread_exitEPNS_17__assoc_sub_stateE"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE9push_backERKS2_ = Module["__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE9push_backERKS2_"] = function() {
                return (__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE9push_backERKS2_ = Module["__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE9push_backERKS2_"] = Module["asm"]["_ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE9push_backERKS2_"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE9__end_capEv = Module["__ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE9__end_capEv"] = function() {
                return (__ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE9__end_capEv = Module["__ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE9__end_capEv"] = Module["asm"]["_ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE9__end_capEv"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE22__construct_one_at_endIJRKS2_EEEvDpOT_ = Module["__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE22__construct_one_at_endIJRKS2_EEEvDpOT_"] = function() {
                return (__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE22__construct_one_at_endIJRKS2_EEEvDpOT_ = Module["__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE22__construct_one_at_endIJRKS2_EEEvDpOT_"] = Module["asm"]["_ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE22__construct_one_at_endIJRKS2_EEEvDpOT_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_ = Module["__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_"] = function() {
                return (__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_ = Module["__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_"] = Module["asm"]["_ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE21__push_back_slow_pathIRKS2_EEvOT_"]).apply(null, arguments)
            };
            var __ZNSt3__215__thread_structC2Ev = Module["__ZNSt3__215__thread_structC2Ev"] = function() {
                return (__ZNSt3__215__thread_structC2Ev = Module["__ZNSt3__215__thread_structC2Ev"] = Module["asm"]["_ZNSt3__215__thread_structC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__219__thread_struct_impC2Ev = Module["__ZNSt3__219__thread_struct_impC2Ev"] = function() {
                return (__ZNSt3__219__thread_struct_impC2Ev = Module["__ZNSt3__219__thread_struct_impC2Ev"] = Module["asm"]["_ZNSt3__219__thread_struct_impC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEEC2Ev = Module["__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEEC2Ev"] = function() {
                return (__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEEC2Ev = Module["__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEEC2Ev"] = Module["asm"]["_ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEEC2Ev = Module["__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEEC2Ev"] = function() {
                return (__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEEC2Ev = Module["__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEEC2Ev"] = Module["asm"]["_ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215__thread_structD2Ev = Module["__ZNSt3__215__thread_structD2Ev"] = function() {
                return (__ZNSt3__215__thread_structD2Ev = Module["__ZNSt3__215__thread_structD2Ev"] = Module["asm"]["_ZNSt3__215__thread_structD2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__211__wrap_iterIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEE4baseEv = Module["__ZNKSt3__211__wrap_iterIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEE4baseEv"] = function() {
                return (__ZNKSt3__211__wrap_iterIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEE4baseEv = Module["__ZNKSt3__211__wrap_iterIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEE4baseEv"] = Module["asm"]["_ZNKSt3__211__wrap_iterIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEE4baseEv"]).apply(null, arguments)
            };
            var __ZNKSt3__211__wrap_iterIPPNS_17__assoc_sub_stateEE4baseEv = Module["__ZNKSt3__211__wrap_iterIPPNS_17__assoc_sub_stateEE4baseEv"] = function() {
                return (__ZNKSt3__211__wrap_iterIPPNS_17__assoc_sub_stateEE4baseEv = Module["__ZNKSt3__211__wrap_iterIPPNS_17__assoc_sub_stateEE4baseEv"] = Module["asm"]["_ZNKSt3__211__wrap_iterIPPNS_17__assoc_sub_stateEE4baseEv"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEEC2Ev = Module["__ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEEC2Ev"] = function() {
                return (__ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEEC2Ev = Module["__ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEEC2Ev"] = Module["asm"]["_ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEEC2Ev = Module["__ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEEC2Ev"] = function() {
                return (__ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEEC2Ev = Module["__ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEEC2Ev"] = Module["asm"]["_ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEEC2IDnNS_18__default_init_tagEEEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEEC2IDnNS_18__default_init_tagEEEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEEC2IDnNS_18__default_init_tagEEEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEEC2IDnNS_18__default_init_tagEEEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEEC2IDnNS_18__default_init_tagEEEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPPNS_17__assoc_sub_stateELi0ELb0EEC2IDnvEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPPNS_17__assoc_sub_stateELi0ELb0EEC2IDnvEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPPNS_17__assoc_sub_stateELi0ELb0EEC2IDnvEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPPNS_17__assoc_sub_stateELi0ELb0EEC2IDnvEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPPNS_17__assoc_sub_stateELi0ELb0EEC2IDnvEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEELi1ELb1EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEELi1ELb1EEC2ENS_18__default_init_tagE"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEELi1ELb1EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEELi1ELb1EEC2ENS_18__default_init_tagE"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEELi1ELb1EEC2ENS_18__default_init_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEEC2IDnNS_18__default_init_tagEEEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEEC2IDnNS_18__default_init_tagEEEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEEC2IDnNS_18__default_init_tagEEEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEEC2IDnNS_18__default_init_tagEEEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEEC2IDnNS_18__default_init_tagEEEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEELi0ELb0EEC2IDnvEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEELi0ELb0EEC2IDnvEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEELi0ELb0EEC2IDnvEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEELi0ELb0EEC2IDnvEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEELi0ELb0EEC2IDnvEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEELi1ELb1EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEELi1ELb1EEC2ENS_18__default_init_tagE"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEELi1ELb1EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEELi1ELb1EEC2ENS_18__default_init_tagE"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEELi1ELb1EEC2ENS_18__default_init_tagE"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE4dataEv = Module["__ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE4dataEv"] = function() {
                return (__ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE4dataEv = Module["__ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE4dataEv"] = Module["asm"]["_ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE4dataEv"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE8capacityEv = Module["__ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE8capacityEv"] = function() {
                return (__ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE8capacityEv = Module["__ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE8capacityEv"] = Module["asm"]["_ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE8capacityEv"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE4sizeEv = Module["__ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE4sizeEv"] = function() {
                return (__ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE4sizeEv = Module["__ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE4sizeEv"] = Module["asm"]["_ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE4sizeEv"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE31__annotate_contiguous_containerEPKvS7_S7_S7_ = Module["__ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE31__annotate_contiguous_containerEPKvS7_S7_S7_"] = function() {
                return (__ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE31__annotate_contiguous_containerEPKvS7_S7_S7_ = Module["__ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE31__annotate_contiguous_containerEPKvS7_S7_S7_"] = Module["asm"]["_ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE31__annotate_contiguous_containerEPKvS7_S7_S7_"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE5clearEv = Module["__ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE5clearEv"] = function() {
                return (__ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE5clearEv = Module["__ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE5clearEv"] = Module["asm"]["_ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE5clearEv"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE7__allocEv = Module["__ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE7__allocEv"] = function() {
                return (__ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE7__allocEv = Module["__ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE7__allocEv"] = Module["asm"]["_ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE7__allocEv"]).apply(null, arguments)
            };
            var __ZNKSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE8capacityEv = Module["__ZNKSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE8capacityEv"] = function() {
                return (__ZNKSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE8capacityEv = Module["__ZNKSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE8capacityEv"] = Module["asm"]["_ZNKSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE8capacityEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE10deallocateERS4_PS3_m = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE10deallocateERS4_PS3_m"] = function() {
                return (__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE10deallocateERS4_PS3_m = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE10deallocateERS4_PS3_m"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE10deallocateERS4_PS3_m"]).apply(null, arguments)
            };
            var __ZNSt3__212__to_addressIPNS_17__assoc_sub_stateEEEPT_S4_ = Module["__ZNSt3__212__to_addressIPNS_17__assoc_sub_stateEEEPT_S4_"] = function() {
                return (__ZNSt3__212__to_addressIPNS_17__assoc_sub_stateEEEPT_S4_ = Module["__ZNSt3__212__to_addressIPNS_17__assoc_sub_stateEEEPT_S4_"] = Module["asm"]["_ZNSt3__212__to_addressIPNS_17__assoc_sub_stateEEEPT_S4_"]).apply(null, arguments)
            };
            var __ZNKSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE9__end_capEv = Module["__ZNKSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE9__end_capEv"] = function() {
                return (__ZNKSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE9__end_capEv = Module["__ZNKSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE9__end_capEv"] = Module["asm"]["_ZNKSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE9__end_capEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE5firstEv"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemIPPNS_17__assoc_sub_stateELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPPNS_17__assoc_sub_stateELi0ELb0EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemIPPNS_17__assoc_sub_stateELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPPNS_17__assoc_sub_stateELi0ELb0EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemIPPNS_17__assoc_sub_stateELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE17__destruct_at_endEPS2_ = Module["__ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE17__destruct_at_endEPS2_"] = function() {
                return (__ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE17__destruct_at_endEPS2_ = Module["__ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE17__destruct_at_endEPS2_"] = Module["asm"]["_ZNSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE17__destruct_at_endEPS2_"]).apply(null, arguments)
            };
            var __ZNSt3__218__hidden_allocatorIPNS_17__assoc_sub_stateEE10deallocateEPS2_m = Module["__ZNSt3__218__hidden_allocatorIPNS_17__assoc_sub_stateEE10deallocateEPS2_m"] = function() {
                return (__ZNSt3__218__hidden_allocatorIPNS_17__assoc_sub_stateEE10deallocateEPS2_m = Module["__ZNSt3__218__hidden_allocatorIPNS_17__assoc_sub_stateEE10deallocateEPS2_m"] = Module["asm"]["_ZNSt3__218__hidden_allocatorIPNS_17__assoc_sub_stateEE10deallocateEPS2_m"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE6secondEv = Module["__ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE6secondEv = Module["__ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE7destroyIS3_EEvRS4_PT_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE7destroyIS3_EEvRS4_PT_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE7destroyIS3_EEvRS4_PT_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE7destroyIS3_EEvRS4_PT_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE7destroyIS3_EEvRS4_PT_"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE9__destroyIS3_EEvNS_17integral_constantIbLb0EEERS4_PT_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE9__destroyIS3_EEvNS_17integral_constantIbLb0EEERS4_PT_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE9__destroyIS3_EEvNS_17integral_constantIbLb0EEERS4_PT_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE9__destroyIS3_EEvNS_17integral_constantIbLb0EEERS4_PT_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE9__destroyIS3_EEvNS_17integral_constantIbLb0EEERS4_PT_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEELi1ELb1EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEELi1ELb1EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEELi1ELb1EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEELi1ELb1EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEELi1ELb1EE5__getEv"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE4dataEv = Module["__ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE4dataEv"] = function() {
                return (__ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE4dataEv = Module["__ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE4dataEv"] = Module["asm"]["_ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE4dataEv"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE8capacityEv = Module["__ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE8capacityEv"] = function() {
                return (__ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE8capacityEv = Module["__ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE8capacityEv"] = Module["asm"]["_ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE8capacityEv"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE4sizeEv = Module["__ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE4sizeEv"] = function() {
                return (__ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE4sizeEv = Module["__ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE4sizeEv"] = Module["asm"]["_ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE4sizeEv"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE31__annotate_contiguous_containerEPKvSB_SB_SB_ = Module["__ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE31__annotate_contiguous_containerEPKvSB_SB_SB_"] = function() {
                return (__ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE31__annotate_contiguous_containerEPKvSB_SB_SB_ = Module["__ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE31__annotate_contiguous_containerEPKvSB_SB_SB_"] = Module["asm"]["_ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE31__annotate_contiguous_containerEPKvSB_SB_SB_"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE5clearEv = Module["__ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE5clearEv"] = function() {
                return (__ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE5clearEv = Module["__ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE5clearEv"] = Module["asm"]["_ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE5clearEv"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE7__allocEv = Module["__ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE7__allocEv"] = function() {
                return (__ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE7__allocEv = Module["__ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE7__allocEv"] = Module["asm"]["_ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE7__allocEv"]).apply(null, arguments)
            };
            var __ZNKSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE8capacityEv = Module["__ZNKSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE8capacityEv"] = function() {
                return (__ZNKSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE8capacityEv = Module["__ZNKSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE8capacityEv"] = Module["asm"]["_ZNKSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE8capacityEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE10deallocateERS8_PS7_m = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE10deallocateERS8_PS7_m"] = function() {
                return (__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE10deallocateERS8_PS7_m = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE10deallocateERS8_PS7_m"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE10deallocateERS8_PS7_m"]).apply(null, arguments)
            };
            var __ZNSt3__212__to_addressINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEPT_S8_ = Module["__ZNSt3__212__to_addressINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEPT_S8_"] = function() {
                return (__ZNSt3__212__to_addressINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEPT_S8_ = Module["__ZNSt3__212__to_addressINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEPT_S8_"] = Module["asm"]["_ZNSt3__212__to_addressINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEPT_S8_"]).apply(null, arguments)
            };
            var __ZNKSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE9__end_capEv = Module["__ZNKSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE9__end_capEv"] = function() {
                return (__ZNKSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE9__end_capEv = Module["__ZNKSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE9__end_capEv"] = Module["asm"]["_ZNKSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE9__end_capEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE5firstEv"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEELi0ELb0EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEELi0ELb0EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE17__destruct_at_endEPS6_ = Module["__ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE17__destruct_at_endEPS6_"] = function() {
                return (__ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE17__destruct_at_endEPS6_ = Module["__ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE17__destruct_at_endEPS6_"] = Module["asm"]["_ZNSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE17__destruct_at_endEPS6_"]).apply(null, arguments)
            };
            var __ZNSt3__218__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEE10deallocateEPS6_m = Module["__ZNSt3__218__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEE10deallocateEPS6_m"] = function() {
                return (__ZNSt3__218__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEE10deallocateEPS6_m = Module["__ZNSt3__218__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEE10deallocateEPS6_m"] = Module["asm"]["_ZNSt3__218__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEE10deallocateEPS6_m"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE6secondEv = Module["__ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE6secondEv = Module["__ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE7destroyIS7_EEvRS8_PT_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE7destroyIS7_EEvRS8_PT_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE7destroyIS7_EEvRS8_PT_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE7destroyIS7_EEvRS8_PT_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE7destroyIS7_EEvRS8_PT_"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE9__destroyIS7_EEvNS_17integral_constantIbLb0EEERS8_PT_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE9__destroyIS7_EEvNS_17integral_constantIbLb0EEERS8_PT_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE9__destroyIS7_EEvNS_17integral_constantIbLb0EEERS8_PT_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE9__destroyIS7_EEvNS_17integral_constantIbLb0EEERS8_PT_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE9__destroyIS7_EEvNS_17integral_constantIbLb0EEERS8_PT_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEELi1ELb1EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEELi1ELb1EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEELi1ELb1EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEELi1ELb1EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEELi1ELb1EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__211__wrap_iterIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEC2ES7_ = Module["__ZNSt3__211__wrap_iterIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEC2ES7_"] = function() {
                return (__ZNSt3__211__wrap_iterIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEC2ES7_ = Module["__ZNSt3__211__wrap_iterIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEC2ES7_"] = Module["asm"]["_ZNSt3__211__wrap_iterIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEC2ES7_"]).apply(null, arguments)
            };
            var __ZNSt3__211__wrap_iterIPPNS_17__assoc_sub_stateEEC2ES3_ = Module["__ZNSt3__211__wrap_iterIPPNS_17__assoc_sub_stateEEC2ES3_"] = function() {
                return (__ZNSt3__211__wrap_iterIPPNS_17__assoc_sub_stateEEC2ES3_ = Module["__ZNSt3__211__wrap_iterIPPNS_17__assoc_sub_stateEEC2ES3_"] = Module["asm"]["_ZNSt3__211__wrap_iterIPPNS_17__assoc_sub_stateEEC2ES3_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE5firstEv = Module["__ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE5firstEv = Module["__ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE21_ConstructTransactionC2ERS9_m = Module["__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE21_ConstructTransactionC2ERS9_m"] = function() {
                return (__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE21_ConstructTransactionC2ERS9_m = Module["__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE21_ConstructTransactionC2ERS9_m"] = Module["asm"]["_ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE21_ConstructTransactionC2ERS9_m"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEOT_RNS_16remove_referenceIS7_E4typeE = Module["__ZNSt3__27forwardINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEOT_RNS_16remove_referenceIS7_E4typeE"] = function() {
                return (__ZNSt3__27forwardINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEOT_RNS_16remove_referenceIS7_E4typeE = Module["__ZNSt3__27forwardINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEOT_RNS_16remove_referenceIS7_E4typeE"] = Module["asm"]["_ZNSt3__27forwardINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEOT_RNS_16remove_referenceIS7_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE9constructIS7_JS7_EEEvRS8_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE9constructIS7_JS7_EEEvRS8_PT_DpOT0_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE9constructIS7_JS7_EEEvRS8_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE9constructIS7_JS7_EEEvRS8_PT_DpOT0_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE9constructIS7_JS7_EEEvRS8_PT_DpOT0_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE21_ConstructTransactionD2Ev = Module["__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE21_ConstructTransactionD2Ev"] = function() {
                return (__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE21_ConstructTransactionD2Ev = Module["__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE21_ConstructTransactionD2Ev"] = Module["asm"]["_ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE21_ConstructTransactionD2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE11__recommendEm = Module["__ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE11__recommendEm"] = function() {
                return (__ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE11__recommendEm = Module["__ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE11__recommendEm"] = Module["asm"]["_ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE11__recommendEm"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEEC2EmmS9_ = Module["__ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEEC2EmmS9_"] = function() {
                return (__ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEEC2EmmS9_ = Module["__ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEEC2EmmS9_"] = Module["asm"]["_ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEEC2EmmS9_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS8_EE = Module["__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS8_EE"] = function() {
                return (__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS8_EE = Module["__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS8_EE"] = Module["asm"]["_ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS6_RS8_EE"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEED2Ev = Module["__ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEED2Ev"] = function() {
                return (__ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEED2Ev = Module["__ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEED2Ev"] = Module["asm"]["_ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEELi0ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEELi0ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE11__constructIS7_JS7_EEEvNS_17integral_constantIbLb0EEERS8_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE11__constructIS7_JS7_EEEvNS_17integral_constantIbLb0EEERS8_PT_DpOT0_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE11__constructIS7_JS7_EEEvNS_17integral_constantIbLb0EEERS8_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE11__constructIS7_JS7_EEEvNS_17integral_constantIbLb0EEERS8_PT_DpOT0_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE11__constructIS7_JS7_EEEvNS_17integral_constantIbLb0EEERS8_PT_DpOT0_"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE8max_sizeEv = Module["__ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE8max_sizeEv"] = function() {
                return (__ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE8max_sizeEv = Module["__ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE8max_sizeEv"] = Module["asm"]["_ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE8max_sizeEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEEC2IDnSA_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEEC2IDnSA_EEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEEC2IDnSA_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEEC2IDnSA_EEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEEC2IDnSA_EEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE7__allocEv = Module["__ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE7__allocEv"] = function() {
                return (__ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE7__allocEv = Module["__ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE7__allocEv"] = Module["asm"]["_ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE7__allocEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE8allocateERS8_m = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE8allocateERS8_m"] = function() {
                return (__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE8allocateERS8_m = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE8allocateERS8_m"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE8allocateERS8_m"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE9__end_capEv = Module["__ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE9__end_capEv"] = function() {
                return (__ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE9__end_capEv = Module["__ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE9__end_capEv"] = Module["asm"]["_ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE9__end_capEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE46__construct_backward_with_exception_guaranteesIS7_EENS_9enable_ifIXaaooL_ZNS_17integral_constantIbLb0EE5valueEEntsr15__has_constructIS8_PT_SE_EE5valuesr31is_trivially_move_constructibleISE_EE5valueEvE4typeERS8_SF_SF_RSF_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE46__construct_backward_with_exception_guaranteesIS7_EENS_9enable_ifIXaaooL_ZNS_17integral_constantIbLb0EE5valueEEntsr15__has_constructIS8_PT_SE_EE5valuesr31is_trivially_move_constructibleISE_EE5valueEvE4typeERS8_SF_SF_RSF_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE46__construct_backward_with_exception_guaranteesIS7_EENS_9enable_ifIXaaooL_ZNS_17integral_constantIbLb0EE5valueEEntsr15__has_constructIS8_PT_SE_EE5valuesr31is_trivially_move_constructibleISE_EE5valueEvE4typeERS8_SF_SF_RSF_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE46__construct_backward_with_exception_guaranteesIS7_EENS_9enable_ifIXaaooL_ZNS_17integral_constantIbLb0EE5valueEEntsr15__has_constructIS8_PT_SE_EE5valuesr31is_trivially_move_constructibleISE_EE5valueEvE4typeERS8_SF_SF_RSF_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE46__construct_backward_with_exception_guaranteesIS7_EENS_9enable_ifIXaaooL_ZNS_17integral_constantIbLb0EE5valueEEntsr15__has_constructIS8_PT_SE_EE5valuesr31is_trivially_move_constructibleISE_EE5valueEvE4typeERS8_SF_SF_RSF_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS9_EE5valueEvE4typeERS9_SC_ = Module["__ZNSt3__24swapIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS9_EE5valueEvE4typeERS9_SC_"] = function() {
                return (__ZNSt3__24swapIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS9_EE5valueEvE4typeERS9_SC_ = Module["__ZNSt3__24swapIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS9_EE5valueEvE4typeERS9_SC_"] = Module["asm"]["_ZNSt3__24swapIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS9_EE5valueEvE4typeERS9_SC_"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE14__annotate_newEm = Module["__ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE14__annotate_newEm"] = function() {
                return (__ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE14__annotate_newEm = Module["__ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE14__annotate_newEm"] = Module["asm"]["_ZNKSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE14__annotate_newEm"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE26__invalidate_all_iteratorsEv = Module["__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE26__invalidate_all_iteratorsEv"] = function() {
                return (__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE26__invalidate_all_iteratorsEv = Module["__ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE26__invalidate_all_iteratorsEv"] = Module["asm"]["_ZNSt3__26vectorINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE26__invalidate_all_iteratorsEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE5clearEv = Module["__ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE5clearEv"] = function() {
                return (__ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE5clearEv = Module["__ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE5clearEv"] = Module["asm"]["_ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE5clearEv"]).apply(null, arguments)
            };
            var __ZNKSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE8capacityEv = Module["__ZNKSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE8capacityEv"] = function() {
                return (__ZNKSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE8capacityEv = Module["__ZNKSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE8capacityEv"] = Module["asm"]["_ZNKSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE8capacityEv"]).apply(null, arguments)
            };
            var __ZNKSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE7__allocEv = Module["__ZNKSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE7__allocEv"] = function() {
                return (__ZNKSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE7__allocEv = Module["__ZNKSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE7__allocEv"] = Module["asm"]["_ZNKSt3__213__vector_baseINS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE7__allocEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE8max_sizeERKS8_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE8max_sizeERKS8_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE8max_sizeERKS8_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE8max_sizeERKS8_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE8max_sizeERKS8_"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE10__max_sizeENS_17integral_constantIbLb1EEERKS8_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE10__max_sizeENS_17integral_constantIbLb1EEERKS8_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE10__max_sizeENS_17integral_constantIbLb1EEERKS8_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE10__max_sizeENS_17integral_constantIbLb1EEERKS8_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEE10__max_sizeENS_17integral_constantIbLb1EEERKS8_"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE6secondEv = Module["__ZNKSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE6secondEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE6secondEv = Module["__ZNKSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE6secondEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEENS_18__hidden_allocatorIS6_EEE6secondEv"]).apply(null, arguments)
            };
            var __ZNKSt3__218__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEE8max_sizeEv = Module["__ZNKSt3__218__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEE8max_sizeEv"] = function() {
                return (__ZNKSt3__218__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEE8max_sizeEv = Module["__ZNKSt3__218__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEE8max_sizeEv"] = Module["asm"]["_ZNKSt3__218__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEE8max_sizeEv"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEELi1ELb1EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEELi1ELb1EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEELi1ELb1EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEELi1ELb1EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemINS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEELi1ELb1EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRNS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEEEOT_RNS_16remove_referenceISA_E4typeE = Module["__ZNSt3__27forwardIRNS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEEEOT_RNS_16remove_referenceISA_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRNS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEEEOT_RNS_16remove_referenceISA_E4typeE = Module["__ZNSt3__27forwardIRNS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEEEOT_RNS_16remove_referenceISA_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRNS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEEEOT_RNS_16remove_referenceISA_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIRNS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEELi1ELb0EEC2IS9_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIRNS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEELi1ELb0EEC2IS9_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIRNS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEELi1ELb0EEC2IS9_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIRNS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEELi1ELb0EEC2IS9_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIRNS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEELi1ELb0EEC2IS9_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__218__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEE8allocateEm = Module["__ZNSt3__218__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEE8allocateEm"] = function() {
                return (__ZNSt3__218__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEE8allocateEm = Module["__ZNSt3__218__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEE8allocateEm"] = Module["asm"]["_ZNSt3__218__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEE8allocateEm"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE6secondEv = Module["__ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE6secondEv = Module["__ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE5firstEv = Module["__ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE5firstEv = Module["__ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIRNS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIRNS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEELi1ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIRNS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIRNS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEELi1ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIRNS_18__hidden_allocatorINS_4pairIPNS_18condition_variableEPNS_5mutexEEEEELi1ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEONS_16remove_referenceIT_E4typeEOSA_ = Module["__ZNSt3__24moveIRPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEONS_16remove_referenceIT_E4typeEOSA_"] = function() {
                return (__ZNSt3__24moveIRPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEONS_16remove_referenceIT_E4typeEOSA_ = Module["__ZNSt3__24moveIRPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEONS_16remove_referenceIT_E4typeEOSA_"] = Module["asm"]["_ZNSt3__24moveIRPNS_4pairIPNS_18condition_variableEPNS_5mutexEEEEEONS_16remove_referenceIT_E4typeEOSA_"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE17__destruct_at_endEPS6_ = Module["__ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE17__destruct_at_endEPS6_"] = function() {
                return (__ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE17__destruct_at_endEPS6_ = Module["__ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE17__destruct_at_endEPS6_"] = Module["asm"]["_ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE17__destruct_at_endEPS6_"]).apply(null, arguments)
            };
            var __ZNKSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE9__end_capEv = Module["__ZNKSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE9__end_capEv"] = function() {
                return (__ZNKSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE9__end_capEv = Module["__ZNKSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE9__end_capEv"] = Module["asm"]["_ZNKSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE9__end_capEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE17__destruct_at_endEPS6_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE17__destruct_at_endEPS6_NS_17integral_constantIbLb0EEE"] = function() {
                return (__ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE17__destruct_at_endEPS6_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE17__destruct_at_endEPS6_NS_17integral_constantIbLb0EEE"] = Module["asm"]["_ZNSt3__214__split_bufferINS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE17__destruct_at_endEPS6_NS_17integral_constantIbLb0EEE"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPNS_4pairIPNS_18condition_variableEPNS_5mutexEEERNS_18__hidden_allocatorIS6_EEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE5firstEv = Module["__ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE5firstEv = Module["__ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE21_ConstructTransactionC2ERS5_m = Module["__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE21_ConstructTransactionC2ERS5_m"] = function() {
                return (__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE21_ConstructTransactionC2ERS5_m = Module["__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE21_ConstructTransactionC2ERS5_m"] = Module["asm"]["_ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE21_ConstructTransactionC2ERS5_m"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRKPNS_17__assoc_sub_stateEEEOT_RNS_16remove_referenceIS5_E4typeE = Module["__ZNSt3__27forwardIRKPNS_17__assoc_sub_stateEEEOT_RNS_16remove_referenceIS5_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRKPNS_17__assoc_sub_stateEEEOT_RNS_16remove_referenceIS5_E4typeE = Module["__ZNSt3__27forwardIRKPNS_17__assoc_sub_stateEEEOT_RNS_16remove_referenceIS5_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRKPNS_17__assoc_sub_stateEEEOT_RNS_16remove_referenceIS5_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE9constructIS3_JRKS3_EEEvRS4_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE9constructIS3_JRKS3_EEEvRS4_PT_DpOT0_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE9constructIS3_JRKS3_EEEvRS4_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE9constructIS3_JRKS3_EEEvRS4_PT_DpOT0_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE9constructIS3_JRKS3_EEEvRS4_PT_DpOT0_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE21_ConstructTransactionD2Ev = Module["__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE21_ConstructTransactionD2Ev"] = function() {
                return (__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE21_ConstructTransactionD2Ev = Module["__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE21_ConstructTransactionD2Ev"] = Module["asm"]["_ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE21_ConstructTransactionD2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE11__recommendEm = Module["__ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE11__recommendEm"] = function() {
                return (__ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE11__recommendEm = Module["__ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE11__recommendEm"] = Module["asm"]["_ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE11__recommendEm"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEEC2EmmS5_ = Module["__ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEEC2EmmS5_"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEEC2EmmS5_ = Module["__ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEEC2EmmS5_"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEEC2EmmS5_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE = Module["__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE"] = function() {
                return (__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE = Module["__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE"] = Module["asm"]["_ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS2_RS4_EE"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEED2Ev = Module["__ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEED2Ev"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEED2Ev = Module["__ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEED2Ev"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPPNS_17__assoc_sub_stateELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPPNS_17__assoc_sub_stateELi0ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPPNS_17__assoc_sub_stateELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPPNS_17__assoc_sub_stateELi0ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPPNS_17__assoc_sub_stateELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE11__constructIS3_JRKS3_EEEvNS_17integral_constantIbLb0EEERS4_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE11__constructIS3_JRKS3_EEEvNS_17integral_constantIbLb0EEERS4_PT_DpOT0_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE11__constructIS3_JRKS3_EEEvNS_17integral_constantIbLb0EEERS4_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE11__constructIS3_JRKS3_EEEvNS_17integral_constantIbLb0EEERS4_PT_DpOT0_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE11__constructIS3_JRKS3_EEEvNS_17integral_constantIbLb0EEERS4_PT_DpOT0_"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE8max_sizeEv = Module["__ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE8max_sizeEv"] = function() {
                return (__ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE8max_sizeEv = Module["__ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE8max_sizeEv"] = Module["asm"]["_ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE8max_sizeEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEEC2IDnS6_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEEC2IDnS6_EEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEEC2IDnS6_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEEC2IDnS6_EEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEEC2IDnS6_EEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE7__allocEv = Module["__ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE7__allocEv"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE7__allocEv = Module["__ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE7__allocEv"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE7__allocEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE8allocateERS4_m = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE8allocateERS4_m"] = function() {
                return (__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE8allocateERS4_m = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE8allocateERS4_m"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE8allocateERS4_m"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE9__end_capEv = Module["__ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE9__end_capEv"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE9__end_capEv = Module["__ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE9__end_capEv"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE9__end_capEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE46__construct_backward_with_exception_guaranteesIS3_EENS_9enable_ifIXaaooL_ZNS_17integral_constantIbLb0EE5valueEEntsr15__has_constructIS4_PT_SA_EE5valuesr31is_trivially_move_constructibleISA_EE5valueEvE4typeERS4_SB_SB_RSB_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE46__construct_backward_with_exception_guaranteesIS3_EENS_9enable_ifIXaaooL_ZNS_17integral_constantIbLb0EE5valueEEntsr15__has_constructIS4_PT_SA_EE5valuesr31is_trivially_move_constructibleISA_EE5valueEvE4typeERS4_SB_SB_RSB_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE46__construct_backward_with_exception_guaranteesIS3_EENS_9enable_ifIXaaooL_ZNS_17integral_constantIbLb0EE5valueEEntsr15__has_constructIS4_PT_SA_EE5valuesr31is_trivially_move_constructibleISA_EE5valueEvE4typeERS4_SB_SB_RSB_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE46__construct_backward_with_exception_guaranteesIS3_EENS_9enable_ifIXaaooL_ZNS_17integral_constantIbLb0EE5valueEEntsr15__has_constructIS4_PT_SA_EE5valuesr31is_trivially_move_constructibleISA_EE5valueEvE4typeERS4_SB_SB_RSB_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE46__construct_backward_with_exception_guaranteesIS3_EENS_9enable_ifIXaaooL_ZNS_17integral_constantIbLb0EE5valueEEntsr15__has_constructIS4_PT_SA_EE5valuesr31is_trivially_move_constructibleISA_EE5valueEvE4typeERS4_SB_SB_RSB_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIPPNS_17__assoc_sub_stateEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS5_EE5valueEvE4typeERS5_S8_ = Module["__ZNSt3__24swapIPPNS_17__assoc_sub_stateEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS5_EE5valueEvE4typeERS5_S8_"] = function() {
                return (__ZNSt3__24swapIPPNS_17__assoc_sub_stateEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS5_EE5valueEvE4typeERS5_S8_ = Module["__ZNSt3__24swapIPPNS_17__assoc_sub_stateEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS5_EE5valueEvE4typeERS5_S8_"] = Module["asm"]["_ZNSt3__24swapIPPNS_17__assoc_sub_stateEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS5_EE5valueEvE4typeERS5_S8_"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE14__annotate_newEm = Module["__ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE14__annotate_newEm"] = function() {
                return (__ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE14__annotate_newEm = Module["__ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE14__annotate_newEm"] = Module["asm"]["_ZNKSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE14__annotate_newEm"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE26__invalidate_all_iteratorsEv = Module["__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE26__invalidate_all_iteratorsEv"] = function() {
                return (__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE26__invalidate_all_iteratorsEv = Module["__ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE26__invalidate_all_iteratorsEv"] = Module["asm"]["_ZNSt3__26vectorIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE26__invalidate_all_iteratorsEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE5clearEv = Module["__ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE5clearEv"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE5clearEv = Module["__ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE5clearEv"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE5clearEv"]).apply(null, arguments)
            };
            var __ZNKSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE8capacityEv = Module["__ZNKSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE8capacityEv"] = function() {
                return (__ZNKSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE8capacityEv = Module["__ZNKSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE8capacityEv"] = Module["asm"]["_ZNKSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE8capacityEv"]).apply(null, arguments)
            };
            var __ZNKSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE7__allocEv = Module["__ZNKSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE7__allocEv"] = function() {
                return (__ZNKSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE7__allocEv = Module["__ZNKSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE7__allocEv"] = Module["asm"]["_ZNKSt3__213__vector_baseIPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE7__allocEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE8max_sizeERKS4_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE8max_sizeERKS4_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE8max_sizeERKS4_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE8max_sizeERKS4_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE8max_sizeERKS4_"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE10__max_sizeENS_17integral_constantIbLb1EEERKS4_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE10__max_sizeENS_17integral_constantIbLb1EEERKS4_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE10__max_sizeENS_17integral_constantIbLb1EEERKS4_ = Module["__ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE10__max_sizeENS_17integral_constantIbLb1EEERKS4_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEE10__max_sizeENS_17integral_constantIbLb1EEERKS4_"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE6secondEv = Module["__ZNKSt3__217__compressed_pairIPPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE6secondEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE6secondEv = Module["__ZNKSt3__217__compressed_pairIPPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE6secondEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPPNS_17__assoc_sub_stateENS_18__hidden_allocatorIS2_EEE6secondEv"]).apply(null, arguments)
            };
            var __ZNKSt3__218__hidden_allocatorIPNS_17__assoc_sub_stateEE8max_sizeEv = Module["__ZNKSt3__218__hidden_allocatorIPNS_17__assoc_sub_stateEE8max_sizeEv"] = function() {
                return (__ZNKSt3__218__hidden_allocatorIPNS_17__assoc_sub_stateEE8max_sizeEv = Module["__ZNKSt3__218__hidden_allocatorIPNS_17__assoc_sub_stateEE8max_sizeEv"] = Module["asm"]["_ZNKSt3__218__hidden_allocatorIPNS_17__assoc_sub_stateEE8max_sizeEv"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEELi1ELb1EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEELi1ELb1EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEELi1ELb1EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEELi1ELb1EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemINS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEELi1ELb1EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRNS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEEEOT_RNS_16remove_referenceIS6_E4typeE = Module["__ZNSt3__27forwardIRNS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEEEOT_RNS_16remove_referenceIS6_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRNS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEEEOT_RNS_16remove_referenceIS6_E4typeE = Module["__ZNSt3__27forwardIRNS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEEEOT_RNS_16remove_referenceIS6_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRNS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEEEEOT_RNS_16remove_referenceIS6_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIRNS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEELi1ELb0EEC2IS5_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIRNS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEELi1ELb0EEC2IS5_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIRNS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEELi1ELb0EEC2IS5_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIRNS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEELi1ELb0EEC2IS5_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIRNS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEELi1ELb0EEC2IS5_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__218__hidden_allocatorIPNS_17__assoc_sub_stateEE8allocateEm = Module["__ZNSt3__218__hidden_allocatorIPNS_17__assoc_sub_stateEE8allocateEm"] = function() {
                return (__ZNSt3__218__hidden_allocatorIPNS_17__assoc_sub_stateEE8allocateEm = Module["__ZNSt3__218__hidden_allocatorIPNS_17__assoc_sub_stateEE8allocateEm"] = Module["asm"]["_ZNSt3__218__hidden_allocatorIPNS_17__assoc_sub_stateEE8allocateEm"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE6secondEv = Module["__ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE6secondEv = Module["__ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE5firstEv = Module["__ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE5firstEv = Module["__ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIRNS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIRNS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEELi1ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIRNS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIRNS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEELi1ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIRNS_18__hidden_allocatorIPNS_17__assoc_sub_stateEEELi1ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRPPNS_17__assoc_sub_stateEEEONS_16remove_referenceIT_E4typeEOS6_ = Module["__ZNSt3__24moveIRPPNS_17__assoc_sub_stateEEEONS_16remove_referenceIT_E4typeEOS6_"] = function() {
                return (__ZNSt3__24moveIRPPNS_17__assoc_sub_stateEEEONS_16remove_referenceIT_E4typeEOS6_ = Module["__ZNSt3__24moveIRPPNS_17__assoc_sub_stateEEEONS_16remove_referenceIT_E4typeEOS6_"] = Module["asm"]["_ZNSt3__24moveIRPPNS_17__assoc_sub_stateEEEONS_16remove_referenceIT_E4typeEOS6_"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE17__destruct_at_endEPS2_ = Module["__ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE17__destruct_at_endEPS2_"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE17__destruct_at_endEPS2_ = Module["__ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE17__destruct_at_endEPS2_"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE17__destruct_at_endEPS2_"]).apply(null, arguments)
            };
            var __ZNKSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE9__end_capEv = Module["__ZNKSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE9__end_capEv"] = function() {
                return (__ZNKSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE9__end_capEv = Module["__ZNKSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE9__end_capEv"] = Module["asm"]["_ZNKSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE9__end_capEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE17__destruct_at_endEPS2_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE17__destruct_at_endEPS2_NS_17integral_constantIbLb0EEE"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE17__destruct_at_endEPS2_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE17__destruct_at_endEPS2_NS_17integral_constantIbLb0EEE"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE17__destruct_at_endEPS2_NS_17integral_constantIbLb0EEE"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPPNS_17__assoc_sub_stateERNS_18__hidden_allocatorIS2_EEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__26threadD1Ev = Module["__ZNSt3__26threadD1Ev"] = function() {
                return (__ZNSt3__26threadD1Ev = Module["__ZNSt3__26threadD1Ev"] = Module["asm"]["_ZNSt3__26threadD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__219__thread_struct_impD1Ev = Module["__ZNSt3__219__thread_struct_impD1Ev"] = function() {
                return (__ZNSt3__219__thread_struct_impD1Ev = Module["__ZNSt3__219__thread_struct_impD1Ev"] = Module["asm"]["_ZNSt3__219__thread_struct_impD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215__thread_structD1Ev = Module["__ZNSt3__215__thread_structD1Ev"] = function() {
                return (__ZNSt3__215__thread_structD1Ev = Module["__ZNSt3__215__thread_structD1Ev"] = Module["asm"]["_ZNSt3__215__thread_structD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__26__sortIRNS_6__lessIccEEPcEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIccEEPcEEvT0_S5_T_"] = function() {
                return (__ZNSt3__26__sortIRNS_6__lessIccEEPcEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIccEEPcEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__26__sortIRNS_6__lessIccEEPcEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNKSt3__26__lessIccEclERKcS3_ = Module["__ZNKSt3__26__lessIccEclERKcS3_"] = function() {
                return (__ZNKSt3__26__lessIccEclERKcS3_ = Module["__ZNKSt3__26__lessIccEclERKcS3_"] = Module["asm"]["_ZNKSt3__26__lessIccEclERKcS3_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort4IRNS_6__lessIccEEPcEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIccEEPcEEjT0_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort4IRNS_6__lessIccEEPcEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIccEEPcEEjT0_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort4IRNS_6__lessIccEEPcEEjT0_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort5IRNS_6__lessIccEEPcEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIccEEPcEEjT0_S5_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort5IRNS_6__lessIccEEPcEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIccEEPcEEjT0_S5_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort5IRNS_6__lessIccEEPcEEjT0_S5_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__218__insertion_sort_3IRNS_6__lessIccEEPcEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIccEEPcEEvT0_S5_T_"] = function() {
                return (__ZNSt3__218__insertion_sort_3IRNS_6__lessIccEEPcEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIccEEPcEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__218__insertion_sort_3IRNS_6__lessIccEEPcEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort3IRNS_6__lessIccEEPcEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIccEEPcEEjT0_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort3IRNS_6__lessIccEEPcEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIccEEPcEEjT0_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort3IRNS_6__lessIccEEPcEEjT0_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIccEEPcEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIccEEPcEEbT0_S5_T_"] = function() {
                return (__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIccEEPcEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIccEEPcEEbT0_S5_T_"] = Module["asm"]["_ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIccEEPcEEbT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__26__sortIRNS_6__lessIwwEEPwEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIwwEEPwEEvT0_S5_T_"] = function() {
                return (__ZNSt3__26__sortIRNS_6__lessIwwEEPwEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIwwEEPwEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__26__sortIRNS_6__lessIwwEEPwEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNKSt3__26__lessIwwEclERKwS3_ = Module["__ZNKSt3__26__lessIwwEclERKwS3_"] = function() {
                return (__ZNKSt3__26__lessIwwEclERKwS3_ = Module["__ZNKSt3__26__lessIwwEclERKwS3_"] = Module["asm"]["_ZNKSt3__26__lessIwwEclERKwS3_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort4IRNS_6__lessIwwEEPwEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIwwEEPwEEjT0_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort4IRNS_6__lessIwwEEPwEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIwwEEPwEEjT0_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort4IRNS_6__lessIwwEEPwEEjT0_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort5IRNS_6__lessIwwEEPwEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIwwEEPwEEjT0_S5_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort5IRNS_6__lessIwwEEPwEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIwwEEPwEEjT0_S5_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort5IRNS_6__lessIwwEEPwEEjT0_S5_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__218__insertion_sort_3IRNS_6__lessIwwEEPwEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIwwEEPwEEvT0_S5_T_"] = function() {
                return (__ZNSt3__218__insertion_sort_3IRNS_6__lessIwwEEPwEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIwwEEPwEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__218__insertion_sort_3IRNS_6__lessIwwEEPwEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort3IRNS_6__lessIwwEEPwEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIwwEEPwEEjT0_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort3IRNS_6__lessIwwEEPwEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIwwEEPwEEjT0_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort3IRNS_6__lessIwwEEPwEEjT0_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIwwEEPwEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIwwEEPwEEbT0_S5_T_"] = function() {
                return (__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIwwEEPwEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIwwEEPwEEbT0_S5_T_"] = Module["asm"]["_ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIwwEEPwEEbT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__26__sortIRNS_6__lessIaaEEPaEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIaaEEPaEEvT0_S5_T_"] = function() {
                return (__ZNSt3__26__sortIRNS_6__lessIaaEEPaEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIaaEEPaEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__26__sortIRNS_6__lessIaaEEPaEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNKSt3__26__lessIaaEclERKaS3_ = Module["__ZNKSt3__26__lessIaaEclERKaS3_"] = function() {
                return (__ZNKSt3__26__lessIaaEclERKaS3_ = Module["__ZNKSt3__26__lessIaaEclERKaS3_"] = Module["asm"]["_ZNKSt3__26__lessIaaEclERKaS3_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIaEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIaEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = function() {
                return (__ZNSt3__24swapIaEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIaEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = Module["asm"]["_ZNSt3__24swapIaEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort4IRNS_6__lessIaaEEPaEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIaaEEPaEEjT0_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort4IRNS_6__lessIaaEEPaEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIaaEEPaEEjT0_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort4IRNS_6__lessIaaEEPaEEjT0_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort5IRNS_6__lessIaaEEPaEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIaaEEPaEEjT0_S5_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort5IRNS_6__lessIaaEEPaEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIaaEEPaEEjT0_S5_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort5IRNS_6__lessIaaEEPaEEjT0_S5_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__218__insertion_sort_3IRNS_6__lessIaaEEPaEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIaaEEPaEEvT0_S5_T_"] = function() {
                return (__ZNSt3__218__insertion_sort_3IRNS_6__lessIaaEEPaEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIaaEEPaEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__218__insertion_sort_3IRNS_6__lessIaaEEPaEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort3IRNS_6__lessIaaEEPaEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIaaEEPaEEjT0_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort3IRNS_6__lessIaaEEPaEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIaaEEPaEEjT0_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort3IRNS_6__lessIaaEEPaEEjT0_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIaaEEPaEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIaaEEPaEEbT0_S5_T_"] = function() {
                return (__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIaaEEPaEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIaaEEPaEEbT0_S5_T_"] = Module["asm"]["_ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIaaEEPaEEbT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRaEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRaEEONS_16remove_referenceIT_E4typeEOS3_"] = function() {
                return (__ZNSt3__24moveIRaEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRaEEONS_16remove_referenceIT_E4typeEOS3_"] = Module["asm"]["_ZNSt3__24moveIRaEEONS_16remove_referenceIT_E4typeEOS3_"]).apply(null, arguments)
            };
            var __ZNSt3__26__sortIRNS_6__lessIhhEEPhEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIhhEEPhEEvT0_S5_T_"] = function() {
                return (__ZNSt3__26__sortIRNS_6__lessIhhEEPhEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIhhEEPhEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__26__sortIRNS_6__lessIhhEEPhEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNKSt3__26__lessIhhEclERKhS3_ = Module["__ZNKSt3__26__lessIhhEclERKhS3_"] = function() {
                return (__ZNKSt3__26__lessIhhEclERKhS3_ = Module["__ZNKSt3__26__lessIhhEclERKhS3_"] = Module["asm"]["_ZNKSt3__26__lessIhhEclERKhS3_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIhEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIhEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = function() {
                return (__ZNSt3__24swapIhEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIhEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = Module["asm"]["_ZNSt3__24swapIhEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort4IRNS_6__lessIhhEEPhEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIhhEEPhEEjT0_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort4IRNS_6__lessIhhEEPhEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIhhEEPhEEjT0_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort4IRNS_6__lessIhhEEPhEEjT0_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort5IRNS_6__lessIhhEEPhEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIhhEEPhEEjT0_S5_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort5IRNS_6__lessIhhEEPhEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIhhEEPhEEjT0_S5_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort5IRNS_6__lessIhhEEPhEEjT0_S5_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__218__insertion_sort_3IRNS_6__lessIhhEEPhEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIhhEEPhEEvT0_S5_T_"] = function() {
                return (__ZNSt3__218__insertion_sort_3IRNS_6__lessIhhEEPhEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIhhEEPhEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__218__insertion_sort_3IRNS_6__lessIhhEEPhEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort3IRNS_6__lessIhhEEPhEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIhhEEPhEEjT0_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort3IRNS_6__lessIhhEEPhEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIhhEEPhEEjT0_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort3IRNS_6__lessIhhEEPhEEjT0_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIhhEEPhEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIhhEEPhEEbT0_S5_T_"] = function() {
                return (__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIhhEEPhEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIhhEEPhEEbT0_S5_T_"] = Module["asm"]["_ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIhhEEPhEEbT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRhEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRhEEONS_16remove_referenceIT_E4typeEOS3_"] = function() {
                return (__ZNSt3__24moveIRhEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRhEEONS_16remove_referenceIT_E4typeEOS3_"] = Module["asm"]["_ZNSt3__24moveIRhEEONS_16remove_referenceIT_E4typeEOS3_"]).apply(null, arguments)
            };
            var __ZNSt3__26__sortIRNS_6__lessIssEEPsEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIssEEPsEEvT0_S5_T_"] = function() {
                return (__ZNSt3__26__sortIRNS_6__lessIssEEPsEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIssEEPsEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__26__sortIRNS_6__lessIssEEPsEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNKSt3__26__lessIssEclERKsS3_ = Module["__ZNKSt3__26__lessIssEclERKsS3_"] = function() {
                return (__ZNKSt3__26__lessIssEclERKsS3_ = Module["__ZNKSt3__26__lessIssEclERKsS3_"] = Module["asm"]["_ZNKSt3__26__lessIssEclERKsS3_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIsEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIsEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = function() {
                return (__ZNSt3__24swapIsEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIsEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = Module["asm"]["_ZNSt3__24swapIsEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort4IRNS_6__lessIssEEPsEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIssEEPsEEjT0_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort4IRNS_6__lessIssEEPsEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIssEEPsEEjT0_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort4IRNS_6__lessIssEEPsEEjT0_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort5IRNS_6__lessIssEEPsEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIssEEPsEEjT0_S5_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort5IRNS_6__lessIssEEPsEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIssEEPsEEjT0_S5_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort5IRNS_6__lessIssEEPsEEjT0_S5_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__218__insertion_sort_3IRNS_6__lessIssEEPsEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIssEEPsEEvT0_S5_T_"] = function() {
                return (__ZNSt3__218__insertion_sort_3IRNS_6__lessIssEEPsEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIssEEPsEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__218__insertion_sort_3IRNS_6__lessIssEEPsEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort3IRNS_6__lessIssEEPsEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIssEEPsEEjT0_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort3IRNS_6__lessIssEEPsEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIssEEPsEEjT0_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort3IRNS_6__lessIssEEPsEEjT0_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIssEEPsEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIssEEPsEEbT0_S5_T_"] = function() {
                return (__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIssEEPsEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIssEEPsEEbT0_S5_T_"] = Module["asm"]["_ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIssEEPsEEbT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRsEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRsEEONS_16remove_referenceIT_E4typeEOS3_"] = function() {
                return (__ZNSt3__24moveIRsEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRsEEONS_16remove_referenceIT_E4typeEOS3_"] = Module["asm"]["_ZNSt3__24moveIRsEEONS_16remove_referenceIT_E4typeEOS3_"]).apply(null, arguments)
            };
            var __ZNSt3__26__sortIRNS_6__lessIttEEPtEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIttEEPtEEvT0_S5_T_"] = function() {
                return (__ZNSt3__26__sortIRNS_6__lessIttEEPtEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIttEEPtEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__26__sortIRNS_6__lessIttEEPtEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNKSt3__26__lessIttEclERKtS3_ = Module["__ZNKSt3__26__lessIttEclERKtS3_"] = function() {
                return (__ZNKSt3__26__lessIttEclERKtS3_ = Module["__ZNKSt3__26__lessIttEclERKtS3_"] = Module["asm"]["_ZNKSt3__26__lessIttEclERKtS3_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapItEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapItEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = function() {
                return (__ZNSt3__24swapItEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapItEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = Module["asm"]["_ZNSt3__24swapItEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort4IRNS_6__lessIttEEPtEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIttEEPtEEjT0_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort4IRNS_6__lessIttEEPtEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIttEEPtEEjT0_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort4IRNS_6__lessIttEEPtEEjT0_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort5IRNS_6__lessIttEEPtEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIttEEPtEEjT0_S5_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort5IRNS_6__lessIttEEPtEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIttEEPtEEjT0_S5_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort5IRNS_6__lessIttEEPtEEjT0_S5_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__218__insertion_sort_3IRNS_6__lessIttEEPtEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIttEEPtEEvT0_S5_T_"] = function() {
                return (__ZNSt3__218__insertion_sort_3IRNS_6__lessIttEEPtEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIttEEPtEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__218__insertion_sort_3IRNS_6__lessIttEEPtEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort3IRNS_6__lessIttEEPtEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIttEEPtEEjT0_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort3IRNS_6__lessIttEEPtEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIttEEPtEEjT0_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort3IRNS_6__lessIttEEPtEEjT0_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIttEEPtEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIttEEPtEEbT0_S5_T_"] = function() {
                return (__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIttEEPtEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIttEEPtEEbT0_S5_T_"] = Module["asm"]["_ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIttEEPtEEbT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRtEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRtEEONS_16remove_referenceIT_E4typeEOS3_"] = function() {
                return (__ZNSt3__24moveIRtEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRtEEONS_16remove_referenceIT_E4typeEOS3_"] = Module["asm"]["_ZNSt3__24moveIRtEEONS_16remove_referenceIT_E4typeEOS3_"]).apply(null, arguments)
            };
            var __ZNSt3__26__sortIRNS_6__lessIiiEEPiEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIiiEEPiEEvT0_S5_T_"] = function() {
                return (__ZNSt3__26__sortIRNS_6__lessIiiEEPiEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIiiEEPiEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__26__sortIRNS_6__lessIiiEEPiEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort4IRNS_6__lessIiiEEPiEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIiiEEPiEEjT0_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort4IRNS_6__lessIiiEEPiEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIiiEEPiEEjT0_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort4IRNS_6__lessIiiEEPiEEjT0_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort5IRNS_6__lessIiiEEPiEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIiiEEPiEEjT0_S5_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort5IRNS_6__lessIiiEEPiEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIiiEEPiEEjT0_S5_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort5IRNS_6__lessIiiEEPiEEjT0_S5_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__218__insertion_sort_3IRNS_6__lessIiiEEPiEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIiiEEPiEEvT0_S5_T_"] = function() {
                return (__ZNSt3__218__insertion_sort_3IRNS_6__lessIiiEEPiEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIiiEEPiEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__218__insertion_sort_3IRNS_6__lessIiiEEPiEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort3IRNS_6__lessIiiEEPiEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIiiEEPiEEjT0_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort3IRNS_6__lessIiiEEPiEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIiiEEPiEEjT0_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort3IRNS_6__lessIiiEEPiEEjT0_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIiiEEPiEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIiiEEPiEEbT0_S5_T_"] = function() {
                return (__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIiiEEPiEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIiiEEPiEEbT0_S5_T_"] = Module["asm"]["_ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIiiEEPiEEbT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__26__sortIRNS_6__lessIjjEEPjEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIjjEEPjEEvT0_S5_T_"] = function() {
                return (__ZNSt3__26__sortIRNS_6__lessIjjEEPjEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIjjEEPjEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__26__sortIRNS_6__lessIjjEEPjEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNKSt3__26__lessIjjEclERKjS3_ = Module["__ZNKSt3__26__lessIjjEclERKjS3_"] = function() {
                return (__ZNKSt3__26__lessIjjEclERKjS3_ = Module["__ZNKSt3__26__lessIjjEclERKjS3_"] = Module["asm"]["_ZNKSt3__26__lessIjjEclERKjS3_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort4IRNS_6__lessIjjEEPjEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIjjEEPjEEjT0_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort4IRNS_6__lessIjjEEPjEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIjjEEPjEEjT0_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort4IRNS_6__lessIjjEEPjEEjT0_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort5IRNS_6__lessIjjEEPjEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIjjEEPjEEjT0_S5_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort5IRNS_6__lessIjjEEPjEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIjjEEPjEEjT0_S5_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort5IRNS_6__lessIjjEEPjEEjT0_S5_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__218__insertion_sort_3IRNS_6__lessIjjEEPjEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIjjEEPjEEvT0_S5_T_"] = function() {
                return (__ZNSt3__218__insertion_sort_3IRNS_6__lessIjjEEPjEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIjjEEPjEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__218__insertion_sort_3IRNS_6__lessIjjEEPjEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort3IRNS_6__lessIjjEEPjEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIjjEEPjEEjT0_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort3IRNS_6__lessIjjEEPjEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIjjEEPjEEjT0_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort3IRNS_6__lessIjjEEPjEEjT0_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIjjEEPjEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIjjEEPjEEbT0_S5_T_"] = function() {
                return (__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIjjEEPjEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIjjEEPjEEbT0_S5_T_"] = Module["asm"]["_ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIjjEEPjEEbT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__26__sortIRNS_6__lessIllEEPlEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIllEEPlEEvT0_S5_T_"] = function() {
                return (__ZNSt3__26__sortIRNS_6__lessIllEEPlEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIllEEPlEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__26__sortIRNS_6__lessIllEEPlEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNKSt3__26__lessIllEclERKlS3_ = Module["__ZNKSt3__26__lessIllEclERKlS3_"] = function() {
                return (__ZNKSt3__26__lessIllEclERKlS3_ = Module["__ZNKSt3__26__lessIllEclERKlS3_"] = Module["asm"]["_ZNKSt3__26__lessIllEclERKlS3_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort4IRNS_6__lessIllEEPlEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIllEEPlEEjT0_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort4IRNS_6__lessIllEEPlEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIllEEPlEEjT0_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort4IRNS_6__lessIllEEPlEEjT0_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort5IRNS_6__lessIllEEPlEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIllEEPlEEjT0_S5_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort5IRNS_6__lessIllEEPlEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIllEEPlEEjT0_S5_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort5IRNS_6__lessIllEEPlEEjT0_S5_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__218__insertion_sort_3IRNS_6__lessIllEEPlEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIllEEPlEEvT0_S5_T_"] = function() {
                return (__ZNSt3__218__insertion_sort_3IRNS_6__lessIllEEPlEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIllEEPlEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__218__insertion_sort_3IRNS_6__lessIllEEPlEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort3IRNS_6__lessIllEEPlEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIllEEPlEEjT0_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort3IRNS_6__lessIllEEPlEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIllEEPlEEjT0_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort3IRNS_6__lessIllEEPlEEjT0_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIllEEPlEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIllEEPlEEbT0_S5_T_"] = function() {
                return (__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIllEEPlEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIllEEPlEEbT0_S5_T_"] = Module["asm"]["_ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIllEEPlEEbT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__26__sortIRNS_6__lessImmEEPmEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessImmEEPmEEvT0_S5_T_"] = function() {
                return (__ZNSt3__26__sortIRNS_6__lessImmEEPmEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessImmEEPmEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__26__sortIRNS_6__lessImmEEPmEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapImEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapImEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = function() {
                return (__ZNSt3__24swapImEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapImEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = Module["asm"]["_ZNSt3__24swapImEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort4IRNS_6__lessImmEEPmEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessImmEEPmEEjT0_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort4IRNS_6__lessImmEEPmEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessImmEEPmEEjT0_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort4IRNS_6__lessImmEEPmEEjT0_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort5IRNS_6__lessImmEEPmEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessImmEEPmEEjT0_S5_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort5IRNS_6__lessImmEEPmEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessImmEEPmEEjT0_S5_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort5IRNS_6__lessImmEEPmEEjT0_S5_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__218__insertion_sort_3IRNS_6__lessImmEEPmEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessImmEEPmEEvT0_S5_T_"] = function() {
                return (__ZNSt3__218__insertion_sort_3IRNS_6__lessImmEEPmEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessImmEEPmEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__218__insertion_sort_3IRNS_6__lessImmEEPmEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort3IRNS_6__lessImmEEPmEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessImmEEPmEEjT0_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort3IRNS_6__lessImmEEPmEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessImmEEPmEEjT0_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort3IRNS_6__lessImmEEPmEEjT0_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__227__insertion_sort_incompleteIRNS_6__lessImmEEPmEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessImmEEPmEEbT0_S5_T_"] = function() {
                return (__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessImmEEPmEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessImmEEPmEEbT0_S5_T_"] = Module["asm"]["_ZNSt3__227__insertion_sort_incompleteIRNS_6__lessImmEEPmEEbT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRmEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRmEEONS_16remove_referenceIT_E4typeEOS3_"] = function() {
                return (__ZNSt3__24moveIRmEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRmEEONS_16remove_referenceIT_E4typeEOS3_"] = Module["asm"]["_ZNSt3__24moveIRmEEONS_16remove_referenceIT_E4typeEOS3_"]).apply(null, arguments)
            };
            var __ZNSt3__26__sortIRNS_6__lessIxxEEPxEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIxxEEPxEEvT0_S5_T_"] = function() {
                return (__ZNSt3__26__sortIRNS_6__lessIxxEEPxEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIxxEEPxEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__26__sortIRNS_6__lessIxxEEPxEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNKSt3__26__lessIxxEclERKxS3_ = Module["__ZNKSt3__26__lessIxxEclERKxS3_"] = function() {
                return (__ZNKSt3__26__lessIxxEclERKxS3_ = Module["__ZNKSt3__26__lessIxxEclERKxS3_"] = Module["asm"]["_ZNKSt3__26__lessIxxEclERKxS3_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIxEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIxEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = function() {
                return (__ZNSt3__24swapIxEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIxEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = Module["asm"]["_ZNSt3__24swapIxEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort4IRNS_6__lessIxxEEPxEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIxxEEPxEEjT0_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort4IRNS_6__lessIxxEEPxEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIxxEEPxEEjT0_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort4IRNS_6__lessIxxEEPxEEjT0_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort5IRNS_6__lessIxxEEPxEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIxxEEPxEEjT0_S5_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort5IRNS_6__lessIxxEEPxEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIxxEEPxEEjT0_S5_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort5IRNS_6__lessIxxEEPxEEjT0_S5_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__218__insertion_sort_3IRNS_6__lessIxxEEPxEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIxxEEPxEEvT0_S5_T_"] = function() {
                return (__ZNSt3__218__insertion_sort_3IRNS_6__lessIxxEEPxEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIxxEEPxEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__218__insertion_sort_3IRNS_6__lessIxxEEPxEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort3IRNS_6__lessIxxEEPxEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIxxEEPxEEjT0_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort3IRNS_6__lessIxxEEPxEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIxxEEPxEEjT0_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort3IRNS_6__lessIxxEEPxEEjT0_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIxxEEPxEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIxxEEPxEEbT0_S5_T_"] = function() {
                return (__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIxxEEPxEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIxxEEPxEEbT0_S5_T_"] = Module["asm"]["_ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIxxEEPxEEbT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRxEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRxEEONS_16remove_referenceIT_E4typeEOS3_"] = function() {
                return (__ZNSt3__24moveIRxEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRxEEONS_16remove_referenceIT_E4typeEOS3_"] = Module["asm"]["_ZNSt3__24moveIRxEEONS_16remove_referenceIT_E4typeEOS3_"]).apply(null, arguments)
            };
            var __ZNSt3__26__sortIRNS_6__lessIyyEEPyEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIyyEEPyEEvT0_S5_T_"] = function() {
                return (__ZNSt3__26__sortIRNS_6__lessIyyEEPyEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIyyEEPyEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__26__sortIRNS_6__lessIyyEEPyEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNKSt3__26__lessIyyEclERKyS3_ = Module["__ZNKSt3__26__lessIyyEclERKyS3_"] = function() {
                return (__ZNKSt3__26__lessIyyEclERKyS3_ = Module["__ZNKSt3__26__lessIyyEclERKyS3_"] = Module["asm"]["_ZNKSt3__26__lessIyyEclERKyS3_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIyEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIyEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = function() {
                return (__ZNSt3__24swapIyEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIyEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = Module["asm"]["_ZNSt3__24swapIyEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort4IRNS_6__lessIyyEEPyEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIyyEEPyEEjT0_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort4IRNS_6__lessIyyEEPyEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIyyEEPyEEjT0_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort4IRNS_6__lessIyyEEPyEEjT0_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort5IRNS_6__lessIyyEEPyEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIyyEEPyEEjT0_S5_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort5IRNS_6__lessIyyEEPyEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIyyEEPyEEjT0_S5_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort5IRNS_6__lessIyyEEPyEEjT0_S5_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__218__insertion_sort_3IRNS_6__lessIyyEEPyEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIyyEEPyEEvT0_S5_T_"] = function() {
                return (__ZNSt3__218__insertion_sort_3IRNS_6__lessIyyEEPyEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIyyEEPyEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__218__insertion_sort_3IRNS_6__lessIyyEEPyEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort3IRNS_6__lessIyyEEPyEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIyyEEPyEEjT0_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort3IRNS_6__lessIyyEEPyEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIyyEEPyEEjT0_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort3IRNS_6__lessIyyEEPyEEjT0_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIyyEEPyEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIyyEEPyEEbT0_S5_T_"] = function() {
                return (__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIyyEEPyEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIyyEEPyEEbT0_S5_T_"] = Module["asm"]["_ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIyyEEPyEEbT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRyEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRyEEONS_16remove_referenceIT_E4typeEOS3_"] = function() {
                return (__ZNSt3__24moveIRyEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRyEEONS_16remove_referenceIT_E4typeEOS3_"] = Module["asm"]["_ZNSt3__24moveIRyEEONS_16remove_referenceIT_E4typeEOS3_"]).apply(null, arguments)
            };
            var __ZNSt3__26__sortIRNS_6__lessIffEEPfEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIffEEPfEEvT0_S5_T_"] = function() {
                return (__ZNSt3__26__sortIRNS_6__lessIffEEPfEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIffEEPfEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__26__sortIRNS_6__lessIffEEPfEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNKSt3__26__lessIffEclERKfS3_ = Module["__ZNKSt3__26__lessIffEclERKfS3_"] = function() {
                return (__ZNKSt3__26__lessIffEclERKfS3_ = Module["__ZNKSt3__26__lessIffEclERKfS3_"] = Module["asm"]["_ZNKSt3__26__lessIffEclERKfS3_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIfEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIfEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = function() {
                return (__ZNSt3__24swapIfEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIfEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = Module["asm"]["_ZNSt3__24swapIfEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort4IRNS_6__lessIffEEPfEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIffEEPfEEjT0_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort4IRNS_6__lessIffEEPfEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIffEEPfEEjT0_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort4IRNS_6__lessIffEEPfEEjT0_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort5IRNS_6__lessIffEEPfEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIffEEPfEEjT0_S5_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort5IRNS_6__lessIffEEPfEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIffEEPfEEjT0_S5_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort5IRNS_6__lessIffEEPfEEjT0_S5_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__218__insertion_sort_3IRNS_6__lessIffEEPfEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIffEEPfEEvT0_S5_T_"] = function() {
                return (__ZNSt3__218__insertion_sort_3IRNS_6__lessIffEEPfEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIffEEPfEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__218__insertion_sort_3IRNS_6__lessIffEEPfEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort3IRNS_6__lessIffEEPfEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIffEEPfEEjT0_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort3IRNS_6__lessIffEEPfEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIffEEPfEEjT0_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort3IRNS_6__lessIffEEPfEEjT0_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIffEEPfEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIffEEPfEEbT0_S5_T_"] = function() {
                return (__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIffEEPfEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIffEEPfEEbT0_S5_T_"] = Module["asm"]["_ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIffEEPfEEbT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRfEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRfEEONS_16remove_referenceIT_E4typeEOS3_"] = function() {
                return (__ZNSt3__24moveIRfEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRfEEONS_16remove_referenceIT_E4typeEOS3_"] = Module["asm"]["_ZNSt3__24moveIRfEEONS_16remove_referenceIT_E4typeEOS3_"]).apply(null, arguments)
            };
            var __ZNSt3__26__sortIRNS_6__lessIddEEPdEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIddEEPdEEvT0_S5_T_"] = function() {
                return (__ZNSt3__26__sortIRNS_6__lessIddEEPdEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIddEEPdEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__26__sortIRNS_6__lessIddEEPdEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNKSt3__26__lessIddEclERKdS3_ = Module["__ZNKSt3__26__lessIddEclERKdS3_"] = function() {
                return (__ZNKSt3__26__lessIddEclERKdS3_ = Module["__ZNKSt3__26__lessIddEclERKdS3_"] = Module["asm"]["_ZNKSt3__26__lessIddEclERKdS3_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIdEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIdEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = function() {
                return (__ZNSt3__24swapIdEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIdEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = Module["asm"]["_ZNSt3__24swapIdEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort4IRNS_6__lessIddEEPdEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIddEEPdEEjT0_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort4IRNS_6__lessIddEEPdEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIddEEPdEEjT0_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort4IRNS_6__lessIddEEPdEEjT0_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort5IRNS_6__lessIddEEPdEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIddEEPdEEjT0_S5_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort5IRNS_6__lessIddEEPdEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIddEEPdEEjT0_S5_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort5IRNS_6__lessIddEEPdEEjT0_S5_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__218__insertion_sort_3IRNS_6__lessIddEEPdEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIddEEPdEEvT0_S5_T_"] = function() {
                return (__ZNSt3__218__insertion_sort_3IRNS_6__lessIddEEPdEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIddEEPdEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__218__insertion_sort_3IRNS_6__lessIddEEPdEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort3IRNS_6__lessIddEEPdEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIddEEPdEEjT0_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort3IRNS_6__lessIddEEPdEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIddEEPdEEjT0_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort3IRNS_6__lessIddEEPdEEjT0_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIddEEPdEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIddEEPdEEbT0_S5_T_"] = function() {
                return (__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIddEEPdEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIddEEPdEEbT0_S5_T_"] = Module["asm"]["_ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIddEEPdEEbT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRdEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRdEEONS_16remove_referenceIT_E4typeEOS3_"] = function() {
                return (__ZNSt3__24moveIRdEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRdEEONS_16remove_referenceIT_E4typeEOS3_"] = Module["asm"]["_ZNSt3__24moveIRdEEONS_16remove_referenceIT_E4typeEOS3_"]).apply(null, arguments)
            };
            var __ZNSt3__26__sortIRNS_6__lessIeeEEPeEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIeeEEPeEEvT0_S5_T_"] = function() {
                return (__ZNSt3__26__sortIRNS_6__lessIeeEEPeEEvT0_S5_T_ = Module["__ZNSt3__26__sortIRNS_6__lessIeeEEPeEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__26__sortIRNS_6__lessIeeEEPeEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNKSt3__26__lessIeeEclERKeS3_ = Module["__ZNKSt3__26__lessIeeEclERKeS3_"] = function() {
                return (__ZNKSt3__26__lessIeeEclERKeS3_ = Module["__ZNKSt3__26__lessIeeEclERKeS3_"] = Module["asm"]["_ZNKSt3__26__lessIeeEclERKeS3_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIeEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIeEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = function() {
                return (__ZNSt3__24swapIeEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_ = Module["__ZNSt3__24swapIeEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"] = Module["asm"]["_ZNSt3__24swapIeEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS2_EE5valueEvE4typeERS2_S5_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort4IRNS_6__lessIeeEEPeEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIeeEEPeEEjT0_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort4IRNS_6__lessIeeEEPeEEjT0_S5_S5_S5_T_ = Module["__ZNSt3__27__sort4IRNS_6__lessIeeEEPeEEjT0_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort4IRNS_6__lessIeeEEPeEEjT0_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort5IRNS_6__lessIeeEEPeEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIeeEEPeEEjT0_S5_S5_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort5IRNS_6__lessIeeEEPeEEjT0_S5_S5_S5_S5_T_ = Module["__ZNSt3__27__sort5IRNS_6__lessIeeEEPeEEjT0_S5_S5_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort5IRNS_6__lessIeeEEPeEEjT0_S5_S5_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__218__insertion_sort_3IRNS_6__lessIeeEEPeEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIeeEEPeEEvT0_S5_T_"] = function() {
                return (__ZNSt3__218__insertion_sort_3IRNS_6__lessIeeEEPeEEvT0_S5_T_ = Module["__ZNSt3__218__insertion_sort_3IRNS_6__lessIeeEEPeEEvT0_S5_T_"] = Module["asm"]["_ZNSt3__218__insertion_sort_3IRNS_6__lessIeeEEPeEEvT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__27__sort3IRNS_6__lessIeeEEPeEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIeeEEPeEEjT0_S5_S5_T_"] = function() {
                return (__ZNSt3__27__sort3IRNS_6__lessIeeEEPeEEjT0_S5_S5_T_ = Module["__ZNSt3__27__sort3IRNS_6__lessIeeEEPeEEjT0_S5_S5_T_"] = Module["asm"]["_ZNSt3__27__sort3IRNS_6__lessIeeEEPeEEjT0_S5_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIeeEEPeEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIeeEEPeEEbT0_S5_T_"] = function() {
                return (__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIeeEEPeEEbT0_S5_T_ = Module["__ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIeeEEPeEEbT0_S5_T_"] = Module["asm"]["_ZNSt3__227__insertion_sort_incompleteIRNS_6__lessIeeEEPeEEbT0_S5_T_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIReEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIReEEONS_16remove_referenceIT_E4typeEOS3_"] = function() {
                return (__ZNSt3__24moveIReEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIReEEONS_16remove_referenceIT_E4typeEOS3_"] = Module["asm"]["_ZNSt3__24moveIReEEONS_16remove_referenceIT_E4typeEOS3_"]).apply(null, arguments)
            };
            var __ZNSt3__212__rs_defaultC2Ev = Module["__ZNSt3__212__rs_defaultC2Ev"] = function() {
                return (__ZNSt3__212__rs_defaultC2Ev = Module["__ZNSt3__212__rs_defaultC2Ev"] = Module["asm"]["_ZNSt3__212__rs_defaultC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212__rs_defaultC2ERKS0_ = Module["__ZNSt3__212__rs_defaultC2ERKS0_"] = function() {
                return (__ZNSt3__212__rs_defaultC2ERKS0_ = Module["__ZNSt3__212__rs_defaultC2ERKS0_"] = Module["asm"]["_ZNSt3__212__rs_defaultC2ERKS0_"]).apply(null, arguments)
            };
            var __ZNSt3__212__rs_defaultD2Ev = Module["__ZNSt3__212__rs_defaultD2Ev"] = function() {
                return (__ZNSt3__212__rs_defaultD2Ev = Module["__ZNSt3__212__rs_defaultD2Ev"] = Module["asm"]["_ZNSt3__212__rs_defaultD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212__rs_defaultclEv = Module["__ZNSt3__212__rs_defaultclEv"] = function() {
                return (__ZNSt3__212__rs_defaultclEv = Module["__ZNSt3__212__rs_defaultclEv"] = Module["asm"]["_ZNSt3__212__rs_defaultclEv"]).apply(null, arguments)
            };
            var __ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EEC2Ej = Module["__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EEC2Ej"] = function() {
                return (__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EEC2Ej = Module["__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EEC2Ej"] = Module["asm"]["_ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EEC2Ej"]).apply(null, arguments)
            };
            var __ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EEclEv = Module["__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EEclEv"] = function() {
                return (__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EEclEv = Module["__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EEclEv"] = Module["asm"]["_ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EEclEv"]).apply(null, arguments)
            };
            var __ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE4seedEj = Module["__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE4seedEj"] = function() {
                return (__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE4seedEj = Module["__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE4seedEj"] = Module["asm"]["_ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE4seedEj"]).apply(null, arguments)
            };
            var __ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__rshiftILm1EEENS_9enable_ifIXltT_L_ZNS1_3_DtEEEjE4typeEj = Module["__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__rshiftILm1EEENS_9enable_ifIXltT_L_ZNS1_3_DtEEEjE4typeEj"] = function() {
                return (__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__rshiftILm1EEENS_9enable_ifIXltT_L_ZNS1_3_DtEEEjE4typeEj = Module["__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__rshiftILm1EEENS_9enable_ifIXltT_L_ZNS1_3_DtEEEjE4typeEj"] = Module["asm"]["_ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__rshiftILm1EEENS_9enable_ifIXltT_L_ZNS1_3_DtEEEjE4typeEj"]).apply(null, arguments)
            };
            var __ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__rshiftILm11EEENS_9enable_ifIXltT_L_ZNS1_3_DtEEEjE4typeEj = Module["__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__rshiftILm11EEENS_9enable_ifIXltT_L_ZNS1_3_DtEEEjE4typeEj"] = function() {
                return (__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__rshiftILm11EEENS_9enable_ifIXltT_L_ZNS1_3_DtEEEjE4typeEj = Module["__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__rshiftILm11EEENS_9enable_ifIXltT_L_ZNS1_3_DtEEEjE4typeEj"] = Module["asm"]["_ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__rshiftILm11EEENS_9enable_ifIXltT_L_ZNS1_3_DtEEEjE4typeEj"]).apply(null, arguments)
            };
            var __ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__lshiftILm7EEENS_9enable_ifIXltT_Lm32EEjE4typeEj = Module["__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__lshiftILm7EEENS_9enable_ifIXltT_Lm32EEjE4typeEj"] = function() {
                return (__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__lshiftILm7EEENS_9enable_ifIXltT_Lm32EEjE4typeEj = Module["__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__lshiftILm7EEENS_9enable_ifIXltT_Lm32EEjE4typeEj"] = Module["asm"]["_ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__lshiftILm7EEENS_9enable_ifIXltT_Lm32EEjE4typeEj"]).apply(null, arguments)
            };
            var __ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__lshiftILm15EEENS_9enable_ifIXltT_Lm32EEjE4typeEj = Module["__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__lshiftILm15EEENS_9enable_ifIXltT_Lm32EEjE4typeEj"] = function() {
                return (__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__lshiftILm15EEENS_9enable_ifIXltT_Lm32EEjE4typeEj = Module["__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__lshiftILm15EEENS_9enable_ifIXltT_Lm32EEjE4typeEj"] = Module["asm"]["_ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__lshiftILm15EEENS_9enable_ifIXltT_Lm32EEjE4typeEj"]).apply(null, arguments)
            };
            var __ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__rshiftILm18EEENS_9enable_ifIXltT_L_ZNS1_3_DtEEEjE4typeEj = Module["__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__rshiftILm18EEENS_9enable_ifIXltT_L_ZNS1_3_DtEEEjE4typeEj"] = function() {
                return (__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__rshiftILm18EEENS_9enable_ifIXltT_L_ZNS1_3_DtEEEjE4typeEj = Module["__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__rshiftILm18EEENS_9enable_ifIXltT_L_ZNS1_3_DtEEEjE4typeEj"] = Module["asm"]["_ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__rshiftILm18EEENS_9enable_ifIXltT_L_ZNS1_3_DtEEEjE4typeEj"]).apply(null, arguments)
            };
            var __ZNSt3__28__rs_getEv = Module["__ZNSt3__28__rs_getEv"] = function() {
                return (__ZNSt3__28__rs_getEv = Module["__ZNSt3__28__rs_getEv"] = Module["asm"]["_ZNSt3__28__rs_getEv"]).apply(null, arguments)
            };
            var __ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__rshiftILm30EEENS_9enable_ifIXltT_L_ZNS1_3_DtEEEjE4typeEj = Module["__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__rshiftILm30EEENS_9enable_ifIXltT_L_ZNS1_3_DtEEEjE4typeEj"] = function() {
                return (__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__rshiftILm30EEENS_9enable_ifIXltT_L_ZNS1_3_DtEEEjE4typeEj = Module["__ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__rshiftILm30EEENS_9enable_ifIXltT_L_ZNS1_3_DtEEEjE4typeEj"] = Module["asm"]["_ZNSt3__223mersenne_twister_engineIjLm32ELm624ELm397ELm31ELj2567483615ELm11ELj4294967295ELm7ELj2636928640ELm15ELj4022730752ELm18ELj1812433253EE8__rshiftILm30EEENS_9enable_ifIXltT_L_ZNS1_3_DtEEEjE4typeEj"]).apply(null, arguments)
            };
            var __ZNSt3__212__rs_defaultC1Ev = Module["__ZNSt3__212__rs_defaultC1Ev"] = function() {
                return (__ZNSt3__212__rs_defaultC1Ev = Module["__ZNSt3__212__rs_defaultC1Ev"] = Module["asm"]["_ZNSt3__212__rs_defaultC1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212__rs_defaultC1ERKS0_ = Module["__ZNSt3__212__rs_defaultC1ERKS0_"] = function() {
                return (__ZNSt3__212__rs_defaultC1ERKS0_ = Module["__ZNSt3__212__rs_defaultC1ERKS0_"] = Module["asm"]["_ZNSt3__212__rs_defaultC1ERKS0_"]).apply(null, arguments)
            };
            var __ZNSt3__212__rs_defaultD1Ev = Module["__ZNSt3__212__rs_defaultD1Ev"] = function() {
                return (__ZNSt3__212__rs_defaultD1Ev = Module["__ZNSt3__212__rs_defaultD1Ev"] = Module["asm"]["_ZNSt3__212__rs_defaultD1Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__220__vector_base_commonILb1EE20__throw_out_of_rangeEv = Module["__ZNKSt3__220__vector_base_commonILb1EE20__throw_out_of_rangeEv"] = function() {
                return (__ZNKSt3__220__vector_base_commonILb1EE20__throw_out_of_rangeEv = Module["__ZNKSt3__220__vector_base_commonILb1EE20__throw_out_of_rangeEv"] = Module["asm"]["_ZNKSt3__220__vector_base_commonILb1EE20__throw_out_of_rangeEv"]).apply(null, arguments)
            };
            var __ZNSt3__217bad_function_callD2Ev = Module["__ZNSt3__217bad_function_callD2Ev"] = function() {
                return (__ZNSt3__217bad_function_callD2Ev = Module["__ZNSt3__217bad_function_callD2Ev"] = Module["asm"]["_ZNSt3__217bad_function_callD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217bad_function_callD0Ev = Module["__ZNSt3__217bad_function_callD0Ev"] = function() {
                return (__ZNSt3__217bad_function_callD0Ev = Module["__ZNSt3__217bad_function_callD0Ev"] = Module["asm"]["_ZNSt3__217bad_function_callD0Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__217bad_function_call4whatEv = Module["__ZNKSt3__217bad_function_call4whatEv"] = function() {
                return (__ZNKSt3__217bad_function_call4whatEv = Module["__ZNKSt3__217bad_function_call4whatEv"] = Module["asm"]["_ZNKSt3__217bad_function_call4whatEv"]).apply(null, arguments)
            };
            var __ZNSt3__217bad_function_callD1Ev = Module["__ZNSt3__217bad_function_callD1Ev"] = function() {
                return (__ZNSt3__217bad_function_callD1Ev = Module["__ZNSt3__217bad_function_callD1Ev"] = Module["asm"]["_ZNSt3__217bad_function_callD1Ev"]).apply(null, arguments)
            };
            var __ZNKSt18bad_variant_access4whatEv = Module["__ZNKSt18bad_variant_access4whatEv"] = function() {
                return (__ZNKSt18bad_variant_access4whatEv = Module["__ZNKSt18bad_variant_access4whatEv"] = Module["asm"]["_ZNKSt18bad_variant_access4whatEv"]).apply(null, arguments)
            };
            var __ZNSt18bad_variant_accessD0Ev = Module["__ZNSt18bad_variant_accessD0Ev"] = function() {
                return (__ZNSt18bad_variant_accessD0Ev = Module["__ZNSt18bad_variant_accessD0Ev"] = Module["asm"]["_ZNSt18bad_variant_accessD0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212__next_primeEm = Module["__ZNSt3__212__next_primeEm"] = function() {
                return (__ZNSt3__212__next_primeEm = Module["__ZNSt3__212__next_primeEm"] = Module["asm"]["_ZNSt3__212__next_primeEm"]).apply(null, arguments)
            };
            var __ZNSt3__211lower_boundIPKjmEET_S3_S3_RKT0_ = Module["__ZNSt3__211lower_boundIPKjmEET_S3_S3_RKT0_"] = function() {
                return (__ZNSt3__211lower_boundIPKjmEET_S3_S3_RKT0_ = Module["__ZNSt3__211lower_boundIPKjmEET_S3_S3_RKT0_"] = Module["asm"]["_ZNSt3__211lower_boundIPKjmEET_S3_S3_RKT0_"]).apply(null, arguments)
            };
            var __ZNSt3__220__check_for_overflowILm4EEENS_9enable_ifIXeqT_Li4EEvE4typeEm = Module["__ZNSt3__220__check_for_overflowILm4EEENS_9enable_ifIXeqT_Li4EEvE4typeEm"] = function() {
                return (__ZNSt3__220__check_for_overflowILm4EEENS_9enable_ifIXeqT_Li4EEvE4typeEm = Module["__ZNSt3__220__check_for_overflowILm4EEENS_9enable_ifIXeqT_Li4EEvE4typeEm"] = Module["asm"]["_ZNSt3__220__check_for_overflowILm4EEENS_9enable_ifIXeqT_Li4EEvE4typeEm"]).apply(null, arguments)
            };
            var __ZNSt3__211lower_boundIPKjmNS_6__lessIjmEEEET_S5_S5_RKT0_T1_ = Module["__ZNSt3__211lower_boundIPKjmNS_6__lessIjmEEEET_S5_S5_RKT0_T1_"] = function() {
                return (__ZNSt3__211lower_boundIPKjmNS_6__lessIjmEEEET_S5_S5_RKT0_T1_ = Module["__ZNSt3__211lower_boundIPKjmNS_6__lessIjmEEEET_S5_S5_RKT0_T1_"] = Module["asm"]["_ZNSt3__211lower_boundIPKjmNS_6__lessIjmEEEET_S5_S5_RKT0_T1_"]).apply(null, arguments)
            };
            var __ZNSt3__222__throw_overflow_errorEPKc = Module["__ZNSt3__222__throw_overflow_errorEPKc"] = function() {
                return (__ZNSt3__222__throw_overflow_errorEPKc = Module["__ZNSt3__222__throw_overflow_errorEPKc"] = Module["asm"]["_ZNSt3__222__throw_overflow_errorEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__213__lower_boundIRNS_6__lessIjmEEPKjmEET0_S6_S6_RKT1_T_ = Module["__ZNSt3__213__lower_boundIRNS_6__lessIjmEEPKjmEET0_S6_S6_RKT1_T_"] = function() {
                return (__ZNSt3__213__lower_boundIRNS_6__lessIjmEEPKjmEET0_S6_S6_RKT1_T_ = Module["__ZNSt3__213__lower_boundIRNS_6__lessIjmEEPKjmEET0_S6_S6_RKT1_T_"] = Module["asm"]["_ZNSt3__213__lower_boundIRNS_6__lessIjmEEPKjmEET0_S6_S6_RKT1_T_"]).apply(null, arguments)
            };
            var __ZNSt3__28distanceIPKjEENS_15iterator_traitsIT_E15difference_typeES4_S4_ = Module["__ZNSt3__28distanceIPKjEENS_15iterator_traitsIT_E15difference_typeES4_S4_"] = function() {
                return (__ZNSt3__28distanceIPKjEENS_15iterator_traitsIT_E15difference_typeES4_S4_ = Module["__ZNSt3__28distanceIPKjEENS_15iterator_traitsIT_E15difference_typeES4_S4_"] = Module["asm"]["_ZNSt3__28distanceIPKjEENS_15iterator_traitsIT_E15difference_typeES4_S4_"]).apply(null, arguments)
            };
            var __ZNSt3__27advanceIPKjEEvRT_NS_15iterator_traitsIS3_E15difference_typeE = Module["__ZNSt3__27advanceIPKjEEvRT_NS_15iterator_traitsIS3_E15difference_typeE"] = function() {
                return (__ZNSt3__27advanceIPKjEEvRT_NS_15iterator_traitsIS3_E15difference_typeE = Module["__ZNSt3__27advanceIPKjEEvRT_NS_15iterator_traitsIS3_E15difference_typeE"] = Module["asm"]["_ZNSt3__27advanceIPKjEEvRT_NS_15iterator_traitsIS3_E15difference_typeE"]).apply(null, arguments)
            };
            var __ZNKSt3__26__lessIjmEclERKjRKm = Module["__ZNKSt3__26__lessIjmEclERKjRKm"] = function() {
                return (__ZNKSt3__26__lessIjmEclERKjRKm = Module["__ZNKSt3__26__lessIjmEclERKjRKm"] = Module["asm"]["_ZNKSt3__26__lessIjmEclERKjRKm"]).apply(null, arguments)
            };
            var __ZNSt3__210__distanceIPKjEENS_15iterator_traitsIT_E15difference_typeES4_S4_NS_26random_access_iterator_tagE = Module["__ZNSt3__210__distanceIPKjEENS_15iterator_traitsIT_E15difference_typeES4_S4_NS_26random_access_iterator_tagE"] = function() {
                return (__ZNSt3__210__distanceIPKjEENS_15iterator_traitsIT_E15difference_typeES4_S4_NS_26random_access_iterator_tagE = Module["__ZNSt3__210__distanceIPKjEENS_15iterator_traitsIT_E15difference_typeES4_S4_NS_26random_access_iterator_tagE"] = Module["asm"]["_ZNSt3__210__distanceIPKjEENS_15iterator_traitsIT_E15difference_typeES4_S4_NS_26random_access_iterator_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__29__advanceIPKjEEvRT_NS_15iterator_traitsIS3_E15difference_typeENS_26random_access_iterator_tagE = Module["__ZNSt3__29__advanceIPKjEEvRT_NS_15iterator_traitsIS3_E15difference_typeENS_26random_access_iterator_tagE"] = function() {
                return (__ZNSt3__29__advanceIPKjEEvRT_NS_15iterator_traitsIS3_E15difference_typeENS_26random_access_iterator_tagE = Module["__ZNSt3__29__advanceIPKjEEvRT_NS_15iterator_traitsIS3_E15difference_typeENS_26random_access_iterator_tagE"] = Module["asm"]["_ZNSt3__29__advanceIPKjEEvRT_NS_15iterator_traitsIS3_E15difference_typeENS_26random_access_iterator_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__218condition_variableD2Ev = Module["__ZNSt3__218condition_variableD2Ev"] = function() {
                return (__ZNSt3__218condition_variableD2Ev = Module["__ZNSt3__218condition_variableD2Ev"] = Module["asm"]["_ZNSt3__218condition_variableD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__224__libcpp_condvar_destroyEP14pthread_cond_t = Module["__ZNSt3__224__libcpp_condvar_destroyEP14pthread_cond_t"] = function() {
                return (__ZNSt3__224__libcpp_condvar_destroyEP14pthread_cond_t = Module["__ZNSt3__224__libcpp_condvar_destroyEP14pthread_cond_t"] = Module["asm"]["_ZNSt3__224__libcpp_condvar_destroyEP14pthread_cond_t"]).apply(null, arguments)
            };
            var __ZNKSt12bad_any_cast4whatEv = Module["__ZNKSt12bad_any_cast4whatEv"] = function() {
                return (__ZNKSt12bad_any_cast4whatEv = Module["__ZNKSt12bad_any_cast4whatEv"] = Module["asm"]["_ZNKSt12bad_any_cast4whatEv"]).apply(null, arguments)
            };
            var __ZNKSt12experimental15fundamentals_v112bad_any_cast4whatEv = Module["__ZNKSt12experimental15fundamentals_v112bad_any_cast4whatEv"] = function() {
                return (__ZNKSt12experimental15fundamentals_v112bad_any_cast4whatEv = Module["__ZNKSt12experimental15fundamentals_v112bad_any_cast4whatEv"] = Module["asm"]["_ZNKSt12experimental15fundamentals_v112bad_any_cast4whatEv"]).apply(null, arguments)
            };
            var __ZNSt12bad_any_castD0Ev = Module["__ZNSt12bad_any_castD0Ev"] = function() {
                return (__ZNSt12bad_any_castD0Ev = Module["__ZNSt12bad_any_castD0Ev"] = Module["asm"]["_ZNSt12bad_any_castD0Ev"]).apply(null, arguments)
            };
            var __ZNSt8bad_castD2Ev = Module["__ZNSt8bad_castD2Ev"] = function() {
                return (__ZNSt8bad_castD2Ev = Module["__ZNSt8bad_castD2Ev"] = Module["asm"]["_ZNSt8bad_castD2Ev"]).apply(null, arguments)
            };
            var __ZNSt12experimental15fundamentals_v112bad_any_castD0Ev = Module["__ZNSt12experimental15fundamentals_v112bad_any_castD0Ev"] = function() {
                return (__ZNSt12experimental15fundamentals_v112bad_any_castD0Ev = Module["__ZNSt12experimental15fundamentals_v112bad_any_castD0Ev"] = Module["asm"]["_ZNSt12experimental15fundamentals_v112bad_any_castD0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono12system_clock3nowEv = Module["__ZNSt3__26chrono12system_clock3nowEv"] = function() {
                return (__ZNSt3__26chrono12system_clock3nowEv = Module["__ZNSt3__26chrono12system_clock3nowEv"] = Module["asm"]["_ZNSt3__26chrono12system_clock3nowEv"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1EEEEC2IlEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1EEEEC2IlEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"] = function() {
                return (__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1EEEEC2IlEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1EEEEC2IlEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"] = Module["asm"]["_ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1EEEEC2IlEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000EEEEC2IlEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000EEEEC2IlEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"] = function() {
                return (__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000EEEEC2IlEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000EEEEC2IlEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"] = Module["asm"]["_ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000EEEEC2IlEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__26chronoplIxNS_5ratioILx1ELx1EEExNS2_ILx1ELx1000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_ = Module["__ZNSt3__26chronoplIxNS_5ratioILx1ELx1EEExNS2_ILx1ELx1000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"] = function() {
                return (__ZNSt3__26chronoplIxNS_5ratioILx1ELx1EEExNS2_ILx1ELx1000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_ = Module["__ZNSt3__26chronoplIxNS_5ratioILx1ELx1EEExNS2_ILx1ELx1000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"] = Module["asm"]["_ZNSt3__26chronoplIxNS_5ratioILx1ELx1EEExNS2_ILx1ELx1000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono10time_pointINS0_12system_clockENS0_8durationIxNS_5ratioILx1ELx1000000EEEEEEC2ERKS6_ = Module["__ZNSt3__26chrono10time_pointINS0_12system_clockENS0_8durationIxNS_5ratioILx1ELx1000000EEEEEEC2ERKS6_"] = function() {
                return (__ZNSt3__26chrono10time_pointINS0_12system_clockENS0_8durationIxNS_5ratioILx1ELx1000000EEEEEEC2ERKS6_ = Module["__ZNSt3__26chrono10time_pointINS0_12system_clockENS0_8durationIxNS_5ratioILx1ELx1000000EEEEEEC2ERKS6_"] = Module["asm"]["_ZNSt3__26chrono10time_pointINS0_12system_clockENS0_8durationIxNS_5ratioILx1ELx1000000EEEEEEC2ERKS6_"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000EEEEC2IxNS2_ILx1ELx1EEEEERKNS1_IT_T0_EEPNS_9enable_ifIXaasr13__no_overflowIS8_S3_EE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEaaeqsr13__no_overflowIS8_S3_E4typeE3denLi1Entsr23treat_as_floating_pointIS7_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000EEEEC2IxNS2_ILx1ELx1EEEEERKNS1_IT_T0_EEPNS_9enable_ifIXaasr13__no_overflowIS8_S3_EE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEaaeqsr13__no_overflowIS8_S3_E4typeE3denLi1Entsr23treat_as_floating_pointIS7_EE5valueEvE4typeE"] = function() {
                return (__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000EEEEC2IxNS2_ILx1ELx1EEEEERKNS1_IT_T0_EEPNS_9enable_ifIXaasr13__no_overflowIS8_S3_EE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEaaeqsr13__no_overflowIS8_S3_E4typeE3denLi1Entsr23treat_as_floating_pointIS7_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000EEEEC2IxNS2_ILx1ELx1EEEEERKNS1_IT_T0_EEPNS_9enable_ifIXaasr13__no_overflowIS8_S3_EE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEaaeqsr13__no_overflowIS8_S3_E4typeE3denLi1Entsr23treat_as_floating_pointIS7_EE5valueEvE4typeE"] = Module["asm"]["_ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000EEEEC2IxNS2_ILx1ELx1EEEEERKNS1_IT_T0_EEPNS_9enable_ifIXaasr13__no_overflowIS8_S3_EE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEaaeqsr13__no_overflowIS8_S3_E4typeE3denLi1Entsr23treat_as_floating_pointIS7_EE5valueEvE4typeE"]).apply(null, arguments)
            };
            var __ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1000000EEEE5countEv = Module["__ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1000000EEEE5countEv"] = function() {
                return (__ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1000000EEEE5countEv = Module["__ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1000000EEEE5countEv"] = Module["asm"]["_ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1000000EEEE5countEv"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000EEEEC2IxEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000EEEEC2IxEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"] = function() {
                return (__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000EEEEC2IxEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000EEEEC2IxEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"] = Module["asm"]["_ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000EEEEC2IxEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono12system_clock9to_time_tERKNS0_10time_pointIS1_NS0_8durationIxNS_5ratioILx1ELx1000000EEEEEEE = Module["__ZNSt3__26chrono12system_clock9to_time_tERKNS0_10time_pointIS1_NS0_8durationIxNS_5ratioILx1ELx1000000EEEEEEE"] = function() {
                return (__ZNSt3__26chrono12system_clock9to_time_tERKNS0_10time_pointIS1_NS0_8durationIxNS_5ratioILx1ELx1000000EEEEEEE = Module["__ZNSt3__26chrono12system_clock9to_time_tERKNS0_10time_pointIS1_NS0_8durationIxNS_5ratioILx1ELx1000000EEEEEEE"] = Module["asm"]["_ZNSt3__26chrono12system_clock9to_time_tERKNS0_10time_pointIS1_NS0_8durationIxNS_5ratioILx1ELx1000000EEEEEEE"]).apply(null, arguments)
            };
            var __ZNKSt3__26chrono10time_pointINS0_12system_clockENS0_8durationIxNS_5ratioILx1ELx1000000EEEEEE16time_since_epochEv = Module["__ZNKSt3__26chrono10time_pointINS0_12system_clockENS0_8durationIxNS_5ratioILx1ELx1000000EEEEEE16time_since_epochEv"] = function() {
                return (__ZNKSt3__26chrono10time_pointINS0_12system_clockENS0_8durationIxNS_5ratioILx1ELx1000000EEEEEE16time_since_epochEv = Module["__ZNKSt3__26chrono10time_pointINS0_12system_clockENS0_8durationIxNS_5ratioILx1ELx1000000EEEEEE16time_since_epochEv"] = Module["asm"]["_ZNKSt3__26chrono10time_pointINS0_12system_clockENS0_8durationIxNS_5ratioILx1ELx1000000EEEEEE16time_since_epochEv"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEExNS3_ILx1ELx1000000EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE = Module["__ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEExNS3_ILx1ELx1000000EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"] = function() {
                return (__ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEExNS3_ILx1ELx1000000EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE = Module["__ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEExNS3_ILx1ELx1000000EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"] = Module["asm"]["_ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEExNS3_ILx1ELx1000000EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"]).apply(null, arguments)
            };
            var __ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1000000EEEEENS2_IxNS3_ILx1ELx1EEEEES4_Lb1ELb0EEclERKS5_ = Module["__ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1000000EEEEENS2_IxNS3_ILx1ELx1EEEEES4_Lb1ELb0EEclERKS5_"] = function() {
                return (__ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1000000EEEEENS2_IxNS3_ILx1ELx1EEEEES4_Lb1ELb0EEclERKS5_ = Module["__ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1000000EEEEENS2_IxNS3_ILx1ELx1EEEEES4_Lb1ELb0EEclERKS5_"] = Module["asm"]["_ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1000000EEEEENS2_IxNS3_ILx1ELx1EEEEES4_Lb1ELb0EEclERKS5_"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono12system_clock11from_time_tEl = Module["__ZNSt3__26chrono12system_clock11from_time_tEl"] = function() {
                return (__ZNSt3__26chrono12system_clock11from_time_tEl = Module["__ZNSt3__26chrono12system_clock11from_time_tEl"] = Module["asm"]["_ZNSt3__26chrono12system_clock11from_time_tEl"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1000000EEEEExNS3_ILx1ELx1EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE = Module["__ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1000000EEEEExNS3_ILx1ELx1EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"] = function() {
                return (__ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1000000EEEEExNS3_ILx1ELx1EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE = Module["__ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1000000EEEEExNS3_ILx1ELx1EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"] = Module["asm"]["_ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1000000EEEEExNS3_ILx1ELx1EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono12steady_clock3nowEv = Module["__ZNSt3__26chrono12steady_clock3nowEv"] = function() {
                return (__ZNSt3__26chrono12steady_clock3nowEv = Module["__ZNSt3__26chrono12steady_clock3nowEv"] = Module["asm"]["_ZNSt3__26chrono12steady_clock3nowEv"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEEC2IlEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEEC2IlEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"] = function() {
                return (__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEEC2IlEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEEC2IlEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"] = Module["asm"]["_ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEEC2IlEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_xEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__26chronoplIxNS_5ratioILx1ELx1EEExNS2_ILx1ELx1000000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_ = Module["__ZNSt3__26chronoplIxNS_5ratioILx1ELx1EEExNS2_ILx1ELx1000000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"] = function() {
                return (__ZNSt3__26chronoplIxNS_5ratioILx1ELx1EEExNS2_ILx1ELx1000000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_ = Module["__ZNSt3__26chronoplIxNS_5ratioILx1ELx1EEExNS2_ILx1ELx1000000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"] = Module["asm"]["_ZNSt3__26chronoplIxNS_5ratioILx1ELx1EEExNS2_ILx1ELx1000000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono10time_pointINS0_12steady_clockENS0_8durationIxNS_5ratioILx1ELx1000000000EEEEEEC2ERKS6_ = Module["__ZNSt3__26chrono10time_pointINS0_12steady_clockENS0_8durationIxNS_5ratioILx1ELx1000000000EEEEEEC2ERKS6_"] = function() {
                return (__ZNSt3__26chrono10time_pointINS0_12steady_clockENS0_8durationIxNS_5ratioILx1ELx1000000000EEEEEEC2ERKS6_ = Module["__ZNSt3__26chrono10time_pointINS0_12steady_clockENS0_8durationIxNS_5ratioILx1ELx1000000000EEEEEEC2ERKS6_"] = Module["asm"]["_ZNSt3__26chrono10time_pointINS0_12steady_clockENS0_8durationIxNS_5ratioILx1ELx1000000000EEEEEEC2ERKS6_"]).apply(null, arguments)
            };
            var __ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEENS2_IxNS3_ILx1ELx1000000EEEEENS3_ILx1000000ELx1EEELb0ELb1EEclERKS5_ = Module["__ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEENS2_IxNS3_ILx1ELx1000000EEEEENS3_ILx1000000ELx1EEELb0ELb1EEclERKS5_"] = function() {
                return (__ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEENS2_IxNS3_ILx1ELx1000000EEEEENS3_ILx1000000ELx1EEELb0ELb1EEclERKS5_ = Module["__ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEENS2_IxNS3_ILx1ELx1000000EEEEENS3_ILx1000000ELx1EEELb0ELb1EEclERKS5_"] = Module["asm"]["_ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEENS2_IxNS3_ILx1ELx1000000EEEEENS3_ILx1000000ELx1EEELb0ELb1EEclERKS5_"]).apply(null, arguments)
            };
            var __ZNKSt3__219__libcpp_debug_info4whatEv = Module["__ZNKSt3__219__libcpp_debug_info4whatEv"] = function() {
                return (__ZNKSt3__219__libcpp_debug_info4whatEv = Module["__ZNKSt3__219__libcpp_debug_info4whatEv"] = Module["asm"]["_ZNKSt3__219__libcpp_debug_info4whatEv"]).apply(null, arguments)
            };
            var __ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEOS9_PKS6_ = Module["__ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEOS9_PKS6_"] = function() {
                return (__ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEOS9_PKS6_ = Module["__ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEOS9_PKS6_"] = Module["asm"]["_ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEOS9_PKS6_"]).apply(null, arguments)
            };
            var __ZNSt3__229__libcpp_abort_debug_functionERKNS_19__libcpp_debug_infoE = Module["__ZNSt3__229__libcpp_abort_debug_functionERKNS_19__libcpp_debug_infoE"] = function() {
                return (__ZNSt3__229__libcpp_abort_debug_functionERKNS_19__libcpp_debug_infoE = Module["__ZNSt3__229__libcpp_abort_debug_functionERKNS_19__libcpp_debug_infoE"] = Module["asm"]["_ZNSt3__229__libcpp_abort_debug_functionERKNS_19__libcpp_debug_infoE"]).apply(null, arguments)
            };
            var __ZNSt3__227__libcpp_set_debug_functionEPFvRKNS_19__libcpp_debug_infoEE = Module["__ZNSt3__227__libcpp_set_debug_functionEPFvRKNS_19__libcpp_debug_infoEE"] = function() {
                return (__ZNSt3__227__libcpp_set_debug_functionEPFvRKNS_19__libcpp_debug_infoEE = Module["__ZNSt3__227__libcpp_set_debug_functionEPFvRKNS_19__libcpp_debug_infoEE"] = Module["asm"]["_ZNSt3__227__libcpp_set_debug_functionEPFvRKNS_19__libcpp_debug_infoEE"]).apply(null, arguments)
            };
            var __ZNSt3__28__get_dbEv = Module["__ZNSt3__28__get_dbEv"] = function() {
                return (__ZNSt3__28__get_dbEv = Module["__ZNSt3__28__get_dbEv"] = Module["asm"]["_ZNSt3__28__get_dbEv"]).apply(null, arguments)
            };
            var __ZNSt3__211__libcpp_dbC2Ev = Module["__ZNSt3__211__libcpp_dbC2Ev"] = function() {
                return (__ZNSt3__211__libcpp_dbC2Ev = Module["__ZNSt3__211__libcpp_dbC2Ev"] = Module["asm"]["_ZNSt3__211__libcpp_dbC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214__get_const_dbEv = Module["__ZNSt3__214__get_const_dbEv"] = function() {
                return (__ZNSt3__214__get_const_dbEv = Module["__ZNSt3__214__get_const_dbEv"] = Module["asm"]["_ZNSt3__214__get_const_dbEv"]).apply(null, arguments)
            };
            var __ZNSt3__28__i_nodeD2Ev = Module["__ZNSt3__28__i_nodeD2Ev"] = function() {
                return (__ZNSt3__28__i_nodeD2Ev = Module["__ZNSt3__28__i_nodeD2Ev"] = Module["asm"]["_ZNSt3__28__i_nodeD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28__c_nodeD2Ev = Module["__ZNSt3__28__c_nodeD2Ev"] = function() {
                return (__ZNSt3__28__c_nodeD2Ev = Module["__ZNSt3__28__c_nodeD2Ev"] = Module["asm"]["_ZNSt3__28__c_nodeD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28__c_nodeD0Ev = Module["__ZNSt3__28__c_nodeD0Ev"] = function() {
                return (__ZNSt3__28__c_nodeD0Ev = Module["__ZNSt3__28__c_nodeD0Ev"] = Module["asm"]["_ZNSt3__28__c_nodeD0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__211__libcpp_dbD2Ev = Module["__ZNSt3__211__libcpp_dbD2Ev"] = function() {
                return (__ZNSt3__211__libcpp_dbD2Ev = Module["__ZNSt3__211__libcpp_dbD2Ev"] = Module["asm"]["_ZNSt3__211__libcpp_dbD2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__211__libcpp_db15__find_c_from_iEPv = Module["__ZNKSt3__211__libcpp_db15__find_c_from_iEPv"] = function() {
                return (__ZNKSt3__211__libcpp_db15__find_c_from_iEPv = Module["__ZNKSt3__211__libcpp_db15__find_c_from_iEPv"] = Module["asm"]["_ZNKSt3__211__libcpp_db15__find_c_from_iEPv"]).apply(null, arguments)
            };
            var __ZNKSt3__211__libcpp_db15__find_iteratorEPKv = Module["__ZNKSt3__211__libcpp_db15__find_iteratorEPKv"] = function() {
                return (__ZNKSt3__211__libcpp_db15__find_iteratorEPKv = Module["__ZNKSt3__211__libcpp_db15__find_iteratorEPKv"] = Module["asm"]["_ZNKSt3__211__libcpp_db15__find_iteratorEPKv"]).apply(null, arguments)
            };
            var __ZNSt3__211__libcpp_db11__insert_icEPvPKv = Module["__ZNSt3__211__libcpp_db11__insert_icEPvPKv"] = function() {
                return (__ZNSt3__211__libcpp_db11__insert_icEPvPKv = Module["__ZNSt3__211__libcpp_db11__insert_icEPvPKv"] = Module["asm"]["_ZNSt3__211__libcpp_db11__insert_icEPvPKv"]).apply(null, arguments)
            };
            var __ZNSt3__211__libcpp_db17__insert_iteratorEPv = Module["__ZNSt3__211__libcpp_db17__insert_iteratorEPv"] = function() {
                return (__ZNSt3__211__libcpp_db17__insert_iteratorEPv = Module["__ZNSt3__211__libcpp_db17__insert_iteratorEPv"] = Module["asm"]["_ZNSt3__211__libcpp_db17__insert_iteratorEPv"]).apply(null, arguments)
            };
            var __ZNSt3__28__c_node5__addEPNS_8__i_nodeE = Module["__ZNSt3__28__c_node5__addEPNS_8__i_nodeE"] = function() {
                return (__ZNSt3__28__c_node5__addEPNS_8__i_nodeE = Module["__ZNSt3__28__c_node5__addEPNS_8__i_nodeE"] = Module["asm"]["_ZNSt3__28__c_node5__addEPNS_8__i_nodeE"]).apply(null, arguments)
            };
            var __ZNKSt3__24hashIPvEclES1_ = Module["__ZNKSt3__24hashIPvEclES1_"] = function() {
                return (__ZNKSt3__24hashIPvEclES1_ = Module["__ZNKSt3__24hashIPvEclES1_"] = Module["asm"]["_ZNKSt3__24hashIPvEclES1_"]).apply(null, arguments)
            };
            var __ZNSt3__28__i_nodeC2EPvPS0_PNS_8__c_nodeE = Module["__ZNSt3__28__i_nodeC2EPvPS0_PNS_8__c_nodeE"] = function() {
                return (__ZNSt3__28__i_nodeC2EPvPS0_PNS_8__c_nodeE = Module["__ZNSt3__28__i_nodeC2EPvPS0_PNS_8__c_nodeE"] = Module["asm"]["_ZNSt3__28__i_nodeC2EPvPS0_PNS_8__c_nodeE"]).apply(null, arguments)
            };
            var __ZNSt3__211__libcpp_db10__insert_cEPvPFPNS_8__c_nodeES1_S1_S3_E = Module["__ZNSt3__211__libcpp_db10__insert_cEPvPFPNS_8__c_nodeES1_S1_S3_E"] = function() {
                return (__ZNSt3__211__libcpp_db10__insert_cEPvPFPNS_8__c_nodeES1_S1_S3_E = Module["__ZNSt3__211__libcpp_db10__insert_cEPvPFPNS_8__c_nodeES1_S1_S3_E"] = Module["asm"]["_ZNSt3__211__libcpp_db10__insert_cEPvPFPNS_8__c_nodeES1_S1_S3_E"]).apply(null, arguments)
            };
            var __ZNSt3__211__libcpp_db9__erase_iEPv = Module["__ZNSt3__211__libcpp_db9__erase_iEPv"] = function() {
                return (__ZNSt3__211__libcpp_db9__erase_iEPv = Module["__ZNSt3__211__libcpp_db9__erase_iEPv"] = Module["asm"]["_ZNSt3__211__libcpp_db9__erase_iEPv"]).apply(null, arguments)
            };
            var __ZNSt3__28__c_node8__removeEPNS_8__i_nodeE = Module["__ZNSt3__28__c_node8__removeEPNS_8__i_nodeE"] = function() {
                return (__ZNSt3__28__c_node8__removeEPNS_8__i_nodeE = Module["__ZNSt3__28__c_node8__removeEPNS_8__i_nodeE"] = Module["asm"]["_ZNSt3__28__c_node8__removeEPNS_8__i_nodeE"]).apply(null, arguments)
            };
            var __ZNSt3__24findIPPNS_8__i_nodeES2_EET_S4_S4_RKT0_ = Module["__ZNSt3__24findIPPNS_8__i_nodeES2_EET_S4_S4_RKT0_"] = function() {
                return (__ZNSt3__24findIPPNS_8__i_nodeES2_EET_S4_S4_RKT0_ = Module["__ZNSt3__24findIPPNS_8__i_nodeES2_EET_S4_S4_RKT0_"] = Module["asm"]["_ZNSt3__24findIPPNS_8__i_nodeES2_EET_S4_S4_RKT0_"]).apply(null, arguments)
            };
            var __ZNSt3__211__libcpp_db16__invalidate_allEPv = Module["__ZNSt3__211__libcpp_db16__invalidate_allEPv"] = function() {
                return (__ZNSt3__211__libcpp_db16__invalidate_allEPv = Module["__ZNSt3__211__libcpp_db16__invalidate_allEPv"] = Module["asm"]["_ZNSt3__211__libcpp_db16__invalidate_allEPv"]).apply(null, arguments)
            };
            var __ZNKSt3__211__libcpp_db17__find_c_and_lockEPv = Module["__ZNKSt3__211__libcpp_db17__find_c_and_lockEPv"] = function() {
                return (__ZNKSt3__211__libcpp_db17__find_c_and_lockEPv = Module["__ZNKSt3__211__libcpp_db17__find_c_and_lockEPv"] = Module["asm"]["_ZNKSt3__211__libcpp_db17__find_c_and_lockEPv"]).apply(null, arguments)
            };
            var __ZNKSt3__211__libcpp_db8__find_cEPv = Module["__ZNKSt3__211__libcpp_db8__find_cEPv"] = function() {
                return (__ZNKSt3__211__libcpp_db8__find_cEPv = Module["__ZNKSt3__211__libcpp_db8__find_cEPv"] = Module["asm"]["_ZNKSt3__211__libcpp_db8__find_cEPv"]).apply(null, arguments)
            };
            var __ZNKSt3__211__libcpp_db6unlockEv = Module["__ZNKSt3__211__libcpp_db6unlockEv"] = function() {
                return (__ZNKSt3__211__libcpp_db6unlockEv = Module["__ZNKSt3__211__libcpp_db6unlockEv"] = Module["asm"]["_ZNKSt3__211__libcpp_db6unlockEv"]).apply(null, arguments)
            };
            var __ZNSt3__211__libcpp_db9__erase_cEPv = Module["__ZNSt3__211__libcpp_db9__erase_cEPv"] = function() {
                return (__ZNSt3__211__libcpp_db9__erase_cEPv = Module["__ZNSt3__211__libcpp_db9__erase_cEPv"] = Module["asm"]["_ZNSt3__211__libcpp_db9__erase_cEPv"]).apply(null, arguments)
            };
            var __ZNSt3__211__libcpp_db15__iterator_copyEPvPKv = Module["__ZNSt3__211__libcpp_db15__iterator_copyEPvPKv"] = function() {
                return (__ZNSt3__211__libcpp_db15__iterator_copyEPvPKv = Module["__ZNSt3__211__libcpp_db15__iterator_copyEPvPKv"] = Module["asm"]["_ZNSt3__211__libcpp_db15__iterator_copyEPvPKv"]).apply(null, arguments)
            };
            var __ZNKSt3__211__libcpp_db17__dereferenceableEPKv = Module["__ZNKSt3__211__libcpp_db17__dereferenceableEPKv"] = function() {
                return (__ZNKSt3__211__libcpp_db17__dereferenceableEPKv = Module["__ZNKSt3__211__libcpp_db17__dereferenceableEPKv"] = Module["asm"]["_ZNKSt3__211__libcpp_db17__dereferenceableEPKv"]).apply(null, arguments)
            };
            var __ZNKSt3__211__libcpp_db15__decrementableEPKv = Module["__ZNKSt3__211__libcpp_db15__decrementableEPKv"] = function() {
                return (__ZNKSt3__211__libcpp_db15__decrementableEPKv = Module["__ZNKSt3__211__libcpp_db15__decrementableEPKv"] = Module["asm"]["_ZNKSt3__211__libcpp_db15__decrementableEPKv"]).apply(null, arguments)
            };
            var __ZNKSt3__211__libcpp_db9__addableEPKvl = Module["__ZNKSt3__211__libcpp_db9__addableEPKvl"] = function() {
                return (__ZNKSt3__211__libcpp_db9__addableEPKvl = Module["__ZNKSt3__211__libcpp_db9__addableEPKvl"] = Module["asm"]["_ZNKSt3__211__libcpp_db9__addableEPKvl"]).apply(null, arguments)
            };
            var __ZNKSt3__211__libcpp_db15__subscriptableEPKvl = Module["__ZNKSt3__211__libcpp_db15__subscriptableEPKvl"] = function() {
                return (__ZNKSt3__211__libcpp_db15__subscriptableEPKvl = Module["__ZNKSt3__211__libcpp_db15__subscriptableEPKvl"] = Module["asm"]["_ZNKSt3__211__libcpp_db15__subscriptableEPKvl"]).apply(null, arguments)
            };
            var __ZNKSt3__211__libcpp_db22__less_than_comparableEPKvS2_ = Module["__ZNKSt3__211__libcpp_db22__less_than_comparableEPKvS2_"] = function() {
                return (__ZNKSt3__211__libcpp_db22__less_than_comparableEPKvS2_ = Module["__ZNKSt3__211__libcpp_db22__less_than_comparableEPKvS2_"] = Module["asm"]["_ZNKSt3__211__libcpp_db22__less_than_comparableEPKvS2_"]).apply(null, arguments)
            };
            var __ZNSt3__211__libcpp_db4swapEPvS1_ = Module["__ZNSt3__211__libcpp_db4swapEPvS1_"] = function() {
                return (__ZNSt3__211__libcpp_db4swapEPvS1_ = Module["__ZNSt3__211__libcpp_db4swapEPvS1_"] = Module["asm"]["_ZNSt3__211__libcpp_db4swapEPvS1_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIPPNS_8__i_nodeEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS5_EE5valueEvE4typeERS5_S8_ = Module["__ZNSt3__24swapIPPNS_8__i_nodeEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS5_EE5valueEvE4typeERS5_S8_"] = function() {
                return (__ZNSt3__24swapIPPNS_8__i_nodeEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS5_EE5valueEvE4typeERS5_S8_ = Module["__ZNSt3__24swapIPPNS_8__i_nodeEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS5_EE5valueEvE4typeERS5_S8_"] = Module["asm"]["_ZNSt3__24swapIPPNS_8__i_nodeEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS5_EE5valueEvE4typeERS5_S8_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRPPNS_8__i_nodeEEEONS_16remove_referenceIT_E4typeEOS6_ = Module["__ZNSt3__24moveIRPPNS_8__i_nodeEEEONS_16remove_referenceIT_E4typeEOS6_"] = function() {
                return (__ZNSt3__24moveIRPPNS_8__i_nodeEEEONS_16remove_referenceIT_E4typeEOS6_ = Module["__ZNSt3__24moveIRPPNS_8__i_nodeEEEONS_16remove_referenceIT_E4typeEOS6_"] = Module["asm"]["_ZNSt3__24moveIRPPNS_8__i_nodeEEEONS_16remove_referenceIT_E4typeEOS6_"]).apply(null, arguments)
            };
            var __ZNSt3__211__libcpp_db10__insert_iEPv = Module["__ZNSt3__211__libcpp_db10__insert_iEPv"] = function() {
                return (__ZNSt3__211__libcpp_db10__insert_iEPv = Module["__ZNSt3__211__libcpp_db10__insert_iEPv"] = Module["asm"]["_ZNSt3__211__libcpp_db10__insert_iEPv"]).apply(null, arguments)
            };
            var __ZNSt3__28__i_nodeD1Ev = Module["__ZNSt3__28__i_nodeD1Ev"] = function() {
                return (__ZNSt3__28__i_nodeD1Ev = Module["__ZNSt3__28__i_nodeD1Ev"] = Module["asm"]["_ZNSt3__28__i_nodeD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28__c_nodeD1Ev = Module["__ZNSt3__28__c_nodeD1Ev"] = function() {
                return (__ZNSt3__28__c_nodeD1Ev = Module["__ZNSt3__28__c_nodeD1Ev"] = Module["asm"]["_ZNSt3__28__c_nodeD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__211__libcpp_dbC1Ev = Module["__ZNSt3__211__libcpp_dbC1Ev"] = function() {
                return (__ZNSt3__211__libcpp_dbC1Ev = Module["__ZNSt3__211__libcpp_dbC1Ev"] = Module["asm"]["_ZNSt3__211__libcpp_dbC1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__211__libcpp_dbD1Ev = Module["__ZNSt3__211__libcpp_dbD1Ev"] = function() {
                return (__ZNSt3__211__libcpp_dbD1Ev = Module["__ZNSt3__211__libcpp_dbD1Ev"] = Module["asm"]["_ZNSt3__211__libcpp_dbD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_baseD2Ev = Module["__ZNSt3__28ios_baseD2Ev"] = function() {
                return (__ZNSt3__28ios_baseD2Ev = Module["__ZNSt3__28ios_baseD2Ev"] = Module["asm"]["_ZNSt3__28ios_baseD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base16__call_callbacksENS0_5eventE = Module["__ZNSt3__28ios_base16__call_callbacksENS0_5eventE"] = function() {
                return (__ZNSt3__28ios_base16__call_callbacksENS0_5eventE = Module["__ZNSt3__28ios_base16__call_callbacksENS0_5eventE"] = Module["asm"]["_ZNSt3__28ios_base16__call_callbacksENS0_5eventE"]).apply(null, arguments)
            };
            var __ZNSt3__29basic_iosIcNS_11char_traitsIcEEED0Ev = Module["__ZNSt3__29basic_iosIcNS_11char_traitsIcEEED0Ev"] = function() {
                return (__ZNSt3__29basic_iosIcNS_11char_traitsIcEEED0Ev = Module["__ZNSt3__29basic_iosIcNS_11char_traitsIcEEED0Ev"] = Module["asm"]["_ZNSt3__29basic_iosIcNS_11char_traitsIcEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29basic_iosIcNS_11char_traitsIcEEE7copyfmtERKS3_ = Module["__ZNSt3__29basic_iosIcNS_11char_traitsIcEEE7copyfmtERKS3_"] = function() {
                return (__ZNSt3__29basic_iosIcNS_11char_traitsIcEEE7copyfmtERKS3_ = Module["__ZNSt3__29basic_iosIcNS_11char_traitsIcEEE7copyfmtERKS3_"] = Module["asm"]["_ZNSt3__29basic_iosIcNS_11char_traitsIcEEE7copyfmtERKS3_"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base7copyfmtERKS0_ = Module["__ZNSt3__28ios_base7copyfmtERKS0_"] = function() {
                return (__ZNSt3__28ios_base7copyfmtERKS0_ = Module["__ZNSt3__28ios_base7copyfmtERKS0_"] = Module["asm"]["_ZNSt3__28ios_base7copyfmtERKS0_"]).apply(null, arguments)
            };
            var __ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE10exceptionsEv = Module["__ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE10exceptionsEv"] = function() {
                return (__ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE10exceptionsEv = Module["__ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE10exceptionsEv"] = Module["asm"]["_ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE10exceptionsEv"]).apply(null, arguments)
            };
            var __ZNSt3__29basic_iosIcNS_11char_traitsIcEEE10exceptionsEj = Module["__ZNSt3__29basic_iosIcNS_11char_traitsIcEEE10exceptionsEj"] = function() {
                return (__ZNSt3__29basic_iosIcNS_11char_traitsIcEEE10exceptionsEj = Module["__ZNSt3__29basic_iosIcNS_11char_traitsIcEEE10exceptionsEj"] = Module["asm"]["_ZNSt3__29basic_iosIcNS_11char_traitsIcEEE10exceptionsEj"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIPFvNS_8ios_base5eventERS1_iEPFvPvEEC2ILb1EvEEPS5_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS8_EEXT_EE20__good_rval_ref_typeE = Module["__ZNSt3__210unique_ptrIPFvNS_8ios_base5eventERS1_iEPFvPvEEC2ILb1EvEEPS5_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS8_EEXT_EE20__good_rval_ref_typeE"] = function() {
                return (__ZNSt3__210unique_ptrIPFvNS_8ios_base5eventERS1_iEPFvPvEEC2ILb1EvEEPS5_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS8_EEXT_EE20__good_rval_ref_typeE = Module["__ZNSt3__210unique_ptrIPFvNS_8ios_base5eventERS1_iEPFvPvEEC2ILb1EvEEPS5_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS8_EEXT_EE20__good_rval_ref_typeE"] = Module["asm"]["_ZNSt3__210unique_ptrIPFvNS_8ios_base5eventERS1_iEPFvPvEEC2ILb1EvEEPS5_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS8_EEXT_EE20__good_rval_ref_typeE"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIiPFvPvEEC2ILb1EvEEPiNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE = Module["__ZNSt3__210unique_ptrIiPFvPvEEC2ILb1EvEEPiNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE"] = function() {
                return (__ZNSt3__210unique_ptrIiPFvPvEEC2ILb1EvEEPiNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE = Module["__ZNSt3__210unique_ptrIiPFvPvEEC2ILb1EvEEPiNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE"] = Module["asm"]["_ZNSt3__210unique_ptrIiPFvPvEEC2ILb1EvEEPiNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIlPFvPvEEC2ILb1EvEEPlNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE = Module["__ZNSt3__210unique_ptrIlPFvPvEEC2ILb1EvEEPlNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE"] = function() {
                return (__ZNSt3__210unique_ptrIlPFvPvEEC2ILb1EvEEPlNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE = Module["__ZNSt3__210unique_ptrIlPFvPvEEC2ILb1EvEEPlNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE"] = Module["asm"]["_ZNSt3__210unique_ptrIlPFvPvEEC2ILb1EvEEPlNS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIPvPFvS1_EEC2ILb1EvEEPS1_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE = Module["__ZNSt3__210unique_ptrIPvPFvS1_EEC2ILb1EvEEPS1_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE"] = function() {
                return (__ZNSt3__210unique_ptrIPvPFvS1_EEC2ILb1EvEEPS1_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE = Module["__ZNSt3__210unique_ptrIPvPFvS1_EEC2ILb1EvEEPS1_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE"] = Module["asm"]["_ZNSt3__210unique_ptrIPvPFvS1_EEC2ILb1EvEEPS1_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS3_EEXT_EE20__good_rval_ref_typeE"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIPFvNS_8ios_base5eventERS1_iEPFvPvEE5resetEPS5_ = Module["__ZNSt3__210unique_ptrIPFvNS_8ios_base5eventERS1_iEPFvPvEE5resetEPS5_"] = function() {
                return (__ZNSt3__210unique_ptrIPFvNS_8ios_base5eventERS1_iEPFvPvEE5resetEPS5_ = Module["__ZNSt3__210unique_ptrIPFvNS_8ios_base5eventERS1_iEPFvPvEE5resetEPS5_"] = Module["asm"]["_ZNSt3__210unique_ptrIPFvNS_8ios_base5eventERS1_iEPFvPvEE5resetEPS5_"]).apply(null, arguments)
            };
            var __ZNKSt3__210unique_ptrIPFvNS_8ios_base5eventERS1_iEPFvPvEEcvbEv = Module["__ZNKSt3__210unique_ptrIPFvNS_8ios_base5eventERS1_iEPFvPvEEcvbEv"] = function() {
                return (__ZNKSt3__210unique_ptrIPFvNS_8ios_base5eventERS1_iEPFvPvEEcvbEv = Module["__ZNKSt3__210unique_ptrIPFvNS_8ios_base5eventERS1_iEPFvPvEEcvbEv"] = Module["asm"]["_ZNKSt3__210unique_ptrIPFvNS_8ios_base5eventERS1_iEPFvPvEEcvbEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIiPFvPvEE5resetEPi = Module["__ZNSt3__210unique_ptrIiPFvPvEE5resetEPi"] = function() {
                return (__ZNSt3__210unique_ptrIiPFvPvEE5resetEPi = Module["__ZNSt3__210unique_ptrIiPFvPvEE5resetEPi"] = Module["asm"]["_ZNSt3__210unique_ptrIiPFvPvEE5resetEPi"]).apply(null, arguments)
            };
            var __ZNKSt3__210unique_ptrIiPFvPvEEcvbEv = Module["__ZNKSt3__210unique_ptrIiPFvPvEEcvbEv"] = function() {
                return (__ZNKSt3__210unique_ptrIiPFvPvEEcvbEv = Module["__ZNKSt3__210unique_ptrIiPFvPvEEcvbEv"] = Module["asm"]["_ZNKSt3__210unique_ptrIiPFvPvEEcvbEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIlPFvPvEE5resetEPl = Module["__ZNSt3__210unique_ptrIlPFvPvEE5resetEPl"] = function() {
                return (__ZNSt3__210unique_ptrIlPFvPvEE5resetEPl = Module["__ZNSt3__210unique_ptrIlPFvPvEE5resetEPl"] = Module["asm"]["_ZNSt3__210unique_ptrIlPFvPvEE5resetEPl"]).apply(null, arguments)
            };
            var __ZNKSt3__210unique_ptrIlPFvPvEEcvbEv = Module["__ZNKSt3__210unique_ptrIlPFvPvEEcvbEv"] = function() {
                return (__ZNKSt3__210unique_ptrIlPFvPvEEcvbEv = Module["__ZNKSt3__210unique_ptrIlPFvPvEEcvbEv"] = Module["asm"]["_ZNKSt3__210unique_ptrIlPFvPvEEcvbEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIPvPFvS1_EE5resetEPS1_ = Module["__ZNSt3__210unique_ptrIPvPFvS1_EE5resetEPS1_"] = function() {
                return (__ZNSt3__210unique_ptrIPvPFvS1_EE5resetEPS1_ = Module["__ZNSt3__210unique_ptrIPvPFvS1_EE5resetEPS1_"] = Module["asm"]["_ZNSt3__210unique_ptrIPvPFvS1_EE5resetEPS1_"]).apply(null, arguments)
            };
            var __ZNKSt3__210unique_ptrIPvPFvS1_EEcvbEv = Module["__ZNKSt3__210unique_ptrIPvPFvS1_EEcvbEv"] = function() {
                return (__ZNKSt3__210unique_ptrIPvPFvS1_EEcvbEv = Module["__ZNKSt3__210unique_ptrIPvPFvS1_EEcvbEv"] = Module["asm"]["_ZNKSt3__210unique_ptrIPvPFvS1_EEcvbEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIPFvNS_8ios_base5eventERS1_iEPFvPvEE7releaseEv = Module["__ZNSt3__210unique_ptrIPFvNS_8ios_base5eventERS1_iEPFvPvEE7releaseEv"] = function() {
                return (__ZNSt3__210unique_ptrIPFvNS_8ios_base5eventERS1_iEPFvPvEE7releaseEv = Module["__ZNSt3__210unique_ptrIPFvNS_8ios_base5eventERS1_iEPFvPvEE7releaseEv"] = Module["asm"]["_ZNSt3__210unique_ptrIPFvNS_8ios_base5eventERS1_iEPFvPvEE7releaseEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIiPFvPvEE7releaseEv = Module["__ZNSt3__210unique_ptrIiPFvPvEE7releaseEv"] = function() {
                return (__ZNSt3__210unique_ptrIiPFvPvEE7releaseEv = Module["__ZNSt3__210unique_ptrIiPFvPvEE7releaseEv"] = Module["asm"]["_ZNSt3__210unique_ptrIiPFvPvEE7releaseEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIlPFvPvEE7releaseEv = Module["__ZNSt3__210unique_ptrIlPFvPvEE7releaseEv"] = function() {
                return (__ZNSt3__210unique_ptrIlPFvPvEE7releaseEv = Module["__ZNSt3__210unique_ptrIlPFvPvEE7releaseEv"] = Module["asm"]["_ZNSt3__210unique_ptrIlPFvPvEE7releaseEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIPvPFvS1_EE7releaseEv = Module["__ZNSt3__210unique_ptrIPvPFvS1_EE7releaseEv"] = function() {
                return (__ZNSt3__210unique_ptrIPvPFvS1_EE7releaseEv = Module["__ZNSt3__210unique_ptrIPvPFvS1_EE7releaseEv"] = Module["asm"]["_ZNSt3__210unique_ptrIPvPFvS1_EE7releaseEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIPvPFvS1_EED2Ev = Module["__ZNSt3__210unique_ptrIPvPFvS1_EED2Ev"] = function() {
                return (__ZNSt3__210unique_ptrIPvPFvS1_EED2Ev = Module["__ZNSt3__210unique_ptrIPvPFvS1_EED2Ev"] = Module["asm"]["_ZNSt3__210unique_ptrIPvPFvS1_EED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIlPFvPvEED2Ev = Module["__ZNSt3__210unique_ptrIlPFvPvEED2Ev"] = function() {
                return (__ZNSt3__210unique_ptrIlPFvPvEED2Ev = Module["__ZNSt3__210unique_ptrIlPFvPvEED2Ev"] = Module["asm"]["_ZNSt3__210unique_ptrIlPFvPvEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIiPFvPvEED2Ev = Module["__ZNSt3__210unique_ptrIiPFvPvEED2Ev"] = function() {
                return (__ZNSt3__210unique_ptrIiPFvPvEED2Ev = Module["__ZNSt3__210unique_ptrIiPFvPvEED2Ev"] = Module["asm"]["_ZNSt3__210unique_ptrIiPFvPvEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIPFvNS_8ios_base5eventERS1_iEPFvPvEED2Ev = Module["__ZNSt3__210unique_ptrIPFvNS_8ios_base5eventERS1_iEPFvPvEED2Ev"] = function() {
                return (__ZNSt3__210unique_ptrIPFvNS_8ios_base5eventERS1_iEPFvPvEED2Ev = Module["__ZNSt3__210unique_ptrIPFvNS_8ios_base5eventERS1_iEPFvPvEED2Ev"] = Module["asm"]["_ZNSt3__210unique_ptrIPFvNS_8ios_base5eventERS1_iEPFvPvEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base10exceptionsEj = Module["__ZNSt3__28ios_base10exceptionsEj"] = function() {
                return (__ZNSt3__28ios_base10exceptionsEj = Module["__ZNSt3__28ios_base10exceptionsEj"] = Module["asm"]["_ZNSt3__28ios_base10exceptionsEj"]).apply(null, arguments)
            };
            var __ZNKSt3__28ios_base10exceptionsEv = Module["__ZNKSt3__28ios_base10exceptionsEv"] = function() {
                return (__ZNKSt3__28ios_base10exceptionsEv = Module["__ZNKSt3__28ios_base10exceptionsEv"] = Module["asm"]["_ZNKSt3__28ios_base10exceptionsEv"]).apply(null, arguments)
            };
            var __ZNSt3__29basic_iosIwNS_11char_traitsIwEEED2Ev = Module["__ZNSt3__29basic_iosIwNS_11char_traitsIwEEED2Ev"] = function() {
                return (__ZNSt3__29basic_iosIwNS_11char_traitsIwEEED2Ev = Module["__ZNSt3__29basic_iosIwNS_11char_traitsIwEEED2Ev"] = Module["asm"]["_ZNSt3__29basic_iosIwNS_11char_traitsIwEEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29basic_iosIwNS_11char_traitsIwEEED0Ev = Module["__ZNSt3__29basic_iosIwNS_11char_traitsIwEEED0Ev"] = function() {
                return (__ZNSt3__29basic_iosIwNS_11char_traitsIwEEED0Ev = Module["__ZNSt3__29basic_iosIwNS_11char_traitsIwEEED0Ev"] = Module["asm"]["_ZNSt3__29basic_iosIwNS_11char_traitsIwEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29basic_iosIwNS_11char_traitsIwEEE7copyfmtERKS3_ = Module["__ZNSt3__29basic_iosIwNS_11char_traitsIwEEE7copyfmtERKS3_"] = function() {
                return (__ZNSt3__29basic_iosIwNS_11char_traitsIwEEE7copyfmtERKS3_ = Module["__ZNSt3__29basic_iosIwNS_11char_traitsIwEEE7copyfmtERKS3_"] = Module["asm"]["_ZNSt3__29basic_iosIwNS_11char_traitsIwEEE7copyfmtERKS3_"]).apply(null, arguments)
            };
            var __ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE10exceptionsEv = Module["__ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE10exceptionsEv"] = function() {
                return (__ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE10exceptionsEv = Module["__ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE10exceptionsEv"] = Module["asm"]["_ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE10exceptionsEv"]).apply(null, arguments)
            };
            var __ZNSt3__29basic_iosIwNS_11char_traitsIwEEE10exceptionsEj = Module["__ZNSt3__29basic_iosIwNS_11char_traitsIwEEE10exceptionsEj"] = function() {
                return (__ZNSt3__29basic_iosIwNS_11char_traitsIwEEE10exceptionsEj = Module["__ZNSt3__29basic_iosIwNS_11char_traitsIwEEE10exceptionsEj"] = Module["asm"]["_ZNSt3__29basic_iosIwNS_11char_traitsIwEEE10exceptionsEj"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED0Ev = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED0Ev"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED0Ev = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED0Ev"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2ERKS3_ = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2ERKS3_"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2ERKS3_ = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2ERKS3_"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC2ERKS3_"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEaSERKS3_ = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEaSERKS3_"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEaSERKS3_ = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEaSERKS3_"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEaSERKS3_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapINS_6localeEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS3_EE5valueEvE4typeERS3_S6_ = Module["__ZNSt3__24swapINS_6localeEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS3_EE5valueEvE4typeERS3_S6_"] = function() {
                return (__ZNSt3__24swapINS_6localeEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS3_EE5valueEvE4typeERS3_S6_ = Module["__ZNSt3__24swapINS_6localeEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS3_EE5valueEvE4typeERS3_S6_"] = Module["asm"]["_ZNSt3__24swapINS_6localeEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS3_EE5valueEvE4typeERS3_S6_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIPcEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS3_EE5valueEvE4typeERS3_S6_ = Module["__ZNSt3__24swapIPcEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS3_EE5valueEvE4typeERS3_S6_"] = function() {
                return (__ZNSt3__24swapIPcEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS3_EE5valueEvE4typeERS3_S6_ = Module["__ZNSt3__24swapIPcEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS3_EE5valueEvE4typeERS3_S6_"] = Module["asm"]["_ZNSt3__24swapIPcEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS3_EE5valueEvE4typeERS3_S6_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRNS_6localeEEEONS_16remove_referenceIT_E4typeEOS4_ = Module["__ZNSt3__24moveIRNS_6localeEEEONS_16remove_referenceIT_E4typeEOS4_"] = function() {
                return (__ZNSt3__24moveIRNS_6localeEEEONS_16remove_referenceIT_E4typeEOS4_ = Module["__ZNSt3__24moveIRNS_6localeEEEONS_16remove_referenceIT_E4typeEOS4_"] = Module["asm"]["_ZNSt3__24moveIRNS_6localeEEEONS_16remove_referenceIT_E4typeEOS4_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRPcEEONS_16remove_referenceIT_E4typeEOS4_ = Module["__ZNSt3__24moveIRPcEEONS_16remove_referenceIT_E4typeEOS4_"] = function() {
                return (__ZNSt3__24moveIRPcEEONS_16remove_referenceIT_E4typeEOS4_ = Module["__ZNSt3__24moveIRPcEEONS_16remove_referenceIT_E4typeEOS4_"] = Module["asm"]["_ZNSt3__24moveIRPcEEONS_16remove_referenceIT_E4typeEOS4_"]).apply(null, arguments)
            };
            var __ZNSt3__23minIlEERKT_S3_S3_ = Module["__ZNSt3__23minIlEERKT_S3_S3_"] = function() {
                return (__ZNSt3__23minIlEERKT_S3_S3_ = Module["__ZNSt3__23minIlEERKT_S3_S3_"] = Module["asm"]["_ZNSt3__23minIlEERKT_S3_S3_"]).apply(null, arguments)
            };
            var __ZNSt3__23minIlNS_6__lessIllEEEERKT_S5_S5_T0_ = Module["__ZNSt3__23minIlNS_6__lessIllEEEERKT_S5_S5_T0_"] = function() {
                return (__ZNSt3__23minIlNS_6__lessIllEEEERKT_S5_S5_T0_ = Module["__ZNSt3__23minIlNS_6__lessIllEEEERKT_S5_S5_T0_"] = Module["asm"]["_ZNSt3__23minIlNS_6__lessIllEEEERKT_S5_S5_T0_"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED0Ev = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED0Ev"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED0Ev = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED0Ev"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC2ERKS3_ = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC2ERKS3_"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC2ERKS3_ = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC2ERKS3_"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC2ERKS3_"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEaSERKS3_ = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEaSERKS3_"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEaSERKS3_ = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEaSERKS3_"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEaSERKS3_"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE4swapERS3_ = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE4swapERS3_"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE4swapERS3_ = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE4swapERS3_"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE4swapERS3_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIPwEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS3_EE5valueEvE4typeERS3_S6_ = Module["__ZNSt3__24swapIPwEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS3_EE5valueEvE4typeERS3_S6_"] = function() {
                return (__ZNSt3__24swapIPwEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS3_EE5valueEvE4typeERS3_S6_ = Module["__ZNSt3__24swapIPwEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS3_EE5valueEvE4typeERS3_S6_"] = Module["asm"]["_ZNSt3__24swapIPwEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS3_EE5valueEvE4typeERS3_S6_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRPwEEONS_16remove_referenceIT_E4typeEOS4_ = Module["__ZNSt3__24moveIRPwEEONS_16remove_referenceIT_E4typeEOS4_"] = function() {
                return (__ZNSt3__24moveIRPwEEONS_16remove_referenceIT_E4typeEOS4_ = Module["__ZNSt3__24moveIRPwEEONS_16remove_referenceIT_E4typeEOS4_"] = Module["asm"]["_ZNSt3__24moveIRPwEEONS_16remove_referenceIT_E4typeEOS4_"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5imbueERKNS_6localeE = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5imbueERKNS_6localeE"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5imbueERKNS_6localeE = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5imbueERKNS_6localeE"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5imbueERKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5gbumpEi = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5gbumpEi"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5gbumpEi = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5gbumpEi"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5gbumpEi"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE6sentryC2ERS3_b = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE6sentryC2ERS3_b"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE6sentryC2ERS3_b = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE6sentryC2ERS3_b"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE6sentryC2ERS3_b"]).apply(null, arguments)
            };
            var __ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE4goodEv = Module["__ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE4goodEv"] = function() {
                return (__ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE4goodEv = Module["__ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE4goodEv"] = Module["asm"]["_ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE4goodEv"]).apply(null, arguments)
            };
            var __ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE3tieEv = Module["__ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE3tieEv"] = function() {
                return (__ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE3tieEv = Module["__ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE3tieEv"] = Module["asm"]["_ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE3tieEv"]).apply(null, arguments)
            };
            var __ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEC2ERNS_13basic_istreamIcS2_EE = Module["__ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEC2ERNS_13basic_istreamIcS2_EE"] = function() {
                return (__ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEC2ERNS_13basic_istreamIcS2_EE = Module["__ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEC2ERNS_13basic_istreamIcS2_EE"] = Module["asm"]["_ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEC2ERNS_13basic_istreamIcS2_EE"]).apply(null, arguments)
            };
            var __ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEC2Ev = Module["__ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEC2Ev"] = function() {
                return (__ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEC2Ev = Module["__ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEC2Ev"] = Module["asm"]["_ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29basic_iosIcNS_11char_traitsIcEEE8setstateEj = Module["__ZNSt3__29basic_iosIcNS_11char_traitsIcEEE8setstateEj"] = function() {
                return (__ZNSt3__29basic_iosIcNS_11char_traitsIcEEE8setstateEj = Module["__ZNSt3__29basic_iosIcNS_11char_traitsIcEEE8setstateEj"] = Module["asm"]["_ZNSt3__29basic_iosIcNS_11char_traitsIcEEE8setstateEj"]).apply(null, arguments)
            };
            var __ZNKSt3__28ios_base4goodEv = Module["__ZNKSt3__28ios_base4goodEv"] = function() {
                return (__ZNKSt3__28ios_base4goodEv = Module["__ZNKSt3__28ios_base4goodEv"] = Module["asm"]["_ZNKSt3__28ios_base4goodEv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryC2ERS3_ = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryC2ERS3_"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryC2ERS3_ = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryC2ERS3_"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryC2ERS3_"]).apply(null, arguments)
            };
            var __ZNKSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentrycvbEv = Module["__ZNKSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentrycvbEv"] = function() {
                return (__ZNKSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentrycvbEv = Module["__ZNKSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentrycvbEv"] = Module["asm"]["_ZNKSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentrycvbEv"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7pubsyncEv = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7pubsyncEv"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7pubsyncEv = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7pubsyncEv"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7pubsyncEv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base8setstateEj = Module["__ZNSt3__28ios_base8setstateEj"] = function() {
                return (__ZNSt3__28ios_base8setstateEj = Module["__ZNSt3__28ios_base8setstateEj"] = Module["asm"]["_ZNSt3__28ios_base8setstateEj"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsEPNS_15basic_streambufIcS2_EE = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsEPNS_15basic_streambufIcS2_EE"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsEPNS_15basic_streambufIcS2_EE = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsEPNS_15basic_streambufIcS2_EE"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsEPNS_15basic_streambufIcS2_EE"]).apply(null, arguments)
            };
            var __ZNKSt3__213basic_istreamIcNS_11char_traitsIcEEE6sentrycvbEv = Module["__ZNKSt3__213basic_istreamIcNS_11char_traitsIcEEE6sentrycvbEv"] = function() {
                return (__ZNKSt3__213basic_istreamIcNS_11char_traitsIcEEE6sentrycvbEv = Module["__ZNKSt3__213basic_istreamIcNS_11char_traitsIcEEE6sentrycvbEv"] = Module["asm"]["_ZNKSt3__213basic_istreamIcNS_11char_traitsIcEEE6sentrycvbEv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERb = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERb"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERb = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERb"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERb"]).apply(null, arguments)
            };
            var __ZNSt3__218__input_arithmeticIbcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIbcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = function() {
                return (__ZNSt3__218__input_arithmeticIbcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIbcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = Module["asm"]["_ZNSt3__218__input_arithmeticIbcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"]).apply(null, arguments)
            };
            var __ZNSt3__29use_facetINS_7num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_7num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEERKT_RKNS_6localeE"] = function() {
                return (__ZNSt3__29use_facetINS_7num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_7num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEERKT_RKNS_6localeE"] = Module["asm"]["_ZNSt3__29use_facetINS_7num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEEEERKT_RKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRb = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRb"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRb = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRb"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRb"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERs = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERs"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERs = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERs"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERs"]).apply(null, arguments)
            };
            var __ZNSt3__238__input_arithmetic_with_numeric_limitsIscNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__238__input_arithmetic_with_numeric_limitsIscNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = function() {
                return (__ZNSt3__238__input_arithmetic_with_numeric_limitsIscNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__238__input_arithmetic_with_numeric_limitsIscNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = Module["asm"]["_ZNSt3__238__input_arithmetic_with_numeric_limitsIscNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRl = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRl"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRl = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRl"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRl"]).apply(null, arguments)
            };
            var __ZNSt3__214numeric_limitsIsE3minEv = Module["__ZNSt3__214numeric_limitsIsE3minEv"] = function() {
                return (__ZNSt3__214numeric_limitsIsE3minEv = Module["__ZNSt3__214numeric_limitsIsE3minEv"] = Module["asm"]["_ZNSt3__214numeric_limitsIsE3minEv"]).apply(null, arguments)
            };
            var __ZNSt3__214numeric_limitsIsE3maxEv = Module["__ZNSt3__214numeric_limitsIsE3maxEv"] = function() {
                return (__ZNSt3__214numeric_limitsIsE3maxEv = Module["__ZNSt3__214numeric_limitsIsE3maxEv"] = Module["asm"]["_ZNSt3__214numeric_limitsIsE3maxEv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERt = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERt"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERt = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERt"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERt"]).apply(null, arguments)
            };
            var __ZNSt3__218__input_arithmeticItcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticItcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = function() {
                return (__ZNSt3__218__input_arithmeticItcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticItcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = Module["asm"]["_ZNSt3__218__input_arithmeticItcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRt = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRt"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRt = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRt"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRt"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERi = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERi"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERi = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERi"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERi"]).apply(null, arguments)
            };
            var __ZNSt3__238__input_arithmetic_with_numeric_limitsIicNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__238__input_arithmetic_with_numeric_limitsIicNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = function() {
                return (__ZNSt3__238__input_arithmetic_with_numeric_limitsIicNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__238__input_arithmetic_with_numeric_limitsIicNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = Module["asm"]["_ZNSt3__238__input_arithmetic_with_numeric_limitsIicNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERj = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERj"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERj = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERj"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERj"]).apply(null, arguments)
            };
            var __ZNSt3__218__input_arithmeticIjcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIjcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = function() {
                return (__ZNSt3__218__input_arithmeticIjcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIjcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = Module["asm"]["_ZNSt3__218__input_arithmeticIjcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjS8_ = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjS8_"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjS8_ = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjS8_"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjS8_"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERl = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERl"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERl = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERl"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERl"]).apply(null, arguments)
            };
            var __ZNSt3__218__input_arithmeticIlcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIlcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = function() {
                return (__ZNSt3__218__input_arithmeticIlcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIlcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = Module["asm"]["_ZNSt3__218__input_arithmeticIlcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERm = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERm"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERm = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERm"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERm"]).apply(null, arguments)
            };
            var __ZNSt3__218__input_arithmeticImcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticImcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = function() {
                return (__ZNSt3__218__input_arithmeticImcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticImcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = Module["asm"]["_ZNSt3__218__input_arithmeticImcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRm = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRm"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRm = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRm"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRm"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERx = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERx"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERx = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERx"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERx"]).apply(null, arguments)
            };
            var __ZNSt3__218__input_arithmeticIxcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIxcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = function() {
                return (__ZNSt3__218__input_arithmeticIxcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIxcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = Module["asm"]["_ZNSt3__218__input_arithmeticIxcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRx = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRx"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRx = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRx"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRx"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERy = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERy"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERy = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERy"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERy"]).apply(null, arguments)
            };
            var __ZNSt3__218__input_arithmeticIycNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIycNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = function() {
                return (__ZNSt3__218__input_arithmeticIycNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIycNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = Module["asm"]["_ZNSt3__218__input_arithmeticIycNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRy = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRy"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRy = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRy"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRy"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERf = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERf"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERf = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERf"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERf"]).apply(null, arguments)
            };
            var __ZNSt3__218__input_arithmeticIfcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIfcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = function() {
                return (__ZNSt3__218__input_arithmeticIfcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIfcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = Module["asm"]["_ZNSt3__218__input_arithmeticIfcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRf = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRf"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRf = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRf"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRf"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERd = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERd"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERd = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERd"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERd"]).apply(null, arguments)
            };
            var __ZNSt3__218__input_arithmeticIdcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIdcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = function() {
                return (__ZNSt3__218__input_arithmeticIdcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIdcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = Module["asm"]["_ZNSt3__218__input_arithmeticIdcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRd = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRd"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRd = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRd"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRd"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERe = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERe"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERe = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERe"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERe"]).apply(null, arguments)
            };
            var __ZNSt3__218__input_arithmeticIecNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIecNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = function() {
                return (__ZNSt3__218__input_arithmeticIecNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIecNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = Module["asm"]["_ZNSt3__218__input_arithmeticIecNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES7_RT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRe = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRe"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRe = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRe"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRe"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERPv = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERPv"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERPv = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERPv"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEErsERPv"]).apply(null, arguments)
            };
            var __ZNSt3__218__input_arithmeticIPvcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES8_RT_ = Module["__ZNSt3__218__input_arithmeticIPvcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES8_RT_"] = function() {
                return (__ZNSt3__218__input_arithmeticIPvcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES8_RT_ = Module["__ZNSt3__218__input_arithmeticIPvcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES8_RT_"] = Module["asm"]["_ZNSt3__218__input_arithmeticIPvcNS_11char_traitsIcEEEERNS_13basic_istreamIT0_T1_EES8_RT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRPv = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRPv"] = function() {
                return (__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRPv = Module["__ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRPv"] = Module["asm"]["_ZNKSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE3getES4_S4_RNS_8ios_baseERjRPv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE3getEv = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE3getEv"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE3getEv = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE3getEv"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE3getEv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE3getEPclc = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE3getEPclc"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE3getEPclc = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE3getEPclc"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE3getEPclc"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE3getERNS_15basic_streambufIcS2_EEc = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE3getERNS_15basic_streambufIcS2_EEc"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE3getERNS_15basic_streambufIcS2_EEc = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE3getERNS_15basic_streambufIcS2_EEc"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE3getERNS_15basic_streambufIcS2_EEc"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE7getlineEPclc = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE7getlineEPclc"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE7getlineEPclc = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE7getlineEPclc"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE7getlineEPclc"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE6ignoreEli = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE6ignoreEli"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE6ignoreEli = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE6ignoreEli"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE6ignoreEli"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE4peekEv = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE4peekEv"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE4peekEv = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE4peekEv"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE4peekEv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE4readEPcl = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE4readEPcl"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE4readEPcl = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE4readEPcl"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE4readEPcl"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5sgetnEPcl = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5sgetnEPcl"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5sgetnEPcl = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5sgetnEPcl"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE5sgetnEPcl"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE8readsomeEPcl = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE8readsomeEPcl"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE8readsomeEPcl = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE8readsomeEPcl"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE8readsomeEPcl"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE8in_availEv = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE8in_availEv"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE8in_availEv = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE8in_availEv"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE8in_availEv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE7putbackEc = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE7putbackEc"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE7putbackEc = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE7putbackEc"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE7putbackEc"]).apply(null, arguments)
            };
            var __ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE7rdstateEv = Module["__ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE7rdstateEv"] = function() {
                return (__ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE7rdstateEv = Module["__ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE7rdstateEv"] = Module["asm"]["_ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE7rdstateEv"]).apply(null, arguments)
            };
            var __ZNSt3__29basic_iosIcNS_11char_traitsIcEEE5clearEj = Module["__ZNSt3__29basic_iosIcNS_11char_traitsIcEEE5clearEj"] = function() {
                return (__ZNSt3__29basic_iosIcNS_11char_traitsIcEEE5clearEj = Module["__ZNSt3__29basic_iosIcNS_11char_traitsIcEEE5clearEj"] = Module["asm"]["_ZNSt3__29basic_iosIcNS_11char_traitsIcEEE5clearEj"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9sputbackcEc = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9sputbackcEc"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9sputbackcEc = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9sputbackcEc"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE9sputbackcEc"]).apply(null, arguments)
            };
            var __ZNKSt3__28ios_base7rdstateEv = Module["__ZNKSt3__28ios_base7rdstateEv"] = function() {
                return (__ZNKSt3__28ios_base7rdstateEv = Module["__ZNKSt3__28ios_base7rdstateEv"] = Module["asm"]["_ZNKSt3__28ios_base7rdstateEv"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base5clearEj = Module["__ZNSt3__28ios_base5clearEj"] = function() {
                return (__ZNSt3__28ios_base5clearEj = Module["__ZNSt3__28ios_base5clearEj"] = Module["asm"]["_ZNSt3__28ios_base5clearEj"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE5ungetEv = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE5ungetEv"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE5ungetEv = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE5ungetEv"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE5ungetEv"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7sungetcEv = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7sungetcEv"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7sungetcEv = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7sungetcEv"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7sungetcEv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE4syncEv = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE4syncEv"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE4syncEv = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE4syncEv"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE4syncEv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE5tellgEv = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE5tellgEv"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE5tellgEv = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE5tellgEv"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE5tellgEv"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE10pubseekoffExNS_8ios_base7seekdirEj = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE10pubseekoffExNS_8ios_base7seekdirEj"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE10pubseekoffExNS_8ios_base7seekdirEj = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE10pubseekoffExNS_8ios_base7seekdirEj"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE10pubseekoffExNS_8ios_base7seekdirEj"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE5seekgENS_4fposI11__mbstate_tEE = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE5seekgENS_4fposI11__mbstate_tEE"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE5seekgENS_4fposI11__mbstate_tEE = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE5seekgENS_4fposI11__mbstate_tEE"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE5seekgENS_4fposI11__mbstate_tEE"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE10pubseekposENS_4fposI11__mbstate_tEEj = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE10pubseekposENS_4fposI11__mbstate_tEEj"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE10pubseekposENS_4fposI11__mbstate_tEEj = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE10pubseekposENS_4fposI11__mbstate_tEEj"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE10pubseekposENS_4fposI11__mbstate_tEEj"]).apply(null, arguments)
            };
            var __ZNSt3__2eqI11__mbstate_tEEbRKNS_4fposIT_EES6_ = Module["__ZNSt3__2eqI11__mbstate_tEEbRKNS_4fposIT_EES6_"] = function() {
                return (__ZNSt3__2eqI11__mbstate_tEEbRKNS_4fposIT_EES6_ = Module["__ZNSt3__2eqI11__mbstate_tEEbRKNS_4fposIT_EES6_"] = Module["asm"]["_ZNSt3__2eqI11__mbstate_tEEbRKNS_4fposIT_EES6_"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE5seekgExNS_8ios_base7seekdirE = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE5seekgExNS_8ios_base7seekdirE"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE5seekgExNS_8ios_base7seekdirE = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE5seekgExNS_8ios_base7seekdirE"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE5seekgExNS_8ios_base7seekdirE"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED2Ev = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED2Ev"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED2Ev = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED2Ev"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED1Ev = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED1Ev"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED1Ev = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED1Ev"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED1Ev"]).apply(null, arguments)
            };
            var __ZTv0_n12_NSt3__213basic_istreamIwNS_11char_traitsIwEEED1Ev = Module["__ZTv0_n12_NSt3__213basic_istreamIwNS_11char_traitsIwEEED1Ev"] = function() {
                return (__ZTv0_n12_NSt3__213basic_istreamIwNS_11char_traitsIwEEED1Ev = Module["__ZTv0_n12_NSt3__213basic_istreamIwNS_11char_traitsIwEEED1Ev"] = Module["asm"]["_ZTv0_n12_NSt3__213basic_istreamIwNS_11char_traitsIwEEED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED0Ev = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED0Ev"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED0Ev = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED0Ev"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEED0Ev"]).apply(null, arguments)
            };
            var __ZTv0_n12_NSt3__213basic_istreamIwNS_11char_traitsIwEEED0Ev = Module["__ZTv0_n12_NSt3__213basic_istreamIwNS_11char_traitsIwEEED0Ev"] = function() {
                return (__ZTv0_n12_NSt3__213basic_istreamIwNS_11char_traitsIwEEED0Ev = Module["__ZTv0_n12_NSt3__213basic_istreamIwNS_11char_traitsIwEEED0Ev"] = Module["asm"]["_ZTv0_n12_NSt3__213basic_istreamIwNS_11char_traitsIwEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE6sentryC2ERS3_b = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE6sentryC2ERS3_b"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE6sentryC2ERS3_b = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE6sentryC2ERS3_b"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE6sentryC2ERS3_b"]).apply(null, arguments)
            };
            var __ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE4goodEv = Module["__ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE4goodEv"] = function() {
                return (__ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE4goodEv = Module["__ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE4goodEv"] = Module["asm"]["_ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE4goodEv"]).apply(null, arguments)
            };
            var __ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE3tieEv = Module["__ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE3tieEv"] = function() {
                return (__ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE3tieEv = Module["__ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE3tieEv"] = Module["asm"]["_ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE3tieEv"]).apply(null, arguments)
            };
            var __ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEC2ERNS_13basic_istreamIwS2_EE = Module["__ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEC2ERNS_13basic_istreamIwS2_EE"] = function() {
                return (__ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEC2ERNS_13basic_istreamIwS2_EE = Module["__ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEC2ERNS_13basic_istreamIwS2_EE"] = Module["asm"]["_ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEC2ERNS_13basic_istreamIwS2_EE"]).apply(null, arguments)
            };
            var __ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEC2Ev = Module["__ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEC2Ev"] = function() {
                return (__ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEC2Ev = Module["__ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEC2Ev"] = Module["asm"]["_ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29basic_iosIwNS_11char_traitsIwEEE8setstateEj = Module["__ZNSt3__29basic_iosIwNS_11char_traitsIwEEE8setstateEj"] = function() {
                return (__ZNSt3__29basic_iosIwNS_11char_traitsIwEEE8setstateEj = Module["__ZNSt3__29basic_iosIwNS_11char_traitsIwEEE8setstateEj"] = Module["asm"]["_ZNSt3__29basic_iosIwNS_11char_traitsIwEEE8setstateEj"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryC2ERS3_ = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryC2ERS3_"] = function() {
                return (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryC2ERS3_ = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryC2ERS3_"] = Module["asm"]["_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryC2ERS3_"]).apply(null, arguments)
            };
            var __ZNKSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentrycvbEv = Module["__ZNKSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentrycvbEv"] = function() {
                return (__ZNKSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentrycvbEv = Module["__ZNKSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentrycvbEv"] = Module["asm"]["_ZNKSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentrycvbEv"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7pubsyncEv = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7pubsyncEv"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7pubsyncEv = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7pubsyncEv"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7pubsyncEv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryD2Ev = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryD2Ev"] = function() {
                return (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryD2Ev = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryD2Ev"] = Module["asm"]["_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsEPNS_15basic_streambufIwS2_EE = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsEPNS_15basic_streambufIwS2_EE"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsEPNS_15basic_streambufIwS2_EE = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsEPNS_15basic_streambufIwS2_EE"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsEPNS_15basic_streambufIwS2_EE"]).apply(null, arguments)
            };
            var __ZNKSt3__213basic_istreamIwNS_11char_traitsIwEEE6sentrycvbEv = Module["__ZNKSt3__213basic_istreamIwNS_11char_traitsIwEEE6sentrycvbEv"] = function() {
                return (__ZNKSt3__213basic_istreamIwNS_11char_traitsIwEEE6sentrycvbEv = Module["__ZNKSt3__213basic_istreamIwNS_11char_traitsIwEEE6sentrycvbEv"] = Module["asm"]["_ZNKSt3__213basic_istreamIwNS_11char_traitsIwEEE6sentrycvbEv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERb = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERb"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERb = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERb"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERb"]).apply(null, arguments)
            };
            var __ZNSt3__218__input_arithmeticIbwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIbwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = function() {
                return (__ZNSt3__218__input_arithmeticIbwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIbwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = Module["asm"]["_ZNSt3__218__input_arithmeticIbwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"]).apply(null, arguments)
            };
            var __ZNSt3__29use_facetINS_7num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_7num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEERKT_RKNS_6localeE"] = function() {
                return (__ZNSt3__29use_facetINS_7num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_7num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEERKT_RKNS_6localeE"] = Module["asm"]["_ZNSt3__29use_facetINS_7num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEEEERKT_RKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRb = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRb"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRb = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRb"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRb"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERs = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERs"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERs = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERs"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERs"]).apply(null, arguments)
            };
            var __ZNSt3__238__input_arithmetic_with_numeric_limitsIswNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__238__input_arithmetic_with_numeric_limitsIswNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = function() {
                return (__ZNSt3__238__input_arithmetic_with_numeric_limitsIswNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__238__input_arithmetic_with_numeric_limitsIswNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = Module["asm"]["_ZNSt3__238__input_arithmetic_with_numeric_limitsIswNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRl = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRl"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRl = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRl"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRl"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERt = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERt"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERt = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERt"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERt"]).apply(null, arguments)
            };
            var __ZNSt3__218__input_arithmeticItwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticItwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = function() {
                return (__ZNSt3__218__input_arithmeticItwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticItwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = Module["asm"]["_ZNSt3__218__input_arithmeticItwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRt = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRt"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRt = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRt"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRt"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERi = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERi"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERi = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERi"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERi"]).apply(null, arguments)
            };
            var __ZNSt3__238__input_arithmetic_with_numeric_limitsIiwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__238__input_arithmetic_with_numeric_limitsIiwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = function() {
                return (__ZNSt3__238__input_arithmetic_with_numeric_limitsIiwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__238__input_arithmetic_with_numeric_limitsIiwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = Module["asm"]["_ZNSt3__238__input_arithmetic_with_numeric_limitsIiwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERj = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERj"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERj = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERj"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERj"]).apply(null, arguments)
            };
            var __ZNSt3__218__input_arithmeticIjwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIjwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = function() {
                return (__ZNSt3__218__input_arithmeticIjwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIjwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = Module["asm"]["_ZNSt3__218__input_arithmeticIjwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjS8_ = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjS8_"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjS8_ = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjS8_"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjS8_"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERl = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERl"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERl = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERl"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERl"]).apply(null, arguments)
            };
            var __ZNSt3__218__input_arithmeticIlwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIlwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = function() {
                return (__ZNSt3__218__input_arithmeticIlwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIlwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = Module["asm"]["_ZNSt3__218__input_arithmeticIlwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERm = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERm"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERm = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERm"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERm"]).apply(null, arguments)
            };
            var __ZNSt3__218__input_arithmeticImwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticImwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = function() {
                return (__ZNSt3__218__input_arithmeticImwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticImwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = Module["asm"]["_ZNSt3__218__input_arithmeticImwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRm = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRm"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRm = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRm"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRm"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERx = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERx"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERx = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERx"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERx"]).apply(null, arguments)
            };
            var __ZNSt3__218__input_arithmeticIxwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIxwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = function() {
                return (__ZNSt3__218__input_arithmeticIxwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIxwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = Module["asm"]["_ZNSt3__218__input_arithmeticIxwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRx = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRx"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRx = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRx"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRx"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERy = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERy"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERy = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERy"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERy"]).apply(null, arguments)
            };
            var __ZNSt3__218__input_arithmeticIywNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIywNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = function() {
                return (__ZNSt3__218__input_arithmeticIywNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIywNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = Module["asm"]["_ZNSt3__218__input_arithmeticIywNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRy = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRy"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRy = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRy"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRy"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERf = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERf"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERf = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERf"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERf"]).apply(null, arguments)
            };
            var __ZNSt3__218__input_arithmeticIfwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIfwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = function() {
                return (__ZNSt3__218__input_arithmeticIfwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIfwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = Module["asm"]["_ZNSt3__218__input_arithmeticIfwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRf = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRf"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRf = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRf"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRf"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERd = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERd"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERd = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERd"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERd"]).apply(null, arguments)
            };
            var __ZNSt3__218__input_arithmeticIdwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIdwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = function() {
                return (__ZNSt3__218__input_arithmeticIdwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIdwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = Module["asm"]["_ZNSt3__218__input_arithmeticIdwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRd = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRd"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRd = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRd"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRd"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERe = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERe"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERe = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERe"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERe"]).apply(null, arguments)
            };
            var __ZNSt3__218__input_arithmeticIewNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIewNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = function() {
                return (__ZNSt3__218__input_arithmeticIewNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_ = Module["__ZNSt3__218__input_arithmeticIewNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"] = Module["asm"]["_ZNSt3__218__input_arithmeticIewNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES7_RT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRe = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRe"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRe = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRe"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRe"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERPv = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERPv"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERPv = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERPv"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEErsERPv"]).apply(null, arguments)
            };
            var __ZNSt3__218__input_arithmeticIPvwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES8_RT_ = Module["__ZNSt3__218__input_arithmeticIPvwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES8_RT_"] = function() {
                return (__ZNSt3__218__input_arithmeticIPvwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES8_RT_ = Module["__ZNSt3__218__input_arithmeticIPvwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES8_RT_"] = Module["asm"]["_ZNSt3__218__input_arithmeticIPvwNS_11char_traitsIwEEEERNS_13basic_istreamIT0_T1_EES8_RT_"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRPv = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRPv"] = function() {
                return (__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRPv = Module["__ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRPv"] = Module["asm"]["_ZNKSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE3getES4_S4_RNS_8ios_baseERjRPv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE3getEv = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE3getEv"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE3getEv = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE3getEv"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE3getEv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE3getEPwlw = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE3getEPwlw"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE3getEPwlw = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE3getEPwlw"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE3getEPwlw"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE3getERNS_15basic_streambufIwS2_EEw = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE3getERNS_15basic_streambufIwS2_EEw"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE3getERNS_15basic_streambufIwS2_EEw = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE3getERNS_15basic_streambufIwS2_EEw"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE3getERNS_15basic_streambufIwS2_EEw"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE7getlineEPwlw = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE7getlineEPwlw"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE7getlineEPwlw = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE7getlineEPwlw"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE7getlineEPwlw"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE6ignoreElj = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE6ignoreElj"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE6ignoreElj = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE6ignoreElj"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE6ignoreElj"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE4peekEv = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE4peekEv"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE4peekEv = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE4peekEv"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE4peekEv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE4readEPwl = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE4readEPwl"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE4readEPwl = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE4readEPwl"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE4readEPwl"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5sgetnEPwl = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5sgetnEPwl"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5sgetnEPwl = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5sgetnEPwl"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE5sgetnEPwl"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE8readsomeEPwl = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE8readsomeEPwl"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE8readsomeEPwl = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE8readsomeEPwl"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE8readsomeEPwl"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE8in_availEv = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE8in_availEv"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE8in_availEv = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE8in_availEv"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE8in_availEv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE7putbackEw = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE7putbackEw"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE7putbackEw = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE7putbackEw"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE7putbackEw"]).apply(null, arguments)
            };
            var __ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE7rdstateEv = Module["__ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE7rdstateEv"] = function() {
                return (__ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE7rdstateEv = Module["__ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE7rdstateEv"] = Module["asm"]["_ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE7rdstateEv"]).apply(null, arguments)
            };
            var __ZNSt3__29basic_iosIwNS_11char_traitsIwEEE5clearEj = Module["__ZNSt3__29basic_iosIwNS_11char_traitsIwEEE5clearEj"] = function() {
                return (__ZNSt3__29basic_iosIwNS_11char_traitsIwEEE5clearEj = Module["__ZNSt3__29basic_iosIwNS_11char_traitsIwEEE5clearEj"] = Module["asm"]["_ZNSt3__29basic_iosIwNS_11char_traitsIwEEE5clearEj"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9sputbackcEw = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9sputbackcEw"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9sputbackcEw = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9sputbackcEw"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE9sputbackcEw"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE5ungetEv = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE5ungetEv"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE5ungetEv = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE5ungetEv"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE5ungetEv"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7sungetcEv = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7sungetcEv"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7sungetcEv = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7sungetcEv"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7sungetcEv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE4syncEv = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE4syncEv"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE4syncEv = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE4syncEv"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE4syncEv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE5tellgEv = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE5tellgEv"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE5tellgEv = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE5tellgEv"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE5tellgEv"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE10pubseekoffExNS_8ios_base7seekdirEj = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE10pubseekoffExNS_8ios_base7seekdirEj"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE10pubseekoffExNS_8ios_base7seekdirEj = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE10pubseekoffExNS_8ios_base7seekdirEj"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE10pubseekoffExNS_8ios_base7seekdirEj"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE5seekgENS_4fposI11__mbstate_tEE = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE5seekgENS_4fposI11__mbstate_tEE"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE5seekgENS_4fposI11__mbstate_tEE = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE5seekgENS_4fposI11__mbstate_tEE"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE5seekgENS_4fposI11__mbstate_tEE"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE10pubseekposENS_4fposI11__mbstate_tEEj = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE10pubseekposENS_4fposI11__mbstate_tEEj"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE10pubseekposENS_4fposI11__mbstate_tEEj = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE10pubseekposENS_4fposI11__mbstate_tEEj"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE10pubseekposENS_4fposI11__mbstate_tEEj"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE5seekgExNS_8ios_base7seekdirE = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE5seekgExNS_8ios_base7seekdirE"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE5seekgExNS_8ios_base7seekdirE = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE5seekgExNS_8ios_base7seekdirE"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE5seekgExNS_8ios_base7seekdirE"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEb = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEb"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEb = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEb"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEb"]).apply(null, arguments)
            };
            var __ZNSt3__29use_facetINS_7num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_7num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEERKT_RKNS_6localeE"] = function() {
                return (__ZNSt3__29use_facetINS_7num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_7num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEERKT_RKNS_6localeE"] = Module["asm"]["_ZNSt3__29use_facetINS_7num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEEEERKT_RKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEEC2ERNS_13basic_ostreamIcS2_EE = Module["__ZNSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEEC2ERNS_13basic_ostreamIcS2_EE"] = function() {
                return (__ZNSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEEC2ERNS_13basic_ostreamIcS2_EE = Module["__ZNSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEEC2ERNS_13basic_ostreamIcS2_EE"] = Module["asm"]["_ZNSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEEC2ERNS_13basic_ostreamIcS2_EE"]).apply(null, arguments)
            };
            var __ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE4fillEv = Module["__ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE4fillEv"] = function() {
                return (__ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE4fillEv = Module["__ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE4fillEv"] = Module["asm"]["_ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE4fillEv"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcb = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcb"] = function() {
                return (__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcb = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcb"] = Module["asm"]["_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcb"]).apply(null, arguments)
            };
            var __ZNKSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEE6failedEv = Module["__ZNKSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEE6failedEv"] = function() {
                return (__ZNKSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEE6failedEv = Module["__ZNKSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEE6failedEv"] = Module["asm"]["_ZNKSt3__219ostreambuf_iteratorIcNS_11char_traitsIcEEE6failedEv"]).apply(null, arguments)
            };
            var __ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE5widenEc = Module["__ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE5widenEc"] = function() {
                return (__ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE5widenEc = Module["__ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE5widenEc"] = Module["asm"]["_ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE5widenEc"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEs = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEs"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEs = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEs"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEs"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcl = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcl"] = function() {
                return (__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcl = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcl"] = Module["asm"]["_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcl"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEt = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEt"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEt = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEt"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEt"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcm = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcm"] = function() {
                return (__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcm = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcm"] = Module["asm"]["_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcm"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEi"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEj"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEl = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEl"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEl = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEl"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEl"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEm = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEm"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEm = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEm"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEm"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEx = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEx"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEx = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEx"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEx"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcx = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcx"] = function() {
                return (__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcx = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcx"] = Module["asm"]["_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcx"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEy = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEy"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEy = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEy"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEy"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcy = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcy"] = function() {
                return (__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcy = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcy"] = Module["asm"]["_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcy"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEf"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcd = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcd"] = function() {
                return (__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcd = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcd"] = Module["asm"]["_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcd"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEd"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEe = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEe"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEe = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEe"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEe"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEce = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEce"] = function() {
                return (__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEce = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEce"] = Module["asm"]["_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEce"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPKv"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcPKv = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcPKv"] = function() {
                return (__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcPKv = Module["__ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcPKv"] = Module["asm"]["_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcPKv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPNS_15basic_streambufIcS2_EE = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPNS_15basic_streambufIcS2_EE"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPNS_15basic_streambufIcS2_EE = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPNS_15basic_streambufIcS2_EE"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEPNS_15basic_streambufIcS2_EE"]).apply(null, arguments)
            };
            var __ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEC2EPNS_15basic_streambufIcS2_EE = Module["__ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEC2EPNS_15basic_streambufIcS2_EE"] = function() {
                return (__ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEC2EPNS_15basic_streambufIcS2_EE = Module["__ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEC2EPNS_15basic_streambufIcS2_EE"] = Module["asm"]["_ZNSt3__219istreambuf_iteratorIcNS_11char_traitsIcEEEC2EPNS_15basic_streambufIcS2_EE"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE3putEc"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5writeEPKcl = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5writeEPKcl"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5writeEPKcl = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5writeEPKcl"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE5writeEPKcl"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED2Ev = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED2Ev"] = function() {
                return (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED2Ev = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED2Ev"] = Module["asm"]["_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED1Ev = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED1Ev"] = function() {
                return (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED1Ev = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED1Ev"] = Module["asm"]["_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED1Ev"]).apply(null, arguments)
            };
            var __ZTv0_n12_NSt3__213basic_ostreamIwNS_11char_traitsIwEEED1Ev = Module["__ZTv0_n12_NSt3__213basic_ostreamIwNS_11char_traitsIwEEED1Ev"] = function() {
                return (__ZTv0_n12_NSt3__213basic_ostreamIwNS_11char_traitsIwEEED1Ev = Module["__ZTv0_n12_NSt3__213basic_ostreamIwNS_11char_traitsIwEEED1Ev"] = Module["asm"]["_ZTv0_n12_NSt3__213basic_ostreamIwNS_11char_traitsIwEEED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED0Ev = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED0Ev"] = function() {
                return (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED0Ev = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED0Ev"] = Module["asm"]["_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEED0Ev"]).apply(null, arguments)
            };
            var __ZTv0_n12_NSt3__213basic_ostreamIwNS_11char_traitsIwEEED0Ev = Module["__ZTv0_n12_NSt3__213basic_ostreamIwNS_11char_traitsIwEEED0Ev"] = function() {
                return (__ZTv0_n12_NSt3__213basic_ostreamIwNS_11char_traitsIwEEED0Ev = Module["__ZTv0_n12_NSt3__213basic_ostreamIwNS_11char_traitsIwEEED0Ev"] = Module["asm"]["_ZTv0_n12_NSt3__213basic_ostreamIwNS_11char_traitsIwEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEb = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEb"] = function() {
                return (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEb = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEb"] = Module["asm"]["_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEb"]).apply(null, arguments)
            };
            var __ZNSt3__29use_facetINS_7num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_7num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEERKT_RKNS_6localeE"] = function() {
                return (__ZNSt3__29use_facetINS_7num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEERKT_RKNS_6localeE = Module["__ZNSt3__29use_facetINS_7num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEERKT_RKNS_6localeE"] = Module["asm"]["_ZNSt3__29use_facetINS_7num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEEEERKT_RKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEEC2ERNS_13basic_ostreamIwS2_EE = Module["__ZNSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEEC2ERNS_13basic_ostreamIwS2_EE"] = function() {
                return (__ZNSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEEC2ERNS_13basic_ostreamIwS2_EE = Module["__ZNSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEEC2ERNS_13basic_ostreamIwS2_EE"] = Module["asm"]["_ZNSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEEC2ERNS_13basic_ostreamIwS2_EE"]).apply(null, arguments)
            };
            var __ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE4fillEv = Module["__ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE4fillEv"] = function() {
                return (__ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE4fillEv = Module["__ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE4fillEv"] = Module["asm"]["_ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE4fillEv"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwb = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwb"] = function() {
                return (__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwb = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwb"] = Module["asm"]["_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwb"]).apply(null, arguments)
            };
            var __ZNKSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEE6failedEv = Module["__ZNKSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEE6failedEv"] = function() {
                return (__ZNKSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEE6failedEv = Module["__ZNKSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEE6failedEv"] = Module["asm"]["_ZNKSt3__219ostreambuf_iteratorIwNS_11char_traitsIwEEE6failedEv"]).apply(null, arguments)
            };
            var __ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE5widenEc = Module["__ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE5widenEc"] = function() {
                return (__ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE5widenEc = Module["__ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE5widenEc"] = Module["asm"]["_ZNKSt3__29basic_iosIwNS_11char_traitsIwEEE5widenEc"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEs = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEs"] = function() {
                return (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEs = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEs"] = Module["asm"]["_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEs"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwl = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwl"] = function() {
                return (__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwl = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwl"] = Module["asm"]["_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwl"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEt = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEt"] = function() {
                return (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEt = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEt"] = Module["asm"]["_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEt"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwm = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwm"] = function() {
                return (__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwm = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwm"] = Module["asm"]["_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwm"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEi = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEi"] = function() {
                return (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEi = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEi"] = Module["asm"]["_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEi"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEj = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEj"] = function() {
                return (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEj = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEj"] = Module["asm"]["_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEj"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEl = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEl"] = function() {
                return (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEl = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEl"] = Module["asm"]["_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEl"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEm = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEm"] = function() {
                return (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEm = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEm"] = Module["asm"]["_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEm"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEx = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEx"] = function() {
                return (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEx = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEx"] = Module["asm"]["_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEx"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwx = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwx"] = function() {
                return (__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwx = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwx"] = Module["asm"]["_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwx"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEy = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEy"] = function() {
                return (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEy = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEy"] = Module["asm"]["_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEy"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwy = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwy"] = function() {
                return (__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwy = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwy"] = Module["asm"]["_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwy"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEf = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEf"] = function() {
                return (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEf = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEf"] = Module["asm"]["_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEf"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwd = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwd"] = function() {
                return (__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwd = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwd"] = Module["asm"]["_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwd"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEd = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEd"] = function() {
                return (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEd = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEd"] = Module["asm"]["_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEd"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEe = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEe"] = function() {
                return (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEe = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEe"] = Module["asm"]["_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEe"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwe = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwe"] = function() {
                return (__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwe = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwe"] = Module["asm"]["_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwe"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEPKv = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEPKv"] = function() {
                return (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEPKv = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEPKv"] = Module["asm"]["_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEPKv"]).apply(null, arguments)
            };
            var __ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwPKv = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwPKv"] = function() {
                return (__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwPKv = Module["__ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwPKv"] = Module["asm"]["_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwPKv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEPNS_15basic_streambufIwS2_EE = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEPNS_15basic_streambufIwS2_EE"] = function() {
                return (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEPNS_15basic_streambufIwS2_EE = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEPNS_15basic_streambufIwS2_EE"] = Module["asm"]["_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEPNS_15basic_streambufIwS2_EE"]).apply(null, arguments)
            };
            var __ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEC2EPNS_15basic_streambufIwS2_EE = Module["__ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEC2EPNS_15basic_streambufIwS2_EE"] = function() {
                return (__ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEC2EPNS_15basic_streambufIwS2_EE = Module["__ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEC2EPNS_15basic_streambufIwS2_EE"] = Module["asm"]["_ZNSt3__219istreambuf_iteratorIwNS_11char_traitsIwEEEC2EPNS_15basic_streambufIwS2_EE"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE3putEw = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE3putEw"] = function() {
                return (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE3putEw = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE3putEw"] = Module["asm"]["_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE3putEw"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE5writeEPKwl = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE5writeEPKwl"] = function() {
                return (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE5writeEPKwl = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE5writeEPKwl"] = Module["asm"]["_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE5writeEPKwl"]).apply(null, arguments)
            };
            var __ZNKSt3__219__iostream_category4nameEv = Module["__ZNKSt3__219__iostream_category4nameEv"] = function() {
                return (__ZNKSt3__219__iostream_category4nameEv = Module["__ZNKSt3__219__iostream_category4nameEv"] = Module["asm"]["_ZNKSt3__219__iostream_category4nameEv"]).apply(null, arguments)
            };
            var __ZNKSt3__219__iostream_category7messageEi = Module["__ZNKSt3__219__iostream_category7messageEi"] = function() {
                return (__ZNKSt3__219__iostream_category7messageEi = Module["__ZNKSt3__219__iostream_category7messageEi"] = Module["asm"]["_ZNKSt3__219__iostream_category7messageEi"]).apply(null, arguments)
            };
            var __ZNSt3__217iostream_categoryEv = Module["__ZNSt3__217iostream_categoryEv"] = function() {
                return (__ZNSt3__217iostream_categoryEv = Module["__ZNSt3__217iostream_categoryEv"] = Module["asm"]["_ZNSt3__217iostream_categoryEv"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base7failureC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_10error_codeE = Module["__ZNSt3__28ios_base7failureC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_10error_codeE"] = function() {
                return (__ZNSt3__28ios_base7failureC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_10error_codeE = Module["__ZNSt3__28ios_base7failureC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_10error_codeE"] = Module["asm"]["_ZNSt3__28ios_base7failureC2ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base7failureC2EPKcRKNS_10error_codeE = Module["__ZNSt3__28ios_base7failureC2EPKcRKNS_10error_codeE"] = function() {
                return (__ZNSt3__28ios_base7failureC2EPKcRKNS_10error_codeE = Module["__ZNSt3__28ios_base7failureC2EPKcRKNS_10error_codeE"] = Module["asm"]["_ZNSt3__28ios_base7failureC2EPKcRKNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base7failureD2Ev = Module["__ZNSt3__28ios_base7failureD2Ev"] = function() {
                return (__ZNSt3__28ios_base7failureD2Ev = Module["__ZNSt3__28ios_base7failureD2Ev"] = Module["asm"]["_ZNSt3__28ios_base7failureD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base7failureD0Ev = Module["__ZNSt3__28ios_base7failureD0Ev"] = function() {
                return (__ZNSt3__28ios_base7failureD0Ev = Module["__ZNSt3__28ios_base7failureD0Ev"] = Module["asm"]["_ZNSt3__28ios_base7failureD0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base5imbueERKNS_6localeE = Module["__ZNSt3__28ios_base5imbueERKNS_6localeE"] = function() {
                return (__ZNSt3__28ios_base5imbueERKNS_6localeE = Module["__ZNSt3__28ios_base5imbueERKNS_6localeE"] = Module["asm"]["_ZNSt3__28ios_base5imbueERKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base6xallocEv = Module["__ZNSt3__28ios_base6xallocEv"] = function() {
                return (__ZNSt3__28ios_base6xallocEv = Module["__ZNSt3__28ios_base6xallocEv"] = Module["asm"]["_ZNSt3__28ios_base6xallocEv"]).apply(null, arguments)
            };
            var __ZNSt3__213__atomic_baseIiLb1EEppEi = Module["__ZNSt3__213__atomic_baseIiLb1EEppEi"] = function() {
                return (__ZNSt3__213__atomic_baseIiLb1EEppEi = Module["__ZNSt3__213__atomic_baseIiLb1EEppEi"] = Module["asm"]["_ZNSt3__213__atomic_baseIiLb1EEppEi"]).apply(null, arguments)
            };
            var __ZNSt3__213__atomic_baseIiLb1EE9fetch_addEiNS_12memory_orderE = Module["__ZNSt3__213__atomic_baseIiLb1EE9fetch_addEiNS_12memory_orderE"] = function() {
                return (__ZNSt3__213__atomic_baseIiLb1EE9fetch_addEiNS_12memory_orderE = Module["__ZNSt3__213__atomic_baseIiLb1EE9fetch_addEiNS_12memory_orderE"] = Module["asm"]["_ZNSt3__213__atomic_baseIiLb1EE9fetch_addEiNS_12memory_orderE"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base5iwordEi = Module["__ZNSt3__28ios_base5iwordEi"] = function() {
                return (__ZNSt3__28ios_base5iwordEi = Module["__ZNSt3__28ios_base5iwordEi"] = Module["asm"]["_ZNSt3__28ios_base5iwordEi"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base5pwordEi = Module["__ZNSt3__28ios_base5pwordEi"] = function() {
                return (__ZNSt3__28ios_base5pwordEi = Module["__ZNSt3__28ios_base5pwordEi"] = Module["asm"]["_ZNSt3__28ios_base5pwordEi"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base17register_callbackEPFvNS0_5eventERS0_iEi = Module["__ZNSt3__28ios_base17register_callbackEPFvNS0_5eventERS0_iEi"] = function() {
                return (__ZNSt3__28ios_base17register_callbackEPFvNS0_5eventERS0_iEi = Module["__ZNSt3__28ios_base17register_callbackEPFvNS0_5eventERS0_iEi"] = Module["asm"]["_ZNSt3__28ios_base17register_callbackEPFvNS0_5eventERS0_iEi"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_baseD0Ev = Module["__ZNSt3__28ios_baseD0Ev"] = function() {
                return (__ZNSt3__28ios_baseD0Ev = Module["__ZNSt3__28ios_baseD0Ev"] = Module["asm"]["_ZNSt3__28ios_baseD0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215__throw_failureEPKc = Module["__ZNSt3__215__throw_failureEPKc"] = function() {
                return (__ZNSt3__215__throw_failureEPKc = Module["__ZNSt3__215__throw_failureEPKc"] = Module["asm"]["_ZNSt3__215__throw_failureEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPPFvNS_8ios_base5eventERS1_iEPFvPvEEC2IRS6_S9_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPPFvNS_8ios_base5eventERS1_iEPFvPvEEC2IRS6_S9_EEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIPPFvNS_8ios_base5eventERS1_iEPFvPvEEC2IRS6_S9_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPPFvNS_8ios_base5eventERS1_iEPFvPvEEC2IRS6_S9_EEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIPPFvNS_8ios_base5eventERS1_iEPFvPvEEC2IRS6_S9_EEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPiPFvPvEEC2IRS1_S4_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPiPFvPvEEC2IRS1_S4_EEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIPiPFvPvEEC2IRS1_S4_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPiPFvPvEEC2IRS1_S4_EEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIPiPFvPvEEC2IRS1_S4_EEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPlPFvPvEEC2IRS1_S4_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPlPFvPvEEC2IRS1_S4_EEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIPlPFvPvEEC2IRS1_S4_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPlPFvPvEEC2IRS1_S4_EEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIPlPFvPvEEC2IRS1_S4_EEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPPvPFvS1_EEC2IRS2_S4_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPPvPFvS1_EEC2IRS2_S4_EEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIPPvPFvS1_EEC2IRS2_S4_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPPvPFvS1_EEC2IRS2_S4_EEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIPPvPFvS1_EEC2IRS2_S4_EEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPPFvNS_8ios_base5eventERS1_iEPFvPvEE5firstEv = Module["__ZNSt3__217__compressed_pairIPPFvNS_8ios_base5eventERS1_iEPFvPvEE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPPFvNS_8ios_base5eventERS1_iEPFvPvEE5firstEv = Module["__ZNSt3__217__compressed_pairIPPFvNS_8ios_base5eventERS1_iEPFvPvEE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPPFvNS_8ios_base5eventERS1_iEPFvPvEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPPFvNS_8ios_base5eventERS1_iEPFvPvEE6secondEv = Module["__ZNSt3__217__compressed_pairIPPFvNS_8ios_base5eventERS1_iEPFvPvEE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPPFvNS_8ios_base5eventERS1_iEPFvPvEE6secondEv = Module["__ZNSt3__217__compressed_pairIPPFvNS_8ios_base5eventERS1_iEPFvPvEE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPPFvNS_8ios_base5eventERS1_iEPFvPvEE6secondEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPPFvNS_8ios_base5eventERS1_iEPFvPvEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPPFvNS_8ios_base5eventERS1_iEPFvPvEE5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPPFvNS_8ios_base5eventERS1_iEPFvPvEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPPFvNS_8ios_base5eventERS1_iEPFvPvEE5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPPFvNS_8ios_base5eventERS1_iEPFvPvEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPiPFvPvEE5firstEv = Module["__ZNSt3__217__compressed_pairIPiPFvPvEE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPiPFvPvEE5firstEv = Module["__ZNSt3__217__compressed_pairIPiPFvPvEE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPiPFvPvEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPiPFvPvEE6secondEv = Module["__ZNSt3__217__compressed_pairIPiPFvPvEE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPiPFvPvEE6secondEv = Module["__ZNSt3__217__compressed_pairIPiPFvPvEE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPiPFvPvEE6secondEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPiPFvPvEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPiPFvPvEE5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPiPFvPvEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPiPFvPvEE5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPiPFvPvEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPlPFvPvEE5firstEv = Module["__ZNSt3__217__compressed_pairIPlPFvPvEE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPlPFvPvEE5firstEv = Module["__ZNSt3__217__compressed_pairIPlPFvPvEE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPlPFvPvEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPlPFvPvEE6secondEv = Module["__ZNSt3__217__compressed_pairIPlPFvPvEE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPlPFvPvEE6secondEv = Module["__ZNSt3__217__compressed_pairIPlPFvPvEE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPlPFvPvEE6secondEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPlPFvPvEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPlPFvPvEE5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPlPFvPvEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPlPFvPvEE5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPlPFvPvEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPPvPFvS1_EE5firstEv = Module["__ZNSt3__217__compressed_pairIPPvPFvS1_EE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPPvPFvS1_EE5firstEv = Module["__ZNSt3__217__compressed_pairIPPvPFvS1_EE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPPvPFvS1_EE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPPvPFvS1_EE6secondEv = Module["__ZNSt3__217__compressed_pairIPPvPFvS1_EE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPPvPFvS1_EE6secondEv = Module["__ZNSt3__217__compressed_pairIPPvPFvS1_EE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPPvPFvS1_EE6secondEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPPvPFvS1_EE5firstEv = Module["__ZNKSt3__217__compressed_pairIPPvPFvS1_EE5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPPvPFvS1_EE5firstEv = Module["__ZNKSt3__217__compressed_pairIPPvPFvS1_EE5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPPvPFvS1_EE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base4moveERS0_ = Module["__ZNSt3__28ios_base4moveERS0_"] = function() {
                return (__ZNSt3__28ios_base4moveERS0_ = Module["__ZNSt3__28ios_base4moveERS0_"] = Module["asm"]["_ZNSt3__28ios_base4moveERS0_"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base4swapERS0_ = Module["__ZNSt3__28ios_base4swapERS0_"] = function() {
                return (__ZNSt3__28ios_base4swapERS0_ = Module["__ZNSt3__28ios_base4swapERS0_"] = Module["asm"]["_ZNSt3__28ios_base4swapERS0_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIPPFvNS_8ios_base5eventERS1_iEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS8_EE5valueEvE4typeERS8_SB_ = Module["__ZNSt3__24swapIPPFvNS_8ios_base5eventERS1_iEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS8_EE5valueEvE4typeERS8_SB_"] = function() {
                return (__ZNSt3__24swapIPPFvNS_8ios_base5eventERS1_iEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS8_EE5valueEvE4typeERS8_SB_ = Module["__ZNSt3__24swapIPPFvNS_8ios_base5eventERS1_iEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS8_EE5valueEvE4typeERS8_SB_"] = Module["asm"]["_ZNSt3__24swapIPPFvNS_8ios_base5eventERS1_iEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS8_EE5valueEvE4typeERS8_SB_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIPiEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS3_EE5valueEvE4typeERS3_S6_ = Module["__ZNSt3__24swapIPiEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS3_EE5valueEvE4typeERS3_S6_"] = function() {
                return (__ZNSt3__24swapIPiEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS3_EE5valueEvE4typeERS3_S6_ = Module["__ZNSt3__24swapIPiEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS3_EE5valueEvE4typeERS3_S6_"] = Module["asm"]["_ZNSt3__24swapIPiEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS3_EE5valueEvE4typeERS3_S6_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIPlEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS3_EE5valueEvE4typeERS3_S6_ = Module["__ZNSt3__24swapIPlEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS3_EE5valueEvE4typeERS3_S6_"] = function() {
                return (__ZNSt3__24swapIPlEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS3_EE5valueEvE4typeERS3_S6_ = Module["__ZNSt3__24swapIPlEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS3_EE5valueEvE4typeERS3_S6_"] = Module["asm"]["_ZNSt3__24swapIPlEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS3_EE5valueEvE4typeERS3_S6_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIPPvEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS4_EE5valueEvE4typeERS4_S7_ = Module["__ZNSt3__24swapIPPvEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS4_EE5valueEvE4typeERS4_S7_"] = function() {
                return (__ZNSt3__24swapIPPvEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS4_EE5valueEvE4typeERS4_S7_ = Module["__ZNSt3__24swapIPPvEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS4_EE5valueEvE4typeERS4_S7_"] = Module["asm"]["_ZNSt3__24swapIPPvEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS4_EE5valueEvE4typeERS4_S7_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRPPFvNS_8ios_base5eventERS1_iEEEONS_16remove_referenceIT_E4typeEOS9_ = Module["__ZNSt3__24moveIRPPFvNS_8ios_base5eventERS1_iEEEONS_16remove_referenceIT_E4typeEOS9_"] = function() {
                return (__ZNSt3__24moveIRPPFvNS_8ios_base5eventERS1_iEEEONS_16remove_referenceIT_E4typeEOS9_ = Module["__ZNSt3__24moveIRPPFvNS_8ios_base5eventERS1_iEEEONS_16remove_referenceIT_E4typeEOS9_"] = Module["asm"]["_ZNSt3__24moveIRPPFvNS_8ios_base5eventERS1_iEEEONS_16remove_referenceIT_E4typeEOS9_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRPiEEONS_16remove_referenceIT_E4typeEOS4_ = Module["__ZNSt3__24moveIRPiEEONS_16remove_referenceIT_E4typeEOS4_"] = function() {
                return (__ZNSt3__24moveIRPiEEONS_16remove_referenceIT_E4typeEOS4_ = Module["__ZNSt3__24moveIRPiEEONS_16remove_referenceIT_E4typeEOS4_"] = Module["asm"]["_ZNSt3__24moveIRPiEEONS_16remove_referenceIT_E4typeEOS4_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRPlEEONS_16remove_referenceIT_E4typeEOS4_ = Module["__ZNSt3__24moveIRPlEEONS_16remove_referenceIT_E4typeEOS4_"] = function() {
                return (__ZNSt3__24moveIRPlEEONS_16remove_referenceIT_E4typeEOS4_ = Module["__ZNSt3__24moveIRPlEEONS_16remove_referenceIT_E4typeEOS4_"] = Module["asm"]["_ZNSt3__24moveIRPlEEONS_16remove_referenceIT_E4typeEOS4_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRPPvEEONS_16remove_referenceIT_E4typeEOS5_ = Module["__ZNSt3__24moveIRPPvEEONS_16remove_referenceIT_E4typeEOS5_"] = function() {
                return (__ZNSt3__24moveIRPPvEEONS_16remove_referenceIT_E4typeEOS5_ = Module["__ZNSt3__24moveIRPPvEEONS_16remove_referenceIT_E4typeEOS5_"] = Module["asm"]["_ZNSt3__24moveIRPPvEEONS_16remove_referenceIT_E4typeEOS5_"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base33__set_badbit_and_consider_rethrowEv = Module["__ZNSt3__28ios_base33__set_badbit_and_consider_rethrowEv"] = function() {
                return (__ZNSt3__28ios_base33__set_badbit_and_consider_rethrowEv = Module["__ZNSt3__28ios_base33__set_badbit_and_consider_rethrowEv"] = Module["asm"]["_ZNSt3__28ios_base33__set_badbit_and_consider_rethrowEv"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base34__set_failbit_and_consider_rethrowEv = Module["__ZNSt3__28ios_base34__set_failbit_and_consider_rethrowEv"] = function() {
                return (__ZNSt3__28ios_base34__set_failbit_and_consider_rethrowEv = Module["__ZNSt3__28ios_base34__set_failbit_and_consider_rethrowEv"] = Module["asm"]["_ZNSt3__28ios_base34__set_failbit_and_consider_rethrowEv"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base15sync_with_stdioEb = Module["__ZNSt3__28ios_base15sync_with_stdioEb"] = function() {
                return (__ZNSt3__28ios_base15sync_with_stdioEb = Module["__ZNSt3__28ios_base15sync_with_stdioEb"] = Module["asm"]["_ZNSt3__28ios_base15sync_with_stdioEb"]).apply(null, arguments)
            };
            var __ZNSt3__219__iostream_categoryD0Ev = Module["__ZNSt3__219__iostream_categoryD0Ev"] = function() {
                return (__ZNSt3__219__iostream_categoryD0Ev = Module["__ZNSt3__219__iostream_categoryD0Ev"] = Module["asm"]["_ZNSt3__219__iostream_categoryD0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__223__libcpp_numeric_limitsIsLb1EE3minEv = Module["__ZNSt3__223__libcpp_numeric_limitsIsLb1EE3minEv"] = function() {
                return (__ZNSt3__223__libcpp_numeric_limitsIsLb1EE3minEv = Module["__ZNSt3__223__libcpp_numeric_limitsIsLb1EE3minEv"] = Module["asm"]["_ZNSt3__223__libcpp_numeric_limitsIsLb1EE3minEv"]).apply(null, arguments)
            };
            var __ZNSt3__223__libcpp_numeric_limitsIsLb1EE3maxEv = Module["__ZNSt3__223__libcpp_numeric_limitsIsLb1EE3maxEv"] = function() {
                return (__ZNSt3__223__libcpp_numeric_limitsIsLb1EE3maxEv = Module["__ZNSt3__223__libcpp_numeric_limitsIsLb1EE3maxEv"] = Module["asm"]["_ZNSt3__223__libcpp_numeric_limitsIsLb1EE3maxEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__cxx_atomic_fetch_addIiEET_PNS_22__cxx_atomic_base_implIS1_EES1_NS_12memory_orderE = Module["__ZNSt3__222__cxx_atomic_fetch_addIiEET_PNS_22__cxx_atomic_base_implIS1_EES1_NS_12memory_orderE"] = function() {
                return (__ZNSt3__222__cxx_atomic_fetch_addIiEET_PNS_22__cxx_atomic_base_implIS1_EES1_NS_12memory_orderE = Module["__ZNSt3__222__cxx_atomic_fetch_addIiEET_PNS_22__cxx_atomic_base_implIS1_EES1_NS_12memory_orderE"] = Module["asm"]["_ZNSt3__222__cxx_atomic_fetch_addIiEET_PNS_22__cxx_atomic_base_implIS1_EES1_NS_12memory_orderE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRPPFvNS_8ios_base5eventERS1_iEEEOT_RNS_16remove_referenceIS8_E4typeE = Module["__ZNSt3__27forwardIRPPFvNS_8ios_base5eventERS1_iEEEOT_RNS_16remove_referenceIS8_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRPPFvNS_8ios_base5eventERS1_iEEEOT_RNS_16remove_referenceIS8_E4typeE = Module["__ZNSt3__27forwardIRPPFvNS_8ios_base5eventERS1_iEEEOT_RNS_16remove_referenceIS8_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRPPFvNS_8ios_base5eventERS1_iEEEOT_RNS_16remove_referenceIS8_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPPFvNS_8ios_base5eventERS1_iELi0ELb0EEC2IRS6_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPPFvNS_8ios_base5eventERS1_iELi0ELb0EEC2IRS6_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPPFvNS_8ios_base5eventERS1_iELi0ELb0EEC2IRS6_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPPFvNS_8ios_base5eventERS1_iELi0ELb0EEC2IRS6_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPPFvNS_8ios_base5eventERS1_iELi0ELb0EEC2IRS6_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRPiEEOT_RNS_16remove_referenceIS3_E4typeE = Module["__ZNSt3__27forwardIRPiEEOT_RNS_16remove_referenceIS3_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRPiEEOT_RNS_16remove_referenceIS3_E4typeE = Module["__ZNSt3__27forwardIRPiEEOT_RNS_16remove_referenceIS3_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRPiEEOT_RNS_16remove_referenceIS3_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPiLi0ELb0EEC2IRS1_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPiLi0ELb0EEC2IRS1_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPiLi0ELb0EEC2IRS1_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPiLi0ELb0EEC2IRS1_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPiLi0ELb0EEC2IRS1_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRPlEEOT_RNS_16remove_referenceIS3_E4typeE = Module["__ZNSt3__27forwardIRPlEEOT_RNS_16remove_referenceIS3_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRPlEEOT_RNS_16remove_referenceIS3_E4typeE = Module["__ZNSt3__27forwardIRPlEEOT_RNS_16remove_referenceIS3_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRPlEEOT_RNS_16remove_referenceIS3_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPlLi0ELb0EEC2IRS1_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPlLi0ELb0EEC2IRS1_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPlLi0ELb0EEC2IRS1_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPlLi0ELb0EEC2IRS1_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPlLi0ELb0EEC2IRS1_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRPPvEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRPPvEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRPPvEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRPPvEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRPPvEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPPvLi0ELb0EEC2IRS2_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPPvLi0ELb0EEC2IRS2_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPPvLi0ELb0EEC2IRS2_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPPvLi0ELb0EEC2IRS2_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPPvLi0ELb0EEC2IRS2_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPPFvNS_8ios_base5eventERS1_iELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPPFvNS_8ios_base5eventERS1_iELi0ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPPFvNS_8ios_base5eventERS1_iELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPPFvNS_8ios_base5eventERS1_iELi0ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPPFvNS_8ios_base5eventERS1_iELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemIPPFvNS_8ios_base5eventERS1_iELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPPFvNS_8ios_base5eventERS1_iELi0ELb0EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemIPPFvNS_8ios_base5eventERS1_iELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPPFvNS_8ios_base5eventERS1_iELi0ELb0EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemIPPFvNS_8ios_base5eventERS1_iELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPiLi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPiLi0ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPiLi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPiLi0ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPiLi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemIPiLi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPiLi0ELb0EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemIPiLi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPiLi0ELb0EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemIPiLi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPlLi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPlLi0ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPlLi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPlLi0ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPlLi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemIPlLi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPlLi0ELb0EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemIPlLi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPlLi0ELb0EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemIPlLi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPPvLi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPPvLi0ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPPvLi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPPvLi0ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPPvLi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemIPPvLi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPPvLi0ELb0EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemIPPvLi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPPvLi0ELb0EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemIPPvLi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__29basic_iosIcNS_11char_traitsIcEEED1Ev = Module["__ZNSt3__29basic_iosIcNS_11char_traitsIcEEED1Ev"] = function() {
                return (__ZNSt3__29basic_iosIcNS_11char_traitsIcEEED1Ev = Module["__ZNSt3__29basic_iosIcNS_11char_traitsIcEEED1Ev"] = Module["asm"]["_ZNSt3__29basic_iosIcNS_11char_traitsIcEEED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29basic_iosIwNS_11char_traitsIwEEED1Ev = Module["__ZNSt3__29basic_iosIwNS_11char_traitsIwEEED1Ev"] = function() {
                return (__ZNSt3__29basic_iosIwNS_11char_traitsIwEEED1Ev = Module["__ZNSt3__29basic_iosIwNS_11char_traitsIwEEED1Ev"] = Module["asm"]["_ZNSt3__29basic_iosIwNS_11char_traitsIwEEED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED1Ev = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED1Ev"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED1Ev = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED1Ev"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC1Ev = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC1Ev"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC1Ev = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC1Ev"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC1ERKS3_ = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC1ERKS3_"] = function() {
                return (__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC1ERKS3_ = Module["__ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC1ERKS3_"] = Module["asm"]["_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEEC1ERKS3_"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED1Ev = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED1Ev"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED1Ev = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED1Ev"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC1Ev = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC1Ev"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC1Ev = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC1Ev"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC1ERKS3_ = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC1ERKS3_"] = function() {
                return (__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC1ERKS3_ = Module["__ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC1ERKS3_"] = Module["asm"]["_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEEC1ERKS3_"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE6sentryC1ERS3_b = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE6sentryC1ERS3_b"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE6sentryC1ERS3_b = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE6sentryC1ERS3_b"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE6sentryC1ERS3_b"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE6sentryC1ERS3_b = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE6sentryC1ERS3_b"] = function() {
                return (__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE6sentryC1ERS3_b = Module["__ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE6sentryC1ERS3_b"] = Module["asm"]["_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE6sentryC1ERS3_b"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryC1ERS3_ = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryC1ERS3_"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryC1ERS3_ = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryC1ERS3_"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryC1ERS3_"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD1Ev = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD1Ev"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD1Ev = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD1Ev"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEE6sentryD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryC1ERS3_ = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryC1ERS3_"] = function() {
                return (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryC1ERS3_ = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryC1ERS3_"] = Module["asm"]["_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryC1ERS3_"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryD1Ev = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryD1Ev"] = function() {
                return (__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryD1Ev = Module["__ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryD1Ev"] = Module["asm"]["_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEE6sentryD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base7failureC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_10error_codeE = Module["__ZNSt3__28ios_base7failureC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_10error_codeE"] = function() {
                return (__ZNSt3__28ios_base7failureC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_10error_codeE = Module["__ZNSt3__28ios_base7failureC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_10error_codeE"] = Module["asm"]["_ZNSt3__28ios_base7failureC1ERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base7failureC1EPKcRKNS_10error_codeE = Module["__ZNSt3__28ios_base7failureC1EPKcRKNS_10error_codeE"] = function() {
                return (__ZNSt3__28ios_base7failureC1EPKcRKNS_10error_codeE = Module["__ZNSt3__28ios_base7failureC1EPKcRKNS_10error_codeE"] = Module["asm"]["_ZNSt3__28ios_base7failureC1EPKcRKNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_base7failureD1Ev = Module["__ZNSt3__28ios_base7failureD1Ev"] = function() {
                return (__ZNSt3__28ios_base7failureD1Ev = Module["__ZNSt3__28ios_base7failureD1Ev"] = Module["asm"]["_ZNSt3__28ios_base7failureD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__28ios_baseD1Ev = Module["__ZNSt3__28ios_baseD1Ev"] = function() {
                return (__ZNSt3__28ios_baseD1Ev = Module["__ZNSt3__28ios_baseD1Ev"] = Module["asm"]["_ZNSt3__28ios_baseD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem18directory_iteratorC2ERKNS1_4pathEPNS_10error_codeENS1_17directory_optionsE = Module["__ZNSt3__24__fs10filesystem18directory_iteratorC2ERKNS1_4pathEPNS_10error_codeENS1_17directory_optionsE"] = function() {
                return (__ZNSt3__24__fs10filesystem18directory_iteratorC2ERKNS1_4pathEPNS_10error_codeENS1_17directory_optionsE = Module["__ZNSt3__24__fs10filesystem18directory_iteratorC2ERKNS1_4pathEPNS_10error_codeENS1_17directory_optionsE"] = Module["asm"]["_ZNSt3__24__fs10filesystem18directory_iteratorC2ERKNS1_4pathEPNS_10error_codeENS1_17directory_optionsE"]).apply(null, arguments)
            };
            var __ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEEC2Ev = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEEC2Ev"] = function() {
                return (__ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEEC2Ev = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEEC2Ev"] = Module["asm"]["_ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__210error_codeC2Ev = Module["__ZNSt3__210error_codeC2Ev"] = function() {
                return (__ZNSt3__210error_codeC2Ev = Module["__ZNSt3__210error_codeC2Ev"] = Module["asm"]["_ZNSt3__210error_codeC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__211make_sharedINS_4__fs10filesystem12__dir_streamEJRKNS2_4pathERNS2_17directory_optionsERNS_10error_codeEEEENS_9enable_ifIXntsr8is_arrayIT_EE5valueENS_10shared_ptrISC_EEE4typeEDpOT0_ = Module["__ZNSt3__211make_sharedINS_4__fs10filesystem12__dir_streamEJRKNS2_4pathERNS2_17directory_optionsERNS_10error_codeEEEENS_9enable_ifIXntsr8is_arrayIT_EE5valueENS_10shared_ptrISC_EEE4typeEDpOT0_"] = function() {
                return (__ZNSt3__211make_sharedINS_4__fs10filesystem12__dir_streamEJRKNS2_4pathERNS2_17directory_optionsERNS_10error_codeEEEENS_9enable_ifIXntsr8is_arrayIT_EE5valueENS_10shared_ptrISC_EEE4typeEDpOT0_ = Module["__ZNSt3__211make_sharedINS_4__fs10filesystem12__dir_streamEJRKNS2_4pathERNS2_17directory_optionsERNS_10error_codeEEEENS_9enable_ifIXntsr8is_arrayIT_EE5valueENS_10shared_ptrISC_EEE4typeEDpOT0_"] = Module["asm"]["_ZNSt3__211make_sharedINS_4__fs10filesystem12__dir_streamEJRKNS2_4pathERNS2_17directory_optionsERNS_10error_codeEEEENS_9enable_ifIXntsr8is_arrayIT_EE5valueENS_10shared_ptrISC_EEE4typeEDpOT0_"]).apply(null, arguments)
            };
            var __ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEEaSEOS4_ = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEEaSEOS4_"] = function() {
                return (__ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEEaSEOS4_ = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEEaSEOS4_"] = Module["asm"]["_ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEEaSEOS4_"]).apply(null, arguments)
            };
            var __ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEED2Ev = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEED2Ev"] = function() {
                return (__ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEED2Ev = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEED2Ev"] = Module["asm"]["_ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEED2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEEptEv = Module["__ZNKSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEEptEv"] = function() {
                return (__ZNKSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEEptEv = Module["__ZNKSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEEptEv"] = Module["asm"]["_ZNKSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEEptEv"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem12__dir_stream4goodEv = Module["__ZNKSt3__24__fs10filesystem12__dir_stream4goodEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem12__dir_stream4goodEv = Module["__ZNKSt3__24__fs10filesystem12__dir_stream4goodEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem12__dir_stream4goodEv"]).apply(null, arguments)
            };
            var __ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEE5resetEv = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEE5resetEv"] = function() {
                return (__ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEE5resetEv = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEE5resetEv"] = Module["asm"]["_ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEE5resetEv"]).apply(null, arguments)
            };
            var __ZNSt3__210error_code5clearEv = Module["__ZNSt3__210error_code5clearEv"] = function() {
                return (__ZNSt3__210error_code5clearEv = Module["__ZNSt3__210error_code5clearEv"] = Module["asm"]["_ZNSt3__210error_code5clearEv"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS0_IS4_EEEEEC2Ev = Module["__ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS0_IS4_EEEEEC2Ev"] = function() {
                return (__ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS0_IS4_EEEEEC2Ev = Module["__ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS0_IS4_EEEEEC2Ev"] = Module["asm"]["_ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS0_IS4_EEEEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS0_IS4_EEEEE8allocateEmPKv = Module["__ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS0_IS4_EEEEE8allocateEmPKv"] = function() {
                return (__ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS0_IS4_EEEEE8allocateEmPKv = Module["__ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS0_IS4_EEEEE8allocateEmPKv"] = Module["asm"]["_ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS0_IS4_EEEEE8allocateEmPKv"]).apply(null, arguments)
            };
            var __ZNSt3__222__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS1_IS5_EEEEEEEC2ERS8_m = Module["__ZNSt3__222__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS1_IS5_EEEEEEEC2ERS8_m"] = function() {
                return (__ZNSt3__222__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS1_IS5_EEEEEEEC2ERS8_m = Module["__ZNSt3__222__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS1_IS5_EEEEEEEC2ERS8_m"] = Module["asm"]["_ZNSt3__222__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS1_IS5_EEEEEEEC2ERS8_m"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEEC2ILb1EvEEPS7_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeISA_EEXT_EE20__good_rval_ref_typeE = Module["__ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEEC2ILb1EvEEPS7_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeISA_EEXT_EE20__good_rval_ref_typeE"] = function() {
                return (__ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEEC2ILb1EvEEPS7_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeISA_EEXT_EE20__good_rval_ref_typeE = Module["__ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEEC2ILb1EvEEPS7_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeISA_EEXT_EE20__good_rval_ref_typeE"] = Module["asm"]["_ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEEC2ILb1EvEEPS7_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeISA_EEXT_EE20__good_rval_ref_typeE"]).apply(null, arguments)
            };
            var __ZNKSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE3getEv = Module["__ZNKSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE3getEv"] = function() {
                return (__ZNKSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE3getEv = Module["__ZNKSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE3getEv"] = Module["asm"]["_ZNKSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE3getEv"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEEC2INS_20__shared_ptr_emplaceIS3_S4_EEEERKNS0_IT_EE = Module["__ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEEC2INS_20__shared_ptr_emplaceIS3_S4_EEEERKNS0_IT_EE"] = function() {
                return (__ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEEC2INS_20__shared_ptr_emplaceIS3_S4_EEEERKNS0_IT_EE = Module["__ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEEC2INS_20__shared_ptr_emplaceIS3_S4_EEEERKNS0_IT_EE"] = Module["asm"]["_ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEEC2INS_20__shared_ptr_emplaceIS3_S4_EEEERKNS0_IT_EE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRKNS_4__fs10filesystem4pathEEEOT_RNS_16remove_referenceIS6_E4typeE = Module["__ZNSt3__27forwardIRKNS_4__fs10filesystem4pathEEEOT_RNS_16remove_referenceIS6_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRKNS_4__fs10filesystem4pathEEEOT_RNS_16remove_referenceIS6_E4typeE = Module["__ZNSt3__27forwardIRKNS_4__fs10filesystem4pathEEEOT_RNS_16remove_referenceIS6_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRKNS_4__fs10filesystem4pathEEEOT_RNS_16remove_referenceIS6_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRNS_4__fs10filesystem17directory_optionsEEEOT_RNS_16remove_referenceIS5_E4typeE = Module["__ZNSt3__27forwardIRNS_4__fs10filesystem17directory_optionsEEEOT_RNS_16remove_referenceIS5_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRNS_4__fs10filesystem17directory_optionsEEEOT_RNS_16remove_referenceIS5_E4typeE = Module["__ZNSt3__27forwardIRNS_4__fs10filesystem17directory_optionsEEEOT_RNS_16remove_referenceIS5_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRNS_4__fs10filesystem17directory_optionsEEEOT_RNS_16remove_referenceIS5_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRNS_10error_codeEEEOT_RNS_16remove_referenceIS3_E4typeE = Module["__ZNSt3__27forwardIRNS_10error_codeEEEOT_RNS_16remove_referenceIS3_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRNS_10error_codeEEEOT_RNS_16remove_referenceIS3_E4typeE = Module["__ZNSt3__27forwardIRNS_10error_codeEEEOT_RNS_16remove_referenceIS3_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRNS_10error_codeEEEOT_RNS_16remove_referenceIS3_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEC2IJRKNS2_4pathERNS2_17directory_optionsERNS_10error_codeEEEES5_DpOT_ = Module["__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEC2IJRKNS2_4pathERNS2_17directory_optionsERNS_10error_codeEEEES5_DpOT_"] = function() {
                return (__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEC2IJRKNS2_4pathERNS2_17directory_optionsERNS_10error_codeEEEES5_DpOT_ = Module["__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEC2IJRKNS2_4pathERNS2_17directory_optionsERNS_10error_codeEEEES5_DpOT_"] = Module["asm"]["_ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEC2IJRKNS2_4pathERNS2_17directory_optionsERNS_10error_codeEEEES5_DpOT_"]).apply(null, arguments)
            };
            var __ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE3getEv = Module["__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE3getEv"] = function() {
                return (__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE3getEv = Module["__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE3getEv"] = Module["asm"]["_ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE3getEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE7releaseEv = Module["__ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE7releaseEv"] = function() {
                return (__ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE7releaseEv = Module["__ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE7releaseEv"] = Module["asm"]["_ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE7releaseEv"]).apply(null, arguments)
            };
            var __ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEE27__create_with_control_blockIS3_NS_20__shared_ptr_emplaceIS3_NS_9allocatorIS3_EEEEEES4_PT_PT0_ = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEE27__create_with_control_blockIS3_NS_20__shared_ptr_emplaceIS3_NS_9allocatorIS3_EEEEEES4_PT_PT0_"] = function() {
                return (__ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEE27__create_with_control_blockIS3_NS_20__shared_ptr_emplaceIS3_NS_9allocatorIS3_EEEEEES4_PT_PT0_ = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEE27__create_with_control_blockIS3_NS_20__shared_ptr_emplaceIS3_NS_9allocatorIS3_EEEEEES4_PT_PT0_"] = Module["asm"]["_ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEE27__create_with_control_blockIS3_NS_20__shared_ptr_emplaceIS3_NS_9allocatorIS3_EEEEEES4_PT_PT0_"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEED2Ev = Module["__ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEED2Ev"] = function() {
                return (__ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEED2Ev = Module["__ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEED2Ev"] = Module["asm"]["_ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRNS_10shared_ptrINS_4__fs10filesystem12__dir_streamEEEEEONS_16remove_referenceIT_E4typeEOS8_ = Module["__ZNSt3__24moveIRNS_10shared_ptrINS_4__fs10filesystem12__dir_streamEEEEEONS_16remove_referenceIT_E4typeEOS8_"] = function() {
                return (__ZNSt3__24moveIRNS_10shared_ptrINS_4__fs10filesystem12__dir_streamEEEEEONS_16remove_referenceIT_E4typeEOS8_ = Module["__ZNSt3__24moveIRNS_10shared_ptrINS_4__fs10filesystem12__dir_streamEEEEEONS_16remove_referenceIT_E4typeEOS8_"] = Module["asm"]["_ZNSt3__24moveIRNS_10shared_ptrINS_4__fs10filesystem12__dir_streamEEEEEONS_16remove_referenceIT_E4typeEOS8_"]).apply(null, arguments)
            };
            var __ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEEC2EOS4_ = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEEC2EOS4_"] = function() {
                return (__ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEEC2EOS4_ = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEEC2EOS4_"] = Module["asm"]["_ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEEC2EOS4_"]).apply(null, arguments)
            };
            var __ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEE4swapERS4_ = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEE4swapERS4_"] = function() {
                return (__ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEE4swapERS4_ = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEE4swapERS4_"] = Module["asm"]["_ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEE4swapERS4_"]).apply(null, arguments)
            };
            var __ZNSt3__219__shared_weak_count16__release_sharedEv = Module["__ZNSt3__219__shared_weak_count16__release_sharedEv"] = function() {
                return (__ZNSt3__219__shared_weak_count16__release_sharedEv = Module["__ZNSt3__219__shared_weak_count16__release_sharedEv"] = Module["asm"]["_ZNSt3__219__shared_weak_count16__release_sharedEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem24__throw_filesystem_errorIJRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_10error_codeEEEEvDpOT_ = Module["__ZNSt3__24__fs10filesystem24__throw_filesystem_errorIJRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_10error_codeEEEEvDpOT_"] = function() {
                return (__ZNSt3__24__fs10filesystem24__throw_filesystem_errorIJRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_10error_codeEEEEvDpOT_ = Module["__ZNSt3__24__fs10filesystem24__throw_filesystem_errorIJRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_10error_codeEEEEvDpOT_"] = Module["asm"]["_ZNSt3__24__fs10filesystem24__throw_filesystem_errorIJRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS_10error_codeEEEEvDpOT_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem24__throw_filesystem_errorIJRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS1_4pathERKNS_10error_codeEEEEvDpOT_ = Module["__ZNSt3__24__fs10filesystem24__throw_filesystem_errorIJRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS1_4pathERKNS_10error_codeEEEEvDpOT_"] = function() {
                return (__ZNSt3__24__fs10filesystem24__throw_filesystem_errorIJRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS1_4pathERKNS_10error_codeEEEEvDpOT_ = Module["__ZNSt3__24__fs10filesystem24__throw_filesystem_errorIJRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS1_4pathERKNS_10error_codeEEEEvDpOT_"] = Module["asm"]["_ZNSt3__24__fs10filesystem24__throw_filesystem_errorIJRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS1_4pathERKNS_10error_codeEEEEvDpOT_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem24__throw_filesystem_errorIJRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS1_4pathESC_RKNS_10error_codeEEEEvDpOT_ = Module["__ZNSt3__24__fs10filesystem24__throw_filesystem_errorIJRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS1_4pathESC_RKNS_10error_codeEEEEvDpOT_"] = function() {
                return (__ZNSt3__24__fs10filesystem24__throw_filesystem_errorIJRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS1_4pathESC_RKNS_10error_codeEEEEvDpOT_ = Module["__ZNSt3__24__fs10filesystem24__throw_filesystem_errorIJRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS1_4pathESC_RKNS_10error_codeEEEEvDpOT_"] = Module["asm"]["_ZNSt3__24__fs10filesystem24__throw_filesystem_errorIJRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKNS1_4pathESC_RKNS_10error_codeEEEEvDpOT_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem18directory_iterator11__incrementEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem18directory_iterator11__incrementEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem18directory_iterator11__incrementEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem18directory_iterator11__incrementEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem18directory_iterator11__incrementEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem12__dir_stream7advanceERNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem12__dir_stream7advanceERNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem12__dir_stream7advanceERNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem12__dir_stream7advanceERNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem12__dir_stream7advanceERNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRNS_4__fs10filesystem4pathEEEONS_16remove_referenceIT_E4typeEOS6_ = Module["__ZNSt3__24moveIRNS_4__fs10filesystem4pathEEEONS_16remove_referenceIT_E4typeEOS6_"] = function() {
                return (__ZNSt3__24moveIRNS_4__fs10filesystem4pathEEEONS_16remove_referenceIT_E4typeEOS6_ = Module["__ZNSt3__24moveIRNS_4__fs10filesystem4pathEEEONS_16remove_referenceIT_E4typeEOS6_"] = Module["asm"]["_ZNSt3__24moveIRNS_4__fs10filesystem4pathEEEONS_16remove_referenceIT_E4typeEOS6_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4pathC2EOS2_ = Module["__ZNSt3__24__fs10filesystem4pathC2EOS2_"] = function() {
                return (__ZNSt3__24__fs10filesystem4pathC2EOS2_ = Module["__ZNSt3__24__fs10filesystem4pathC2EOS2_"] = Module["asm"]["_ZNSt3__24__fs10filesystem4pathC2EOS2_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4pathD2Ev = Module["__ZNSt3__24__fs10filesystem4pathD2Ev"] = function() {
                return (__ZNSt3__24__fs10filesystem4pathD2Ev = Module["__ZNSt3__24__fs10filesystem4pathD2Ev"] = Module["asm"]["_ZNSt3__24__fs10filesystem4pathD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217basic_string_viewIcNS_11char_traitsIcEEEC2EPKc = Module["__ZNSt3__217basic_string_viewIcNS_11char_traitsIcEEEC2EPKc"] = function() {
                return (__ZNSt3__217basic_string_viewIcNS_11char_traitsIcEEEC2EPKc = Module["__ZNSt3__217basic_string_viewIcNS_11char_traitsIcEEEC2EPKc"] = Module["asm"]["_ZNSt3__217basic_string_viewIcNS_11char_traitsIcEEEC2EPKc"]).apply(null, arguments)
            };
            var __ZNSt3__2eqIcNS_11char_traitsIcEEEEbNS_17basic_string_viewIT_T0_EENS_11common_typeIJS6_EE4typeE = Module["__ZNSt3__2eqIcNS_11char_traitsIcEEEEbNS_17basic_string_viewIT_T0_EENS_11common_typeIJS6_EE4typeE"] = function() {
                return (__ZNSt3__2eqIcNS_11char_traitsIcEEEEbNS_17basic_string_viewIT_T0_EENS_11common_typeIJS6_EE4typeE = Module["__ZNSt3__2eqIcNS_11char_traitsIcEEEEbNS_17basic_string_viewIT_T0_EENS_11common_typeIJS6_EE4typeE"] = Module["asm"]["_ZNSt3__2eqIcNS_11char_traitsIcEEEEbNS_17basic_string_viewIT_T0_EENS_11common_typeIJS6_EE4typeE"]).apply(null, arguments)
            };
            var __ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE5emptyEv = Module["__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE5emptyEv"] = function() {
                return (__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE5emptyEv = Module["__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE5emptyEv"] = Module["asm"]["_ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE5emptyEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem12__dir_stream5closeEv = Module["__ZNSt3__24__fs10filesystem12__dir_stream5closeEv"] = function() {
                return (__ZNSt3__24__fs10filesystem12__dir_stream5closeEv = Module["__ZNSt3__24__fs10filesystem12__dir_stream5closeEv"] = Module["asm"]["_ZNSt3__24__fs10filesystem12__dir_stream5closeEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4pathC2INS_17basic_string_viewIcNS_11char_traitsIcEEEEvEERKT_NS2_6formatE = Module["__ZNSt3__24__fs10filesystem4pathC2INS_17basic_string_viewIcNS_11char_traitsIcEEEEvEERKT_NS2_6formatE"] = function() {
                return (__ZNSt3__24__fs10filesystem4pathC2INS_17basic_string_viewIcNS_11char_traitsIcEEEEvEERKT_NS2_6formatE = Module["__ZNSt3__24__fs10filesystem4pathC2INS_17basic_string_viewIcNS_11char_traitsIcEEEEvEERKT_NS2_6formatE"] = Module["asm"]["_ZNSt3__24__fs10filesystem4pathC2INS_17basic_string_viewIcNS_11char_traitsIcEEEEvEERKT_NS2_6formatE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystemdvERKNS1_4pathES4_ = Module["__ZNSt3__24__fs10filesystemdvERKNS1_4pathES4_"] = function() {
                return (__ZNSt3__24__fs10filesystemdvERKNS1_4pathES4_ = Module["__ZNSt3__24__fs10filesystemdvERKNS1_4pathES4_"] = Module["asm"]["_ZNSt3__24__fs10filesystemdvERKNS1_4pathES4_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem15directory_entry20__create_iter_resultENS1_9file_typeE = Module["__ZNSt3__24__fs10filesystem15directory_entry20__create_iter_resultENS1_9file_typeE"] = function() {
                return (__ZNSt3__24__fs10filesystem15directory_entry20__create_iter_resultENS1_9file_typeE = Module["__ZNSt3__24__fs10filesystem15directory_entry20__create_iter_resultENS1_9file_typeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem15directory_entry20__create_iter_resultENS1_9file_typeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem15directory_entry19__assign_iter_entryEONS1_4pathENS2_13__cached_dataE = Module["__ZNSt3__24__fs10filesystem15directory_entry19__assign_iter_entryEONS1_4pathENS2_13__cached_dataE"] = function() {
                return (__ZNSt3__24__fs10filesystem15directory_entry19__assign_iter_entryEONS1_4pathENS2_13__cached_dataE = Module["__ZNSt3__24__fs10filesystem15directory_entry19__assign_iter_entryEONS1_4pathENS2_13__cached_dataE"] = Module["asm"]["_ZNSt3__24__fs10filesystem15directory_entry19__assign_iter_entryEONS1_4pathENS2_13__cached_dataE"]).apply(null, arguments)
            };
            var __ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEOS9_SA_ = Module["__ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEOS9_SA_"] = function() {
                return (__ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEOS9_SA_ = Module["__ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEOS9_SA_"] = Module["asm"]["_ZNSt3__2plIcNS_11char_traitsIcEENS_9allocatorIcEEEENS_12basic_stringIT_T0_T1_EEOS9_SA_"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem18directory_iterator13__dereferenceEv = Module["__ZNKSt3__24__fs10filesystem18directory_iterator13__dereferenceEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem18directory_iterator13__dereferenceEv = Module["__ZNKSt3__24__fs10filesystem18directory_iterator13__dereferenceEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem18directory_iterator13__dereferenceEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem28recursive_directory_iteratorC2ERKNS1_4pathENS1_17directory_optionsEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem28recursive_directory_iteratorC2ERKNS1_4pathENS1_17directory_optionsEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem28recursive_directory_iteratorC2ERKNS1_4pathENS1_17directory_optionsEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem28recursive_directory_iteratorC2ERKNS1_4pathENS1_17directory_optionsEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem28recursive_directory_iteratorC2ERKNS1_4pathENS1_17directory_optionsEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEC2EDn = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEC2EDn"] = function() {
                return (__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEC2EDn = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEC2EDn"] = Module["asm"]["_ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEC2EDn"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem12__dir_streamC2ERKNS1_4pathENS1_17directory_optionsERNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem12__dir_streamC2ERKNS1_4pathENS1_17directory_optionsERNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem12__dir_streamC2ERKNS1_4pathENS1_17directory_optionsERNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem12__dir_streamC2ERKNS1_4pathENS1_17directory_optionsERNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem12__dir_streamC2ERKNS1_4pathENS1_17directory_optionsERNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__211make_sharedINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEJEEENS_9enable_ifIXntsr8is_arrayIT_EE5valueENS_10shared_ptrIS6_EEE4typeEDpOT0_ = Module["__ZNSt3__211make_sharedINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEJEEENS_9enable_ifIXntsr8is_arrayIT_EE5valueENS_10shared_ptrIS6_EEE4typeEDpOT0_"] = function() {
                return (__ZNSt3__211make_sharedINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEJEEENS_9enable_ifIXntsr8is_arrayIT_EE5valueENS_10shared_ptrIS6_EEE4typeEDpOT0_ = Module["__ZNSt3__211make_sharedINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEJEEENS_9enable_ifIXntsr8is_arrayIT_EE5valueENS_10shared_ptrIS6_EEE4typeEDpOT0_"] = Module["asm"]["_ZNSt3__211make_sharedINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEJEEENS_9enable_ifIXntsr8is_arrayIT_EE5valueENS_10shared_ptrIS6_EEE4typeEDpOT0_"]).apply(null, arguments)
            };
            var __ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEaSEOS5_ = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEaSEOS5_"] = function() {
                return (__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEaSEOS5_ = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEaSEOS5_"] = Module["asm"]["_ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEaSEOS5_"]).apply(null, arguments)
            };
            var __ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEED2Ev = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEED2Ev"] = function() {
                return (__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEED2Ev = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEED2Ev"] = Module["asm"]["_ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEED2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEptEv = Module["__ZNKSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEptEv"] = function() {
                return (__ZNKSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEptEv = Module["__ZNKSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEptEv"] = Module["asm"]["_ZNKSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEptEv"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRNS_4__fs10filesystem12__dir_streamEEEONS_16remove_referenceIT_E4typeEOS6_ = Module["__ZNSt3__24moveIRNS_4__fs10filesystem12__dir_streamEEEONS_16remove_referenceIT_E4typeEOS6_"] = function() {
                return (__ZNSt3__24moveIRNS_4__fs10filesystem12__dir_streamEEEONS_16remove_referenceIT_E4typeEOS6_ = Module["__ZNSt3__24moveIRNS_4__fs10filesystem12__dir_streamEEEONS_16remove_referenceIT_E4typeEOS6_"] = Module["asm"]["_ZNSt3__24moveIRNS_4__fs10filesystem12__dir_streamEEEONS_16remove_referenceIT_E4typeEOS6_"]).apply(null, arguments)
            };
            var __ZNSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEE4pushEOS3_ = Module["__ZNSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEE4pushEOS3_"] = function() {
                return (__ZNSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEE4pushEOS3_ = Module["__ZNSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEE4pushEOS3_"] = Module["asm"]["_ZNSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEE4pushEOS3_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem12__dir_streamD2Ev = Module["__ZNSt3__24__fs10filesystem12__dir_streamD2Ev"] = function() {
                return (__ZNSt3__24__fs10filesystem12__dir_streamD2Ev = Module["__ZNSt3__24__fs10filesystem12__dir_streamD2Ev"] = Module["asm"]["_ZNSt3__24__fs10filesystem12__dir_streamD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4pathC2ERKS2_ = Module["__ZNSt3__24__fs10filesystem4pathC2ERKS2_"] = function() {
                return (__ZNSt3__24__fs10filesystem4pathC2ERKS2_ = Module["__ZNSt3__24__fs10filesystem4pathC2ERKS2_"] = Module["asm"]["_ZNSt3__24__fs10filesystem4pathC2ERKS2_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem15directory_entryC2Ev = Module["__ZNSt3__24__fs10filesystem15directory_entryC2Ev"] = function() {
                return (__ZNSt3__24__fs10filesystem15directory_entryC2Ev = Module["__ZNSt3__24__fs10filesystem15directory_entryC2Ev"] = Module["asm"]["_ZNSt3__24__fs10filesystem15directory_entryC2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem4path5c_strEv = Module["__ZNKSt3__24__fs10filesystem4path5c_strEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem4path5c_strEv = Module["__ZNKSt3__24__fs10filesystem4path5c_strEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem4path5c_strEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystemanENS1_17directory_optionsES2_ = Module["__ZNSt3__24__fs10filesystemanENS1_17directory_optionsES2_"] = function() {
                return (__ZNSt3__24__fs10filesystemanENS1_17directory_optionsES2_ = Module["__ZNSt3__24__fs10filesystemanENS1_17directory_optionsES2_"] = Module["asm"]["_ZNSt3__24__fs10filesystemanENS1_17directory_optionsES2_"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS0_IS5_EEEEEC2Ev = Module["__ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS0_IS5_EEEEEC2Ev"] = function() {
                return (__ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS0_IS5_EEEEEC2Ev = Module["__ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS0_IS5_EEEEEC2Ev"] = Module["asm"]["_ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS0_IS5_EEEEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS0_IS5_EEEEE8allocateEmPKv = Module["__ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS0_IS5_EEEEE8allocateEmPKv"] = function() {
                return (__ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS0_IS5_EEEEE8allocateEmPKv = Module["__ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS0_IS5_EEEEE8allocateEmPKv"] = Module["asm"]["_ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS0_IS5_EEEEE8allocateEmPKv"]).apply(null, arguments)
            };
            var __ZNSt3__222__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS1_IS6_EEEEEEEC2ERS9_m = Module["__ZNSt3__222__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS1_IS6_EEEEEEEC2ERS9_m"] = function() {
                return (__ZNSt3__222__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS1_IS6_EEEEEEEC2ERS9_m = Module["__ZNSt3__222__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS1_IS6_EEEEEEEC2ERS9_m"] = Module["asm"]["_ZNSt3__222__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS1_IS6_EEEEEEEC2ERS9_m"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEEC2ILb1EvEEPS8_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeISB_EEXT_EE20__good_rval_ref_typeE = Module["__ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEEC2ILb1EvEEPS8_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeISB_EEXT_EE20__good_rval_ref_typeE"] = function() {
                return (__ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEEC2ILb1EvEEPS8_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeISB_EEXT_EE20__good_rval_ref_typeE = Module["__ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEEC2ILb1EvEEPS8_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeISB_EEXT_EE20__good_rval_ref_typeE"] = Module["asm"]["_ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEEC2ILb1EvEEPS8_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeISB_EEXT_EE20__good_rval_ref_typeE"]).apply(null, arguments)
            };
            var __ZNKSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE3getEv = Module["__ZNKSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE3getEv"] = function() {
                return (__ZNKSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE3getEv = Module["__ZNKSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE3getEv"] = Module["asm"]["_ZNKSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE3getEv"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEC2INS_20__shared_ptr_emplaceIS4_S5_EEEERKNS0_IT_EE = Module["__ZNSt3__29allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEC2INS_20__shared_ptr_emplaceIS4_S5_EEEERKNS0_IT_EE"] = function() {
                return (__ZNSt3__29allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEC2INS_20__shared_ptr_emplaceIS4_S5_EEEERKNS0_IT_EE = Module["__ZNSt3__29allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEC2INS_20__shared_ptr_emplaceIS4_S5_EEEERKNS0_IT_EE"] = Module["asm"]["_ZNSt3__29allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEC2INS_20__shared_ptr_emplaceIS4_S5_EEEERKNS0_IT_EE"]).apply(null, arguments)
            };
            var __ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEEC2ES6_ = Module["__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEEC2ES6_"] = function() {
                return (__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEEC2ES6_ = Module["__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEEC2ES6_"] = Module["asm"]["_ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEEC2ES6_"]).apply(null, arguments)
            };
            var __ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEE3getEv = Module["__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEE3getEv"] = function() {
                return (__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEE3getEv = Module["__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEE3getEv"] = Module["asm"]["_ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEE3getEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE7releaseEv = Module["__ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE7releaseEv"] = function() {
                return (__ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE7releaseEv = Module["__ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE7releaseEv"] = Module["asm"]["_ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE7releaseEv"]).apply(null, arguments)
            };
            var __ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEE27__create_with_control_blockIS4_NS_20__shared_ptr_emplaceIS4_NS_9allocatorIS4_EEEEEES5_PT_PT0_ = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEE27__create_with_control_blockIS4_NS_20__shared_ptr_emplaceIS4_NS_9allocatorIS4_EEEEEES5_PT_PT0_"] = function() {
                return (__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEE27__create_with_control_blockIS4_NS_20__shared_ptr_emplaceIS4_NS_9allocatorIS4_EEEEEES5_PT_PT0_ = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEE27__create_with_control_blockIS4_NS_20__shared_ptr_emplaceIS4_NS_9allocatorIS4_EEEEEES5_PT_PT0_"] = Module["asm"]["_ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEE27__create_with_control_blockIS4_NS_20__shared_ptr_emplaceIS4_NS_9allocatorIS4_EEEEEES5_PT_PT0_"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEED2Ev = Module["__ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEED2Ev"] = function() {
                return (__ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEED2Ev = Module["__ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEED2Ev"] = Module["asm"]["_ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRNS_10shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEEEEONS_16remove_referenceIT_E4typeEOS9_ = Module["__ZNSt3__24moveIRNS_10shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEEEEONS_16remove_referenceIT_E4typeEOS9_"] = function() {
                return (__ZNSt3__24moveIRNS_10shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEEEEONS_16remove_referenceIT_E4typeEOS9_ = Module["__ZNSt3__24moveIRNS_10shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEEEEONS_16remove_referenceIT_E4typeEOS9_"] = Module["asm"]["_ZNSt3__24moveIRNS_10shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEEEEONS_16remove_referenceIT_E4typeEOS9_"]).apply(null, arguments)
            };
            var __ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEC2EOS5_ = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEC2EOS5_"] = function() {
                return (__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEC2EOS5_ = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEC2EOS5_"] = Module["asm"]["_ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEC2EOS5_"]).apply(null, arguments)
            };
            var __ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEE4swapERS5_ = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEE4swapERS5_"] = function() {
                return (__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEE4swapERS5_ = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEE4swapERS5_"] = Module["asm"]["_ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEE4swapERS5_"]).apply(null, arguments)
            };
            var __ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE9push_backEOS3_ = Module["__ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE9push_backEOS3_"] = function() {
                return (__ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE9push_backEOS3_ = Module["__ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE9push_backEOS3_"] = Module["asm"]["_ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE9push_backEOS3_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem15directory_entryD2Ev = Module["__ZNSt3__24__fs10filesystem15directory_entryD2Ev"] = function() {
                return (__ZNSt3__24__fs10filesystem15directory_entryD2Ev = Module["__ZNSt3__24__fs10filesystem15directory_entryD2Ev"] = Module["asm"]["_ZNSt3__24__fs10filesystem15directory_entryD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem28recursive_directory_iterator5__popEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem28recursive_directory_iterator5__popEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem28recursive_directory_iterator5__popEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem28recursive_directory_iterator5__popEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem28recursive_directory_iterator5__popEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEE3popEv = Module["__ZNSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEE3popEv"] = function() {
                return (__ZNSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEE3popEv = Module["__ZNSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEE3popEv"] = Module["asm"]["_ZNSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEE3popEv"]).apply(null, arguments)
            };
            var __ZNKSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEE4sizeEv = Module["__ZNKSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEE4sizeEv"] = function() {
                return (__ZNKSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEE4sizeEv = Module["__ZNKSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEE4sizeEv"] = Module["asm"]["_ZNKSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEE4sizeEv"]).apply(null, arguments)
            };
            var __ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEE5resetEv = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEE5resetEv"] = function() {
                return (__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEE5resetEv = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEE5resetEv"] = Module["asm"]["_ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEE5resetEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem28recursive_directory_iterator9__advanceEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem28recursive_directory_iterator9__advanceEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem28recursive_directory_iterator9__advanceEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem28recursive_directory_iterator9__advanceEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem28recursive_directory_iterator9__advanceEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE8pop_backEv = Module["__ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE8pop_backEv"] = function() {
                return (__ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE8pop_backEv = Module["__ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE8pop_backEv"] = Module["asm"]["_ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE8pop_backEv"]).apply(null, arguments)
            };
            var __ZNKSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE4sizeEv = Module["__ZNKSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE4sizeEv"] = function() {
                return (__ZNKSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE4sizeEv = Module["__ZNKSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE4sizeEv"] = Module["asm"]["_ZNKSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE4sizeEv"]).apply(null, arguments)
            };
            var __ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEC2Ev = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEC2Ev"] = function() {
                return (__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEC2Ev = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEC2Ev"] = Module["asm"]["_ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem18directory_iteratorC2Ev = Module["__ZNSt3__24__fs10filesystem18directory_iteratorC2Ev"] = function() {
                return (__ZNSt3__24__fs10filesystem18directory_iteratorC2Ev = Module["__ZNSt3__24__fs10filesystem18directory_iteratorC2Ev"] = Module["asm"]["_ZNSt3__24__fs10filesystem18directory_iteratorC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEE3topEv = Module["__ZNSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEE3topEv"] = function() {
                return (__ZNSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEE3topEv = Module["__ZNSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEE3topEv"] = Module["asm"]["_ZNSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEE3topEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem18directory_iteratorD2Ev = Module["__ZNSt3__24__fs10filesystem18directory_iteratorD2Ev"] = function() {
                return (__ZNSt3__24__fs10filesystem18directory_iteratorD2Ev = Module["__ZNSt3__24__fs10filesystem18directory_iteratorD2Ev"] = Module["asm"]["_ZNSt3__24__fs10filesystem18directory_iteratorD2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem28recursive_directory_iterator7optionsEv = Module["__ZNKSt3__24__fs10filesystem28recursive_directory_iterator7optionsEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem28recursive_directory_iterator7optionsEv = Module["__ZNKSt3__24__fs10filesystem28recursive_directory_iterator7optionsEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem28recursive_directory_iterator7optionsEv"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem28recursive_directory_iterator5depthEv = Module["__ZNKSt3__24__fs10filesystem28recursive_directory_iterator5depthEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem28recursive_directory_iterator5depthEv = Module["__ZNKSt3__24__fs10filesystem28recursive_directory_iterator5depthEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem28recursive_directory_iterator5depthEv"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem28recursive_directory_iterator13__dereferenceEv = Module["__ZNKSt3__24__fs10filesystem28recursive_directory_iterator13__dereferenceEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem28recursive_directory_iterator13__dereferenceEv = Module["__ZNKSt3__24__fs10filesystem28recursive_directory_iterator13__dereferenceEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem28recursive_directory_iterator13__dereferenceEv"]).apply(null, arguments)
            };
            var __ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE4backEv = Module["__ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE4backEv"] = function() {
                return (__ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE4backEv = Module["__ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE4backEv"] = Module["asm"]["_ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE4backEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem28recursive_directory_iterator11__incrementEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem28recursive_directory_iterator11__incrementEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem28recursive_directory_iterator11__incrementEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem28recursive_directory_iterator11__incrementEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem28recursive_directory_iterator11__incrementEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem28recursive_directory_iterator17recursion_pendingEv = Module["__ZNKSt3__24__fs10filesystem28recursive_directory_iterator17recursion_pendingEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem28recursive_directory_iterator17recursion_pendingEv = Module["__ZNKSt3__24__fs10filesystem28recursive_directory_iterator17recursion_pendingEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem28recursive_directory_iterator17recursion_pendingEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem28recursive_directory_iterator15__try_recursionEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem28recursive_directory_iterator15__try_recursionEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem28recursive_directory_iterator15__try_recursionEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem28recursive_directory_iterator15__try_recursionEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem28recursive_directory_iterator15__try_recursionEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem15directory_entry12__get_sym_ftEPNS_10error_codeE = Module["__ZNKSt3__24__fs10filesystem15directory_entry12__get_sym_ftEPNS_10error_codeE"] = function() {
                return (__ZNKSt3__24__fs10filesystem15directory_entry12__get_sym_ftEPNS_10error_codeE = Module["__ZNKSt3__24__fs10filesystem15directory_entry12__get_sym_ftEPNS_10error_codeE"] = Module["asm"]["_ZNKSt3__24__fs10filesystem15directory_entry12__get_sym_ftEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem11file_statusC2ENS1_9file_typeENS1_5permsE = Module["__ZNSt3__24__fs10filesystem11file_statusC2ENS1_9file_typeENS1_5permsE"] = function() {
                return (__ZNSt3__24__fs10filesystem11file_statusC2ENS1_9file_typeENS1_5permsE = Module["__ZNSt3__24__fs10filesystem11file_statusC2ENS1_9file_typeENS1_5permsE"] = Module["asm"]["_ZNSt3__24__fs10filesystem11file_statusC2ENS1_9file_typeENS1_5permsE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem12status_knownENS1_11file_statusE = Module["__ZNSt3__24__fs10filesystem12status_knownENS1_11file_statusE"] = function() {
                return (__ZNSt3__24__fs10filesystem12status_knownENS1_11file_statusE = Module["__ZNSt3__24__fs10filesystem12status_knownENS1_11file_statusE"] = Module["asm"]["_ZNSt3__24__fs10filesystem12status_knownENS1_11file_statusE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem11file_statusD2Ev = Module["__ZNSt3__24__fs10filesystem11file_statusD2Ev"] = function() {
                return (__ZNSt3__24__fs10filesystem11file_statusD2Ev = Module["__ZNSt3__24__fs10filesystem11file_statusD2Ev"] = Module["asm"]["_ZNSt3__24__fs10filesystem11file_statusD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem10is_symlinkENS1_11file_statusE = Module["__ZNSt3__24__fs10filesystem10is_symlinkENS1_11file_statusE"] = function() {
                return (__ZNSt3__24__fs10filesystem10is_symlinkENS1_11file_statusE = Module["__ZNSt3__24__fs10filesystem10is_symlinkENS1_11file_statusE"] = Module["asm"]["_ZNSt3__24__fs10filesystem10is_symlinkENS1_11file_statusE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem12is_directoryENS1_11file_statusE = Module["__ZNSt3__24__fs10filesystem12is_directoryENS1_11file_statusE"] = function() {
                return (__ZNSt3__24__fs10filesystem12is_directoryENS1_11file_statusE = Module["__ZNSt3__24__fs10filesystem12is_directoryENS1_11file_statusE"] = Module["asm"]["_ZNSt3__24__fs10filesystem12is_directoryENS1_11file_statusE"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem15directory_entry8__get_ftEPNS_10error_codeE = Module["__ZNKSt3__24__fs10filesystem15directory_entry8__get_ftEPNS_10error_codeE"] = function() {
                return (__ZNKSt3__24__fs10filesystem15directory_entry8__get_ftEPNS_10error_codeE = Module["__ZNKSt3__24__fs10filesystem15directory_entry8__get_ftEPNS_10error_codeE"] = Module["asm"]["_ZNKSt3__24__fs10filesystem15directory_entry8__get_ftEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem15directory_entry4pathEv = Module["__ZNKSt3__24__fs10filesystem15directory_entry4pathEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem15directory_entry4pathEv = Module["__ZNKSt3__24__fs10filesystem15directory_entry4pathEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem15directory_entry4pathEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem16__symlink_statusERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem16__symlink_statusERKNS1_4pathEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem16__symlink_statusERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem16__symlink_statusERKNS1_4pathEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem16__symlink_statusERKNS1_4pathEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem11file_status4typeEv = Module["__ZNKSt3__24__fs10filesystem11file_status4typeEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem11file_status4typeEv = Module["__ZNKSt3__24__fs10filesystem11file_status4typeEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem11file_status4typeEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem6existsENS1_11file_statusE = Module["__ZNSt3__24__fs10filesystem6existsENS1_11file_statusE"] = function() {
                return (__ZNSt3__24__fs10filesystem6existsENS1_11file_statusE = Module["__ZNSt3__24__fs10filesystem6existsENS1_11file_statusE"] = Module["asm"]["_ZNSt3__24__fs10filesystem6existsENS1_11file_statusE"]).apply(null, arguments)
            };
            var __ZNSt3__215make_error_codeENS_4errcE = Module["__ZNSt3__215make_error_codeENS_4errcE"] = function() {
                return (__ZNSt3__215make_error_codeENS_4errcE = Module["__ZNSt3__215make_error_codeENS_4errcE"] = Module["asm"]["_ZNSt3__215make_error_codeENS_4errcE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem8__statusERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem8__statusERKNS1_4pathEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem8__statusERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem8__statusERKNS1_4pathEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem8__statusERKNS1_4pathEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem9file_typeEEC2ILb1ELb0EEEv = Module["__ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem9file_typeEEC2ILb1ELb0EEEv"] = function() {
                return (__ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem9file_typeEEC2ILb1ELb0EEEv = Module["__ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem9file_typeEEC2ILb1ELb0EEEv"] = Module["asm"]["_ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem9file_typeEEC2ILb1ELb0EEEv"]).apply(null, arguments)
            };
            var __ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem9file_typeEEC2IRA256_cS7_Lb0EEEOT_OT0_ = Module["__ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem9file_typeEEC2IRA256_cS7_Lb0EEEOT_OT0_"] = function() {
                return (__ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem9file_typeEEC2IRA256_cS7_Lb0EEEOT_OT0_ = Module["__ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem9file_typeEEC2IRA256_cS7_Lb0EEEOT_OT0_"] = Module["asm"]["_ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem9file_typeEEC2IRA256_cS7_Lb0EEEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__228__char_traits_length_checkedINS_11char_traitsIcEEEEmPKNT_9char_typeE = Module["__ZNSt3__228__char_traits_length_checkedINS_11char_traitsIcEEEEmPKNT_9char_typeE"] = function() {
                return (__ZNSt3__228__char_traits_length_checkedINS_11char_traitsIcEEEEmPKNT_9char_typeE = Module["__ZNSt3__228__char_traits_length_checkedINS_11char_traitsIcEEEEmPKNT_9char_typeE"] = Module["asm"]["_ZNSt3__228__char_traits_length_checkedINS_11char_traitsIcEEEEmPKNT_9char_typeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4pathaSEOS2_ = Module["__ZNSt3__24__fs10filesystem4pathaSEOS2_"] = function() {
                return (__ZNSt3__24__fs10filesystem4pathaSEOS2_ = Module["__ZNSt3__24__fs10filesystem4pathaSEOS2_"] = Module["asm"]["_ZNSt3__24__fs10filesystem4pathaSEOS2_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4pathdVERKS2_ = Module["__ZNSt3__24__fs10filesystem4pathdVERKS2_"] = function() {
                return (__ZNSt3__24__fs10filesystem4pathdVERKS2_ = Module["__ZNSt3__24__fs10filesystem4pathdVERKS2_"] = Module["asm"]["_ZNSt3__24__fs10filesystem4pathdVERKS2_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEvRNS_12basic_stringIcS7_NS_9allocatorIcEEEERKT_ = Module["__ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEvRNS_12basic_stringIcS7_NS_9allocatorIcEEEERKT_"] = function() {
                return (__ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEvRNS_12basic_stringIcS7_NS_9allocatorIcEEEERKT_ = Module["__ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEvRNS_12basic_stringIcS7_NS_9allocatorIcEEEERKT_"] = Module["asm"]["_ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEvRNS_12basic_stringIcS7_NS_9allocatorIcEEEERKT_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem15directory_entry13__cached_dataC2Ev = Module["__ZNSt3__24__fs10filesystem15directory_entry13__cached_dataC2Ev"] = function() {
                return (__ZNSt3__24__fs10filesystem15directory_entry13__cached_dataC2Ev = Module["__ZNSt3__24__fs10filesystem15directory_entry13__cached_dataC2Ev"] = Module["asm"]["_ZNSt3__24__fs10filesystem15directory_entry13__cached_dataC2Ev"]).apply(null, arguments)
            };
            var __ZZNSt3__24__fs10filesystem15directory_entry20__create_iter_resultENS1_9file_typeEENKUlvE_clEv = Module["__ZZNSt3__24__fs10filesystem15directory_entry20__create_iter_resultENS1_9file_typeEENKUlvE_clEv"] = function() {
                return (__ZZNSt3__24__fs10filesystem15directory_entry20__create_iter_resultENS1_9file_typeEENKUlvE_clEv = Module["__ZZNSt3__24__fs10filesystem15directory_entry20__create_iter_resultENS1_9file_typeEENKUlvE_clEv"] = Module["asm"]["_ZZNSt3__24__fs10filesystem15directory_entry20__create_iter_resultENS1_9file_typeEENKUlvE_clEv"]).apply(null, arguments)
            };
            var __ZNSt3__217basic_string_viewIcNS_11char_traitsIcEEEC2Ev = Module["__ZNSt3__217basic_string_viewIcNS_11char_traitsIcEEEC2Ev"] = function() {
                return (__ZNSt3__217basic_string_viewIcNS_11char_traitsIcEEEC2Ev = Module["__ZNSt3__217basic_string_viewIcNS_11char_traitsIcEEEC2Ev"] = Module["asm"]["_ZNSt3__217basic_string_viewIcNS_11char_traitsIcEEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA256_cEEOT_RNS_16remove_referenceIS3_E4typeE = Module["__ZNSt3__27forwardIRA256_cEEOT_RNS_16remove_referenceIS3_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA256_cEEOT_RNS_16remove_referenceIS3_E4typeE = Module["__ZNSt3__27forwardIRA256_cEEOT_RNS_16remove_referenceIS3_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA256_cEEOT_RNS_16remove_referenceIS3_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardINS_4__fs10filesystem9file_typeEEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardINS_4__fs10filesystem9file_typeEEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardINS_4__fs10filesystem9file_typeEEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardINS_4__fs10filesystem9file_typeEEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardINS_4__fs10filesystem9file_typeEEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem4path11is_absoluteEv = Module["__ZNKSt3__24__fs10filesystem4path11is_absoluteEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem4path11is_absoluteEv = Module["__ZNKSt3__24__fs10filesystem4path11is_absoluteEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem4path11is_absoluteEv"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem4path12has_filenameEv = Module["__ZNKSt3__24__fs10filesystem4path12has_filenameEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem4path12has_filenameEv = Module["__ZNKSt3__24__fs10filesystem4path12has_filenameEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem4path12has_filenameEv"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEpLEc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEpLEc"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEpLEc = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEpLEc"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEpLEc"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem4path6nativeEv = Module["__ZNKSt3__24__fs10filesystem4path6nativeEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem4path6nativeEv = Module["__ZNKSt3__24__fs10filesystem4path6nativeEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem4path6nativeEv"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem4path18has_root_directoryEv = Module["__ZNKSt3__24__fs10filesystem4path18has_root_directoryEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem4path18has_root_directoryEv = Module["__ZNKSt3__24__fs10filesystem4path18has_root_directoryEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem4path18has_root_directoryEv"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem4path10__filenameEv = Module["__ZNKSt3__24__fs10filesystem4path10__filenameEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem4path10__filenameEv = Module["__ZNKSt3__24__fs10filesystem4path10__filenameEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem4path10__filenameEv"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem4path16__root_directoryEv = Module["__ZNKSt3__24__fs10filesystem4path16__root_directoryEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem4path16__root_directoryEv = Module["__ZNKSt3__24__fs10filesystem4path16__root_directoryEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem4path16__root_directoryEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem20__is_pathable_stringINS_17basic_string_viewIcNS_11char_traitsIcEEEEvE13__range_beginERKS6_ = Module["__ZNSt3__24__fs10filesystem20__is_pathable_stringINS_17basic_string_viewIcNS_11char_traitsIcEEEEvE13__range_beginERKS6_"] = function() {
                return (__ZNSt3__24__fs10filesystem20__is_pathable_stringINS_17basic_string_viewIcNS_11char_traitsIcEEEEvE13__range_beginERKS6_ = Module["__ZNSt3__24__fs10filesystem20__is_pathable_stringINS_17basic_string_viewIcNS_11char_traitsIcEEEEvE13__range_beginERKS6_"] = Module["asm"]["_ZNSt3__24__fs10filesystem20__is_pathable_stringINS_17basic_string_viewIcNS_11char_traitsIcEEEEvE13__range_beginERKS6_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem20__is_pathable_stringINS_17basic_string_viewIcNS_11char_traitsIcEEEEvE11__range_endERKS6_ = Module["__ZNSt3__24__fs10filesystem20__is_pathable_stringINS_17basic_string_viewIcNS_11char_traitsIcEEEEvE11__range_endERKS6_"] = function() {
                return (__ZNSt3__24__fs10filesystem20__is_pathable_stringINS_17basic_string_viewIcNS_11char_traitsIcEEEEvE11__range_endERKS6_ = Module["__ZNSt3__24__fs10filesystem20__is_pathable_stringINS_17basic_string_viewIcNS_11char_traitsIcEEEEvE11__range_endERKS6_"] = Module["asm"]["_ZNSt3__24__fs10filesystem20__is_pathable_stringINS_17basic_string_viewIcNS_11char_traitsIcEEEEvE11__range_endERKS6_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem8_PathCVTIcE14__append_rangeIPKcEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeERNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES8_S8_ = Module["__ZNSt3__24__fs10filesystem8_PathCVTIcE14__append_rangeIPKcEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeERNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES8_S8_"] = function() {
                return (__ZNSt3__24__fs10filesystem8_PathCVTIcE14__append_rangeIPKcEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeERNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES8_S8_ = Module["__ZNSt3__24__fs10filesystem8_PathCVTIcE14__append_rangeIPKcEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeERNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES8_S8_"] = Module["asm"]["_ZNSt3__24__fs10filesystem8_PathCVTIcE14__append_rangeIPKcEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeERNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEES8_S8_"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE23__append_forward_unsafeIPKcEERS5_T_SA_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE23__append_forward_unsafeIPKcEERS5_T_SA_"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE23__append_forward_unsafeIPKcEERS5_T_SA_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE23__append_forward_unsafeIPKcEERS5_T_SA_"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE23__append_forward_unsafeIPKcEERS5_T_SA_"]).apply(null, arguments)
            };
            var __ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE6lengthEv = Module["__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE6lengthEv"] = function() {
                return (__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE6lengthEv = Module["__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE6lengthEv"] = Module["asm"]["_ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE6lengthEv"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2IPKcvEET_S9_RKS4_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2IPKcvEET_S9_RKS4_"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2IPKcvEET_S9_RKS4_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2IPKcvEET_S9_RKS4_"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2IPKcvEET_S9_RKS4_"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono10time_pointINS_4__fs10filesystem16_FilesystemClockENS0_8durationInNS_5ratioILx1ELx1000000000EEEEEEC2Ev = Module["__ZNSt3__26chrono10time_pointINS_4__fs10filesystem16_FilesystemClockENS0_8durationInNS_5ratioILx1ELx1000000000EEEEEEC2Ev"] = function() {
                return (__ZNSt3__26chrono10time_pointINS_4__fs10filesystem16_FilesystemClockENS0_8durationInNS_5ratioILx1ELx1000000000EEEEEEC2Ev = Module["__ZNSt3__26chrono10time_pointINS_4__fs10filesystem16_FilesystemClockENS0_8durationInNS_5ratioILx1ELx1000000000EEEEEEC2Ev"] = Module["asm"]["_ZNSt3__26chrono10time_pointINS_4__fs10filesystem16_FilesystemClockENS0_8durationInNS_5ratioILx1ELx1000000000EEEEEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem15directory_entry13__cached_data7__resetEv = Module["__ZNSt3__24__fs10filesystem15directory_entry13__cached_data7__resetEv"] = function() {
                return (__ZNSt3__24__fs10filesystem15directory_entry13__cached_data7__resetEv = Module["__ZNSt3__24__fs10filesystem15directory_entry13__cached_data7__resetEv"] = Module["asm"]["_ZNSt3__24__fs10filesystem15directory_entry13__cached_data7__resetEv"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEE4zeroEv = Module["__ZNSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEE4zeroEv"] = function() {
                return (__ZNSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEE4zeroEv = Module["__ZNSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEE4zeroEv"] = Module["asm"]["_ZNSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEE4zeroEv"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono10time_pointINS_4__fs10filesystem16_FilesystemClockENS0_8durationInNS_5ratioILx1ELx1000000000EEEEEE3minEv = Module["__ZNSt3__26chrono10time_pointINS_4__fs10filesystem16_FilesystemClockENS0_8durationInNS_5ratioILx1ELx1000000000EEEEEE3minEv"] = function() {
                return (__ZNSt3__26chrono10time_pointINS_4__fs10filesystem16_FilesystemClockENS0_8durationInNS_5ratioILx1ELx1000000000EEEEEE3minEv = Module["__ZNSt3__26chrono10time_pointINS_4__fs10filesystem16_FilesystemClockENS0_8durationInNS_5ratioILx1ELx1000000000EEEEEE3minEv"] = Module["asm"]["_ZNSt3__26chrono10time_pointINS_4__fs10filesystem16_FilesystemClockENS0_8durationInNS_5ratioILx1ELx1000000000EEEEEE3minEv"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono15duration_valuesInE4zeroEv = Module["__ZNSt3__26chrono15duration_valuesInE4zeroEv"] = function() {
                return (__ZNSt3__26chrono15duration_valuesInE4zeroEv = Module["__ZNSt3__26chrono15duration_valuesInE4zeroEv"] = Module["asm"]["_ZNSt3__26chrono15duration_valuesInE4zeroEv"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEEC2InEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_nEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEEC2InEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_nEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"] = function() {
                return (__ZNSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEEC2InEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_nEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEEC2InEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_nEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"] = Module["asm"]["_ZNSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEEC2InEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_nEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEE3minEv = Module["__ZNSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEE3minEv"] = function() {
                return (__ZNSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEE3minEv = Module["__ZNSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEE3minEv"] = Module["asm"]["_ZNSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEE3minEv"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono10time_pointINS_4__fs10filesystem16_FilesystemClockENS0_8durationInNS_5ratioILx1ELx1000000000EEEEEEC2ERKS8_ = Module["__ZNSt3__26chrono10time_pointINS_4__fs10filesystem16_FilesystemClockENS0_8durationInNS_5ratioILx1ELx1000000000EEEEEEC2ERKS8_"] = function() {
                return (__ZNSt3__26chrono10time_pointINS_4__fs10filesystem16_FilesystemClockENS0_8durationInNS_5ratioILx1ELx1000000000EEEEEEC2ERKS8_ = Module["__ZNSt3__26chrono10time_pointINS_4__fs10filesystem16_FilesystemClockENS0_8durationInNS_5ratioILx1ELx1000000000EEEEEEC2ERKS8_"] = Module["asm"]["_ZNSt3__26chrono10time_pointINS_4__fs10filesystem16_FilesystemClockENS0_8durationInNS_5ratioILx1ELx1000000000EEEEEEC2ERKS8_"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono15duration_valuesInE3minEv = Module["__ZNSt3__26chrono15duration_valuesInE3minEv"] = function() {
                return (__ZNSt3__26chrono15duration_valuesInE3minEv = Module["__ZNSt3__26chrono15duration_valuesInE3minEv"] = Module["asm"]["_ZNSt3__26chrono15duration_valuesInE3minEv"]).apply(null, arguments)
            };
            var __ZNSt3__214numeric_limitsInE6lowestEv = Module["__ZNSt3__214numeric_limitsInE6lowestEv"] = function() {
                return (__ZNSt3__214numeric_limitsInE6lowestEv = Module["__ZNSt3__214numeric_limitsInE6lowestEv"] = Module["asm"]["_ZNSt3__214numeric_limitsInE6lowestEv"]).apply(null, arguments)
            };
            var __ZNSt3__223__libcpp_numeric_limitsInLb1EE6lowestEv = Module["__ZNSt3__223__libcpp_numeric_limitsInLb1EE6lowestEv"] = function() {
                return (__ZNSt3__223__libcpp_numeric_limitsInLb1EE6lowestEv = Module["__ZNSt3__223__libcpp_numeric_limitsInLb1EE6lowestEv"] = Module["asm"]["_ZNSt3__223__libcpp_numeric_limitsInLb1EE6lowestEv"]).apply(null, arguments)
            };
            var __ZNSt3__223__libcpp_numeric_limitsInLb1EE3minEv = Module["__ZNSt3__223__libcpp_numeric_limitsInLb1EE3minEv"] = function() {
                return (__ZNSt3__223__libcpp_numeric_limitsInLb1EE3minEv = Module["__ZNSt3__223__libcpp_numeric_limitsInLb1EE3minEv"] = Module["asm"]["_ZNSt3__223__libcpp_numeric_limitsInLb1EE3minEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4pathC2Ev = Module["__ZNSt3__24__fs10filesystem4pathC2Ev"] = function() {
                return (__ZNSt3__24__fs10filesystem4pathC2Ev = Module["__ZNSt3__24__fs10filesystem4pathC2Ev"] = Module["asm"]["_ZNSt3__24__fs10filesystem4pathC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIPNS_4__fs10filesystem12__dir_streamEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS6_EE5valueEvE4typeERS6_S9_ = Module["__ZNSt3__24swapIPNS_4__fs10filesystem12__dir_streamEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS6_EE5valueEvE4typeERS6_S9_"] = function() {
                return (__ZNSt3__24swapIPNS_4__fs10filesystem12__dir_streamEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS6_EE5valueEvE4typeERS6_S9_ = Module["__ZNSt3__24swapIPNS_4__fs10filesystem12__dir_streamEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS6_EE5valueEvE4typeERS6_S9_"] = Module["asm"]["_ZNSt3__24swapIPNS_4__fs10filesystem12__dir_streamEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS6_EE5valueEvE4typeERS6_S9_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIPNS_19__shared_weak_countEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS4_EE5valueEvE4typeERS4_S7_ = Module["__ZNSt3__24swapIPNS_19__shared_weak_countEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS4_EE5valueEvE4typeERS4_S7_"] = function() {
                return (__ZNSt3__24swapIPNS_19__shared_weak_countEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS4_EE5valueEvE4typeERS4_S7_ = Module["__ZNSt3__24swapIPNS_19__shared_weak_countEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS4_EE5valueEvE4typeERS4_S7_"] = Module["asm"]["_ZNSt3__24swapIPNS_19__shared_weak_countEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS4_EE5valueEvE4typeERS4_S7_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRPNS_4__fs10filesystem12__dir_streamEEEONS_16remove_referenceIT_E4typeEOS7_ = Module["__ZNSt3__24moveIRPNS_4__fs10filesystem12__dir_streamEEEONS_16remove_referenceIT_E4typeEOS7_"] = function() {
                return (__ZNSt3__24moveIRPNS_4__fs10filesystem12__dir_streamEEEONS_16remove_referenceIT_E4typeEOS7_ = Module["__ZNSt3__24moveIRPNS_4__fs10filesystem12__dir_streamEEEONS_16remove_referenceIT_E4typeEOS7_"] = Module["asm"]["_ZNSt3__24moveIRPNS_4__fs10filesystem12__dir_streamEEEONS_16remove_referenceIT_E4typeEOS7_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRPNS_19__shared_weak_countEEEONS_16remove_referenceIT_E4typeEOS5_ = Module["__ZNSt3__24moveIRPNS_19__shared_weak_countEEEONS_16remove_referenceIT_E4typeEOS5_"] = function() {
                return (__ZNSt3__24moveIRPNS_19__shared_weak_countEEEONS_16remove_referenceIT_E4typeEOS5_ = Module["__ZNSt3__24moveIRPNS_19__shared_weak_countEEEONS_16remove_referenceIT_E4typeEOS5_"] = Module["asm"]["_ZNSt3__24moveIRPNS_19__shared_weak_countEEEONS_16remove_referenceIT_E4typeEOS5_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIPNS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS7_EE5valueEvE4typeERS7_SA_ = Module["__ZNSt3__24swapIPNS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS7_EE5valueEvE4typeERS7_SA_"] = function() {
                return (__ZNSt3__24swapIPNS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS7_EE5valueEvE4typeERS7_SA_ = Module["__ZNSt3__24swapIPNS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS7_EE5valueEvE4typeERS7_SA_"] = Module["asm"]["_ZNSt3__24swapIPNS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS7_EE5valueEvE4typeERS7_SA_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRPNS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEEONS_16remove_referenceIT_E4typeEOS8_ = Module["__ZNSt3__24moveIRPNS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEEONS_16remove_referenceIT_E4typeEOS8_"] = function() {
                return (__ZNSt3__24moveIRPNS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEEONS_16remove_referenceIT_E4typeEOS8_ = Module["__ZNSt3__24moveIRPNS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEEONS_16remove_referenceIT_E4typeEOS8_"] = Module["asm"]["_ZNSt3__24moveIRPNS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEEONS_16remove_referenceIT_E4typeEOS8_"]).apply(null, arguments)
            };
            var __ZNKSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS0_IS4_EEEEE8max_sizeEv = Module["__ZNKSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS0_IS4_EEEEE8max_sizeEv"] = function() {
                return (__ZNKSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS0_IS4_EEEEE8max_sizeEv = Module["__ZNKSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS0_IS4_EEEEE8max_sizeEv"] = Module["asm"]["_ZNKSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS0_IS4_EEEEE8max_sizeEv"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRNS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS2_IS6_EEEEEEEEEEONS_16remove_referenceIT_E4typeEOSD_ = Module["__ZNSt3__24moveIRNS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS2_IS6_EEEEEEEEEEONS_16remove_referenceIT_E4typeEOSD_"] = function() {
                return (__ZNSt3__24moveIRNS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS2_IS6_EEEEEEEEEEONS_16remove_referenceIT_E4typeEOSD_ = Module["__ZNSt3__24moveIRNS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS2_IS6_EEEEEEEEEEONS_16remove_referenceIT_E4typeEOSD_"] = Module["asm"]["_ZNSt3__24moveIRNS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS2_IS6_EEEEEEEEEEONS_16remove_referenceIT_E4typeEOSD_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEEC2IRS8_SB_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEEC2IRS8_SB_EEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEEC2IRS8_SB_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEEC2IRS8_SB_EEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEEC2IRS8_SB_EEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__219__shared_weak_countC2El = Module["__ZNSt3__219__shared_weak_countC2El"] = function() {
                return (__ZNSt3__219__shared_weak_countC2El = Module["__ZNSt3__219__shared_weak_countC2El"] = Module["asm"]["_ZNSt3__219__shared_weak_countC2El"]).apply(null, arguments)
            };
            var __ZNSt3__216forward_as_tupleIJRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEENS_5tupleIJDpOT_EEESA_ = Module["__ZNSt3__216forward_as_tupleIJRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEENS_5tupleIJDpOT_EEESA_"] = function() {
                return (__ZNSt3__216forward_as_tupleIJRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEENS_5tupleIJDpOT_EEESA_ = Module["__ZNSt3__216forward_as_tupleIJRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEENS_5tupleIJDpOT_EEESA_"] = Module["asm"]["_ZNSt3__216forward_as_tupleIJRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEENS_5tupleIJDpOT_EEESA_"]).apply(null, arguments)
            };
            var __ZNSt3__216forward_as_tupleIJRKNS_4__fs10filesystem4pathERNS2_17directory_optionsERNS_10error_codeEEEENS_5tupleIJDpOT_EEESD_ = Module["__ZNSt3__216forward_as_tupleIJRKNS_4__fs10filesystem4pathERNS2_17directory_optionsERNS_10error_codeEEEENS_5tupleIJDpOT_EEESD_"] = function() {
                return (__ZNSt3__216forward_as_tupleIJRKNS_4__fs10filesystem4pathERNS2_17directory_optionsERNS_10error_codeEEEENS_5tupleIJDpOT_EEESD_ = Module["__ZNSt3__216forward_as_tupleIJRKNS_4__fs10filesystem4pathERNS2_17directory_optionsERNS_10error_codeEEEENS_5tupleIJDpOT_EEESD_"] = Module["asm"]["_ZNSt3__216forward_as_tupleIJRKNS_4__fs10filesystem4pathERNS2_17directory_optionsERNS_10error_codeEEEENS_5tupleIJDpOT_EEESD_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem12__dir_streamEEES4_EC2IJRS5_EJRKNS3_4pathERNS3_17directory_optionsERNS_10error_codeEEEENS_21piecewise_construct_tENS_5tupleIJDpT_EEENSH_IJDpT0_EEE = Module["__ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem12__dir_streamEEES4_EC2IJRS5_EJRKNS3_4pathERNS3_17directory_optionsERNS_10error_codeEEEENS_21piecewise_construct_tENS_5tupleIJDpT_EEENSH_IJDpT0_EEE"] = function() {
                return (__ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem12__dir_streamEEES4_EC2IJRS5_EJRKNS3_4pathERNS3_17directory_optionsERNS_10error_codeEEEENS_21piecewise_construct_tENS_5tupleIJDpT_EEENSH_IJDpT0_EEE = Module["__ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem12__dir_streamEEES4_EC2IJRS5_EJRKNS3_4pathERNS3_17directory_optionsERNS_10error_codeEEEENS_21piecewise_construct_tENS_5tupleIJDpT_EEENSH_IJDpT0_EEE"] = Module["asm"]["_ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem12__dir_streamEEES4_EC2IJRS5_EJRKNS3_4pathERNS3_17directory_optionsERNS_10error_codeEEEENS_21piecewise_construct_tENS_5tupleIJDpT_EEENSH_IJDpT0_EEE"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem12__dir_streamEEES4_E6secondEv = Module["__ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem12__dir_streamEEES4_E6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem12__dir_streamEEES4_E6secondEv = Module["__ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem12__dir_streamEEES4_E6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem12__dir_streamEEES4_E6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__29addressofINS_4__fs10filesystem12__dir_streamEEEPT_RS4_ = Module["__ZNSt3__29addressofINS_4__fs10filesystem12__dir_streamEEEPT_RS4_"] = function() {
                return (__ZNSt3__29addressofINS_4__fs10filesystem12__dir_streamEEEPT_RS4_ = Module["__ZNSt3__29addressofINS_4__fs10filesystem12__dir_streamEEEPT_RS4_"] = Module["asm"]["_ZNSt3__29addressofINS_4__fs10filesystem12__dir_streamEEEPT_RS4_"]).apply(null, arguments)
            };
            var __ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEE18__enable_weak_thisEz = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEE18__enable_weak_thisEz"] = function() {
                return (__ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEE18__enable_weak_thisEz = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEE18__enable_weak_thisEz"] = Module["asm"]["_ZNSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEE18__enable_weak_thisEz"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE5firstEv = Module["__ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE5firstEv = Module["__ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE5resetEPS7_ = Module["__ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE5resetEPS7_"] = function() {
                return (__ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE5resetEPS7_ = Module["__ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE5resetEPS7_"] = Module["asm"]["_ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE5resetEPS7_"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEEEEOT_RNS_16remove_referenceISA_E4typeE = Module["__ZNSt3__27forwardIRPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEEEEOT_RNS_16remove_referenceISA_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEEEEOT_RNS_16remove_referenceISA_E4typeE = Module["__ZNSt3__27forwardIRPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEEEEOT_RNS_16remove_referenceISA_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEEEEOT_RNS_16remove_referenceISA_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEELi0ELb0EEC2IRS8_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEELi0ELb0EEC2IRS8_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEELi0ELb0EEC2IRS8_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEELi0ELb0EEC2IRS8_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEELi0ELb0EEC2IRS8_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS2_IS6_EEEEEEEEEEOT_RNS_16remove_referenceISB_E4typeE = Module["__ZNSt3__27forwardINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS2_IS6_EEEEEEEEEEOT_RNS_16remove_referenceISB_E4typeE"] = function() {
                return (__ZNSt3__27forwardINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS2_IS6_EEEEEEEEEEOT_RNS_16remove_referenceISB_E4typeE = Module["__ZNSt3__27forwardINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS2_IS6_EEEEEEEEEEOT_RNS_16remove_referenceISB_E4typeE"] = Module["asm"]["_ZNSt3__27forwardINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS2_IS6_EEEEEEEEEEOT_RNS_16remove_referenceISB_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS2_IS6_EEEEEEEELi1ELb0EEC2ISA_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS2_IS6_EEEEEEEELi1ELb0EEC2ISA_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS2_IS6_EEEEEEEELi1ELb0EEC2ISA_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS2_IS6_EEEEEEEELi1ELb0EEC2ISA_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS2_IS6_EEEEEEEELi1ELb0EEC2ISA_vEEOT_"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEELi0ELb0EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEELi0ELb0EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEOT_RNS_16remove_referenceIS7_E4typeE = Module["__ZNSt3__27forwardIRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEOT_RNS_16remove_referenceIS7_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEOT_RNS_16remove_referenceIS7_E4typeE = Module["__ZNSt3__27forwardIRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEOT_RNS_16remove_referenceIS7_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEOT_RNS_16remove_referenceIS7_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__25tupleIJRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEC2ILb1ELb0EEES6_ = Module["__ZNSt3__25tupleIJRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEC2ILb1ELb0EEES6_"] = function() {
                return (__ZNSt3__25tupleIJRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEC2ILb1ELb0EEES6_ = Module["__ZNSt3__25tupleIJRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEC2ILb1ELb0EEES6_"] = Module["asm"]["_ZNSt3__25tupleIJRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEC2ILb1ELb0EEES6_"]).apply(null, arguments)
            };
            var __ZNSt3__25tupleIJRKNS_4__fs10filesystem4pathERNS2_17directory_optionsERNS_10error_codeEEEC2ILb1ELb0EEES5_S7_S9_ = Module["__ZNSt3__25tupleIJRKNS_4__fs10filesystem4pathERNS2_17directory_optionsERNS_10error_codeEEEC2ILb1ELb0EEES5_S7_S9_"] = function() {
                return (__ZNSt3__25tupleIJRKNS_4__fs10filesystem4pathERNS2_17directory_optionsERNS_10error_codeEEEC2ILb1ELb0EEES5_S7_S9_ = Module["__ZNSt3__25tupleIJRKNS_4__fs10filesystem4pathERNS2_17directory_optionsERNS_10error_codeEEEC2ILb1ELb0EEES5_S7_S9_"] = Module["asm"]["_ZNSt3__25tupleIJRKNS_4__fs10filesystem4pathERNS2_17directory_optionsERNS_10error_codeEEEC2ILb1ELb0EEES5_S7_S9_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRNS_5tupleIJRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEEEEONS_16remove_referenceIT_E4typeEOSB_ = Module["__ZNSt3__24moveIRNS_5tupleIJRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEEEEONS_16remove_referenceIT_E4typeEOSB_"] = function() {
                return (__ZNSt3__24moveIRNS_5tupleIJRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEEEEONS_16remove_referenceIT_E4typeEOSB_ = Module["__ZNSt3__24moveIRNS_5tupleIJRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEEEEONS_16remove_referenceIT_E4typeEOSB_"] = Module["asm"]["_ZNSt3__24moveIRNS_5tupleIJRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEEEEONS_16remove_referenceIT_E4typeEOSB_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem12__dir_streamEEELi0ELb1EEC2IJRS5_EJLm0EEEENS_21piecewise_construct_tENS_5tupleIJDpT_EEENS_15__tuple_indicesIJXspT0_EEEE = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem12__dir_streamEEELi0ELb1EEC2IJRS5_EJLm0EEEENS_21piecewise_construct_tENS_5tupleIJDpT_EEENS_15__tuple_indicesIJXspT0_EEEE"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem12__dir_streamEEELi0ELb1EEC2IJRS5_EJLm0EEEENS_21piecewise_construct_tENS_5tupleIJDpT_EEENS_15__tuple_indicesIJXspT0_EEEE = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem12__dir_streamEEELi0ELb1EEC2IJRS5_EJLm0EEEENS_21piecewise_construct_tENS_5tupleIJDpT_EEENS_15__tuple_indicesIJXspT0_EEEE"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem12__dir_streamEEELi0ELb1EEC2IJRS5_EJLm0EEEENS_21piecewise_construct_tENS_5tupleIJDpT_EEENS_15__tuple_indicesIJXspT0_EEEE"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRNS_5tupleIJRKNS_4__fs10filesystem4pathERNS3_17directory_optionsERNS_10error_codeEEEEEEONS_16remove_referenceIT_E4typeEOSE_ = Module["__ZNSt3__24moveIRNS_5tupleIJRKNS_4__fs10filesystem4pathERNS3_17directory_optionsERNS_10error_codeEEEEEEONS_16remove_referenceIT_E4typeEOSE_"] = function() {
                return (__ZNSt3__24moveIRNS_5tupleIJRKNS_4__fs10filesystem4pathERNS3_17directory_optionsERNS_10error_codeEEEEEEONS_16remove_referenceIT_E4typeEOSE_ = Module["__ZNSt3__24moveIRNS_5tupleIJRKNS_4__fs10filesystem4pathERNS3_17directory_optionsERNS_10error_codeEEEEEEONS_16remove_referenceIT_E4typeEOSE_"] = Module["asm"]["_ZNSt3__24moveIRNS_5tupleIJRKNS_4__fs10filesystem4pathERNS3_17directory_optionsERNS_10error_codeEEEEEEONS_16remove_referenceIT_E4typeEOSE_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem12__dir_streamELi1ELb0EEC2IJRKNS2_4pathERNS2_17directory_optionsERNS_10error_codeEEJLm0ELm1ELm2EEEENS_21piecewise_construct_tENS_5tupleIJDpT_EEENS_15__tuple_indicesIJXspT0_EEEE = Module["__ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem12__dir_streamELi1ELb0EEC2IJRKNS2_4pathERNS2_17directory_optionsERNS_10error_codeEEJLm0ELm1ELm2EEEENS_21piecewise_construct_tENS_5tupleIJDpT_EEENS_15__tuple_indicesIJXspT0_EEEE"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem12__dir_streamELi1ELb0EEC2IJRKNS2_4pathERNS2_17directory_optionsERNS_10error_codeEEJLm0ELm1ELm2EEEENS_21piecewise_construct_tENS_5tupleIJDpT_EEENS_15__tuple_indicesIJXspT0_EEEE = Module["__ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem12__dir_streamELi1ELb0EEC2IJRKNS2_4pathERNS2_17directory_optionsERNS_10error_codeEEJLm0ELm1ELm2EEEENS_21piecewise_construct_tENS_5tupleIJDpT_EEENS_15__tuple_indicesIJXspT0_EEEE"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem12__dir_streamELi1ELb0EEC2IJRKNS2_4pathERNS2_17directory_optionsERNS_10error_codeEEJLm0ELm1ELm2EEEENS_21piecewise_construct_tENS_5tupleIJDpT_EEENS_15__tuple_indicesIJXspT0_EEEE"]).apply(null, arguments)
            };
            var __ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEED2Ev = Module["__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEED2Ev"] = function() {
                return (__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEED2Ev = Module["__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEED2Ev"] = Module["asm"]["_ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem12__dir_streamELi1ELb0EED2Ev = Module["__ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem12__dir_streamELi1ELb0EED2Ev"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem12__dir_streamELi1ELb0EED2Ev = Module["__ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem12__dir_streamELi1ELb0EED2Ev"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem12__dir_streamELi1ELb0EED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEED0Ev = Module["__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEED0Ev"] = function() {
                return (__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEED0Ev = Module["__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEED0Ev"] = Module["asm"]["_ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE16__on_zero_sharedEv = Module["__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE16__on_zero_sharedEv"] = function() {
                return (__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE16__on_zero_sharedEv = Module["__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE16__on_zero_sharedEv"] = Module["asm"]["_ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE16__on_zero_sharedEv"]).apply(null, arguments)
            };
            var __ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE21__on_zero_shared_weakEv = Module["__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE21__on_zero_shared_weakEv"] = function() {
                return (__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE21__on_zero_shared_weakEv = Module["__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE21__on_zero_shared_weakEv"] = Module["asm"]["_ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE21__on_zero_shared_weakEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem12__dir_streamEEES4_E5firstEv = Module["__ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem12__dir_streamEEES4_E5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem12__dir_streamEEES4_E5firstEv = Module["__ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem12__dir_streamEEES4_E5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem12__dir_streamEEES4_E5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS0_IS4_EEEEEC2IS4_EERKNS0_IT_EE = Module["__ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS0_IS4_EEEEEC2IS4_EERKNS0_IT_EE"] = function() {
                return (__ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS0_IS4_EEEEEC2IS4_EERKNS0_IT_EE = Module["__ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS0_IS4_EEEEEC2IS4_EERKNS0_IT_EE"] = Module["asm"]["_ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS0_IS4_EEEEEC2IS4_EERKNS0_IT_EE"]).apply(null, arguments)
            };
            var __ZNSt3__214pointer_traitsIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEEE10pointer_toERS7_ = Module["__ZNSt3__214pointer_traitsIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEEE10pointer_toERS7_"] = function() {
                return (__ZNSt3__214pointer_traitsIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEEE10pointer_toERS7_ = Module["__ZNSt3__214pointer_traitsIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEEE10pointer_toERS7_"] = Module["asm"]["_ZNSt3__214pointer_traitsIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEEE10pointer_toERS7_"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS0_IS4_EEEEE10deallocateEPS6_m = Module["__ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS0_IS4_EEEEE10deallocateEPS6_m"] = function() {
                return (__ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS0_IS4_EEEEE10deallocateEPS6_m = Module["__ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS0_IS4_EEEEE10deallocateEPS6_m"] = Module["asm"]["_ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS0_IS4_EEEEE10deallocateEPS6_m"]).apply(null, arguments)
            };
            var __ZNSt3__212__tuple_implINS_15__tuple_indicesIJLm0EEEEJRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEC2IJLm0EEJS8_EJEJEJS8_EEENS1_IJXspT_EEEENS_13__tuple_typesIJDpT0_EEENS1_IJXspT1_EEEENSC_IJDpT2_EEEDpOT3_ = Module["__ZNSt3__212__tuple_implINS_15__tuple_indicesIJLm0EEEEJRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEC2IJLm0EEJS8_EJEJEJS8_EEENS1_IJXspT_EEEENS_13__tuple_typesIJDpT0_EEENS1_IJXspT1_EEEENSC_IJDpT2_EEEDpOT3_"] = function() {
                return (__ZNSt3__212__tuple_implINS_15__tuple_indicesIJLm0EEEEJRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEC2IJLm0EEJS8_EJEJEJS8_EEENS1_IJXspT_EEEENS_13__tuple_typesIJDpT0_EEENS1_IJXspT1_EEEENSC_IJDpT2_EEEDpOT3_ = Module["__ZNSt3__212__tuple_implINS_15__tuple_indicesIJLm0EEEEJRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEC2IJLm0EEJS8_EJEJEJS8_EEENS1_IJXspT_EEEENS_13__tuple_typesIJDpT0_EEENS1_IJXspT1_EEEENSC_IJDpT2_EEEDpOT3_"] = Module["asm"]["_ZNSt3__212__tuple_implINS_15__tuple_indicesIJLm0EEEEJRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEC2IJLm0EEJS8_EJEJEJS8_EEENS1_IJXspT_EEEENS_13__tuple_typesIJDpT0_EEENS1_IJXspT1_EEEENSC_IJDpT2_EEEDpOT3_"]).apply(null, arguments)
            };
            var __ZNSt3__212__tuple_leafILm0ERNS_9allocatorINS_4__fs10filesystem12__dir_streamEEELb0EEC2IS6_vEEOT_ = Module["__ZNSt3__212__tuple_leafILm0ERNS_9allocatorINS_4__fs10filesystem12__dir_streamEEELb0EEC2IS6_vEEOT_"] = function() {
                return (__ZNSt3__212__tuple_leafILm0ERNS_9allocatorINS_4__fs10filesystem12__dir_streamEEELb0EEC2IS6_vEEOT_ = Module["__ZNSt3__212__tuple_leafILm0ERNS_9allocatorINS_4__fs10filesystem12__dir_streamEEELb0EEC2IS6_vEEOT_"] = Module["asm"]["_ZNSt3__212__tuple_leafILm0ERNS_9allocatorINS_4__fs10filesystem12__dir_streamEEELb0EEC2IS6_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__212__tuple_implINS_15__tuple_indicesIJLm0ELm1ELm2EEEEJRKNS_4__fs10filesystem4pathERNS4_17directory_optionsERNS_10error_codeEEEC2IJLm0ELm1ELm2EEJS7_S9_SB_EJEJEJS7_S9_SB_EEENS1_IJXspT_EEEENS_13__tuple_typesIJDpT0_EEENS1_IJXspT1_EEEENSF_IJDpT2_EEEDpOT3_ = Module["__ZNSt3__212__tuple_implINS_15__tuple_indicesIJLm0ELm1ELm2EEEEJRKNS_4__fs10filesystem4pathERNS4_17directory_optionsERNS_10error_codeEEEC2IJLm0ELm1ELm2EEJS7_S9_SB_EJEJEJS7_S9_SB_EEENS1_IJXspT_EEEENS_13__tuple_typesIJDpT0_EEENS1_IJXspT1_EEEENSF_IJDpT2_EEEDpOT3_"] = function() {
                return (__ZNSt3__212__tuple_implINS_15__tuple_indicesIJLm0ELm1ELm2EEEEJRKNS_4__fs10filesystem4pathERNS4_17directory_optionsERNS_10error_codeEEEC2IJLm0ELm1ELm2EEJS7_S9_SB_EJEJEJS7_S9_SB_EEENS1_IJXspT_EEEENS_13__tuple_typesIJDpT0_EEENS1_IJXspT1_EEEENSF_IJDpT2_EEEDpOT3_ = Module["__ZNSt3__212__tuple_implINS_15__tuple_indicesIJLm0ELm1ELm2EEEEJRKNS_4__fs10filesystem4pathERNS4_17directory_optionsERNS_10error_codeEEEC2IJLm0ELm1ELm2EEJS7_S9_SB_EJEJEJS7_S9_SB_EEENS1_IJXspT_EEEENS_13__tuple_typesIJDpT0_EEENS1_IJXspT1_EEEENSF_IJDpT2_EEEDpOT3_"] = Module["asm"]["_ZNSt3__212__tuple_implINS_15__tuple_indicesIJLm0ELm1ELm2EEEEJRKNS_4__fs10filesystem4pathERNS4_17directory_optionsERNS_10error_codeEEEC2IJLm0ELm1ELm2EEJS7_S9_SB_EJEJEJS7_S9_SB_EEENS1_IJXspT_EEEENS_13__tuple_typesIJDpT0_EEENS1_IJXspT1_EEEENSF_IJDpT2_EEEDpOT3_"]).apply(null, arguments)
            };
            var __ZNSt3__212__tuple_leafILm0ERKNS_4__fs10filesystem4pathELb0EEC2IS5_vEEOT_ = Module["__ZNSt3__212__tuple_leafILm0ERKNS_4__fs10filesystem4pathELb0EEC2IS5_vEEOT_"] = function() {
                return (__ZNSt3__212__tuple_leafILm0ERKNS_4__fs10filesystem4pathELb0EEC2IS5_vEEOT_ = Module["__ZNSt3__212__tuple_leafILm0ERKNS_4__fs10filesystem4pathELb0EEC2IS5_vEEOT_"] = Module["asm"]["_ZNSt3__212__tuple_leafILm0ERKNS_4__fs10filesystem4pathELb0EEC2IS5_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__212__tuple_leafILm1ERNS_4__fs10filesystem17directory_optionsELb0EEC2IS4_vEEOT_ = Module["__ZNSt3__212__tuple_leafILm1ERNS_4__fs10filesystem17directory_optionsELb0EEC2IS4_vEEOT_"] = function() {
                return (__ZNSt3__212__tuple_leafILm1ERNS_4__fs10filesystem17directory_optionsELb0EEC2IS4_vEEOT_ = Module["__ZNSt3__212__tuple_leafILm1ERNS_4__fs10filesystem17directory_optionsELb0EEC2IS4_vEEOT_"] = Module["asm"]["_ZNSt3__212__tuple_leafILm1ERNS_4__fs10filesystem17directory_optionsELb0EEC2IS4_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__212__tuple_leafILm2ERNS_10error_codeELb0EEC2IS2_vEEOT_ = Module["__ZNSt3__212__tuple_leafILm2ERNS_10error_codeELb0EEC2IS2_vEEOT_"] = function() {
                return (__ZNSt3__212__tuple_leafILm2ERNS_10error_codeELb0EEC2IS2_vEEOT_ = Module["__ZNSt3__212__tuple_leafILm2ERNS_10error_codeELb0EEC2IS2_vEEOT_"] = Module["asm"]["_ZNSt3__212__tuple_leafILm2ERNS_10error_codeELb0EEC2IS2_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__23getILm0EJRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEERNS_13tuple_elementIXT_ENS_5tupleIJDpT0_EEEE4typeERSB_ = Module["__ZNSt3__23getILm0EJRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEERNS_13tuple_elementIXT_ENS_5tupleIJDpT0_EEEE4typeERSB_"] = function() {
                return (__ZNSt3__23getILm0EJRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEERNS_13tuple_elementIXT_ENS_5tupleIJDpT0_EEEE4typeERSB_ = Module["__ZNSt3__23getILm0EJRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEERNS_13tuple_elementIXT_ENS_5tupleIJDpT0_EEEE4typeERSB_"] = Module["asm"]["_ZNSt3__23getILm0EJRNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEERNS_13tuple_elementIXT_ENS_5tupleIJDpT0_EEEE4typeERSB_"]).apply(null, arguments)
            };
            var __ZNSt3__23getILm0EJRKNS_4__fs10filesystem4pathERNS2_17directory_optionsERNS_10error_codeEEEERNS_13tuple_elementIXT_ENS_5tupleIJDpT0_EEEE4typeERSE_ = Module["__ZNSt3__23getILm0EJRKNS_4__fs10filesystem4pathERNS2_17directory_optionsERNS_10error_codeEEEERNS_13tuple_elementIXT_ENS_5tupleIJDpT0_EEEE4typeERSE_"] = function() {
                return (__ZNSt3__23getILm0EJRKNS_4__fs10filesystem4pathERNS2_17directory_optionsERNS_10error_codeEEEERNS_13tuple_elementIXT_ENS_5tupleIJDpT0_EEEE4typeERSE_ = Module["__ZNSt3__23getILm0EJRKNS_4__fs10filesystem4pathERNS2_17directory_optionsERNS_10error_codeEEEERNS_13tuple_elementIXT_ENS_5tupleIJDpT0_EEEE4typeERSE_"] = Module["asm"]["_ZNSt3__23getILm0EJRKNS_4__fs10filesystem4pathERNS2_17directory_optionsERNS_10error_codeEEEERNS_13tuple_elementIXT_ENS_5tupleIJDpT0_EEEE4typeERSE_"]).apply(null, arguments)
            };
            var __ZNSt3__23getILm1EJRKNS_4__fs10filesystem4pathERNS2_17directory_optionsERNS_10error_codeEEEERNS_13tuple_elementIXT_ENS_5tupleIJDpT0_EEEE4typeERSE_ = Module["__ZNSt3__23getILm1EJRKNS_4__fs10filesystem4pathERNS2_17directory_optionsERNS_10error_codeEEEERNS_13tuple_elementIXT_ENS_5tupleIJDpT0_EEEE4typeERSE_"] = function() {
                return (__ZNSt3__23getILm1EJRKNS_4__fs10filesystem4pathERNS2_17directory_optionsERNS_10error_codeEEEERNS_13tuple_elementIXT_ENS_5tupleIJDpT0_EEEE4typeERSE_ = Module["__ZNSt3__23getILm1EJRKNS_4__fs10filesystem4pathERNS2_17directory_optionsERNS_10error_codeEEEERNS_13tuple_elementIXT_ENS_5tupleIJDpT0_EEEE4typeERSE_"] = Module["asm"]["_ZNSt3__23getILm1EJRKNS_4__fs10filesystem4pathERNS2_17directory_optionsERNS_10error_codeEEEERNS_13tuple_elementIXT_ENS_5tupleIJDpT0_EEEE4typeERSE_"]).apply(null, arguments)
            };
            var __ZNSt3__23getILm2EJRKNS_4__fs10filesystem4pathERNS2_17directory_optionsERNS_10error_codeEEEERNS_13tuple_elementIXT_ENS_5tupleIJDpT0_EEEE4typeERSE_ = Module["__ZNSt3__23getILm2EJRKNS_4__fs10filesystem4pathERNS2_17directory_optionsERNS_10error_codeEEEERNS_13tuple_elementIXT_ENS_5tupleIJDpT0_EEEE4typeERSE_"] = function() {
                return (__ZNSt3__23getILm2EJRKNS_4__fs10filesystem4pathERNS2_17directory_optionsERNS_10error_codeEEEERNS_13tuple_elementIXT_ENS_5tupleIJDpT0_EEEE4typeERSE_ = Module["__ZNSt3__23getILm2EJRKNS_4__fs10filesystem4pathERNS2_17directory_optionsERNS_10error_codeEEEERNS_13tuple_elementIXT_ENS_5tupleIJDpT0_EEEE4typeERSE_"] = Module["asm"]["_ZNSt3__23getILm2EJRKNS_4__fs10filesystem4pathERNS2_17directory_optionsERNS_10error_codeEEEERNS_13tuple_elementIXT_ENS_5tupleIJDpT0_EEEE4typeERSE_"]).apply(null, arguments)
            };
            var __ZNSt3__212__tuple_leafILm0ERNS_9allocatorINS_4__fs10filesystem12__dir_streamEEELb0EE3getEv = Module["__ZNSt3__212__tuple_leafILm0ERNS_9allocatorINS_4__fs10filesystem12__dir_streamEEELb0EE3getEv"] = function() {
                return (__ZNSt3__212__tuple_leafILm0ERNS_9allocatorINS_4__fs10filesystem12__dir_streamEEELb0EE3getEv = Module["__ZNSt3__212__tuple_leafILm0ERNS_9allocatorINS_4__fs10filesystem12__dir_streamEEELb0EE3getEv"] = Module["asm"]["_ZNSt3__212__tuple_leafILm0ERNS_9allocatorINS_4__fs10filesystem12__dir_streamEEELb0EE3getEv"]).apply(null, arguments)
            };
            var __ZNSt3__212__tuple_leafILm0ERKNS_4__fs10filesystem4pathELb0EE3getEv = Module["__ZNSt3__212__tuple_leafILm0ERKNS_4__fs10filesystem4pathELb0EE3getEv"] = function() {
                return (__ZNSt3__212__tuple_leafILm0ERKNS_4__fs10filesystem4pathELb0EE3getEv = Module["__ZNSt3__212__tuple_leafILm0ERKNS_4__fs10filesystem4pathELb0EE3getEv"] = Module["asm"]["_ZNSt3__212__tuple_leafILm0ERKNS_4__fs10filesystem4pathELb0EE3getEv"]).apply(null, arguments)
            };
            var __ZNSt3__212__tuple_leafILm1ERNS_4__fs10filesystem17directory_optionsELb0EE3getEv = Module["__ZNSt3__212__tuple_leafILm1ERNS_4__fs10filesystem17directory_optionsELb0EE3getEv"] = function() {
                return (__ZNSt3__212__tuple_leafILm1ERNS_4__fs10filesystem17directory_optionsELb0EE3getEv = Module["__ZNSt3__212__tuple_leafILm1ERNS_4__fs10filesystem17directory_optionsELb0EE3getEv"] = Module["asm"]["_ZNSt3__212__tuple_leafILm1ERNS_4__fs10filesystem17directory_optionsELb0EE3getEv"]).apply(null, arguments)
            };
            var __ZNSt3__212__tuple_leafILm2ERNS_10error_codeELb0EE3getEv = Module["__ZNSt3__212__tuple_leafILm2ERNS_10error_codeELb0EE3getEv"] = function() {
                return (__ZNSt3__212__tuple_leafILm2ERNS_10error_codeELb0EE3getEv = Module["__ZNSt3__212__tuple_leafILm2ERNS_10error_codeELb0EE3getEv"] = Module["asm"]["_ZNSt3__212__tuple_leafILm2ERNS_10error_codeELb0EE3getEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem12__dir_streamELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem12__dir_streamELi1ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem12__dir_streamELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem12__dir_streamELi1ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem12__dir_streamELi1ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem12__dir_streamEEELi0ELb1EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem12__dir_streamEEELi0ELb1EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem12__dir_streamEEELi0ELb1EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem12__dir_streamEEELi0ELb1EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem12__dir_streamEEELi0ELb1EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__29addressofINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEEEEPT_RS8_ = Module["__ZNSt3__29addressofINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEEEEPT_RS8_"] = function() {
                return (__ZNSt3__29addressofINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEEEEPT_RS8_ = Module["__ZNSt3__29addressofINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEEEEPT_RS8_"] = Module["asm"]["_ZNSt3__29addressofINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEEEEPT_RS8_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEELi0ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEELi0ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE6secondEv = Module["__ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE6secondEv = Module["__ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEENS_22__allocator_destructorINS5_IS7_EEEEE6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS1_IS5_EEEEEEEclEPS7_ = Module["__ZNSt3__222__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS1_IS5_EEEEEEEclEPS7_"] = function() {
                return (__ZNSt3__222__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS1_IS5_EEEEEEEclEPS7_ = Module["__ZNSt3__222__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS1_IS5_EEEEEEEclEPS7_"] = Module["asm"]["_ZNSt3__222__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS1_IS5_EEEEEEEclEPS7_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS2_IS6_EEEEEEEELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS2_IS6_EEEEEEEELi1ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS2_IS6_EEEEEEEELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS2_IS6_EEEEEEEELi1ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS2_IS6_EEEEEEEELi1ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS1_IS5_EEEEEEE10deallocateERS8_PS7_m = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS1_IS5_EEEEEEE10deallocateERS8_PS7_m"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS1_IS5_EEEEEEE10deallocateERS8_PS7_m = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS1_IS5_EEEEEEE10deallocateERS8_PS7_m"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS1_IS5_EEEEEEE10deallocateERS8_PS7_m"]).apply(null, arguments)
            };
            var __ZNKSt3__25arrayIcLm256EE4sizeEv = Module["__ZNKSt3__25arrayIcLm256EE4sizeEv"] = function() {
                return (__ZNKSt3__25arrayIcLm256EE4sizeEv = Module["__ZNKSt3__25arrayIcLm256EE4sizeEv"] = Module["asm"]["_ZNKSt3__25arrayIcLm256EE4sizeEv"]).apply(null, arguments)
            };
            var __ZNSt3__25arrayIcLm256EE4dataEv = Module["__ZNSt3__25arrayIcLm256EE4dataEv"] = function() {
                return (__ZNSt3__25arrayIcLm256EE4dataEv = Module["__ZNSt3__25arrayIcLm256EE4dataEv"] = Module["asm"]["_ZNSt3__25arrayIcLm256EE4dataEv"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__resize_default_initEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__resize_default_initEm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__resize_default_initEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__resize_default_initEm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__resize_default_initEm"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__append_default_initEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__append_default_initEm"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__append_default_initEm = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__append_default_initEm"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE21__append_default_initEm"]).apply(null, arguments)
            };
            var __ZNKSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS0_IS5_EEEEE8max_sizeEv = Module["__ZNKSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS0_IS5_EEEEE8max_sizeEv"] = function() {
                return (__ZNKSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS0_IS5_EEEEE8max_sizeEv = Module["__ZNKSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS0_IS5_EEEEE8max_sizeEv"] = Module["asm"]["_ZNKSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS0_IS5_EEEEE8max_sizeEv"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRNS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS2_IS7_EEEEEEEEEEONS_16remove_referenceIT_E4typeEOSE_ = Module["__ZNSt3__24moveIRNS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS2_IS7_EEEEEEEEEEONS_16remove_referenceIT_E4typeEOSE_"] = function() {
                return (__ZNSt3__24moveIRNS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS2_IS7_EEEEEEEEEEONS_16remove_referenceIT_E4typeEOSE_ = Module["__ZNSt3__24moveIRNS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS2_IS7_EEEEEEEEEEONS_16remove_referenceIT_E4typeEOSE_"] = Module["asm"]["_ZNSt3__24moveIRNS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS2_IS7_EEEEEEEEEEONS_16remove_referenceIT_E4typeEOSE_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEEC2IRS9_SC_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEEC2IRS9_SC_EEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEEC2IRS9_SC_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEEC2IRS9_SC_EEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEEC2IRS9_SC_EEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRNS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEEEEONS_16remove_referenceIT_E4typeEOS9_ = Module["__ZNSt3__24moveIRNS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEEEEONS_16remove_referenceIT_E4typeEOS9_"] = function() {
                return (__ZNSt3__24moveIRNS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEEEEONS_16remove_referenceIT_E4typeEOS9_ = Module["__ZNSt3__24moveIRNS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEEEEONS_16remove_referenceIT_E4typeEOS9_"] = Module["asm"]["_ZNSt3__24moveIRNS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEEEEONS_16remove_referenceIT_E4typeEOS9_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEES5_EC2IS6_NS_16__value_init_tagEEEOT_OT0_ = Module["__ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEES5_EC2IS6_NS_16__value_init_tagEEEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEES5_EC2IS6_NS_16__value_init_tagEEEOT_OT0_ = Module["__ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEES5_EC2IS6_NS_16__value_init_tagEEEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEES5_EC2IS6_NS_16__value_init_tagEEEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEES5_E6secondEv = Module["__ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEES5_E6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEES5_E6secondEv = Module["__ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEES5_E6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEES5_E6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__29addressofINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEEPT_RS5_ = Module["__ZNSt3__29addressofINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEEPT_RS5_"] = function() {
                return (__ZNSt3__29addressofINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEEPT_RS5_ = Module["__ZNSt3__29addressofINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEEPT_RS5_"] = Module["asm"]["_ZNSt3__29addressofINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEEPT_RS5_"]).apply(null, arguments)
            };
            var __ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEE18__enable_weak_thisEz = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEE18__enable_weak_thisEz"] = function() {
                return (__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEE18__enable_weak_thisEz = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEE18__enable_weak_thisEz"] = Module["asm"]["_ZNSt3__210shared_ptrINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEE18__enable_weak_thisEz"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE5firstEv = Module["__ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE5firstEv = Module["__ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE5resetEPS8_ = Module["__ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE5resetEPS8_"] = function() {
                return (__ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE5resetEPS8_ = Module["__ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE5resetEPS8_"] = Module["asm"]["_ZNSt3__210unique_ptrINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE5resetEPS8_"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEEEEOT_RNS_16remove_referenceISB_E4typeE = Module["__ZNSt3__27forwardIRPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEEEEOT_RNS_16remove_referenceISB_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEEEEOT_RNS_16remove_referenceISB_E4typeE = Module["__ZNSt3__27forwardIRPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEEEEOT_RNS_16remove_referenceISB_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEEEEOT_RNS_16remove_referenceISB_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEELi0ELb0EEC2IRS9_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEELi0ELb0EEC2IRS9_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEELi0ELb0EEC2IRS9_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEELi0ELb0EEC2IRS9_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEELi0ELb0EEC2IRS9_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS2_IS7_EEEEEEEEEEOT_RNS_16remove_referenceISC_E4typeE = Module["__ZNSt3__27forwardINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS2_IS7_EEEEEEEEEEOT_RNS_16remove_referenceISC_E4typeE"] = function() {
                return (__ZNSt3__27forwardINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS2_IS7_EEEEEEEEEEOT_RNS_16remove_referenceISC_E4typeE = Module["__ZNSt3__27forwardINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS2_IS7_EEEEEEEEEEOT_RNS_16remove_referenceISC_E4typeE"] = Module["asm"]["_ZNSt3__27forwardINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS2_IS7_EEEEEEEEEEOT_RNS_16remove_referenceISC_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS2_IS7_EEEEEEEELi1ELb0EEC2ISB_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS2_IS7_EEEEEEEELi1ELb0EEC2ISB_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS2_IS7_EEEEEEEELi1ELb0EEC2ISB_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS2_IS7_EEEEEEEELi1ELb0EEC2ISB_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS2_IS7_EEEEEEEELi1ELb0EEC2ISB_vEEOT_"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEELi0ELb0EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEELi0ELb0EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEEEEOT_RNS_16remove_referenceIS7_E4typeE = Module["__ZNSt3__27forwardINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEEEEOT_RNS_16remove_referenceIS7_E4typeE"] = function() {
                return (__ZNSt3__27forwardINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEEEEOT_RNS_16remove_referenceIS7_E4typeE = Module["__ZNSt3__27forwardINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEEEEOT_RNS_16remove_referenceIS7_E4typeE"] = Module["asm"]["_ZNSt3__27forwardINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEEEEOT_RNS_16remove_referenceIS7_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEELi0ELb1EEC2IS6_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEELi0ELb1EEC2IS6_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEELi0ELb1EEC2IS6_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEELi0ELb1EEC2IS6_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEELi0ELb1EEC2IS6_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardINS_16__value_init_tagEEEOT_RNS_16remove_referenceIS2_E4typeE = Module["__ZNSt3__27forwardINS_16__value_init_tagEEEOT_RNS_16remove_referenceIS2_E4typeE"] = function() {
                return (__ZNSt3__27forwardINS_16__value_init_tagEEEOT_RNS_16remove_referenceIS2_E4typeE = Module["__ZNSt3__27forwardINS_16__value_init_tagEEEOT_RNS_16remove_referenceIS2_E4typeE"] = Module["asm"]["_ZNSt3__27forwardINS_16__value_init_tagEEEOT_RNS_16remove_referenceIS2_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem28recursive_directory_iterator12__shared_impELi1ELb0EEC2ENS_16__value_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem28recursive_directory_iterator12__shared_impELi1ELb0EEC2ENS_16__value_init_tagE"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem28recursive_directory_iterator12__shared_impELi1ELb0EEC2ENS_16__value_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem28recursive_directory_iterator12__shared_impELi1ELb0EEC2ENS_16__value_init_tagE"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem28recursive_directory_iterator12__shared_impELi1ELb0EEC2ENS_16__value_init_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEED2Ev = Module["__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEED2Ev"] = function() {
                return (__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEED2Ev = Module["__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEED2Ev"] = Module["asm"]["_ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem28recursive_directory_iterator12__shared_impELi1ELb0EED2Ev = Module["__ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem28recursive_directory_iterator12__shared_impELi1ELb0EED2Ev"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem28recursive_directory_iterator12__shared_impELi1ELb0EED2Ev = Module["__ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem28recursive_directory_iterator12__shared_impELi1ELb0EED2Ev"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem28recursive_directory_iterator12__shared_impELi1ELb0EED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEED0Ev = Module["__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEED0Ev"] = function() {
                return (__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEED0Ev = Module["__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEED0Ev"] = Module["asm"]["_ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEE16__on_zero_sharedEv = Module["__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEE16__on_zero_sharedEv"] = function() {
                return (__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEE16__on_zero_sharedEv = Module["__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEE16__on_zero_sharedEv"] = Module["asm"]["_ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEE16__on_zero_sharedEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem28recursive_directory_iterator12__shared_impD2Ev = Module["__ZNSt3__24__fs10filesystem28recursive_directory_iterator12__shared_impD2Ev"] = function() {
                return (__ZNSt3__24__fs10filesystem28recursive_directory_iterator12__shared_impD2Ev = Module["__ZNSt3__24__fs10filesystem28recursive_directory_iterator12__shared_impD2Ev"] = Module["asm"]["_ZNSt3__24__fs10filesystem28recursive_directory_iterator12__shared_impD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEE21__on_zero_shared_weakEv = Module["__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEE21__on_zero_shared_weakEv"] = function() {
                return (__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEE21__on_zero_shared_weakEv = Module["__ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEE21__on_zero_shared_weakEv"] = Module["asm"]["_ZNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEE21__on_zero_shared_weakEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEES5_E5firstEv = Module["__ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEES5_E5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEES5_E5firstEv = Module["__ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEES5_E5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEES5_E5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS0_IS5_EEEEEC2IS5_EERKNS0_IT_EE = Module["__ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS0_IS5_EEEEEC2IS5_EERKNS0_IT_EE"] = function() {
                return (__ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS0_IS5_EEEEEC2IS5_EERKNS0_IT_EE = Module["__ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS0_IS5_EEEEEC2IS5_EERKNS0_IT_EE"] = Module["asm"]["_ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS0_IS5_EEEEEC2IS5_EERKNS0_IT_EE"]).apply(null, arguments)
            };
            var __ZNSt3__214pointer_traitsIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEEE10pointer_toERS8_ = Module["__ZNSt3__214pointer_traitsIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEEE10pointer_toERS8_"] = function() {
                return (__ZNSt3__214pointer_traitsIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEEE10pointer_toERS8_ = Module["__ZNSt3__214pointer_traitsIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEEE10pointer_toERS8_"] = Module["asm"]["_ZNSt3__214pointer_traitsIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEEE10pointer_toERS8_"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS0_IS5_EEEEE10deallocateEPS7_m = Module["__ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS0_IS5_EEEEE10deallocateEPS7_m"] = function() {
                return (__ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS0_IS5_EEEEE10deallocateEPS7_m = Module["__ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS0_IS5_EEEEE10deallocateEPS7_m"] = Module["asm"]["_ZNSt3__29allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS0_IS5_EEEEE10deallocateEPS7_m"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem28recursive_directory_iterator12__shared_impC2Ev = Module["__ZNSt3__24__fs10filesystem28recursive_directory_iterator12__shared_impC2Ev"] = function() {
                return (__ZNSt3__24__fs10filesystem28recursive_directory_iterator12__shared_impC2Ev = Module["__ZNSt3__24__fs10filesystem28recursive_directory_iterator12__shared_impC2Ev"] = Module["asm"]["_ZNSt3__24__fs10filesystem28recursive_directory_iterator12__shared_impC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEEC2Ev = Module["__ZNSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEEC2Ev"] = function() {
                return (__ZNSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEEC2Ev = Module["__ZNSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEEC2Ev"] = Module["asm"]["_ZNSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEC2Ev = Module["__ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEC2Ev"] = function() {
                return (__ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEC2Ev = Module["__ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEC2Ev"] = Module["asm"]["_ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEC2Ev = Module["__ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEC2Ev"] = function() {
                return (__ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEC2Ev = Module["__ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEC2Ev"] = Module["asm"]["_ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEC2Ev = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEC2Ev"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEC2Ev = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEC2Ev"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairImNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEC2IiNS_18__default_init_tagEEEOT_OT0_ = Module["__ZNSt3__217__compressed_pairImNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEC2IiNS_18__default_init_tagEEEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairImNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEC2IiNS_18__default_init_tagEEEOT_OT0_ = Module["__ZNSt3__217__compressed_pairImNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEC2IiNS_18__default_init_tagEEEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairImNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEC2IiNS_18__default_init_tagEEEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEC2IDnNS_18__default_init_tagEEEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEC2IDnNS_18__default_init_tagEEEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEC2IDnNS_18__default_init_tagEEEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEC2IDnNS_18__default_init_tagEEEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEEC2IDnNS_18__default_init_tagEEEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIiEEOT_RNS_16remove_referenceIS1_E4typeE = Module["__ZNSt3__27forwardIiEEOT_RNS_16remove_referenceIS1_E4typeE"] = function() {
                return (__ZNSt3__27forwardIiEEOT_RNS_16remove_referenceIS1_E4typeE = Module["__ZNSt3__27forwardIiEEOT_RNS_16remove_referenceIS1_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIiEEOT_RNS_16remove_referenceIS1_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemImLi0ELb0EEC2IivEEOT_ = Module["__ZNSt3__222__compressed_pair_elemImLi0ELb0EEC2IivEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemImLi0ELb0EEC2IivEEOT_ = Module["__ZNSt3__222__compressed_pair_elemImLi0ELb0EEC2IivEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemImLi0ELb0EEC2IivEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem12__dir_streamEEELi1ELb1EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem12__dir_streamEEELi1ELb1EEC2ENS_18__default_init_tagE"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem12__dir_streamEEELi1ELb1EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem12__dir_streamEEELi1ELb1EEC2ENS_18__default_init_tagE"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem12__dir_streamEEELi1ELb1EEC2ENS_18__default_init_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPPNS_4__fs10filesystem12__dir_streamELi0ELb0EEC2IDnvEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPPNS_4__fs10filesystem12__dir_streamELi0ELb0EEC2IDnvEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPPNS_4__fs10filesystem12__dir_streamELi0ELb0EEC2IDnvEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPPNS_4__fs10filesystem12__dir_streamELi0ELb0EEC2IDnvEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPPNS_4__fs10filesystem12__dir_streamELi0ELb0EEC2IDnvEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEELi1ELb1EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEELi1ELb1EEC2ENS_18__default_init_tagE"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEELi1ELb1EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEELi1ELb1EEC2ENS_18__default_init_tagE"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEELi1ELb1EEC2ENS_18__default_init_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEEC2Ev = Module["__ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEEC2Ev"] = function() {
                return (__ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEEC2Ev = Module["__ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEEC2Ev"] = Module["asm"]["_ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEEC2Ev = Module["__ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEEC2Ev"] = function() {
                return (__ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEEC2Ev = Module["__ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEEC2Ev"] = Module["asm"]["_ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEED2Ev = Module["__ZNSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEED2Ev"] = function() {
                return (__ZNSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEED2Ev = Module["__ZNSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEED2Ev"] = Module["asm"]["_ZNSt3__25stackINS_4__fs10filesystem12__dir_streamENS_5dequeIS3_NS_9allocatorIS3_EEEEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEED2Ev = Module["__ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEED2Ev"] = function() {
                return (__ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEED2Ev = Module["__ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEED2Ev"] = Module["asm"]["_ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE5clearEv = Module["__ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE5clearEv"] = function() {
                return (__ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE5clearEv = Module["__ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE5clearEv"] = Module["asm"]["_ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE5clearEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5beginEv = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5beginEv"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5beginEv = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5beginEv"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5beginEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE3endEv = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE3endEv"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE3endEv = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE3endEv"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE3endEv"]).apply(null, arguments)
            };
            var __ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE7__allocEv = Module["__ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE7__allocEv"] = function() {
                return (__ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE7__allocEv = Module["__ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE7__allocEv"] = Module["asm"]["_ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE7__allocEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE10deallocateERS5_PS4_m = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE10deallocateERS5_PS4_m"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE10deallocateERS5_PS4_m = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE10deallocateERS5_PS4_m"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE10deallocateERS5_PS4_m"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEED2Ev = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEED2Ev"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEED2Ev = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEED2Ev"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE5beginEv = Module["__ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE5beginEv"] = function() {
                return (__ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE5beginEv = Module["__ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE5beginEv"] = Module["asm"]["_ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE5beginEv"]).apply(null, arguments)
            };
            var __ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE3endEv = Module["__ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE3endEv"] = function() {
                return (__ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE3endEv = Module["__ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE3endEv"] = Module["asm"]["_ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE3endEv"]).apply(null, arguments)
            };
            var __ZNSt3__2neERKNS_16__deque_iteratorINS_4__fs10filesystem12__dir_streamEPS3_RS3_PS4_lLl0EEES9_ = Module["__ZNSt3__2neERKNS_16__deque_iteratorINS_4__fs10filesystem12__dir_streamEPS3_RS3_PS4_lLl0EEES9_"] = function() {
                return (__ZNSt3__2neERKNS_16__deque_iteratorINS_4__fs10filesystem12__dir_streamEPS3_RS3_PS4_lLl0EEES9_ = Module["__ZNSt3__2neERKNS_16__deque_iteratorINS_4__fs10filesystem12__dir_streamEPS3_RS3_PS4_lLl0EEES9_"] = Module["asm"]["_ZNSt3__2neERKNS_16__deque_iteratorINS_4__fs10filesystem12__dir_streamEPS3_RS3_PS4_lLl0EEES9_"]).apply(null, arguments)
            };
            var __ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE4sizeEv = Module["__ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE4sizeEv"] = function() {
                return (__ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE4sizeEv = Module["__ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE4sizeEv"] = Module["asm"]["_ZNSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE4sizeEv"]).apply(null, arguments)
            };
            var __ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE4sizeEv = Module["__ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE4sizeEv"] = function() {
                return (__ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE4sizeEv = Module["__ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE4sizeEv"] = Module["asm"]["_ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE4sizeEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5frontEv = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5frontEv"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5frontEv = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5frontEv"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5frontEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE9pop_frontEv = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE9pop_frontEv"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE9pop_frontEv = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE9pop_frontEv"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE9pop_frontEv"]).apply(null, arguments)
            };
            var __ZNKSt3__216__deque_iteratorINS_4__fs10filesystem12__dir_streamEPS3_RS3_PS4_lLl0EEdeEv = Module["__ZNKSt3__216__deque_iteratorINS_4__fs10filesystem12__dir_streamEPS3_RS3_PS4_lLl0EEdeEv"] = function() {
                return (__ZNKSt3__216__deque_iteratorINS_4__fs10filesystem12__dir_streamEPS3_RS3_PS4_lLl0EEdeEv = Module["__ZNKSt3__216__deque_iteratorINS_4__fs10filesystem12__dir_streamEPS3_RS3_PS4_lLl0EEdeEv"] = Module["asm"]["_ZNKSt3__216__deque_iteratorINS_4__fs10filesystem12__dir_streamEPS3_RS3_PS4_lLl0EEdeEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE7destroyIS4_EEvRS5_PT_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE7destroyIS4_EEvRS5_PT_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE7destroyIS4_EEvRS5_PT_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE7destroyIS4_EEvRS5_PT_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE7destroyIS4_EEvRS5_PT_"]).apply(null, arguments)
            };
            var __ZNSt3__216__deque_iteratorINS_4__fs10filesystem12__dir_streamEPS3_RS3_PS4_lLl0EEppEv = Module["__ZNSt3__216__deque_iteratorINS_4__fs10filesystem12__dir_streamEPS3_RS3_PS4_lLl0EEppEv"] = function() {
                return (__ZNSt3__216__deque_iteratorINS_4__fs10filesystem12__dir_streamEPS3_RS3_PS4_lLl0EEppEv = Module["__ZNSt3__216__deque_iteratorINS_4__fs10filesystem12__dir_streamEPS3_RS3_PS4_lLl0EEppEv"] = Module["asm"]["_ZNSt3__216__deque_iteratorINS_4__fs10filesystem12__dir_streamEPS3_RS3_PS4_lLl0EEppEv"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEE10deallocateEPS3_m = Module["__ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEE10deallocateEPS3_m"] = function() {
                return (__ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEE10deallocateEPS3_m = Module["__ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEE10deallocateEPS3_m"] = Module["asm"]["_ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEE10deallocateEPS3_m"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairImNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE6secondEv = Module["__ZNSt3__217__compressed_pairImNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairImNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE6secondEv = Module["__ZNSt3__217__compressed_pairImNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairImNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5clearEv = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5clearEv"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5clearEv = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5clearEv"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5clearEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE7__allocEv = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE7__allocEv"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE7__allocEv = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE7__allocEv"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE7__allocEv"]).apply(null, arguments)
            };
            var __ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE8capacityEv = Module["__ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE8capacityEv"] = function() {
                return (__ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE8capacityEv = Module["__ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE8capacityEv"] = Module["asm"]["_ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE8capacityEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE10deallocateERS6_PS5_m = Module["__ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE10deallocateERS6_PS5_m"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE10deallocateERS6_PS5_m = Module["__ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE10deallocateERS6_PS5_m"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE10deallocateERS6_PS5_m"]).apply(null, arguments)
            };
            var __ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5emptyEv = Module["__ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5emptyEv"] = function() {
                return (__ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5emptyEv = Module["__ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5emptyEv"] = Module["asm"]["_ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5emptyEv"]).apply(null, arguments)
            };
            var __ZNSt3__216__deque_iteratorINS_4__fs10filesystem12__dir_streamEPS3_RS3_PS4_lLl0EEC2ES6_S4_ = Module["__ZNSt3__216__deque_iteratorINS_4__fs10filesystem12__dir_streamEPS3_RS3_PS4_lLl0EEC2ES6_S4_"] = function() {
                return (__ZNSt3__216__deque_iteratorINS_4__fs10filesystem12__dir_streamEPS3_RS3_PS4_lLl0EEC2ES6_S4_ = Module["__ZNSt3__216__deque_iteratorINS_4__fs10filesystem12__dir_streamEPS3_RS3_PS4_lLl0EEC2ES6_S4_"] = Module["asm"]["_ZNSt3__216__deque_iteratorINS_4__fs10filesystem12__dir_streamEPS3_RS3_PS4_lLl0EEC2ES6_S4_"]).apply(null, arguments)
            };
            var __ZNSt3__2eqERKNS_16__deque_iteratorINS_4__fs10filesystem12__dir_streamEPS3_RS3_PS4_lLl0EEES9_ = Module["__ZNSt3__2eqERKNS_16__deque_iteratorINS_4__fs10filesystem12__dir_streamEPS3_RS3_PS4_lLl0EEES9_"] = function() {
                return (__ZNSt3__2eqERKNS_16__deque_iteratorINS_4__fs10filesystem12__dir_streamEPS3_RS3_PS4_lLl0EEES9_ = Module["__ZNSt3__2eqERKNS_16__deque_iteratorINS_4__fs10filesystem12__dir_streamEPS3_RS3_PS4_lLl0EEES9_"] = Module["asm"]["_ZNSt3__2eqERKNS_16__deque_iteratorINS_4__fs10filesystem12__dir_streamEPS3_RS3_PS4_lLl0EEES9_"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE9__destroyIS4_EEvNS_17integral_constantIbLb1EEERS5_PT_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE9__destroyIS4_EEvNS_17integral_constantIbLb1EEERS5_PT_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE9__destroyIS4_EEvNS_17integral_constantIbLb1EEERS5_PT_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE9__destroyIS4_EEvNS_17integral_constantIbLb1EEERS5_PT_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE9__destroyIS4_EEvNS_17integral_constantIbLb1EEERS5_PT_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairImNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE5firstEv = Module["__ZNSt3__217__compressed_pairImNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairImNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE5firstEv = Module["__ZNSt3__217__compressed_pairImNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairImNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE19__destruct_at_beginEPS4_ = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE19__destruct_at_beginEPS4_"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE19__destruct_at_beginEPS4_ = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE19__destruct_at_beginEPS4_"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE19__destruct_at_beginEPS4_"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEE7destroyEPS3_ = Module["__ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEE7destroyEPS3_"] = function() {
                return (__ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEE7destroyEPS3_ = Module["__ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEE7destroyEPS3_"] = Module["asm"]["_ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEE7destroyEPS3_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemImLi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemImLi0ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemImLi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemImLi0ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemImLi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE19__destruct_at_beginEPS4_NS_17integral_constantIbLb1EEE = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE19__destruct_at_beginEPS4_NS_17integral_constantIbLb1EEE"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE19__destruct_at_beginEPS4_NS_17integral_constantIbLb1EEE = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE19__destruct_at_beginEPS4_NS_17integral_constantIbLb1EEE"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE19__destruct_at_beginEPS4_NS_17integral_constantIbLb1EEE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem12__dir_streamEEELi1ELb1EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem12__dir_streamEEELi1ELb1EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem12__dir_streamEEELi1ELb1EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem12__dir_streamEEELi1ELb1EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem12__dir_streamEEELi1ELb1EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE17__destruct_at_endEPS4_ = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE17__destruct_at_endEPS4_"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE17__destruct_at_endEPS4_ = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE17__destruct_at_endEPS4_"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE17__destruct_at_endEPS4_"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE10deallocateEPS4_m = Module["__ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE10deallocateEPS4_m"] = function() {
                return (__ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE10deallocateEPS4_m = Module["__ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE10deallocateEPS4_m"] = Module["asm"]["_ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE10deallocateEPS4_m"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE6secondEv = Module["__ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE6secondEv = Module["__ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE6secondEv"]).apply(null, arguments)
            };
            var __ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE9__end_capEv = Module["__ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE9__end_capEv"] = function() {
                return (__ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE9__end_capEv = Module["__ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE9__end_capEv"] = Module["asm"]["_ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE9__end_capEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE17__destruct_at_endEPS4_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE17__destruct_at_endEPS4_NS_17integral_constantIbLb0EEE"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE17__destruct_at_endEPS4_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE17__destruct_at_endEPS4_NS_17integral_constantIbLb0EEE"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE17__destruct_at_endEPS4_NS_17integral_constantIbLb0EEE"]).apply(null, arguments)
            };
            var __ZNSt3__212__to_addressIPNS_4__fs10filesystem12__dir_streamEEEPT_S6_ = Module["__ZNSt3__212__to_addressIPNS_4__fs10filesystem12__dir_streamEEEPT_S6_"] = function() {
                return (__ZNSt3__212__to_addressIPNS_4__fs10filesystem12__dir_streamEEEPT_S6_ = Module["__ZNSt3__212__to_addressIPNS_4__fs10filesystem12__dir_streamEEEPT_S6_"] = Module["asm"]["_ZNSt3__212__to_addressIPNS_4__fs10filesystem12__dir_streamEEEPT_S6_"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE7destroyIS5_EEvRS6_PT_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE7destroyIS5_EEvRS6_PT_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE7destroyIS5_EEvRS6_PT_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE7destroyIS5_EEvRS6_PT_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE7destroyIS5_EEvRS6_PT_"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE9__destroyIS5_EEvNS_17integral_constantIbLb1EEERS6_PT_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE9__destroyIS5_EEvNS_17integral_constantIbLb1EEERS6_PT_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE9__destroyIS5_EEvNS_17integral_constantIbLb1EEERS6_PT_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE9__destroyIS5_EEvNS_17integral_constantIbLb1EEERS6_PT_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE9__destroyIS5_EEvNS_17integral_constantIbLb1EEERS6_PT_"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE7destroyEPS4_ = Module["__ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE7destroyEPS4_"] = function() {
                return (__ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE7destroyEPS4_ = Module["__ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE7destroyEPS4_"] = Module["asm"]["_ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE7destroyEPS4_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEELi1ELb1EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEELi1ELb1EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEELi1ELb1EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEELi1ELb1EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEELi1ELb1EE5__getEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5firstEv"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemIPPNS_4__fs10filesystem12__dir_streamELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPPNS_4__fs10filesystem12__dir_streamELi0ELb0EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemIPPNS_4__fs10filesystem12__dir_streamELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPPNS_4__fs10filesystem12__dir_streamELi0ELb0EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemIPPNS_4__fs10filesystem12__dir_streamELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem28recursive_directory_iterator12__shared_impELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem28recursive_directory_iterator12__shared_impELi1ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem28recursive_directory_iterator12__shared_impELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem28recursive_directory_iterator12__shared_impELi1ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_4__fs10filesystem28recursive_directory_iterator12__shared_impELi1ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEELi0ELb1EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEELi0ELb1EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEELi0ELb1EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEELi0ELb1EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4__fs10filesystem28recursive_directory_iterator12__shared_impEEELi0ELb1EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__29addressofINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEEEEPT_RS9_ = Module["__ZNSt3__29addressofINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEEEEPT_RS9_"] = function() {
                return (__ZNSt3__29addressofINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEEEEPT_RS9_ = Module["__ZNSt3__29addressofINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEEEEPT_RS9_"] = Module["asm"]["_ZNSt3__29addressofINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEEEEPT_RS9_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEELi0ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEELi0ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE6secondEv = Module["__ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE6secondEv = Module["__ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS5_EEEENS_22__allocator_destructorINS6_IS8_EEEEE6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS1_IS6_EEEEEEEclEPS8_ = Module["__ZNSt3__222__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS1_IS6_EEEEEEEclEPS8_"] = function() {
                return (__ZNSt3__222__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS1_IS6_EEEEEEEclEPS8_ = Module["__ZNSt3__222__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS1_IS6_EEEEEEEclEPS8_"] = Module["asm"]["_ZNSt3__222__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS1_IS6_EEEEEEEclEPS8_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS2_IS7_EEEEEEEELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS2_IS7_EEEEEEEELi1ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS2_IS7_EEEEEEEELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS2_IS7_EEEEEEEELi1ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS2_IS7_EEEEEEEELi1ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS1_IS6_EEEEEEE10deallocateERS9_PS8_m = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS1_IS6_EEEEEEE10deallocateERS9_PS8_m"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS1_IS6_EEEEEEE10deallocateERS9_PS8_m = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS1_IS6_EEEEEEE10deallocateERS9_PS8_m"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_20__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS1_IS6_EEEEEEE10deallocateERS9_PS8_m"]).apply(null, arguments)
            };
            var __ZNKSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE12__back_spareEv = Module["__ZNKSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE12__back_spareEv"] = function() {
                return (__ZNKSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE12__back_spareEv = Module["__ZNKSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE12__back_spareEv"] = Module["asm"]["_ZNKSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE12__back_spareEv"]).apply(null, arguments)
            };
            var __ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE19__add_back_capacityEv = Module["__ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE19__add_back_capacityEv"] = function() {
                return (__ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE19__add_back_capacityEv = Module["__ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE19__add_back_capacityEv"] = Module["asm"]["_ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE19__add_back_capacityEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE9constructIS4_JS4_EEEvRS5_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE9constructIS4_JS4_EEEvRS5_PT_DpOT0_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE9constructIS4_JS4_EEEvRS5_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE9constructIS4_JS4_EEEvRS5_PT_DpOT0_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE9constructIS4_JS4_EEEvRS5_PT_DpOT0_"]).apply(null, arguments)
            };
            var __ZNKSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE10__capacityEv = Module["__ZNKSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE10__capacityEv"] = function() {
                return (__ZNKSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE10__capacityEv = Module["__ZNKSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE10__capacityEv"] = Module["asm"]["_ZNKSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE10__capacityEv"]).apply(null, arguments)
            };
            var __ZNKSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE4sizeEv = Module["__ZNKSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE4sizeEv"] = function() {
                return (__ZNKSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE4sizeEv = Module["__ZNKSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE4sizeEv"] = Module["asm"]["_ZNKSt3__212__deque_baseINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE4sizeEv"]).apply(null, arguments)
            };
            var __ZNKSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE13__front_spareEv = Module["__ZNKSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE13__front_spareEv"] = function() {
                return (__ZNKSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE13__front_spareEv = Module["__ZNKSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE13__front_spareEv"] = Module["asm"]["_ZNKSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE13__front_spareEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE9push_backERKS4_ = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE9push_backERKS4_"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE9push_backERKS4_ = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE9push_backERKS4_"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE9push_backERKS4_"]).apply(null, arguments)
            };
            var __ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE12__back_spareEv = Module["__ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE12__back_spareEv"] = function() {
                return (__ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE12__back_spareEv = Module["__ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE12__back_spareEv"] = Module["asm"]["_ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE12__back_spareEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE8allocateERS5_m = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE8allocateERS5_m"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE8allocateERS5_m = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE8allocateERS5_m"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE8allocateERS5_m"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE9push_backEOS4_ = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE9push_backEOS4_"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE9push_backEOS4_ = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE9push_backEOS4_"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE9push_backEOS4_"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEEC2EmmS7_ = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEEC2EmmS7_"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEEC2EmmS7_ = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEEC2EmmS7_"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEEC2EmmS7_"]).apply(null, arguments)
            };
            var __ZNSt3__222__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEC2ERS5_m = Module["__ZNSt3__222__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEC2ERS5_m"] = function() {
                return (__ZNSt3__222__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEC2ERS5_m = Module["__ZNSt3__222__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEC2ERS5_m"] = Module["asm"]["_ZNSt3__222__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEC2ERS5_m"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEEC2ILb1EvEES4_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS8_EEXT_EE20__good_rval_ref_typeE = Module["__ZNSt3__210unique_ptrIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEEC2ILb1EvEES4_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS8_EEXT_EE20__good_rval_ref_typeE"] = function() {
                return (__ZNSt3__210unique_ptrIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEEC2ILb1EvEES4_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS8_EEXT_EE20__good_rval_ref_typeE = Module["__ZNSt3__210unique_ptrIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEEC2ILb1EvEES4_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS8_EEXT_EE20__good_rval_ref_typeE"] = Module["asm"]["_ZNSt3__210unique_ptrIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEEC2ILb1EvEES4_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS8_EEXT_EE20__good_rval_ref_typeE"]).apply(null, arguments)
            };
            var __ZNKSt3__210unique_ptrIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE3getEv = Module["__ZNKSt3__210unique_ptrIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE3getEv"] = function() {
                return (__ZNKSt3__210unique_ptrIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE3getEv = Module["__ZNKSt3__210unique_ptrIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE3getEv"] = Module["asm"]["_ZNKSt3__210unique_ptrIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE3getEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE9push_backEOS4_ = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE9push_backEOS4_"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE9push_backEOS4_ = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE9push_backEOS4_"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE9push_backEOS4_"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE7releaseEv = Module["__ZNSt3__210unique_ptrIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE7releaseEv"] = function() {
                return (__ZNSt3__210unique_ptrIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE7releaseEv = Module["__ZNSt3__210unique_ptrIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE7releaseEv"] = Module["asm"]["_ZNSt3__210unique_ptrIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE7releaseEv"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIPPNS_4__fs10filesystem12__dir_streamEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS7_EE5valueEvE4typeERS7_SA_ = Module["__ZNSt3__24swapIPPNS_4__fs10filesystem12__dir_streamEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS7_EE5valueEvE4typeERS7_SA_"] = function() {
                return (__ZNSt3__24swapIPPNS_4__fs10filesystem12__dir_streamEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS7_EE5valueEvE4typeERS7_SA_ = Module["__ZNSt3__24swapIPPNS_4__fs10filesystem12__dir_streamEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS7_EE5valueEvE4typeERS7_SA_"] = Module["asm"]["_ZNSt3__24swapIPPNS_4__fs10filesystem12__dir_streamEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS7_EE5valueEvE4typeERS7_SA_"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE9__end_capEv = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE9__end_capEv"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE9__end_capEv = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE9__end_capEv"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE9__end_capEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE9__end_capEv = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE9__end_capEv"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE9__end_capEv = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE9__end_capEv"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE9__end_capEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEED2Ev = Module["__ZNSt3__210unique_ptrIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEED2Ev"] = function() {
                return (__ZNSt3__210unique_ptrIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEED2Ev = Module["__ZNSt3__210unique_ptrIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEED2Ev"] = Module["asm"]["_ZNSt3__210unique_ptrIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEED2Ev = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEED2Ev"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEED2Ev = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEED2Ev"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE10push_frontERKS4_ = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE10push_frontERKS4_"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE10push_frontERKS4_ = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE10push_frontERKS4_"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE10push_frontERKS4_"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE10push_frontEOS4_ = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE10push_frontEOS4_"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE10push_frontEOS4_ = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE10push_frontEOS4_"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE10push_frontEOS4_"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardINS_4__fs10filesystem12__dir_streamEEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardINS_4__fs10filesystem12__dir_streamEEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardINS_4__fs10filesystem12__dir_streamEEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardINS_4__fs10filesystem12__dir_streamEEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardINS_4__fs10filesystem12__dir_streamEEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE11__constructIS4_JS4_EEEvNS_17integral_constantIbLb1EEERS5_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE11__constructIS4_JS4_EEEvNS_17integral_constantIbLb1EEERS5_PT_DpOT0_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE11__constructIS4_JS4_EEEvNS_17integral_constantIbLb1EEERS5_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE11__constructIS4_JS4_EEEvNS_17integral_constantIbLb1EEERS5_PT_DpOT0_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE11__constructIS4_JS4_EEEvNS_17integral_constantIbLb1EEERS5_PT_DpOT0_"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairImNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE5firstEv = Module["__ZNKSt3__217__compressed_pairImNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairImNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE5firstEv = Module["__ZNKSt3__217__compressed_pairImNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairImNS_9allocatorINS_4__fs10filesystem12__dir_streamEEEE5firstEv"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemImLi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemImLi0ELb0EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemImLi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemImLi0ELb0EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemImLi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIPPNS_4__fs10filesystem12__dir_streamES5_EET0_T_S7_S6_ = Module["__ZNSt3__24moveIPPNS_4__fs10filesystem12__dir_streamES5_EET0_T_S7_S6_"] = function() {
                return (__ZNSt3__24moveIPPNS_4__fs10filesystem12__dir_streamES5_EET0_T_S7_S6_ = Module["__ZNSt3__24moveIPPNS_4__fs10filesystem12__dir_streamES5_EET0_T_S7_S6_"] = Module["asm"]["_ZNSt3__24moveIPPNS_4__fs10filesystem12__dir_streamES5_EET0_T_S7_S6_"]).apply(null, arguments)
            };
            var __ZNSt3__213move_iteratorIPPNS_4__fs10filesystem12__dir_streamEEC2ES5_ = Module["__ZNSt3__213move_iteratorIPPNS_4__fs10filesystem12__dir_streamEEC2ES5_"] = function() {
                return (__ZNSt3__213move_iteratorIPPNS_4__fs10filesystem12__dir_streamEEC2ES5_ = Module["__ZNSt3__213move_iteratorIPPNS_4__fs10filesystem12__dir_streamEEC2ES5_"] = Module["asm"]["_ZNSt3__213move_iteratorIPPNS_4__fs10filesystem12__dir_streamEEC2ES5_"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE18__construct_at_endINS_13move_iteratorIPS4_EEEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeESE_SE_ = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE18__construct_at_endINS_13move_iteratorIPS4_EEEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeESE_SE_"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE18__construct_at_endINS_13move_iteratorIPS4_EEEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeESE_SE_ = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE18__construct_at_endINS_13move_iteratorIPS4_EEEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeESE_SE_"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE18__construct_at_endINS_13move_iteratorIPS4_EEEENS_9enable_ifIXsr27__is_cpp17_forward_iteratorIT_EE5valueEvE4typeESE_SE_"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE9constructIS5_JRKS5_EEEvRS6_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE9constructIS5_JRKS5_EEEvRS6_PT_DpOT0_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE9constructIS5_JRKS5_EEEvRS6_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE9constructIS5_JRKS5_EEEvRS6_PT_DpOT0_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE9constructIS5_JRKS5_EEEvRS6_PT_DpOT0_"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE9constructIS5_JS5_EEEvRS6_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE9constructIS5_JS5_EEEvRS6_PT_DpOT0_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE9constructIS5_JS5_EEEvRS6_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE9constructIS5_JS5_EEEvRS6_PT_DpOT0_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE9constructIS5_JS5_EEEvRS6_PT_DpOT0_"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEE8allocateEmPKv = Module["__ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEE8allocateEmPKv"] = function() {
                return (__ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEE8allocateEmPKv = Module["__ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEE8allocateEmPKv"] = Module["asm"]["_ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEE8allocateEmPKv"]).apply(null, arguments)
            };
            var __ZNSt3__213move_backwardIPPNS_4__fs10filesystem12__dir_streamES5_EET0_T_S7_S6_ = Module["__ZNSt3__213move_backwardIPPNS_4__fs10filesystem12__dir_streamES5_EET0_T_S7_S6_"] = function() {
                return (__ZNSt3__213move_backwardIPPNS_4__fs10filesystem12__dir_streamES5_EET0_T_S7_S6_ = Module["__ZNSt3__213move_backwardIPPNS_4__fs10filesystem12__dir_streamES5_EET0_T_S7_S6_"] = Module["asm"]["_ZNSt3__213move_backwardIPPNS_4__fs10filesystem12__dir_streamES5_EET0_T_S7_S6_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEEC2IDnS8_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEEC2IDnS8_EEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEEC2IDnS8_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEEC2IDnS8_EEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEEC2IDnS8_EEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE7__allocEv = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE7__allocEv"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE7__allocEv = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE7__allocEv"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE7__allocEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE8allocateERS6_m = Module["__ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE8allocateERS6_m"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE8allocateERS6_m = Module["__ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE8allocateERS6_m"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE8allocateERS6_m"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRNS_22__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEEEONS_16remove_referenceIT_E4typeEOSA_ = Module["__ZNSt3__24moveIRNS_22__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEEEONS_16remove_referenceIT_E4typeEOSA_"] = function() {
                return (__ZNSt3__24moveIRNS_22__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEEEONS_16remove_referenceIT_E4typeEOSA_ = Module["__ZNSt3__24moveIRNS_22__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEEEONS_16remove_referenceIT_E4typeEOSA_"] = Module["asm"]["_ZNSt3__24moveIRNS_22__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEEEONS_16remove_referenceIT_E4typeEOSA_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEEC2IRS4_S8_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEEC2IRS4_S8_EEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEEC2IRS4_S8_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEEC2IRS4_S8_EEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEEC2IRS4_S8_EEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE5firstEv = Module["__ZNSt3__217__compressed_pairIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE5firstEv = Module["__ZNSt3__217__compressed_pairIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRPPNS_4__fs10filesystem12__dir_streamEEEONS_16remove_referenceIT_E4typeEOS8_ = Module["__ZNSt3__24moveIRPPNS_4__fs10filesystem12__dir_streamEEEONS_16remove_referenceIT_E4typeEOS8_"] = function() {
                return (__ZNSt3__24moveIRPPNS_4__fs10filesystem12__dir_streamEEEONS_16remove_referenceIT_E4typeEOS8_ = Module["__ZNSt3__24moveIRPPNS_4__fs10filesystem12__dir_streamEEEONS_16remove_referenceIT_E4typeEOS8_"] = Module["asm"]["_ZNSt3__24moveIRPPNS_4__fs10filesystem12__dir_streamEEEONS_16remove_referenceIT_E4typeEOS8_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5firstEv = Module["__ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5firstEv = Module["__ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE5firstEv = Module["__ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE5firstEv = Module["__ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE5resetES4_ = Module["__ZNSt3__210unique_ptrIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE5resetES4_"] = function() {
                return (__ZNSt3__210unique_ptrIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE5resetES4_ = Module["__ZNSt3__210unique_ptrIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE5resetES4_"] = Module["asm"]["_ZNSt3__210unique_ptrIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE5resetES4_"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE5clearEv = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE5clearEv"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE5clearEv = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE5clearEv"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE5clearEv"]).apply(null, arguments)
            };
            var __ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE8capacityEv = Module["__ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE8capacityEv"] = function() {
                return (__ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE8capacityEv = Module["__ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE8capacityEv"] = Module["asm"]["_ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE8capacityEv"]).apply(null, arguments)
            };
            var __ZNSt3__213__unwrap_iterIPPNS_4__fs10filesystem12__dir_streamEEET_S6_ = Module["__ZNSt3__213__unwrap_iterIPPNS_4__fs10filesystem12__dir_streamEEET_S6_"] = function() {
                return (__ZNSt3__213__unwrap_iterIPPNS_4__fs10filesystem12__dir_streamEEET_S6_ = Module["__ZNSt3__213__unwrap_iterIPPNS_4__fs10filesystem12__dir_streamEEET_S6_"] = Module["asm"]["_ZNSt3__213__unwrap_iterIPPNS_4__fs10filesystem12__dir_streamEEET_S6_"]).apply(null, arguments)
            };
            var __ZNSt3__26__moveIPNS_4__fs10filesystem12__dir_streamES4_EENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableISA_EE5valueEPSA_E4typeEPS7_SE_SB_ = Module["__ZNSt3__26__moveIPNS_4__fs10filesystem12__dir_streamES4_EENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableISA_EE5valueEPSA_E4typeEPS7_SE_SB_"] = function() {
                return (__ZNSt3__26__moveIPNS_4__fs10filesystem12__dir_streamES4_EENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableISA_EE5valueEPSA_E4typeEPS7_SE_SB_ = Module["__ZNSt3__26__moveIPNS_4__fs10filesystem12__dir_streamES4_EENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableISA_EE5valueEPSA_E4typeEPS7_SE_SB_"] = Module["asm"]["_ZNSt3__26__moveIPNS_4__fs10filesystem12__dir_streamES4_EENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableISA_EE5valueEPSA_E4typeEPS7_SE_SB_"]).apply(null, arguments)
            };
            var __ZNSt3__28distanceINS_13move_iteratorIPPNS_4__fs10filesystem12__dir_streamEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_ = Module["__ZNSt3__28distanceINS_13move_iteratorIPPNS_4__fs10filesystem12__dir_streamEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_"] = function() {
                return (__ZNSt3__28distanceINS_13move_iteratorIPPNS_4__fs10filesystem12__dir_streamEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_ = Module["__ZNSt3__28distanceINS_13move_iteratorIPPNS_4__fs10filesystem12__dir_streamEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_"] = Module["asm"]["_ZNSt3__28distanceINS_13move_iteratorIPPNS_4__fs10filesystem12__dir_streamEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE21_ConstructTransactionC2EPPS4_m = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE21_ConstructTransactionC2EPPS4_m"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE21_ConstructTransactionC2EPPS4_m = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE21_ConstructTransactionC2EPPS4_m"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE21_ConstructTransactionC2EPPS4_m"]).apply(null, arguments)
            };
            var __ZNKSt3__213move_iteratorIPPNS_4__fs10filesystem12__dir_streamEEdeEv = Module["__ZNKSt3__213move_iteratorIPPNS_4__fs10filesystem12__dir_streamEEdeEv"] = function() {
                return (__ZNKSt3__213move_iteratorIPPNS_4__fs10filesystem12__dir_streamEEdeEv = Module["__ZNKSt3__213move_iteratorIPPNS_4__fs10filesystem12__dir_streamEEdeEv"] = Module["asm"]["_ZNKSt3__213move_iteratorIPPNS_4__fs10filesystem12__dir_streamEEdeEv"]).apply(null, arguments)
            };
            var __ZNSt3__213move_iteratorIPPNS_4__fs10filesystem12__dir_streamEEppEv = Module["__ZNSt3__213move_iteratorIPPNS_4__fs10filesystem12__dir_streamEEppEv"] = function() {
                return (__ZNSt3__213move_iteratorIPPNS_4__fs10filesystem12__dir_streamEEppEv = Module["__ZNSt3__213move_iteratorIPPNS_4__fs10filesystem12__dir_streamEEppEv"] = Module["asm"]["_ZNSt3__213move_iteratorIPPNS_4__fs10filesystem12__dir_streamEEppEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE21_ConstructTransactionD2Ev = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE21_ConstructTransactionD2Ev"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE21_ConstructTransactionD2Ev = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE21_ConstructTransactionD2Ev"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE21_ConstructTransactionD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRKPNS_4__fs10filesystem12__dir_streamEEEOT_RNS_16remove_referenceIS7_E4typeE = Module["__ZNSt3__27forwardIRKPNS_4__fs10filesystem12__dir_streamEEEOT_RNS_16remove_referenceIS7_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRKPNS_4__fs10filesystem12__dir_streamEEEOT_RNS_16remove_referenceIS7_E4typeE = Module["__ZNSt3__27forwardIRKPNS_4__fs10filesystem12__dir_streamEEEOT_RNS_16remove_referenceIS7_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRKPNS_4__fs10filesystem12__dir_streamEEEOT_RNS_16remove_referenceIS7_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE11__constructIS5_JRKS5_EEEvNS_17integral_constantIbLb1EEERS6_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE11__constructIS5_JRKS5_EEEvNS_17integral_constantIbLb1EEERS6_PT_DpOT0_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE11__constructIS5_JRKS5_EEEvNS_17integral_constantIbLb1EEERS6_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE11__constructIS5_JRKS5_EEEvNS_17integral_constantIbLb1EEERS6_PT_DpOT0_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE11__constructIS5_JRKS5_EEEvNS_17integral_constantIbLb1EEERS6_PT_DpOT0_"]).apply(null, arguments)
            };
            var __ZNSt3__210__distanceINS_13move_iteratorIPPNS_4__fs10filesystem12__dir_streamEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_NS_26random_access_iterator_tagE = Module["__ZNSt3__210__distanceINS_13move_iteratorIPPNS_4__fs10filesystem12__dir_streamEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_NS_26random_access_iterator_tagE"] = function() {
                return (__ZNSt3__210__distanceINS_13move_iteratorIPPNS_4__fs10filesystem12__dir_streamEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_NS_26random_access_iterator_tagE = Module["__ZNSt3__210__distanceINS_13move_iteratorIPPNS_4__fs10filesystem12__dir_streamEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_NS_26random_access_iterator_tagE"] = Module["asm"]["_ZNSt3__210__distanceINS_13move_iteratorIPPNS_4__fs10filesystem12__dir_streamEEEEENS_15iterator_traitsIT_E15difference_typeES9_S9_NS_26random_access_iterator_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIPNS_4__fs10filesystem12__dir_streamEEEOT_RNS_16remove_referenceIS5_E4typeE = Module["__ZNSt3__27forwardIPNS_4__fs10filesystem12__dir_streamEEEOT_RNS_16remove_referenceIS5_E4typeE"] = function() {
                return (__ZNSt3__27forwardIPNS_4__fs10filesystem12__dir_streamEEEOT_RNS_16remove_referenceIS5_E4typeE = Module["__ZNSt3__27forwardIPNS_4__fs10filesystem12__dir_streamEEEOT_RNS_16remove_referenceIS5_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIPNS_4__fs10filesystem12__dir_streamEEEOT_RNS_16remove_referenceIS5_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE11__constructIS5_JS5_EEEvNS_17integral_constantIbLb1EEERS6_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE11__constructIS5_JS5_EEEvNS_17integral_constantIbLb1EEERS6_PT_DpOT0_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE11__constructIS5_JS5_EEEvNS_17integral_constantIbLb1EEERS6_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE11__constructIS5_JS5_EEEvNS_17integral_constantIbLb1EEERS6_PT_DpOT0_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEE11__constructIS5_JS5_EEEvNS_17integral_constantIbLb1EEERS6_PT_DpOT0_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE6secondEv = Module["__ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE6secondEv = Module["__ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__2miIPPNS_4__fs10filesystem12__dir_streamES5_EEDTmicldtfp_4baseEcldtfp0_4baseEERKNS_13move_iteratorIT_EERKNS7_IT0_EE = Module["__ZNSt3__2miIPPNS_4__fs10filesystem12__dir_streamES5_EEDTmicldtfp_4baseEcldtfp0_4baseEERKNS_13move_iteratorIT_EERKNS7_IT0_EE"] = function() {
                return (__ZNSt3__2miIPPNS_4__fs10filesystem12__dir_streamES5_EEDTmicldtfp_4baseEcldtfp0_4baseEERKNS_13move_iteratorIT_EERKNS7_IT0_EE = Module["__ZNSt3__2miIPPNS_4__fs10filesystem12__dir_streamES5_EEDTmicldtfp_4baseEcldtfp0_4baseEERKNS_13move_iteratorIT_EERKNS7_IT0_EE"] = Module["asm"]["_ZNSt3__2miIPPNS_4__fs10filesystem12__dir_streamES5_EEDTmicldtfp_4baseEcldtfp0_4baseEERKNS_13move_iteratorIT_EERKNS7_IT0_EE"]).apply(null, arguments)
            };
            var __ZNKSt3__213move_iteratorIPPNS_4__fs10filesystem12__dir_streamEE4baseEv = Module["__ZNKSt3__213move_iteratorIPPNS_4__fs10filesystem12__dir_streamEE4baseEv"] = function() {
                return (__ZNKSt3__213move_iteratorIPPNS_4__fs10filesystem12__dir_streamEE4baseEv = Module["__ZNKSt3__213move_iteratorIPPNS_4__fs10filesystem12__dir_streamEE4baseEv"] = Module["asm"]["_ZNKSt3__213move_iteratorIPPNS_4__fs10filesystem12__dir_streamEE4baseEv"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE9constructIS4_JS4_EEEvPT_DpOT0_ = Module["__ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE9constructIS4_JS4_EEEvPT_DpOT0_"] = function() {
                return (__ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE9constructIS4_JS4_EEEvPT_DpOT0_ = Module["__ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE9constructIS4_JS4_EEEvPT_DpOT0_"] = Module["asm"]["_ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE9constructIS4_JS4_EEEvPT_DpOT0_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIRNS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIRNS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEELi1ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIRNS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIRNS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEELi1ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIRNS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEELi1ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE9constructIS4_JRKS4_EEEvPT_DpOT0_ = Module["__ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE9constructIS4_JRKS4_EEEvPT_DpOT0_"] = function() {
                return (__ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE9constructIS4_JRKS4_EEEvPT_DpOT0_ = Module["__ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE9constructIS4_JRKS4_EEEvPT_DpOT0_"] = Module["asm"]["_ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE9constructIS4_JRKS4_EEEvPT_DpOT0_"]).apply(null, arguments)
            };
            var __ZNKSt3__29allocatorINS_4__fs10filesystem12__dir_streamEE8max_sizeEv = Module["__ZNKSt3__29allocatorINS_4__fs10filesystem12__dir_streamEE8max_sizeEv"] = function() {
                return (__ZNKSt3__29allocatorINS_4__fs10filesystem12__dir_streamEE8max_sizeEv = Module["__ZNKSt3__29allocatorINS_4__fs10filesystem12__dir_streamEE8max_sizeEv"] = Module["asm"]["_ZNKSt3__29allocatorINS_4__fs10filesystem12__dir_streamEE8max_sizeEv"]).apply(null, arguments)
            };
            var __ZNSt3__215__move_backwardIPNS_4__fs10filesystem12__dir_streamES4_EENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableISA_EE5valueEPSA_E4typeEPS7_SE_SB_ = Module["__ZNSt3__215__move_backwardIPNS_4__fs10filesystem12__dir_streamES4_EENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableISA_EE5valueEPSA_E4typeEPS7_SE_SB_"] = function() {
                return (__ZNSt3__215__move_backwardIPNS_4__fs10filesystem12__dir_streamES4_EENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableISA_EE5valueEPSA_E4typeEPS7_SE_SB_ = Module["__ZNSt3__215__move_backwardIPNS_4__fs10filesystem12__dir_streamES4_EENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableISA_EE5valueEPSA_E4typeEPS7_SE_SB_"] = Module["asm"]["_ZNSt3__215__move_backwardIPNS_4__fs10filesystem12__dir_streamES4_EENS_9enable_ifIXaasr7is_sameINS_12remove_constIT_E4typeET0_EE5valuesr28is_trivially_copy_assignableISA_EE5valueEPSA_E4typeEPS7_SE_SB_"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRNS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEEEOT_RNS_16remove_referenceIS8_E4typeE = Module["__ZNSt3__27forwardIRNS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEEEOT_RNS_16remove_referenceIS8_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRNS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEEEOT_RNS_16remove_referenceIS8_E4typeE = Module["__ZNSt3__27forwardIRNS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEEEOT_RNS_16remove_referenceIS8_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRNS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEEEEOT_RNS_16remove_referenceIS8_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIRNS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEELi1ELb0EEC2IS7_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIRNS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEELi1ELb0EEC2IS7_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIRNS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEELi1ELb0EEC2IS7_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIRNS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEELi1ELb0EEC2IS7_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIRNS_9allocatorIPNS_4__fs10filesystem12__dir_streamEEELi1ELb0EEC2IS7_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE8allocateEmPKv = Module["__ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE8allocateEmPKv"] = function() {
                return (__ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE8allocateEmPKv = Module["__ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE8allocateEmPKv"] = Module["asm"]["_ZNSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE8allocateEmPKv"]).apply(null, arguments)
            };
            var __ZNKSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE8max_sizeEv = Module["__ZNKSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE8max_sizeEv"] = function() {
                return (__ZNKSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE8max_sizeEv = Module["__ZNKSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE8max_sizeEv"] = Module["asm"]["_ZNKSt3__29allocatorIPNS_4__fs10filesystem12__dir_streamEE8max_sizeEv"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRPNS_4__fs10filesystem12__dir_streamEEEOT_RNS_16remove_referenceIS6_E4typeE = Module["__ZNSt3__27forwardIRPNS_4__fs10filesystem12__dir_streamEEEOT_RNS_16remove_referenceIS6_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRPNS_4__fs10filesystem12__dir_streamEEEOT_RNS_16remove_referenceIS6_E4typeE = Module["__ZNSt3__27forwardIRPNS_4__fs10filesystem12__dir_streamEEEOT_RNS_16remove_referenceIS6_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRPNS_4__fs10filesystem12__dir_streamEEEOT_RNS_16remove_referenceIS6_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPNS_4__fs10filesystem12__dir_streamELi0ELb0EEC2IRS4_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPNS_4__fs10filesystem12__dir_streamELi0ELb0EEC2IRS4_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPNS_4__fs10filesystem12__dir_streamELi0ELb0EEC2IRS4_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPNS_4__fs10filesystem12__dir_streamELi0ELb0EEC2IRS4_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPNS_4__fs10filesystem12__dir_streamELi0ELb0EEC2IRS4_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardINS_22__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEEEOT_RNS_16remove_referenceIS8_E4typeE = Module["__ZNSt3__27forwardINS_22__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEEEOT_RNS_16remove_referenceIS8_E4typeE"] = function() {
                return (__ZNSt3__27forwardINS_22__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEEEOT_RNS_16remove_referenceIS8_E4typeE = Module["__ZNSt3__27forwardINS_22__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEEEOT_RNS_16remove_referenceIS8_E4typeE"] = Module["asm"]["_ZNSt3__27forwardINS_22__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEEEEOT_RNS_16remove_referenceIS8_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEELi1ELb0EEC2IS7_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEELi1ELb0EEC2IS7_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEELi1ELb0EEC2IS7_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEELi1ELb0EEC2IS7_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEELi1ELb0EEC2IS7_vEEOT_"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemIPNS_4__fs10filesystem12__dir_streamELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPNS_4__fs10filesystem12__dir_streamELi0ELb0EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemIPNS_4__fs10filesystem12__dir_streamELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPNS_4__fs10filesystem12__dir_streamELi0ELb0EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemIPNS_4__fs10filesystem12__dir_streamELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPNS_4__fs10filesystem12__dir_streamELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPNS_4__fs10filesystem12__dir_streamELi0ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPNS_4__fs10filesystem12__dir_streamELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPNS_4__fs10filesystem12__dir_streamELi0ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPNS_4__fs10filesystem12__dir_streamELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPPNS_4__fs10filesystem12__dir_streamELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPPNS_4__fs10filesystem12__dir_streamELi0ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPPNS_4__fs10filesystem12__dir_streamELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPPNS_4__fs10filesystem12__dir_streamELi0ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPPNS_4__fs10filesystem12__dir_streamELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE6secondEv = Module["__ZNSt3__217__compressed_pairIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE6secondEv = Module["__ZNSt3__217__compressed_pairIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_4__fs10filesystem12__dir_streamENS_22__allocator_destructorINS_9allocatorIS3_EEEEE6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEclEPS4_ = Module["__ZNSt3__222__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEclEPS4_"] = function() {
                return (__ZNSt3__222__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEclEPS4_ = Module["__ZNSt3__222__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEclEPS4_"] = Module["asm"]["_ZNSt3__222__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEclEPS4_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEELi1ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEELi1ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_22__allocator_destructorINS_9allocatorINS_4__fs10filesystem12__dir_streamEEEEELi1ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE17__destruct_at_endEPS4_ = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE17__destruct_at_endEPS4_"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE17__destruct_at_endEPS4_ = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE17__destruct_at_endEPS4_"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE17__destruct_at_endEPS4_"]).apply(null, arguments)
            };
            var __ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE9__end_capEv = Module["__ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE9__end_capEv"] = function() {
                return (__ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE9__end_capEv = Module["__ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE9__end_capEv"] = Module["asm"]["_ZNKSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE9__end_capEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE17__destruct_at_endEPS4_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE17__destruct_at_endEPS4_NS_17integral_constantIbLb0EEE"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE17__destruct_at_endEPS4_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE17__destruct_at_endEPS4_NS_17integral_constantIbLb0EEE"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE17__destruct_at_endEPS4_NS_17integral_constantIbLb0EEE"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPPNS_4__fs10filesystem12__dir_streamERNS_9allocatorIS4_EEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEE9constructIS3_JS3_EEEvPT_DpOT0_ = Module["__ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEE9constructIS3_JS3_EEEvPT_DpOT0_"] = function() {
                return (__ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEE9constructIS3_JS3_EEEvPT_DpOT0_ = Module["__ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEE9constructIS3_JS3_EEEvPT_DpOT0_"] = Module["asm"]["_ZNSt3__29allocatorINS_4__fs10filesystem12__dir_streamEE9constructIS3_JS3_EEEvPT_DpOT0_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem12__dir_streamC2EOS2_ = Module["__ZNSt3__24__fs10filesystem12__dir_streamC2EOS2_"] = function() {
                return (__ZNSt3__24__fs10filesystem12__dir_streamC2EOS2_ = Module["__ZNSt3__24__fs10filesystem12__dir_streamC2EOS2_"] = Module["asm"]["_ZNSt3__24__fs10filesystem12__dir_streamC2EOS2_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRNS_4__fs10filesystem15directory_entryEEEONS_16remove_referenceIT_E4typeEOS6_ = Module["__ZNSt3__24moveIRNS_4__fs10filesystem15directory_entryEEEONS_16remove_referenceIT_E4typeEOS6_"] = function() {
                return (__ZNSt3__24moveIRNS_4__fs10filesystem15directory_entryEEEONS_16remove_referenceIT_E4typeEOS6_ = Module["__ZNSt3__24moveIRNS_4__fs10filesystem15directory_entryEEEONS_16remove_referenceIT_E4typeEOS6_"] = Module["asm"]["_ZNSt3__24moveIRNS_4__fs10filesystem15directory_entryEEEONS_16remove_referenceIT_E4typeEOS6_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem15directory_entryC2EOS2_ = Module["__ZNSt3__24__fs10filesystem15directory_entryC2EOS2_"] = function() {
                return (__ZNSt3__24__fs10filesystem15directory_entryC2EOS2_ = Module["__ZNSt3__24__fs10filesystem15directory_entryC2EOS2_"] = Module["asm"]["_ZNSt3__24__fs10filesystem15directory_entryC2EOS2_"]).apply(null, arguments)
            };
            var __ZNSt3__212__to_addressINS_4__fs10filesystem12__dir_streamEEEPT_S5_ = Module["__ZNSt3__212__to_addressINS_4__fs10filesystem12__dir_streamEEEPT_S5_"] = function() {
                return (__ZNSt3__212__to_addressINS_4__fs10filesystem12__dir_streamEEEPT_S5_ = Module["__ZNSt3__212__to_addressINS_4__fs10filesystem12__dir_streamEEEPT_S5_"] = Module["asm"]["_ZNSt3__212__to_addressINS_4__fs10filesystem12__dir_streamEEEPT_S5_"]).apply(null, arguments)
            };
            var __ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE25__maybe_remove_back_spareEb = Module["__ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE25__maybe_remove_back_spareEb"] = function() {
                return (__ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE25__maybe_remove_back_spareEb = Module["__ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE25__maybe_remove_back_spareEb"] = Module["asm"]["_ZNSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE25__maybe_remove_back_spareEb"]).apply(null, arguments)
            };
            var __ZNKSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE19__back_spare_blocksEv = Module["__ZNKSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE19__back_spare_blocksEv"] = function() {
                return (__ZNKSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE19__back_spare_blocksEv = Module["__ZNKSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE19__back_spare_blocksEv"] = Module["asm"]["_ZNKSt3__25dequeINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEE19__back_spare_blocksEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE4backEv = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE4backEv"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE4backEv = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE4backEv"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE4backEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE8pop_backEv = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE8pop_backEv"] = function() {
                return (__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE8pop_backEv = Module["__ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE8pop_backEv"] = Module["asm"]["_ZNSt3__214__split_bufferIPNS_4__fs10filesystem12__dir_streamENS_9allocatorIS4_EEE8pop_backEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem18directory_iteratorC1ERKNS1_4pathEPNS_10error_codeENS1_17directory_optionsE = Module["__ZNSt3__24__fs10filesystem18directory_iteratorC1ERKNS1_4pathEPNS_10error_codeENS1_17directory_optionsE"] = function() {
                return (__ZNSt3__24__fs10filesystem18directory_iteratorC1ERKNS1_4pathEPNS_10error_codeENS1_17directory_optionsE = Module["__ZNSt3__24__fs10filesystem18directory_iteratorC1ERKNS1_4pathEPNS_10error_codeENS1_17directory_optionsE"] = Module["asm"]["_ZNSt3__24__fs10filesystem18directory_iteratorC1ERKNS1_4pathEPNS_10error_codeENS1_17directory_optionsE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem28recursive_directory_iteratorC1ERKNS1_4pathENS1_17directory_optionsEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem28recursive_directory_iteratorC1ERKNS1_4pathENS1_17directory_optionsEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem28recursive_directory_iteratorC1ERKNS1_4pathENS1_17directory_optionsEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem28recursive_directory_iteratorC1ERKNS1_4pathENS1_17directory_optionsEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem28recursive_directory_iteratorC1ERKNS1_4pathENS1_17directory_optionsEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem16_FilesystemClock3nowEv = Module["__ZNSt3__24__fs10filesystem16_FilesystemClock3nowEv"] = function() {
                return (__ZNSt3__24__fs10filesystem16_FilesystemClock3nowEv = Module["__ZNSt3__24__fs10filesystem16_FilesystemClock3nowEv"] = Module["asm"]["_ZNSt3__24__fs10filesystem16_FilesystemClock3nowEv"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono8durationInNS_5ratioILx1ELx1EEEEC2IlEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_nEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationInNS_5ratioILx1ELx1EEEEC2IlEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_nEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"] = function() {
                return (__ZNSt3__26chrono8durationInNS_5ratioILx1ELx1EEEEC2IlEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_nEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationInNS_5ratioILx1ELx1EEEEC2IlEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_nEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"] = Module["asm"]["_ZNSt3__26chrono8durationInNS_5ratioILx1ELx1EEEEC2IlEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_nEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEEC2IlEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_nEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEEC2IlEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_nEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"] = function() {
                return (__ZNSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEEC2IlEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_nEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEEC2IlEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_nEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"] = Module["asm"]["_ZNSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEEC2IlEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_nEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono13duration_castINS0_8durationInNS_5ratioILx1ELx1000000000EEEEEnS4_EENS_9enable_ifIXsr13__is_durationIT_EE5valueES7_E4typeERKNS2_IT0_T1_EE = Module["__ZNSt3__26chrono13duration_castINS0_8durationInNS_5ratioILx1ELx1000000000EEEEEnS4_EENS_9enable_ifIXsr13__is_durationIT_EE5valueES7_E4typeERKNS2_IT0_T1_EE"] = function() {
                return (__ZNSt3__26chrono13duration_castINS0_8durationInNS_5ratioILx1ELx1000000000EEEEEnS4_EENS_9enable_ifIXsr13__is_durationIT_EE5valueES7_E4typeERKNS2_IT0_T1_EE = Module["__ZNSt3__26chrono13duration_castINS0_8durationInNS_5ratioILx1ELx1000000000EEEEEnS4_EENS_9enable_ifIXsr13__is_durationIT_EE5valueES7_E4typeERKNS2_IT0_T1_EE"] = Module["asm"]["_ZNSt3__26chrono13duration_castINS0_8durationInNS_5ratioILx1ELx1000000000EEEEEnS4_EENS_9enable_ifIXsr13__is_durationIT_EE5valueES7_E4typeERKNS2_IT0_T1_EE"]).apply(null, arguments)
            };
            var __ZNSt3__26chronoplInNS_5ratioILx1ELx1EEEnNS2_ILx1ELx1000000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_ = Module["__ZNSt3__26chronoplInNS_5ratioILx1ELx1EEEnNS2_ILx1ELx1000000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"] = function() {
                return (__ZNSt3__26chronoplInNS_5ratioILx1ELx1EEEnNS2_ILx1ELx1000000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_ = Module["__ZNSt3__26chronoplInNS_5ratioILx1ELx1EEEnNS2_ILx1ELx1000000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"] = Module["asm"]["_ZNSt3__26chronoplInNS_5ratioILx1ELx1EEEnNS2_ILx1ELx1000000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEEC2InNS2_ILx1ELx1EEEEERKNS1_IT_T0_EEPNS_9enable_ifIXaasr13__no_overflowIS8_S3_EE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEaaeqsr13__no_overflowIS8_S3_E4typeE3denLi1Entsr23treat_as_floating_pointIS7_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEEC2InNS2_ILx1ELx1EEEEERKNS1_IT_T0_EEPNS_9enable_ifIXaasr13__no_overflowIS8_S3_EE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEaaeqsr13__no_overflowIS8_S3_E4typeE3denLi1Entsr23treat_as_floating_pointIS7_EE5valueEvE4typeE"] = function() {
                return (__ZNSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEEC2InNS2_ILx1ELx1EEEEERKNS1_IT_T0_EEPNS_9enable_ifIXaasr13__no_overflowIS8_S3_EE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEaaeqsr13__no_overflowIS8_S3_E4typeE3denLi1Entsr23treat_as_floating_pointIS7_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEEC2InNS2_ILx1ELx1EEEEERKNS1_IT_T0_EEPNS_9enable_ifIXaasr13__no_overflowIS8_S3_EE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEaaeqsr13__no_overflowIS8_S3_E4typeE3denLi1Entsr23treat_as_floating_pointIS7_EE5valueEvE4typeE"] = Module["asm"]["_ZNSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEEC2InNS2_ILx1ELx1EEEEERKNS1_IT_T0_EEPNS_9enable_ifIXaasr13__no_overflowIS8_S3_EE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEaaeqsr13__no_overflowIS8_S3_E4typeE3denLi1Entsr23treat_as_floating_pointIS7_EE5valueEvE4typeE"]).apply(null, arguments)
            };
            var __ZNKSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEE5countEv = Module["__ZNKSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEE5countEv"] = function() {
                return (__ZNKSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEE5countEv = Module["__ZNKSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEE5countEv"] = Module["asm"]["_ZNKSt3__26chrono8durationInNS_5ratioILx1ELx1000000000EEEE5countEv"]).apply(null, arguments)
            };
            var __ZNKSt3__26chrono15__duration_castINS0_8durationInNS_5ratioILx1ELx1000000000EEEEES5_NS3_ILx1ELx1EEELb1ELb1EEclERKS5_ = Module["__ZNKSt3__26chrono15__duration_castINS0_8durationInNS_5ratioILx1ELx1000000000EEEEES5_NS3_ILx1ELx1EEELb1ELb1EEclERKS5_"] = function() {
                return (__ZNKSt3__26chrono15__duration_castINS0_8durationInNS_5ratioILx1ELx1000000000EEEEES5_NS3_ILx1ELx1EEELb1ELb1EEclERKS5_ = Module["__ZNKSt3__26chrono15__duration_castINS0_8durationInNS_5ratioILx1ELx1000000000EEEEES5_NS3_ILx1ELx1EEELb1ELb1EEclERKS5_"] = Module["asm"]["_ZNKSt3__26chrono15__duration_castINS0_8durationInNS_5ratioILx1ELx1000000000EEEEES5_NS3_ILx1ELx1EEELb1ELb1EEclERKS5_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem16filesystem_errorD2Ev = Module["__ZNSt3__24__fs10filesystem16filesystem_errorD2Ev"] = function() {
                return (__ZNSt3__24__fs10filesystem16filesystem_errorD2Ev = Module["__ZNSt3__24__fs10filesystem16filesystem_errorD2Ev"] = Module["asm"]["_ZNSt3__24__fs10filesystem16filesystem_errorD2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__210shared_ptrINS_4__fs10filesystem16filesystem_error8_StorageEED2Ev = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem16filesystem_error8_StorageEED2Ev"] = function() {
                return (__ZNSt3__210shared_ptrINS_4__fs10filesystem16filesystem_error8_StorageEED2Ev = Module["__ZNSt3__210shared_ptrINS_4__fs10filesystem16filesystem_error8_StorageEED2Ev"] = Module["asm"]["_ZNSt3__210shared_ptrINS_4__fs10filesystem16filesystem_error8_StorageEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem16filesystem_errorD0Ev = Module["__ZNSt3__24__fs10filesystem16filesystem_errorD0Ev"] = function() {
                return (__ZNSt3__24__fs10filesystem16filesystem_errorD0Ev = Module["__ZNSt3__24__fs10filesystem16filesystem_errorD0Ev"] = Module["asm"]["_ZNSt3__24__fs10filesystem16filesystem_errorD0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem16filesystem_error13__create_whatEi = Module["__ZNSt3__24__fs10filesystem16filesystem_error13__create_whatEi"] = function() {
                return (__ZNSt3__24__fs10filesystem16filesystem_error13__create_whatEi = Module["__ZNSt3__24__fs10filesystem16filesystem_error13__create_whatEi"] = Module["asm"]["_ZNSt3__24__fs10filesystem16filesystem_error13__create_whatEi"]).apply(null, arguments)
            };
            var __ZNKSt3__210shared_ptrINS_4__fs10filesystem16filesystem_error8_StorageEEptEv = Module["__ZNKSt3__210shared_ptrINS_4__fs10filesystem16filesystem_error8_StorageEEptEv"] = function() {
                return (__ZNKSt3__210shared_ptrINS_4__fs10filesystem16filesystem_error8_StorageEEptEv = Module["__ZNKSt3__210shared_ptrINS_4__fs10filesystem16filesystem_error8_StorageEEptEv"] = Module["asm"]["_ZNKSt3__210shared_ptrINS_4__fs10filesystem16filesystem_error8_StorageEEptEv"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem16filesystem_error5path1Ev = Module["__ZNKSt3__24__fs10filesystem16filesystem_error5path1Ev"] = function() {
                return (__ZNKSt3__24__fs10filesystem16filesystem_error5path1Ev = Module["__ZNKSt3__24__fs10filesystem16filesystem_error5path1Ev"] = Module["asm"]["_ZNKSt3__24__fs10filesystem16filesystem_error5path1Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem16filesystem_error5path2Ev = Module["__ZNKSt3__24__fs10filesystem16filesystem_error5path2Ev"] = function() {
                return (__ZNKSt3__24__fs10filesystem16filesystem_error5path2Ev = Module["__ZNKSt3__24__fs10filesystem16filesystem_error5path2Ev"] = Module["asm"]["_ZNKSt3__24__fs10filesystem16filesystem_error5path2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem10__absoluteERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem10__absoluteERKNS1_4pathEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem10__absoluteERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem10__absoluteERKNS1_4pathEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem10__absoluteERKNS1_4pathEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem14__current_pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem14__current_pathEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem14__current_pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem14__current_pathEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem14__current_pathEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem11__canonicalERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem11__canonicalERKNS1_4pathEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem11__canonicalERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem11__canonicalERKNS1_4pathEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem11__canonicalERKNS1_4pathEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4pathC2IPcvEERKT_NS2_6formatE = Module["__ZNSt3__24__fs10filesystem4pathC2IPcvEERKT_NS2_6formatE"] = function() {
                return (__ZNSt3__24__fs10filesystem4pathC2IPcvEERKT_NS2_6formatE = Module["__ZNSt3__24__fs10filesystem4pathC2IPcvEERKT_NS2_6formatE"] = Module["asm"]["_ZNSt3__24__fs10filesystem4pathC2IPcvEERKT_NS2_6formatE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceIPcEEvRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKT_ = Module["__ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceIPcEEvRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKT_"] = function() {
                return (__ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceIPcEEvRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKT_ = Module["__ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceIPcEEvRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKT_"] = Module["asm"]["_ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceIPcEEvRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKT_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem6__copyERKNS1_4pathES4_NS1_12copy_optionsEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem6__copyERKNS1_4pathES4_NS1_12copy_optionsEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem6__copyERKNS1_4pathES4_NS1_12copy_optionsEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem6__copyERKNS1_4pathES4_NS1_12copy_optionsEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem6__copyERKNS1_4pathES4_NS1_12copy_optionsEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystemorENS1_12copy_optionsES2_ = Module["__ZNSt3__24__fs10filesystemorENS1_12copy_optionsES2_"] = function() {
                return (__ZNSt3__24__fs10filesystemorENS1_12copy_optionsES2_ = Module["__ZNSt3__24__fs10filesystemorENS1_12copy_optionsES2_"] = Module["asm"]["_ZNSt3__24__fs10filesystemorENS1_12copy_optionsES2_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystemanENS1_12copy_optionsES2_ = Module["__ZNSt3__24__fs10filesystemanENS1_12copy_optionsES2_"] = function() {
                return (__ZNSt3__24__fs10filesystemanENS1_12copy_optionsES2_ = Module["__ZNSt3__24__fs10filesystemanENS1_12copy_optionsES2_"] = Module["asm"]["_ZNSt3__24__fs10filesystemanENS1_12copy_optionsES2_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem8is_otherENS1_11file_statusE = Module["__ZNSt3__24__fs10filesystem8is_otherENS1_11file_statusE"] = function() {
                return (__ZNSt3__24__fs10filesystem8is_otherENS1_11file_statusE = Module["__ZNSt3__24__fs10filesystem8is_otherENS1_11file_statusE"] = Module["asm"]["_ZNSt3__24__fs10filesystem8is_otherENS1_11file_statusE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem15is_regular_fileENS1_11file_statusE = Module["__ZNSt3__24__fs10filesystem15is_regular_fileENS1_11file_statusE"] = function() {
                return (__ZNSt3__24__fs10filesystem15is_regular_fileENS1_11file_statusE = Module["__ZNSt3__24__fs10filesystem15is_regular_fileENS1_11file_statusE"] = Module["asm"]["_ZNSt3__24__fs10filesystem15is_regular_fileENS1_11file_statusE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem14__copy_symlinkERKNS1_4pathES4_PNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem14__copy_symlinkERKNS1_4pathES4_PNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem14__copy_symlinkERKNS1_4pathES4_PNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem14__copy_symlinkERKNS1_4pathES4_PNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem14__copy_symlinkERKNS1_4pathES4_PNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem16__create_symlinkERKNS1_4pathES4_PNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem16__create_symlinkERKNS1_4pathES4_PNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem16__create_symlinkERKNS1_4pathES4_PNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem16__create_symlinkERKNS1_4pathES4_PNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem16__create_symlinkERKNS1_4pathES4_PNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem18__create_hard_linkERKNS1_4pathES4_PNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem18__create_hard_linkERKNS1_4pathES4_PNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem18__create_hard_linkERKNS1_4pathES4_PNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem18__create_hard_linkERKNS1_4pathES4_PNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem18__create_hard_linkERKNS1_4pathES4_PNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem4path8filenameEv = Module["__ZNKSt3__24__fs10filesystem4path8filenameEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem4path8filenameEv = Module["__ZNKSt3__24__fs10filesystem4path8filenameEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem4path8filenameEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem11__copy_fileERKNS1_4pathES4_NS1_12copy_optionsEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem11__copy_fileERKNS1_4pathES4_NS1_12copy_optionsEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem11__copy_fileERKNS1_4pathES4_NS1_12copy_optionsEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem11__copy_fileERKNS1_4pathES4_NS1_12copy_optionsEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem11__copy_fileERKNS1_4pathES4_NS1_12copy_optionsEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem18__create_directoryERKNS1_4pathES4_PNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem18__create_directoryERKNS1_4pathES4_PNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem18__create_directoryERKNS1_4pathES4_PNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem18__create_directoryERKNS1_4pathES4_PNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem18__create_directoryERKNS1_4pathES4_PNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem18directory_iteratorC2ERKNS1_4pathE = Module["__ZNSt3__24__fs10filesystem18directory_iteratorC2ERKNS1_4pathE"] = function() {
                return (__ZNSt3__24__fs10filesystem18directory_iteratorC2ERKNS1_4pathE = Module["__ZNSt3__24__fs10filesystem18directory_iteratorC2ERKNS1_4pathE"] = Module["asm"]["_ZNSt3__24__fs10filesystem18directory_iteratorC2ERKNS1_4pathE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem18directory_iteratorC2ERKNS1_4pathERNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem18directory_iteratorC2ERKNS1_4pathERNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem18directory_iteratorC2ERKNS1_4pathERNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem18directory_iteratorC2ERKNS1_4pathERNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem18directory_iteratorC2ERKNS1_4pathERNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystemneERKNS1_18directory_iteratorES4_ = Module["__ZNSt3__24__fs10filesystemneERKNS1_18directory_iteratorES4_"] = function() {
                return (__ZNSt3__24__fs10filesystemneERKNS1_18directory_iteratorES4_ = Module["__ZNSt3__24__fs10filesystemneERKNS1_18directory_iteratorES4_"] = Module["asm"]["_ZNSt3__24__fs10filesystemneERKNS1_18directory_iteratorES4_"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem18directory_iteratorptEv = Module["__ZNKSt3__24__fs10filesystem18directory_iteratorptEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem18directory_iteratorptEv = Module["__ZNKSt3__24__fs10filesystem18directory_iteratorptEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem18directory_iteratorptEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem18directory_iterator9incrementERNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem18directory_iterator9incrementERNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem18directory_iterator9incrementERNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem18directory_iterator9incrementERNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem18directory_iterator9incrementERNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem14__read_symlinkERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem14__read_symlinkERKNS1_4pathEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem14__read_symlinkERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem14__read_symlinkERKNS1_4pathEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem14__read_symlinkERKNS1_4pathEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2INS_17basic_string_viewIcS2_EEvEERKT_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2INS_17basic_string_viewIcS2_EEvEERKT_"] = function() {
                return (__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2INS_17basic_string_viewIcS2_EEvEERKT_ = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2INS_17basic_string_viewIcS2_EEvEERKT_"] = Module["asm"]["_ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEC2INS_17basic_string_viewIcS2_EEvEERKT_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4pathC2EONS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS2_6formatE = Module["__ZNSt3__24__fs10filesystem4pathC2EONS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS2_6formatE"] = function() {
                return (__ZNSt3__24__fs10filesystem4pathC2EONS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS2_6formatE = Module["__ZNSt3__24__fs10filesystem4pathC2EONS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS2_6formatE"] = Module["asm"]["_ZNSt3__24__fs10filesystem4pathC2EONS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEENS2_6formatE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystemeqERKNS1_18directory_iteratorES4_ = Module["__ZNSt3__24__fs10filesystemeqERKNS1_18directory_iteratorES4_"] = function() {
                return (__ZNSt3__24__fs10filesystemeqERKNS1_18directory_iteratorES4_ = Module["__ZNSt3__24__fs10filesystemeqERKNS1_18directory_iteratorES4_"] = Module["asm"]["_ZNSt3__24__fs10filesystemeqERKNS1_18directory_iteratorES4_"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem18directory_iteratordeEv = Module["__ZNKSt3__24__fs10filesystem18directory_iteratordeEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem18directory_iteratordeEv = Module["__ZNKSt3__24__fs10filesystem18directory_iteratordeEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem18directory_iteratordeEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem20__create_directoriesERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem20__create_directoriesERKNS1_4pathEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem20__create_directoriesERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem20__create_directoriesERKNS1_4pathEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem20__create_directoriesERKNS1_4pathEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem4path11parent_pathEv = Module["__ZNKSt3__24__fs10filesystem4path11parent_pathEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem4path11parent_pathEv = Module["__ZNKSt3__24__fs10filesystem4path11parent_pathEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem4path11parent_pathEv"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem4path5emptyEv = Module["__ZNKSt3__24__fs10filesystem4path5emptyEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem4path5emptyEv = Module["__ZNKSt3__24__fs10filesystem4path5emptyEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem4path5emptyEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem6statusERKNS1_4pathERNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem6statusERKNS1_4pathERNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem6statusERKNS1_4pathERNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem6statusERKNS1_4pathERNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem6statusERKNS1_4pathERNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem18__create_directoryERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem18__create_directoryERKNS1_4pathEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem18__create_directoryERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem18__create_directoryERKNS1_4pathEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem18__create_directoryERKNS1_4pathEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem4path13__parent_pathEv = Module["__ZNKSt3__24__fs10filesystem4path13__parent_pathEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem4path13__parent_pathEv = Module["__ZNKSt3__24__fs10filesystem4path13__parent_pathEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem4path13__parent_pathEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem26__create_directory_symlinkERKNS1_4pathES4_PNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem26__create_directory_symlinkERKNS1_4pathES4_PNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem26__create_directory_symlinkERKNS1_4pathES4_PNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem26__create_directory_symlinkERKNS1_4pathES4_PNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem26__create_directory_symlinkERKNS1_4pathES4_PNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIA_cNS_14default_deleteIS1_EEEC2IPcLb1EvvEET_ = Module["__ZNSt3__210unique_ptrIA_cNS_14default_deleteIS1_EEEC2IPcLb1EvvEET_"] = function() {
                return (__ZNSt3__210unique_ptrIA_cNS_14default_deleteIS1_EEEC2IPcLb1EvvEET_ = Module["__ZNSt3__210unique_ptrIA_cNS_14default_deleteIS1_EEEC2IPcLb1EvvEET_"] = Module["asm"]["_ZNSt3__210unique_ptrIA_cNS_14default_deleteIS1_EEEC2IPcLb1EvvEET_"]).apply(null, arguments)
            };
            var __ZNKSt3__210unique_ptrIA_cNS_14default_deleteIS1_EEE3getEv = Module["__ZNKSt3__210unique_ptrIA_cNS_14default_deleteIS1_EEE3getEv"] = function() {
                return (__ZNKSt3__210unique_ptrIA_cNS_14default_deleteIS1_EEE3getEv = Module["__ZNKSt3__210unique_ptrIA_cNS_14default_deleteIS1_EEE3getEv"] = Module["asm"]["_ZNKSt3__210unique_ptrIA_cNS_14default_deleteIS1_EEE3getEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIA_cNS_14default_deleteIS1_EEED2Ev = Module["__ZNSt3__210unique_ptrIA_cNS_14default_deleteIS1_EEED2Ev"] = function() {
                return (__ZNSt3__210unique_ptrIA_cNS_14default_deleteIS1_EEED2Ev = Module["__ZNSt3__210unique_ptrIA_cNS_14default_deleteIS1_EEED2Ev"] = Module["asm"]["_ZNSt3__210unique_ptrIA_cNS_14default_deleteIS1_EEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPcNS_14default_deleteIA_cEEEC2IRS1_NS_18__default_init_tagEEEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPcNS_14default_deleteIA_cEEEC2IRS1_NS_18__default_init_tagEEEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIPcNS_14default_deleteIA_cEEEC2IRS1_NS_18__default_init_tagEEEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPcNS_14default_deleteIA_cEEEC2IRS1_NS_18__default_init_tagEEEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIPcNS_14default_deleteIA_cEEEC2IRS1_NS_18__default_init_tagEEEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPcNS_14default_deleteIA_cEEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPcNS_14default_deleteIA_cEEE5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPcNS_14default_deleteIA_cEEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPcNS_14default_deleteIA_cEEE5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPcNS_14default_deleteIA_cEEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrIA_cNS_14default_deleteIS1_EEE5resetEDn = Module["__ZNSt3__210unique_ptrIA_cNS_14default_deleteIS1_EEE5resetEDn"] = function() {
                return (__ZNSt3__210unique_ptrIA_cNS_14default_deleteIS1_EEE5resetEDn = Module["__ZNSt3__210unique_ptrIA_cNS_14default_deleteIS1_EEE5resetEDn"] = Module["asm"]["_ZNSt3__210unique_ptrIA_cNS_14default_deleteIS1_EEE5resetEDn"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem14__current_pathERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem14__current_pathERKNS1_4pathEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem14__current_pathERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem14__current_pathERKNS1_4pathEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem14__current_pathERKNS1_4pathEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem12__equivalentERKNS1_4pathES4_PNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem12__equivalentERKNS1_4pathES4_PNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem12__equivalentERKNS1_4pathES4_PNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem12__equivalentERKNS1_4pathES4_PNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem12__equivalentERKNS1_4pathES4_PNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4pathC2INS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEvEERKT_NS2_6formatE = Module["__ZNSt3__24__fs10filesystem4pathC2INS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEvEERKT_NS2_6formatE"] = function() {
                return (__ZNSt3__24__fs10filesystem4pathC2INS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEvEERKT_NS2_6formatE = Module["__ZNSt3__24__fs10filesystem4pathC2INS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEvEERKT_NS2_6formatE"] = Module["asm"]["_ZNSt3__24__fs10filesystem4pathC2INS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEvEERKT_NS2_6formatE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEEvRSA_RKT_ = Module["__ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEEvRSA_RKT_"] = function() {
                return (__ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEEvRSA_RKT_ = Module["__ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEEvRSA_RKT_"] = Module["asm"]["_ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEEEvRSA_RKT_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem11__file_sizeERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem11__file_sizeERKNS1_4pathEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem11__file_sizeERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem11__file_sizeERKNS1_4pathEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem11__file_sizeERKNS1_4pathEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem17__hard_link_countERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem17__hard_link_countERKNS1_4pathEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem17__hard_link_countERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem17__hard_link_countERKNS1_4pathEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem17__hard_link_countERKNS1_4pathEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem13__fs_is_emptyERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem13__fs_is_emptyERKNS1_4pathEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem13__fs_is_emptyERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem13__fs_is_emptyERKNS1_4pathEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem13__fs_is_emptyERKNS1_4pathEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__2eqINS_4__fs10filesystem12__dir_streamES3_EEbRKNS_10shared_ptrIT_EERKNS4_IT0_EE = Module["__ZNSt3__2eqINS_4__fs10filesystem12__dir_streamES3_EEbRKNS_10shared_ptrIT_EERKNS4_IT0_EE"] = function() {
                return (__ZNSt3__2eqINS_4__fs10filesystem12__dir_streamES3_EEbRKNS_10shared_ptrIT_EERKNS4_IT0_EE = Module["__ZNSt3__2eqINS_4__fs10filesystem12__dir_streamES3_EEbRKNS_10shared_ptrIT_EERKNS4_IT0_EE"] = Module["asm"]["_ZNSt3__2eqINS_4__fs10filesystem12__dir_streamES3_EEbRKNS_10shared_ptrIT_EERKNS4_IT0_EE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem17__last_write_timeERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem17__last_write_timeERKNS1_4pathEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem17__last_write_timeERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem17__last_write_timeERKNS1_4pathEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem17__last_write_timeERKNS1_4pathEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem17__last_write_timeERKNS1_4pathENS_6chrono10time_pointINS1_16_FilesystemClockENS5_8durationInNS_5ratioILx1ELx1000000000EEEEEEEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem17__last_write_timeERKNS1_4pathENS_6chrono10time_pointINS1_16_FilesystemClockENS5_8durationInNS_5ratioILx1ELx1000000000EEEEEEEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem17__last_write_timeERKNS1_4pathENS_6chrono10time_pointINS1_16_FilesystemClockENS5_8durationInNS_5ratioILx1ELx1000000000EEEEEEEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem17__last_write_timeERKNS1_4pathENS_6chrono10time_pointINS1_16_FilesystemClockENS5_8durationInNS_5ratioILx1ELx1000000000EEEEEEEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem17__last_write_timeERKNS1_4pathENS_6chrono10time_pointINS1_16_FilesystemClockENS5_8durationInNS_5ratioILx1ELx1000000000EEEEEEEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__25arrayI8timespecLm2EEixEm = Module["__ZNSt3__25arrayI8timespecLm2EEixEm"] = function() {
                return (__ZNSt3__25arrayI8timespecLm2EEixEm = Module["__ZNSt3__25arrayI8timespecLm2EEixEm"] = Module["asm"]["_ZNSt3__25arrayI8timespecLm2EEixEm"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem13__permissionsERKNS1_4pathENS1_5permsENS1_12perm_optionsEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem13__permissionsERKNS1_4pathENS1_5permsENS1_12perm_optionsEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem13__permissionsERKNS1_4pathENS1_5permsENS1_12perm_optionsEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem13__permissionsERKNS1_4pathENS1_5permsENS1_12perm_optionsEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem13__permissionsERKNS1_4pathENS1_5permsENS1_12perm_optionsEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystemaNERNS1_5permsES2_ = Module["__ZNSt3__24__fs10filesystemaNERNS1_5permsES2_"] = function() {
                return (__ZNSt3__24__fs10filesystemaNERNS1_5permsES2_ = Module["__ZNSt3__24__fs10filesystemaNERNS1_5permsES2_"] = Module["asm"]["_ZNSt3__24__fs10filesystemaNERNS1_5permsES2_"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem11file_status11permissionsEv = Module["__ZNKSt3__24__fs10filesystem11file_status11permissionsEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem11file_status11permissionsEv = Module["__ZNKSt3__24__fs10filesystem11file_status11permissionsEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem11file_status11permissionsEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystemoRERNS1_5permsES2_ = Module["__ZNSt3__24__fs10filesystemoRERNS1_5permsES2_"] = function() {
                return (__ZNSt3__24__fs10filesystemoRERNS1_5permsES2_ = Module["__ZNSt3__24__fs10filesystemoRERNS1_5permsES2_"] = Module["asm"]["_ZNSt3__24__fs10filesystemoRERNS1_5permsES2_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystemcoENS1_5permsE = Module["__ZNSt3__24__fs10filesystemcoENS1_5permsE"] = function() {
                return (__ZNSt3__24__fs10filesystemcoENS1_5permsE = Module["__ZNSt3__24__fs10filesystemcoENS1_5permsE"] = Module["asm"]["_ZNSt3__24__fs10filesystemcoENS1_5permsE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystemanENS1_5permsES2_ = Module["__ZNSt3__24__fs10filesystemanENS1_5permsES2_"] = function() {
                return (__ZNSt3__24__fs10filesystemanENS1_5permsES2_ = Module["__ZNSt3__24__fs10filesystemanENS1_5permsES2_"] = Module["asm"]["_ZNSt3__24__fs10filesystemanENS1_5permsES2_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystemanENS1_12perm_optionsES2_ = Module["__ZNSt3__24__fs10filesystemanENS1_12perm_optionsES2_"] = function() {
                return (__ZNSt3__24__fs10filesystemanENS1_12perm_optionsES2_ = Module["__ZNSt3__24__fs10filesystemanENS1_12perm_optionsES2_"] = Module["asm"]["_ZNSt3__24__fs10filesystemanENS1_12perm_optionsES2_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystemorENS1_5permsES2_ = Module["__ZNSt3__24__fs10filesystemorENS1_5permsES2_"] = function() {
                return (__ZNSt3__24__fs10filesystemorENS1_5permsES2_ = Module["__ZNSt3__24__fs10filesystemorENS1_5permsES2_"] = Module["asm"]["_ZNSt3__24__fs10filesystemorENS1_5permsES2_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem8__removeERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem8__removeERKNS1_4pathEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem8__removeERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem8__removeERKNS1_4pathEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem8__removeERKNS1_4pathEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem12__remove_allERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem12__remove_allERKNS1_4pathEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem12__remove_allERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem12__remove_allERKNS1_4pathEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem12__remove_allERKNS1_4pathEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__215error_conditionC2INS_4errcEEET_PNS_9enable_ifIXsr23is_error_condition_enumIS3_EE5valueEvE4typeE = Module["__ZNSt3__215error_conditionC2INS_4errcEEET_PNS_9enable_ifIXsr23is_error_condition_enumIS3_EE5valueEvE4typeE"] = function() {
                return (__ZNSt3__215error_conditionC2INS_4errcEEET_PNS_9enable_ifIXsr23is_error_condition_enumIS3_EE5valueEvE4typeE = Module["__ZNSt3__215error_conditionC2INS_4errcEEET_PNS_9enable_ifIXsr23is_error_condition_enumIS3_EE5valueEvE4typeE"] = Module["asm"]["_ZNSt3__215error_conditionC2INS_4errcEEET_PNS_9enable_ifIXsr23is_error_condition_enumIS3_EE5valueEvE4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__2eqERKNS_10error_codeERKNS_15error_conditionE = Module["__ZNSt3__2eqERKNS_10error_codeERKNS_15error_conditionE"] = function() {
                return (__ZNSt3__2eqERKNS_10error_codeERKNS_15error_conditionE = Module["__ZNSt3__2eqERKNS_10error_codeERKNS_15error_conditionE"] = Module["asm"]["_ZNSt3__2eqERKNS_10error_codeERKNS_15error_conditionE"]).apply(null, arguments)
            };
            var __ZNSt3__220make_error_conditionENS_4errcE = Module["__ZNSt3__220make_error_conditionENS_4errcE"] = function() {
                return (__ZNSt3__220make_error_conditionENS_4errcE = Module["__ZNSt3__220make_error_conditionENS_4errcE"] = Module["asm"]["_ZNSt3__220make_error_conditionENS_4errcE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem8__renameERKNS1_4pathES4_PNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem8__renameERKNS1_4pathES4_PNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem8__renameERKNS1_4pathES4_PNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem8__renameERKNS1_4pathES4_PNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem8__renameERKNS1_4pathES4_PNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem13__resize_fileERKNS1_4pathEyPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem13__resize_fileERKNS1_4pathEyPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem13__resize_fileERKNS1_4pathEyPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem13__resize_fileERKNS1_4pathEyPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem13__resize_fileERKNS1_4pathEyPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem7__spaceERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem7__spaceERKNS1_4pathEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem7__spaceERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem7__spaceERKNS1_4pathEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem7__spaceERKNS1_4pathEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem21__temp_directory_pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem21__temp_directory_pathEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem21__temp_directory_pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem21__temp_directory_pathEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem21__temp_directory_pathEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4pathC2IPKcvEERKT_NS2_6formatE = Module["__ZNSt3__24__fs10filesystem4pathC2IPKcvEERKT_NS2_6formatE"] = function() {
                return (__ZNSt3__24__fs10filesystem4pathC2IPKcvEERKT_NS2_6formatE = Module["__ZNSt3__24__fs10filesystem4pathC2IPKcvEERKT_NS2_6formatE"] = Module["asm"]["_ZNSt3__24__fs10filesystem4pathC2IPKcvEERKT_NS2_6formatE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceIPKcEEvRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKT_ = Module["__ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceIPKcEEvRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKT_"] = function() {
                return (__ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceIPKcEEvRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKT_ = Module["__ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceIPKcEEvRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKT_"] = Module["asm"]["_ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceIPKcEEvRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKT_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem18__weakly_canonicalERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem18__weakly_canonicalERKNS1_4pathEPNS_10error_codeE"] = function() {
                return (__ZNSt3__24__fs10filesystem18__weakly_canonicalERKNS1_4pathEPNS_10error_codeE = Module["__ZNSt3__24__fs10filesystem18__weakly_canonicalERKNS1_4pathEPNS_10error_codeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem18__weakly_canonicalERKNS1_4pathEPNS_10error_codeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4pathC2IA1_cvEERKT_NS2_6formatE = Module["__ZNSt3__24__fs10filesystem4pathC2IA1_cvEERKT_NS2_6formatE"] = function() {
                return (__ZNSt3__24__fs10filesystem4pathC2IA1_cvEERKT_NS2_6formatE = Module["__ZNSt3__24__fs10filesystem4pathC2IA1_cvEERKT_NS2_6formatE"] = Module["asm"]["_ZNSt3__24__fs10filesystem4pathC2IA1_cvEERKT_NS2_6formatE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4path9__reserveEm = Module["__ZNSt3__24__fs10filesystem4path9__reserveEm"] = function() {
                return (__ZNSt3__24__fs10filesystem4path9__reserveEm = Module["__ZNSt3__24__fs10filesystem4path9__reserveEm"] = Module["asm"]["_ZNSt3__24__fs10filesystem4path9__reserveEm"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEEC2Ev = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEEC2Ev"] = function() {
                return (__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEEC2Ev = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEEC2Ev"] = Module["asm"]["_ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEEC2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE4backEv = Module["__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE4backEv"] = function() {
                return (__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE4backEv = Module["__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE4backEv"] = Module["asm"]["_ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE4backEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4path6assignINS_17basic_string_viewIcNS_11char_traitsIcEEEEEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS9_ = Module["__ZNSt3__24__fs10filesystem4path6assignINS_17basic_string_viewIcNS_11char_traitsIcEEEEEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS9_"] = function() {
                return (__ZNSt3__24__fs10filesystem4path6assignINS_17basic_string_viewIcNS_11char_traitsIcEEEEEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS9_ = Module["__ZNSt3__24__fs10filesystem4path6assignINS_17basic_string_viewIcNS_11char_traitsIcEEEEEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS9_"] = Module["asm"]["_ZNSt3__24__fs10filesystem4path6assignINS_17basic_string_viewIcNS_11char_traitsIcEEEEEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS9_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE9push_backEOS4_ = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE9push_backEOS4_"] = function() {
                return (__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE9push_backEOS4_ = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE9push_backEOS4_"] = Module["asm"]["_ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE9push_backEOS4_"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE5emptyEv = Module["__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE5emptyEv"] = function() {
                return (__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE5emptyEv = Module["__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE5emptyEv"] = Module["asm"]["_ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE5emptyEv"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE6rbeginEv = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE6rbeginEv"] = function() {
                return (__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE6rbeginEv = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE6rbeginEv"] = Module["asm"]["_ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE6rbeginEv"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE4rendEv = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE4rendEv"] = function() {
                return (__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE4rendEv = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE4rendEv"] = Module["asm"]["_ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE4rendEv"]).apply(null, arguments)
            };
            var __ZNSt3__2neINS_11__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEES7_EEbRKNS_16reverse_iteratorIT_EERKNS8_IT0_EE = Module["__ZNSt3__2neINS_11__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEES7_EEbRKNS_16reverse_iteratorIT_EERKNS8_IT0_EE"] = function() {
                return (__ZNSt3__2neINS_11__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEES7_EEbRKNS_16reverse_iteratorIT_EERKNS8_IT0_EE = Module["__ZNSt3__2neINS_11__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEES7_EEbRKNS_16reverse_iteratorIT_EERKNS8_IT0_EE"] = Module["asm"]["_ZNSt3__2neINS_11__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEES7_EEbRKNS_16reverse_iteratorIT_EERKNS8_IT0_EE"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem4path16lexically_normalEv = Module["__ZNKSt3__24__fs10filesystem4path16lexically_normalEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem4path16lexically_normalEv = Module["__ZNKSt3__24__fs10filesystem4path16lexically_normalEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem4path16lexically_normalEv"]).apply(null, arguments)
            };
            var __ZNKSt3__216reverse_iteratorINS_11__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEEdeEv = Module["__ZNKSt3__216reverse_iteratorINS_11__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEEdeEv"] = function() {
                return (__ZNKSt3__216reverse_iteratorINS_11__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEEdeEv = Module["__ZNKSt3__216reverse_iteratorINS_11__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEEdeEv"] = Module["asm"]["_ZNKSt3__216reverse_iteratorINS_11__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEEdeEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4pathdVINS_17basic_string_viewIcNS_11char_traitsIcEEEEEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS9_ = Module["__ZNSt3__24__fs10filesystem4pathdVINS_17basic_string_viewIcNS_11char_traitsIcEEEEEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS9_"] = function() {
                return (__ZNSt3__24__fs10filesystem4pathdVINS_17basic_string_viewIcNS_11char_traitsIcEEEEEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS9_ = Module["__ZNSt3__24__fs10filesystem4pathdVINS_17basic_string_viewIcNS_11char_traitsIcEEEEEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS9_"] = Module["asm"]["_ZNSt3__24__fs10filesystem4pathdVINS_17basic_string_viewIcNS_11char_traitsIcEEEEEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS9_"]).apply(null, arguments)
            };
            var __ZNSt3__216reverse_iteratorINS_11__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEEppEv = Module["__ZNSt3__216reverse_iteratorINS_11__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEEppEv"] = function() {
                return (__ZNSt3__216reverse_iteratorINS_11__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEEppEv = Module["__ZNSt3__216reverse_iteratorINS_11__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEEppEv"] = Module["asm"]["_ZNSt3__216reverse_iteratorINS_11__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEEppEv"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEED2Ev = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEED2Ev"] = function() {
                return (__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEED2Ev = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEED2Ev"] = Module["asm"]["_ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceIA1_cEEvRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKT_ = Module["__ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceIA1_cEEvRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKT_"] = function() {
                return (__ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceIA1_cEEvRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKT_ = Module["__ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceIA1_cEEvRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKT_"] = Module["asm"]["_ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceIA1_cEEvRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKT_"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEEC2Ev = Module["__ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEEC2Ev"] = function() {
                return (__ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEEC2Ev = Module["__ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEEC2Ev"] = Module["asm"]["_ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE9__end_capEv = Module["__ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE9__end_capEv"] = function() {
                return (__ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE9__end_capEv = Module["__ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE9__end_capEv"] = Module["asm"]["_ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE9__end_capEv"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEONS_16remove_referenceIT_E4typeEOS7_ = Module["__ZNSt3__24moveIRNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEONS_16remove_referenceIT_E4typeEOS7_"] = function() {
                return (__ZNSt3__24moveIRNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEONS_16remove_referenceIT_E4typeEOS7_ = Module["__ZNSt3__24moveIRNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEONS_16remove_referenceIT_E4typeEOS7_"] = Module["asm"]["_ZNSt3__24moveIRNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEONS_16remove_referenceIT_E4typeEOS7_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE22__construct_one_at_endIJS4_EEEvDpOT_ = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE22__construct_one_at_endIJS4_EEEvDpOT_"] = function() {
                return (__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE22__construct_one_at_endIJS4_EEEvDpOT_ = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE22__construct_one_at_endIJS4_EEEvDpOT_"] = Module["asm"]["_ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE22__construct_one_at_endIJS4_EEEvDpOT_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE21__push_back_slow_pathIS4_EEvOT_ = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE21__push_back_slow_pathIS4_EEvOT_"] = function() {
                return (__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE21__push_back_slow_pathIS4_EEvOT_ = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE21__push_back_slow_pathIS4_EEvOT_"] = Module["asm"]["_ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE21__push_back_slow_pathIS4_EEvOT_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE3endEv = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE3endEv"] = function() {
                return (__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE3endEv = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE3endEv"] = Module["asm"]["_ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE3endEv"]).apply(null, arguments)
            };
            var __ZNSt3__216reverse_iteratorINS_11__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEEC2ES7_ = Module["__ZNSt3__216reverse_iteratorINS_11__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEEC2ES7_"] = function() {
                return (__ZNSt3__216reverse_iteratorINS_11__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEEC2ES7_ = Module["__ZNSt3__216reverse_iteratorINS_11__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEEC2ES7_"] = Module["asm"]["_ZNSt3__216reverse_iteratorINS_11__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEEC2ES7_"]).apply(null, arguments)
            };
            var __ZNKSt3__216reverse_iteratorINS_11__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE4baseEv = Module["__ZNKSt3__216reverse_iteratorINS_11__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE4baseEv"] = function() {
                return (__ZNKSt3__216reverse_iteratorINS_11__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE4baseEv = Module["__ZNKSt3__216reverse_iteratorINS_11__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE4baseEv"] = Module["asm"]["_ZNKSt3__216reverse_iteratorINS_11__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE4baseEv"]).apply(null, arguments)
            };
            var __ZNSt3__2neIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEbRKNS_11__wrap_iterIT_EESA_ = Module["__ZNSt3__2neIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEbRKNS_11__wrap_iterIT_EESA_"] = function() {
                return (__ZNSt3__2neIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEbRKNS_11__wrap_iterIT_EESA_ = Module["__ZNSt3__2neIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEbRKNS_11__wrap_iterIT_EESA_"] = Module["asm"]["_ZNSt3__2neIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEbRKNS_11__wrap_iterIT_EESA_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE5beginEv = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE5beginEv"] = function() {
                return (__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE5beginEv = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE5beginEv"] = Module["asm"]["_ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE5beginEv"]).apply(null, arguments)
            };
            var __ZNSt3__211__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEmmEv = Module["__ZNSt3__211__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEmmEv"] = function() {
                return (__ZNSt3__211__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEmmEv = Module["__ZNSt3__211__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEmmEv"] = Module["asm"]["_ZNSt3__211__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEmmEv"]).apply(null, arguments)
            };
            var __ZNKSt3__211__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEdeEv = Module["__ZNKSt3__211__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEdeEv"] = function() {
                return (__ZNKSt3__211__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEdeEv = Module["__ZNKSt3__211__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEdeEv"] = Module["asm"]["_ZNKSt3__211__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEdeEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4path6appendINS_17basic_string_viewIcNS_11char_traitsIcEEEEEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS9_ = Module["__ZNSt3__24__fs10filesystem4path6appendINS_17basic_string_viewIcNS_11char_traitsIcEEEEEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS9_"] = function() {
                return (__ZNSt3__24__fs10filesystem4path6appendINS_17basic_string_viewIcNS_11char_traitsIcEEEEEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS9_ = Module["__ZNSt3__24__fs10filesystem4path6appendINS_17basic_string_viewIcNS_11char_traitsIcEEEEEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS9_"] = Module["asm"]["_ZNSt3__24__fs10filesystem4path6appendINS_17basic_string_viewIcNS_11char_traitsIcEEEEEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS9_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEEC2Ev = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEEC2Ev"] = function() {
                return (__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEEC2Ev = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEEC2Ev"] = Module["asm"]["_ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE7reserveEm = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE7reserveEm"] = function() {
                return (__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE7reserveEm = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE7reserveEm"] = Module["asm"]["_ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE7reserveEm"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE5emptyEv = Module["__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE5emptyEv"] = function() {
                return (__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE5emptyEv = Module["__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE5emptyEv"] = Module["asm"]["_ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE5emptyEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4pathC2IA2_cvEERKT_NS2_6formatE = Module["__ZNSt3__24__fs10filesystem4pathC2IA2_cvEERKT_NS2_6formatE"] = function() {
                return (__ZNSt3__24__fs10filesystem4pathC2IA2_cvEERKT_NS2_6formatE = Module["__ZNSt3__24__fs10filesystem4pathC2IA2_cvEERKT_NS2_6formatE"] = Module["asm"]["_ZNSt3__24__fs10filesystem4pathC2IA2_cvEERKT_NS2_6formatE"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE4backEv = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE4backEv"] = function() {
                return (__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE4backEv = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE4backEv"] = Module["asm"]["_ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE4backEv"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE8pop_backEv = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE8pop_backEv"] = function() {
                return (__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE8pop_backEv = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE8pop_backEv"] = Module["asm"]["_ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE8pop_backEv"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE4sizeEv = Module["__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE4sizeEv"] = function() {
                return (__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE4sizeEv = Module["__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE4sizeEv"] = Module["asm"]["_ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE4sizeEv"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE5beginEv = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE5beginEv"] = function() {
                return (__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE5beginEv = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE5beginEv"] = Module["asm"]["_ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE5beginEv"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE3endEv = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE3endEv"] = function() {
                return (__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE3endEv = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE3endEv"] = Module["asm"]["_ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE3endEv"]).apply(null, arguments)
            };
            var __ZNSt3__2neIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEbRKNS_11__wrap_iterIT_EESF_ = Module["__ZNSt3__2neIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEbRKNS_11__wrap_iterIT_EESF_"] = function() {
                return (__ZNSt3__2neIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEbRKNS_11__wrap_iterIT_EESF_ = Module["__ZNSt3__2neIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEbRKNS_11__wrap_iterIT_EESF_"] = Module["asm"]["_ZNSt3__2neIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEbRKNS_11__wrap_iterIT_EESF_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4pathdVIA1_cEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS6_ = Module["__ZNSt3__24__fs10filesystem4pathdVIA1_cEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS6_"] = function() {
                return (__ZNSt3__24__fs10filesystem4pathdVIA1_cEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS6_ = Module["__ZNSt3__24__fs10filesystem4pathdVIA1_cEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS6_"] = Module["asm"]["_ZNSt3__24__fs10filesystem4pathdVIA1_cEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS6_"]).apply(null, arguments)
            };
            var __ZNKSt3__211__wrap_iterIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEdeEv = Module["__ZNKSt3__211__wrap_iterIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEdeEv"] = function() {
                return (__ZNKSt3__211__wrap_iterIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEdeEv = Module["__ZNKSt3__211__wrap_iterIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEdeEv"] = Module["asm"]["_ZNKSt3__211__wrap_iterIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEdeEv"]).apply(null, arguments)
            };
            var __ZNSt3__211__wrap_iterIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEppEv = Module["__ZNSt3__211__wrap_iterIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEppEv"] = function() {
                return (__ZNSt3__211__wrap_iterIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEppEv = Module["__ZNSt3__211__wrap_iterIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEppEv"] = Module["asm"]["_ZNSt3__211__wrap_iterIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEppEv"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEED2Ev = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEED2Ev"] = function() {
                return (__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEED2Ev = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEED2Ev"] = Module["asm"]["_ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEED2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE17__annotate_deleteEv = Module["__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE17__annotate_deleteEv"] = function() {
                return (__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE17__annotate_deleteEv = Module["__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE17__annotate_deleteEv"] = Module["asm"]["_ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE17__annotate_deleteEv"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEED2Ev = Module["__ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEED2Ev"] = function() {
                return (__ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEED2Ev = Module["__ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEED2Ev"] = Module["asm"]["_ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4path17replace_extensionERKS2_ = Module["__ZNSt3__24__fs10filesystem4path17replace_extensionERKS2_"] = function() {
                return (__ZNSt3__24__fs10filesystem4path17replace_extensionERKS2_ = Module["__ZNSt3__24__fs10filesystem4path17replace_extensionERKS2_"] = Module["asm"]["_ZNSt3__24__fs10filesystem4path17replace_extensionERKS2_"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem4path9extensionEv = Module["__ZNKSt3__24__fs10filesystem4path9extensionEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem4path9extensionEv = Module["__ZNKSt3__24__fs10filesystem4path9extensionEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem4path9extensionEv"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem4path11__extensionEv = Module["__ZNKSt3__24__fs10filesystem4path11__extensionEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem4path11__extensionEv = Module["__ZNKSt3__24__fs10filesystem4path11__extensionEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem4path11__extensionEv"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem4path11__root_nameEv = Module["__ZNKSt3__24__fs10filesystem4path11__root_nameEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem4path11__root_nameEv = Module["__ZNKSt3__24__fs10filesystem4path11__root_nameEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem4path11__root_nameEv"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem4path15__root_path_rawEv = Module["__ZNKSt3__24__fs10filesystem4path15__root_path_rawEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem4path15__root_path_rawEv = Module["__ZNKSt3__24__fs10filesystem4path15__root_path_rawEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem4path15__root_path_rawEv"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem4path15__relative_pathEv = Module["__ZNKSt3__24__fs10filesystem4path15__relative_pathEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem4path15__relative_pathEv = Module["__ZNKSt3__24__fs10filesystem4path15__relative_pathEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem4path15__relative_pathEv"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4backEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4backEv"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4backEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4backEv"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4backEv"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem4path6__stemEv = Module["__ZNKSt3__24__fs10filesystem4path6__stemEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem4path6__stemEv = Module["__ZNKSt3__24__fs10filesystem4path6__stemEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem4path6__stemEv"]).apply(null, arguments)
            };
            var __ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEES4_EC2IRKS4_RA1_KcLb0EEEOT_OT0_ = Module["__ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEES4_EC2IRKS4_RA1_KcLb0EEEOT_OT0_"] = function() {
                return (__ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEES4_EC2IRKS4_RA1_KcLb0EEEOT_OT0_ = Module["__ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEES4_EC2IRKS4_RA1_KcLb0EEEOT_OT0_"] = Module["asm"]["_ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEES4_EC2IRKS4_RA1_KcLb0EEEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE12find_last_ofEcm = Module["__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE12find_last_ofEcm"] = function() {
                return (__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE12find_last_ofEcm = Module["__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE12find_last_ofEcm"] = Module["asm"]["_ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE12find_last_ofEcm"]).apply(null, arguments)
            };
            var __ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEES4_EC2IRKS4_S4_Lb0EEEOT_OT0_ = Module["__ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEES4_EC2IRKS4_S4_Lb0EEEOT_OT0_"] = function() {
                return (__ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEES4_EC2IRKS4_S4_Lb0EEEOT_OT0_ = Module["__ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEES4_EC2IRKS4_S4_Lb0EEEOT_OT0_"] = Module["asm"]["_ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEES4_EC2IRKS4_S4_Lb0EEEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEES4_EC2IS4_S4_Lb0EEEOT_OT0_ = Module["__ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEES4_EC2IS4_S4_Lb0EEEOT_OT0_"] = function() {
                return (__ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEES4_EC2IS4_S4_Lb0EEEOT_OT0_ = Module["__ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEES4_EC2IS4_S4_Lb0EEEOT_OT0_"] = Module["asm"]["_ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEES4_EC2IS4_S4_Lb0EEEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEEC2Ev = Module["__ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEEC2Ev"] = function() {
                return (__ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEEC2Ev = Module["__ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEEC2Ev"] = Module["asm"]["_ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEEC2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE8capacityEv = Module["__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE8capacityEv"] = function() {
                return (__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE8capacityEv = Module["__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE8capacityEv"] = Module["asm"]["_ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE8capacityEv"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE7__allocEv = Module["__ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE7__allocEv"] = function() {
                return (__ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE7__allocEv = Module["__ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE7__allocEv"] = Module["asm"]["_ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE7__allocEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEEC2EmmSC_ = Module["__ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEEC2EmmSC_"] = function() {
                return (__ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEEC2EmmSC_ = Module["__ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEEC2EmmSC_"] = Module["asm"]["_ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEEC2EmmSC_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS9_RSB_EE = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS9_RSB_EE"] = function() {
                return (__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS9_RSB_EE = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS9_RSB_EE"] = Module["asm"]["_ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS9_RSB_EE"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEED2Ev = Module["__ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEED2Ev"] = function() {
                return (__ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEED2Ev = Module["__ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEED2Ev"] = Module["asm"]["_ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE12emplace_backIJRS5_RS8_EEEvDpOT_ = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE12emplace_backIJRS5_RS8_EEEvDpOT_"] = function() {
                return (__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE12emplace_backIJRS5_RS8_EEEvDpOT_ = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE12emplace_backIJRS5_RS8_EEEvDpOT_"] = Module["asm"]["_ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE12emplace_backIJRS5_RS8_EEEvDpOT_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE17__destruct_at_endEPS9_ = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE17__destruct_at_endEPS9_"] = function() {
                return (__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE17__destruct_at_endEPS9_ = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE17__destruct_at_endEPS9_"] = Module["asm"]["_ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE17__destruct_at_endEPS9_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceIA2_cEEvRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKT_ = Module["__ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceIA2_cEEvRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKT_"] = function() {
                return (__ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceIA2_cEEvRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKT_ = Module["__ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceIA2_cEEvRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKT_"] = Module["asm"]["_ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceIA2_cEEvRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKT_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE11__make_iterEPS9_ = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE11__make_iterEPS9_"] = function() {
                return (__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE11__make_iterEPS9_ = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE11__make_iterEPS9_"] = Module["asm"]["_ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE11__make_iterEPS9_"]).apply(null, arguments)
            };
            var __ZNSt3__2eqIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEESA_EEbRKNS_11__wrap_iterIT_EERKNSB_IT0_EE = Module["__ZNSt3__2eqIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEESA_EEbRKNS_11__wrap_iterIT_EERKNSB_IT0_EE"] = function() {
                return (__ZNSt3__2eqIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEESA_EEbRKNS_11__wrap_iterIT_EERKNSB_IT0_EE = Module["__ZNSt3__2eqIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEESA_EEbRKNS_11__wrap_iterIT_EERKNSB_IT0_EE"] = Module["asm"]["_ZNSt3__2eqIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEESA_EEbRKNS_11__wrap_iterIT_EERKNSB_IT0_EE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4path6appendIA1_cEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS6_ = Module["__ZNSt3__24__fs10filesystem4path6appendIA1_cEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS6_"] = function() {
                return (__ZNSt3__24__fs10filesystem4path6appendIA1_cEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS6_ = Module["__ZNSt3__24__fs10filesystem4path6appendIA1_cEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS6_"] = Module["asm"]["_ZNSt3__24__fs10filesystem4path6appendIA1_cEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS6_"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE17__annotate_deleteEv = Module["__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE17__annotate_deleteEv"] = function() {
                return (__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE17__annotate_deleteEv = Module["__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE17__annotate_deleteEv"] = Module["asm"]["_ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE17__annotate_deleteEv"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEED2Ev = Module["__ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEED2Ev"] = function() {
                return (__ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEED2Ev = Module["__ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEED2Ev"] = Module["asm"]["_ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEED2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem4path18lexically_relativeERKS2_ = Module["__ZNKSt3__24__fs10filesystem4path18lexically_relativeERKS2_"] = function() {
                return (__ZNKSt3__24__fs10filesystem4path18lexically_relativeERKS2_ = Module["__ZNKSt3__24__fs10filesystem4path18lexically_relativeERKS2_"] = Module["asm"]["_ZNKSt3__24__fs10filesystem4path18lexically_relativeERKS2_"]).apply(null, arguments)
            };
            var __ZNSt3__2neIcNS_11char_traitsIcEEEEbNS_17basic_string_viewIT_T0_EES6_ = Module["__ZNSt3__2neIcNS_11char_traitsIcEEEEbNS_17basic_string_viewIT_T0_EES6_"] = function() {
                return (__ZNSt3__2neIcNS_11char_traitsIcEEEEbNS_17basic_string_viewIT_T0_EES6_ = Module["__ZNSt3__2neIcNS_11char_traitsIcEEEEbNS_17basic_string_viewIT_T0_EES6_"] = Module["asm"]["_ZNSt3__2neIcNS_11char_traitsIcEEEEbNS_17basic_string_viewIT_T0_EES6_"]).apply(null, arguments)
            };
            var __ZNSt3__2eqIcNS_11char_traitsIcEEEEbNS_17basic_string_viewIT_T0_EES6_ = Module["__ZNSt3__2eqIcNS_11char_traitsIcEEEEbNS_17basic_string_viewIT_T0_EES6_"] = function() {
                return (__ZNSt3__2eqIcNS_11char_traitsIcEEEEbNS_17basic_string_viewIT_T0_EES6_ = Module["__ZNSt3__2eqIcNS_11char_traitsIcEEEEbNS_17basic_string_viewIT_T0_EES6_"] = Module["asm"]["_ZNSt3__2eqIcNS_11char_traitsIcEEEEbNS_17basic_string_viewIT_T0_EES6_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4pathdVIA3_cEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS6_ = Module["__ZNSt3__24__fs10filesystem4pathdVIA3_cEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS6_"] = function() {
                return (__ZNSt3__24__fs10filesystem4pathdVIA3_cEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS6_ = Module["__ZNSt3__24__fs10filesystem4pathdVIA3_cEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS6_"] = Module["asm"]["_ZNSt3__24__fs10filesystem4pathdVIA3_cEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS6_"]).apply(null, arguments)
            };
            var __ZNSt3__2neIcNS_11char_traitsIcEEEEbNS_17basic_string_viewIT_T0_EENS_11common_typeIJS6_EE4typeE = Module["__ZNSt3__2neIcNS_11char_traitsIcEEEEbNS_17basic_string_viewIT_T0_EENS_11common_typeIJS6_EE4typeE"] = function() {
                return (__ZNSt3__2neIcNS_11char_traitsIcEEEEbNS_17basic_string_viewIT_T0_EENS_11common_typeIJS6_EE4typeE = Module["__ZNSt3__2neIcNS_11char_traitsIcEEEEbNS_17basic_string_viewIT_T0_EENS_11common_typeIJS6_EE4typeE"] = Module["asm"]["_ZNSt3__2neIcNS_11char_traitsIcEEEEbNS_17basic_string_viewIT_T0_EENS_11common_typeIJS6_EE4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4path6appendIA3_cEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS6_ = Module["__ZNSt3__24__fs10filesystem4path6appendIA3_cEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS6_"] = function() {
                return (__ZNSt3__24__fs10filesystem4path6appendIA3_cEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS6_ = Module["__ZNSt3__24__fs10filesystem4path6appendIA3_cEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS6_"] = Module["asm"]["_ZNSt3__24__fs10filesystem4path6appendIA3_cEENS_9enable_ifIXsr13__is_pathableIT_EE5valueERS2_E4typeERKS6_"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem4path9__compareENS_17basic_string_viewIcNS_11char_traitsIcEEEE = Module["__ZNKSt3__24__fs10filesystem4path9__compareENS_17basic_string_viewIcNS_11char_traitsIcEEEE"] = function() {
                return (__ZNKSt3__24__fs10filesystem4path9__compareENS_17basic_string_viewIcNS_11char_traitsIcEEEE = Module["__ZNKSt3__24__fs10filesystem4path9__compareENS_17basic_string_viewIcNS_11char_traitsIcEEEE"] = Module["asm"]["_ZNKSt3__24__fs10filesystem4path9__compareENS_17basic_string_viewIcNS_11char_traitsIcEEEE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem10hash_valueERKNS1_4pathE = Module["__ZNSt3__24__fs10filesystem10hash_valueERKNS1_4pathE"] = function() {
                return (__ZNSt3__24__fs10filesystem10hash_valueERKNS1_4pathE = Module["__ZNSt3__24__fs10filesystem10hash_valueERKNS1_4pathE"] = Module["asm"]["_ZNSt3__24__fs10filesystem10hash_valueERKNS1_4pathE"]).apply(null, arguments)
            };
            var __ZNKSt3__24hashINS_17basic_string_viewIcNS_11char_traitsIcEEEEEclES4_ = Module["__ZNKSt3__24hashINS_17basic_string_viewIcNS_11char_traitsIcEEEEEclES4_"] = function() {
                return (__ZNKSt3__24hashINS_17basic_string_viewIcNS_11char_traitsIcEEEEEclES4_ = Module["__ZNKSt3__24hashINS_17basic_string_viewIcNS_11char_traitsIcEEEEEclES4_"] = Module["asm"]["_ZNKSt3__24hashINS_17basic_string_viewIcNS_11char_traitsIcEEEEEclES4_"]).apply(null, arguments)
            };
            var __ZNSt3__214__hash_combineEmm = Module["__ZNSt3__214__hash_combineEmm"] = function() {
                return (__ZNSt3__214__hash_combineEmm = Module["__ZNSt3__214__hash_combineEmm"] = Module["asm"]["_ZNSt3__214__hash_combineEmm"]).apply(null, arguments)
            };
            var __ZNKSt3__213__scalar_hashINS_6_PairTELm2EEclES1_ = Module["__ZNKSt3__213__scalar_hashINS_6_PairTELm2EEclES1_"] = function() {
                return (__ZNKSt3__213__scalar_hashINS_6_PairTELm2EEclES1_ = Module["__ZNKSt3__213__scalar_hashINS_6_PairTELm2EEclES1_"] = Module["asm"]["_ZNKSt3__213__scalar_hashINS_6_PairTELm2EEclES1_"]).apply(null, arguments)
            };
            var __ZNSt3__216__do_string_hashIPKcEEmT_S3_ = Module["__ZNSt3__216__do_string_hashIPKcEEmT_S3_"] = function() {
                return (__ZNSt3__216__do_string_hashIPKcEEmT_S3_ = Module["__ZNSt3__216__do_string_hashIPKcEEmT_S3_"] = Module["asm"]["_ZNSt3__216__do_string_hashIPKcEEmT_S3_"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem4path5beginEv = Module["__ZNKSt3__24__fs10filesystem4path5beginEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem4path5beginEv = Module["__ZNKSt3__24__fs10filesystem4path5beginEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem4path5beginEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4path8iteratorC2Ev = Module["__ZNSt3__24__fs10filesystem4path8iteratorC2Ev"] = function() {
                return (__ZNSt3__24__fs10filesystem4path8iteratorC2Ev = Module["__ZNSt3__24__fs10filesystem4path8iteratorC2Ev"] = Module["asm"]["_ZNSt3__24__fs10filesystem4path8iteratorC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4path13__assign_viewERKNS_17basic_string_viewIcNS_11char_traitsIcEEEE = Module["__ZNSt3__24__fs10filesystem4path13__assign_viewERKNS_17basic_string_viewIcNS_11char_traitsIcEEEE"] = function() {
                return (__ZNSt3__24__fs10filesystem4path13__assign_viewERKNS_17basic_string_viewIcNS_11char_traitsIcEEEE = Module["__ZNSt3__24__fs10filesystem4path13__assign_viewERKNS_17basic_string_viewIcNS_11char_traitsIcEEEE"] = Module["asm"]["_ZNSt3__24__fs10filesystem4path13__assign_viewERKNS_17basic_string_viewIcNS_11char_traitsIcEEEE"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem4path3endEv = Module["__ZNKSt3__24__fs10filesystem4path3endEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem4path3endEv = Module["__ZNKSt3__24__fs10filesystem4path3endEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem4path3endEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4path8iterator11__incrementEv = Module["__ZNSt3__24__fs10filesystem4path8iterator11__incrementEv"] = function() {
                return (__ZNSt3__24__fs10filesystem4path8iterator11__incrementEv = Module["__ZNSt3__24__fs10filesystem4path8iterator11__incrementEv"] = Module["asm"]["_ZNSt3__24__fs10filesystem4path8iterator11__incrementEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4path8iterator11__decrementEv = Module["__ZNSt3__24__fs10filesystem4path8iterator11__decrementEv"] = function() {
                return (__ZNSt3__24__fs10filesystem4path8iterator11__decrementEv = Module["__ZNSt3__24__fs10filesystem4path8iterator11__decrementEv"] = Module["asm"]["_ZNSt3__24__fs10filesystem4path8iterator11__decrementEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem15directory_entry12__do_refreshEv = Module["__ZNSt3__24__fs10filesystem15directory_entry12__do_refreshEv"] = function() {
                return (__ZNSt3__24__fs10filesystem15directory_entry12__do_refreshEv = Module["__ZNSt3__24__fs10filesystem15directory_entry12__do_refreshEv"] = Module["asm"]["_ZNSt3__24__fs10filesystem15directory_entry12__do_refreshEv"]).apply(null, arguments)
            };
            var __ZNKSt3__24__fs10filesystem16filesystem_error4whatEv = Module["__ZNKSt3__24__fs10filesystem16filesystem_error4whatEv"] = function() {
                return (__ZNKSt3__24__fs10filesystem16filesystem_error4whatEv = Module["__ZNKSt3__24__fs10filesystem16filesystem_error4whatEv"] = Module["asm"]["_ZNKSt3__24__fs10filesystem16filesystem_error4whatEv"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono13duration_castINS0_8durationInNS_5ratioILx1ELx1000000000EEEEEnNS3_ILx1ELx1EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE = Module["__ZNSt3__26chrono13duration_castINS0_8durationInNS_5ratioILx1ELx1000000000EEEEEnNS3_ILx1ELx1EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"] = function() {
                return (__ZNSt3__26chrono13duration_castINS0_8durationInNS_5ratioILx1ELx1000000000EEEEEnNS3_ILx1ELx1EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE = Module["__ZNSt3__26chrono13duration_castINS0_8durationInNS_5ratioILx1ELx1000000000EEEEEnNS3_ILx1ELx1EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"] = Module["asm"]["_ZNSt3__26chrono13duration_castINS0_8durationInNS_5ratioILx1ELx1000000000EEEEEnNS3_ILx1ELx1EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"]).apply(null, arguments)
            };
            var __ZNKSt3__26chrono15__duration_castINS0_8durationInNS_5ratioILx1ELx1EEEEENS2_InNS3_ILx1ELx1000000000EEEEENS3_ILx1000000000ELx1EEELb0ELb1EEclERKS5_ = Module["__ZNKSt3__26chrono15__duration_castINS0_8durationInNS_5ratioILx1ELx1EEEEENS2_InNS3_ILx1ELx1000000000EEEEENS3_ILx1000000000ELx1EEELb0ELb1EEclERKS5_"] = function() {
                return (__ZNKSt3__26chrono15__duration_castINS0_8durationInNS_5ratioILx1ELx1EEEEENS2_InNS3_ILx1ELx1000000000EEEEENS3_ILx1000000000ELx1EEELb0ELb1EEclERKS5_ = Module["__ZNKSt3__26chrono15__duration_castINS0_8durationInNS_5ratioILx1ELx1EEEEENS2_InNS3_ILx1ELx1000000000EEEEENS3_ILx1000000000ELx1EEELb0ELb1EEclERKS5_"] = Module["asm"]["_ZNKSt3__26chrono15__duration_castINS0_8durationInNS_5ratioILx1ELx1EEEEENS2_InNS3_ILx1ELx1000000000EEEEENS3_ILx1000000000ELx1EEELb0ELb1EEclERKS5_"]).apply(null, arguments)
            };
            var __ZNKSt3__26chrono8durationInNS_5ratioILx1ELx1EEEE5countEv = Module["__ZNKSt3__26chrono8durationInNS_5ratioILx1ELx1EEEE5countEv"] = function() {
                return (__ZNKSt3__26chrono8durationInNS_5ratioILx1ELx1EEEE5countEv = Module["__ZNKSt3__26chrono8durationInNS_5ratioILx1ELx1EEEE5countEv"] = Module["asm"]["_ZNKSt3__26chrono8durationInNS_5ratioILx1ELx1EEEE5countEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem11file_statusC2Ev = Module["__ZNSt3__24__fs10filesystem11file_statusC2Ev"] = function() {
                return (__ZNSt3__24__fs10filesystem11file_statusC2Ev = Module["__ZNSt3__24__fs10filesystem11file_statusC2Ev"] = Module["asm"]["_ZNSt3__24__fs10filesystem11file_statusC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem11file_status4typeENS1_9file_typeE = Module["__ZNSt3__24__fs10filesystem11file_status4typeENS1_9file_typeE"] = function() {
                return (__ZNSt3__24__fs10filesystem11file_status4typeENS1_9file_typeE = Module["__ZNSt3__24__fs10filesystem11file_status4typeENS1_9file_typeE"] = Module["asm"]["_ZNSt3__24__fs10filesystem11file_status4typeENS1_9file_typeE"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem11file_status11permissionsENS1_5permsE = Module["__ZNSt3__24__fs10filesystem11file_status11permissionsENS1_5permsE"] = function() {
                return (__ZNSt3__24__fs10filesystem11file_status11permissionsENS1_5permsE = Module["__ZNSt3__24__fs10filesystem11file_status11permissionsENS1_5permsE"] = Module["asm"]["_ZNSt3__24__fs10filesystem11file_status11permissionsENS1_5permsE"]).apply(null, arguments)
            };
            var __ZNSt3__214basic_ifstreamIcNS_11char_traitsIcEEEC1Ev = Module["__ZNSt3__214basic_ifstreamIcNS_11char_traitsIcEEEC1Ev"] = function() {
                return (__ZNSt3__214basic_ifstreamIcNS_11char_traitsIcEEEC1Ev = Module["__ZNSt3__214basic_ifstreamIcNS_11char_traitsIcEEEC1Ev"] = Module["asm"]["_ZNSt3__214basic_ifstreamIcNS_11char_traitsIcEEEC1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214basic_ifstreamIcNS_11char_traitsIcEEE6__openEij = Module["__ZNSt3__214basic_ifstreamIcNS_11char_traitsIcEEE6__openEij"] = function() {
                return (__ZNSt3__214basic_ifstreamIcNS_11char_traitsIcEEE6__openEij = Module["__ZNSt3__214basic_ifstreamIcNS_11char_traitsIcEEE6__openEij"] = Module["asm"]["_ZNSt3__214basic_ifstreamIcNS_11char_traitsIcEEE6__openEij"]).apply(null, arguments)
            };
            var __ZNKSt3__214basic_ifstreamIcNS_11char_traitsIcEEE7is_openEv = Module["__ZNKSt3__214basic_ifstreamIcNS_11char_traitsIcEEE7is_openEv"] = function() {
                return (__ZNKSt3__214basic_ifstreamIcNS_11char_traitsIcEEE7is_openEv = Module["__ZNKSt3__214basic_ifstreamIcNS_11char_traitsIcEEE7is_openEv"] = Module["asm"]["_ZNKSt3__214basic_ifstreamIcNS_11char_traitsIcEEE7is_openEv"]).apply(null, arguments)
            };
            var __ZNSt3__214basic_ofstreamIcNS_11char_traitsIcEEEC1Ev = Module["__ZNSt3__214basic_ofstreamIcNS_11char_traitsIcEEEC1Ev"] = function() {
                return (__ZNSt3__214basic_ofstreamIcNS_11char_traitsIcEEEC1Ev = Module["__ZNSt3__214basic_ofstreamIcNS_11char_traitsIcEEEC1Ev"] = Module["asm"]["_ZNSt3__214basic_ofstreamIcNS_11char_traitsIcEEEC1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214basic_ofstreamIcNS_11char_traitsIcEEE6__openEij = Module["__ZNSt3__214basic_ofstreamIcNS_11char_traitsIcEEE6__openEij"] = function() {
                return (__ZNSt3__214basic_ofstreamIcNS_11char_traitsIcEEE6__openEij = Module["__ZNSt3__214basic_ofstreamIcNS_11char_traitsIcEEE6__openEij"] = Module["asm"]["_ZNSt3__214basic_ofstreamIcNS_11char_traitsIcEEE6__openEij"]).apply(null, arguments)
            };
            var __ZNKSt3__214basic_ofstreamIcNS_11char_traitsIcEEE7is_openEv = Module["__ZNKSt3__214basic_ofstreamIcNS_11char_traitsIcEEE7is_openEv"] = function() {
                return (__ZNKSt3__214basic_ofstreamIcNS_11char_traitsIcEEE7is_openEv = Module["__ZNKSt3__214basic_ofstreamIcNS_11char_traitsIcEEE7is_openEv"] = Module["asm"]["_ZNKSt3__214basic_ofstreamIcNS_11char_traitsIcEEE7is_openEv"]).apply(null, arguments)
            };
            var __ZNSt3__24copyINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIcS3_EEEET0_T_S8_S7_ = Module["__ZNSt3__24copyINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIcS3_EEEET0_T_S8_S7_"] = function() {
                return (__ZNSt3__24copyINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIcS3_EEEET0_T_S8_S7_ = Module["__ZNSt3__24copyINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIcS3_EEEET0_T_S8_S7_"] = Module["asm"]["_ZNSt3__24copyINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIcS3_EEEET0_T_S8_S7_"]).apply(null, arguments)
            };
            var __ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE4failEv = Module["__ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE4failEv"] = function() {
                return (__ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE4failEv = Module["__ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE4failEv"] = Module["asm"]["_ZNKSt3__29basic_iosIcNS_11char_traitsIcEEE4failEv"]).apply(null, arguments)
            };
            var __ZNSt3__214basic_ofstreamIcNS_11char_traitsIcEEED1Ev = Module["__ZNSt3__214basic_ofstreamIcNS_11char_traitsIcEEED1Ev"] = function() {
                return (__ZNSt3__214basic_ofstreamIcNS_11char_traitsIcEEED1Ev = Module["__ZNSt3__214basic_ofstreamIcNS_11char_traitsIcEEED1Ev"] = Module["asm"]["_ZNSt3__214basic_ofstreamIcNS_11char_traitsIcEEED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214basic_ifstreamIcNS_11char_traitsIcEEED1Ev = Module["__ZNSt3__214basic_ifstreamIcNS_11char_traitsIcEEED1Ev"] = function() {
                return (__ZNSt3__214basic_ifstreamIcNS_11char_traitsIcEEED1Ev = Module["__ZNSt3__214basic_ifstreamIcNS_11char_traitsIcEEED1Ev"] = Module["asm"]["_ZNSt3__214basic_ifstreamIcNS_11char_traitsIcEEED1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_istreamIcNS_11char_traitsIcEEEC2EPNS_15basic_streambufIcS2_EE = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEEC2EPNS_15basic_streambufIcS2_EE"] = function() {
                return (__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEEC2EPNS_15basic_streambufIcS2_EE = Module["__ZNSt3__213basic_istreamIcNS_11char_traitsIcEEEC2EPNS_15basic_streambufIcS2_EE"] = Module["asm"]["_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEEC2EPNS_15basic_streambufIcS2_EE"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_filebufIcNS_11char_traitsIcEEEC2Ev = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEEC2Ev"] = function() {
                return (__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEEC2Ev = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEEC2Ev"] = Module["asm"]["_ZNSt3__213basic_filebufIcNS_11char_traitsIcEEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE6__openEij = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE6__openEij"] = function() {
                return (__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE6__openEij = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE6__openEij"] = Module["asm"]["_ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE6__openEij"]).apply(null, arguments)
            };
            var __ZNKSt3__213basic_filebufIcNS_11char_traitsIcEEE7is_openEv = Module["__ZNKSt3__213basic_filebufIcNS_11char_traitsIcEEE7is_openEv"] = function() {
                return (__ZNKSt3__213basic_filebufIcNS_11char_traitsIcEEE7is_openEv = Module["__ZNKSt3__213basic_filebufIcNS_11char_traitsIcEEE7is_openEv"] = Module["asm"]["_ZNKSt3__213basic_filebufIcNS_11char_traitsIcEEE7is_openEv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEEC2EPNS_15basic_streambufIcS2_EE = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEEC2EPNS_15basic_streambufIcS2_EE"] = function() {
                return (__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEEC2EPNS_15basic_streambufIcS2_EE = Module["__ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEEC2EPNS_15basic_streambufIcS2_EE"] = Module["asm"]["_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEEC2EPNS_15basic_streambufIcS2_EE"]).apply(null, arguments)
            };
            var __ZNSt3__213__unwrap_iterINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEET_S5_ = Module["__ZNSt3__213__unwrap_iterINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEET_S5_"] = function() {
                return (__ZNSt3__213__unwrap_iterINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEET_S5_ = Module["__ZNSt3__213__unwrap_iterINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEET_S5_"] = Module["asm"]["_ZNSt3__213__unwrap_iterINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEET_S5_"]).apply(null, arguments)
            };
            var __ZNSt3__26__copyINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIcS3_EEEET0_T_S8_S7_ = Module["__ZNSt3__26__copyINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIcS3_EEEET0_T_S8_S7_"] = function() {
                return (__ZNSt3__26__copyINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIcS3_EEEET0_T_S8_S7_ = Module["__ZNSt3__26__copyINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIcS3_EEEET0_T_S8_S7_"] = Module["asm"]["_ZNSt3__26__copyINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIcS3_EEEET0_T_S8_S7_"]).apply(null, arguments)
            };
            var __ZNKSt3__28ios_base4failEv = Module["__ZNKSt3__28ios_base4failEv"] = function() {
                return (__ZNKSt3__28ios_base4failEv = Module["__ZNKSt3__28ios_base4failEv"] = Module["asm"]["_ZNKSt3__28ios_base4failEv"]).apply(null, arguments)
            };
            var __ZNSt3__214basic_ofstreamIcNS_11char_traitsIcEEED2Ev = Module["__ZNSt3__214basic_ofstreamIcNS_11char_traitsIcEEED2Ev"] = function() {
                return (__ZNSt3__214basic_ofstreamIcNS_11char_traitsIcEEED2Ev = Module["__ZNSt3__214basic_ofstreamIcNS_11char_traitsIcEEED2Ev"] = Module["asm"]["_ZNSt3__214basic_ofstreamIcNS_11char_traitsIcEEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__214basic_ifstreamIcNS_11char_traitsIcEEED2Ev = Module["__ZNSt3__214basic_ifstreamIcNS_11char_traitsIcEEED2Ev"] = function() {
                return (__ZNSt3__214basic_ifstreamIcNS_11char_traitsIcEEED2Ev = Module["__ZNSt3__214basic_ifstreamIcNS_11char_traitsIcEEED2Ev"] = Module["asm"]["_ZNSt3__214basic_ifstreamIcNS_11char_traitsIcEEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__29has_facetINS_7codecvtIcc11__mbstate_tEEEEbRKNS_6localeE = Module["__ZNSt3__29has_facetINS_7codecvtIcc11__mbstate_tEEEEbRKNS_6localeE"] = function() {
                return (__ZNSt3__29has_facetINS_7codecvtIcc11__mbstate_tEEEEbRKNS_6localeE = Module["__ZNSt3__29has_facetINS_7codecvtIcc11__mbstate_tEEEEbRKNS_6localeE"] = Module["asm"]["_ZNSt3__29has_facetINS_7codecvtIcc11__mbstate_tEEEEbRKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNSt3__214basic_ifstreamIcNS_11char_traitsIcEEED0Ev = Module["__ZNSt3__214basic_ifstreamIcNS_11char_traitsIcEEED0Ev"] = function() {
                return (__ZNSt3__214basic_ifstreamIcNS_11char_traitsIcEEED0Ev = Module["__ZNSt3__214basic_ifstreamIcNS_11char_traitsIcEEED0Ev"] = Module["asm"]["_ZNSt3__214basic_ifstreamIcNS_11char_traitsIcEEED0Ev"]).apply(null, arguments)
            };
            var __ZTv0_n12_NSt3__214basic_ifstreamIcNS_11char_traitsIcEEED1Ev = Module["__ZTv0_n12_NSt3__214basic_ifstreamIcNS_11char_traitsIcEEED1Ev"] = function() {
                return (__ZTv0_n12_NSt3__214basic_ifstreamIcNS_11char_traitsIcEEED1Ev = Module["__ZTv0_n12_NSt3__214basic_ifstreamIcNS_11char_traitsIcEEED1Ev"] = Module["asm"]["_ZTv0_n12_NSt3__214basic_ifstreamIcNS_11char_traitsIcEEED1Ev"]).apply(null, arguments)
            };
            var __ZTv0_n12_NSt3__214basic_ifstreamIcNS_11char_traitsIcEEED0Ev = Module["__ZTv0_n12_NSt3__214basic_ifstreamIcNS_11char_traitsIcEEED0Ev"] = function() {
                return (__ZTv0_n12_NSt3__214basic_ifstreamIcNS_11char_traitsIcEEED0Ev = Module["__ZTv0_n12_NSt3__214basic_ifstreamIcNS_11char_traitsIcEEED0Ev"] = Module["asm"]["_ZTv0_n12_NSt3__214basic_ifstreamIcNS_11char_traitsIcEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_filebufIcNS_11char_traitsIcEEED2Ev = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEED2Ev"] = function() {
                return (__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEED2Ev = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEED2Ev"] = Module["asm"]["_ZNSt3__213basic_filebufIcNS_11char_traitsIcEEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE5closeEv = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE5closeEv"] = function() {
                return (__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE5closeEv = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE5closeEv"] = Module["asm"]["_ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE5closeEv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_filebufIcNS_11char_traitsIcEEED0Ev = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEED0Ev"] = function() {
                return (__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEED0Ev = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEED0Ev"] = Module["asm"]["_ZNSt3__213basic_filebufIcNS_11char_traitsIcEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE5imbueERKNS_6localeE = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE5imbueERKNS_6localeE"] = function() {
                return (__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE5imbueERKNS_6localeE = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE5imbueERKNS_6localeE"] = Module["asm"]["_ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE5imbueERKNS_6localeE"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE6setbufEPcl = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE6setbufEPcl"] = function() {
                return (__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE6setbufEPcl = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE6setbufEPcl"] = Module["asm"]["_ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE6setbufEPcl"]).apply(null, arguments)
            };
            var __ZNSt3__23maxIlEERKT_S3_S3_ = Module["__ZNSt3__23maxIlEERKT_S3_S3_"] = function() {
                return (__ZNSt3__23maxIlEERKT_S3_S3_ = Module["__ZNSt3__23maxIlEERKT_S3_S3_"] = Module["asm"]["_ZNSt3__23maxIlEERKT_S3_S3_"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj"] = function() {
                return (__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj"] = Module["asm"]["_ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj"]).apply(null, arguments)
            };
            var __ZNSt3__24fposI11__mbstate_tE5stateES1_ = Module["__ZNSt3__24fposI11__mbstate_tE5stateES1_"] = function() {
                return (__ZNSt3__24fposI11__mbstate_tE5stateES1_ = Module["__ZNSt3__24fposI11__mbstate_tE5stateES1_"] = Module["asm"]["_ZNSt3__24fposI11__mbstate_tE5stateES1_"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE7seekposENS_4fposI11__mbstate_tEEj = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE7seekposENS_4fposI11__mbstate_tEEj"] = function() {
                return (__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE7seekposENS_4fposI11__mbstate_tEEj = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE7seekposENS_4fposI11__mbstate_tEEj"] = Module["asm"]["_ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE7seekposENS_4fposI11__mbstate_tEEj"]).apply(null, arguments)
            };
            var __ZNKSt3__24fposI11__mbstate_tE5stateEv = Module["__ZNKSt3__24fposI11__mbstate_tE5stateEv"] = function() {
                return (__ZNKSt3__24fposI11__mbstate_tE5stateEv = Module["__ZNKSt3__24fposI11__mbstate_tE5stateEv"] = Module["asm"]["_ZNKSt3__24fposI11__mbstate_tE5stateEv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE4syncEv = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE4syncEv"] = function() {
                return (__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE4syncEv = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE4syncEv"] = Module["asm"]["_ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE4syncEv"]).apply(null, arguments)
            };
            var __ZNKSt3__27codecvtIcc11__mbstate_tE6lengthERS1_PKcS5_m = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE6lengthERS1_PKcS5_m"] = function() {
                return (__ZNKSt3__27codecvtIcc11__mbstate_tE6lengthERS1_PKcS5_m = Module["__ZNKSt3__27codecvtIcc11__mbstate_tE6lengthERS1_PKcS5_m"] = Module["asm"]["_ZNKSt3__27codecvtIcc11__mbstate_tE6lengthERS1_PKcS5_m"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE9underflowEv = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE9underflowEv"] = function() {
                return (__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE9underflowEv = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE9underflowEv"] = Module["asm"]["_ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE9underflowEv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE11__read_modeEv = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE11__read_modeEv"] = function() {
                return (__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE11__read_modeEv = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE11__read_modeEv"] = Module["asm"]["_ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE11__read_modeEv"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE9pbackfailEi = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE9pbackfailEi"] = function() {
                return (__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE9pbackfailEi = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE9pbackfailEi"] = Module["asm"]["_ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE9pbackfailEi"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE8overflowEi = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE8overflowEi"] = function() {
                return (__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE8overflowEi = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE8overflowEi"] = Module["asm"]["_ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE8overflowEi"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE12__write_modeEv = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE12__write_modeEv"] = function() {
                return (__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE12__write_modeEv = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE12__write_modeEv"] = Module["asm"]["_ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE12__write_modeEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrI8_IO_FILEPFiPS1_EEC2ILb1EvEES2_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS4_EEXT_EE20__good_rval_ref_typeE = Module["__ZNSt3__210unique_ptrI8_IO_FILEPFiPS1_EEC2ILb1EvEES2_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS4_EEXT_EE20__good_rval_ref_typeE"] = function() {
                return (__ZNSt3__210unique_ptrI8_IO_FILEPFiPS1_EEC2ILb1EvEES2_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS4_EEXT_EE20__good_rval_ref_typeE = Module["__ZNSt3__210unique_ptrI8_IO_FILEPFiPS1_EEC2ILb1EvEES2_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS4_EEXT_EE20__good_rval_ref_typeE"] = Module["asm"]["_ZNSt3__210unique_ptrI8_IO_FILEPFiPS1_EEC2ILb1EvEES2_NS_16__dependent_typeINS_27__unique_ptr_deleter_sfinaeIS4_EEXT_EE20__good_rval_ref_typeE"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrI8_IO_FILEPFiPS1_EE7releaseEv = Module["__ZNSt3__210unique_ptrI8_IO_FILEPFiPS1_EE7releaseEv"] = function() {
                return (__ZNSt3__210unique_ptrI8_IO_FILEPFiPS1_EE7releaseEv = Module["__ZNSt3__210unique_ptrI8_IO_FILEPFiPS1_EE7releaseEv"] = Module["asm"]["_ZNSt3__210unique_ptrI8_IO_FILEPFiPS1_EE7releaseEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrI8_IO_FILEPFiPS1_EED2Ev = Module["__ZNSt3__210unique_ptrI8_IO_FILEPFiPS1_EED2Ev"] = function() {
                return (__ZNSt3__210unique_ptrI8_IO_FILEPFiPS1_EED2Ev = Module["__ZNSt3__210unique_ptrI8_IO_FILEPFiPS1_EED2Ev"] = Module["asm"]["_ZNSt3__210unique_ptrI8_IO_FILEPFiPS1_EED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRPFiP8_IO_FILEEEEONS_16remove_referenceIT_E4typeEOS7_ = Module["__ZNSt3__24moveIRPFiP8_IO_FILEEEEONS_16remove_referenceIT_E4typeEOS7_"] = function() {
                return (__ZNSt3__24moveIRPFiP8_IO_FILEEEEONS_16remove_referenceIT_E4typeEOS7_ = Module["__ZNSt3__24moveIRPFiP8_IO_FILEEEEONS_16remove_referenceIT_E4typeEOS7_"] = Module["asm"]["_ZNSt3__24moveIRPFiP8_IO_FILEEEEONS_16remove_referenceIT_E4typeEOS7_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIP8_IO_FILEPFiS2_EEC2IRS2_S4_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIP8_IO_FILEPFiS2_EEC2IRS2_S4_EEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIP8_IO_FILEPFiS2_EEC2IRS2_S4_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIP8_IO_FILEPFiS2_EEC2IRS2_S4_EEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIP8_IO_FILEPFiS2_EEC2IRS2_S4_EEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIP8_IO_FILEPFiS2_EE5firstEv = Module["__ZNSt3__217__compressed_pairIP8_IO_FILEPFiS2_EE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIP8_IO_FILEPFiS2_EE5firstEv = Module["__ZNSt3__217__compressed_pairIP8_IO_FILEPFiS2_EE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIP8_IO_FILEPFiS2_EE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__210unique_ptrI8_IO_FILEPFiPS1_EE5resetES2_ = Module["__ZNSt3__210unique_ptrI8_IO_FILEPFiPS1_EE5resetES2_"] = function() {
                return (__ZNSt3__210unique_ptrI8_IO_FILEPFiPS1_EE5resetES2_ = Module["__ZNSt3__210unique_ptrI8_IO_FILEPFiPS1_EE5resetES2_"] = Module["asm"]["_ZNSt3__210unique_ptrI8_IO_FILEPFiPS1_EE5resetES2_"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRP8_IO_FILEEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRP8_IO_FILEEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRP8_IO_FILEEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRP8_IO_FILEEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRP8_IO_FILEEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIP8_IO_FILELi0ELb0EEC2IRS2_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIP8_IO_FILELi0ELb0EEC2IRS2_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIP8_IO_FILELi0ELb0EEC2IRS2_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIP8_IO_FILELi0ELb0EEC2IRS2_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIP8_IO_FILELi0ELb0EEC2IRS2_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIPFiP8_IO_FILEEEEOT_RNS_16remove_referenceIS5_E4typeE = Module["__ZNSt3__27forwardIPFiP8_IO_FILEEEEOT_RNS_16remove_referenceIS5_E4typeE"] = function() {
                return (__ZNSt3__27forwardIPFiP8_IO_FILEEEEOT_RNS_16remove_referenceIS5_E4typeE = Module["__ZNSt3__27forwardIPFiP8_IO_FILEEEEOT_RNS_16remove_referenceIS5_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIPFiP8_IO_FILEEEEOT_RNS_16remove_referenceIS5_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPFiP8_IO_FILEELi1ELb0EEC2IS4_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPFiP8_IO_FILEELi1ELb0EEC2IS4_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPFiP8_IO_FILEELi1ELb0EEC2IS4_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPFiP8_IO_FILEELi1ELb0EEC2IS4_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPFiP8_IO_FILEELi1ELb0EEC2IS4_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIP8_IO_FILELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIP8_IO_FILELi0ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIP8_IO_FILELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIP8_IO_FILELi0ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIP8_IO_FILELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIP8_IO_FILEPFiS2_EE6secondEv = Module["__ZNSt3__217__compressed_pairIP8_IO_FILEPFiS2_EE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIP8_IO_FILEPFiS2_EE6secondEv = Module["__ZNSt3__217__compressed_pairIP8_IO_FILEPFiS2_EE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIP8_IO_FILEPFiS2_EE6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPFiP8_IO_FILEELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPFiP8_IO_FILEELi1ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPFiP8_IO_FILEELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPFiP8_IO_FILEELi1ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPFiP8_IO_FILEELi1ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__23maxIlNS_6__lessIllEEEERKT_S5_S5_T0_ = Module["__ZNSt3__23maxIlNS_6__lessIllEEEERKT_S5_S5_T0_"] = function() {
                return (__ZNSt3__23maxIlNS_6__lessIllEEEERKT_S5_S5_T0_ = Module["__ZNSt3__23maxIlNS_6__lessIllEEEERKT_S5_S5_T0_"] = Module["asm"]["_ZNSt3__23maxIlNS_6__lessIllEEEERKT_S5_S5_T0_"]).apply(null, arguments)
            };
            var __ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE15__make_mdstringEj = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE15__make_mdstringEj"] = function() {
                return (__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE15__make_mdstringEj = Module["__ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE15__make_mdstringEj"] = Module["asm"]["_ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE15__make_mdstringEj"]).apply(null, arguments)
            };
            var __ZNSt3__214basic_ofstreamIcNS_11char_traitsIcEEED0Ev = Module["__ZNSt3__214basic_ofstreamIcNS_11char_traitsIcEEED0Ev"] = function() {
                return (__ZNSt3__214basic_ofstreamIcNS_11char_traitsIcEEED0Ev = Module["__ZNSt3__214basic_ofstreamIcNS_11char_traitsIcEEED0Ev"] = Module["asm"]["_ZNSt3__214basic_ofstreamIcNS_11char_traitsIcEEED0Ev"]).apply(null, arguments)
            };
            var __ZTv0_n12_NSt3__214basic_ofstreamIcNS_11char_traitsIcEEED1Ev = Module["__ZTv0_n12_NSt3__214basic_ofstreamIcNS_11char_traitsIcEEED1Ev"] = function() {
                return (__ZTv0_n12_NSt3__214basic_ofstreamIcNS_11char_traitsIcEEED1Ev = Module["__ZTv0_n12_NSt3__214basic_ofstreamIcNS_11char_traitsIcEEED1Ev"] = Module["asm"]["_ZTv0_n12_NSt3__214basic_ofstreamIcNS_11char_traitsIcEEED1Ev"]).apply(null, arguments)
            };
            var __ZTv0_n12_NSt3__214basic_ofstreamIcNS_11char_traitsIcEEED0Ev = Module["__ZTv0_n12_NSt3__214basic_ofstreamIcNS_11char_traitsIcEEED0Ev"] = function() {
                return (__ZTv0_n12_NSt3__214basic_ofstreamIcNS_11char_traitsIcEEED0Ev = Module["__ZTv0_n12_NSt3__214basic_ofstreamIcNS_11char_traitsIcEEED0Ev"] = Module["asm"]["_ZTv0_n12_NSt3__214basic_ofstreamIcNS_11char_traitsIcEEED0Ev"]).apply(null, arguments)
            };
            var __ZNSt3__216__copy_constexprINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIcS3_EEEET0_T_S8_S7_ = Module["__ZNSt3__216__copy_constexprINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIcS3_EEEET0_T_S8_S7_"] = function() {
                return (__ZNSt3__216__copy_constexprINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIcS3_EEEET0_T_S8_S7_ = Module["__ZNSt3__216__copy_constexprINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIcS3_EEEET0_T_S8_S7_"] = Module["asm"]["_ZNSt3__216__copy_constexprINS_19istreambuf_iteratorIcNS_11char_traitsIcEEEENS_19ostreambuf_iteratorIcS3_EEEET0_T_S8_S7_"]).apply(null, arguments)
            };
            var __ZNKSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEE3getEv = Module["__ZNKSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEE3getEv"] = function() {
                return (__ZNKSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEE3getEv = Module["__ZNKSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEE3getEv"] = Module["asm"]["_ZNKSt3__210shared_ptrINS_4__fs10filesystem12__dir_streamEE3getEv"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono8durationInNS_5ratioILx1ELx1EEEEC2IiEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_nEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationInNS_5ratioILx1ELx1EEEEC2IiEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_nEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"] = function() {
                return (__ZNSt3__26chrono8durationInNS_5ratioILx1ELx1EEEEC2IiEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_nEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationInNS_5ratioILx1ELx1EEEEC2IiEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_nEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"] = Module["asm"]["_ZNSt3__26chrono8durationInNS_5ratioILx1ELx1EEEEC2IiEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_nEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__26chronomiInNS_5ratioILx1ELx1EEEnNS2_ILx1ELx1000000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_ = Module["__ZNSt3__26chronomiInNS_5ratioILx1ELx1EEEnNS2_ILx1ELx1000000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"] = function() {
                return (__ZNSt3__26chronomiInNS_5ratioILx1ELx1EEEnNS2_ILx1ELx1000000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_ = Module["__ZNSt3__26chronomiInNS_5ratioILx1ELx1EEEnNS2_ILx1ELx1000000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"] = Module["asm"]["_ZNSt3__26chronomiInNS_5ratioILx1ELx1EEEnNS2_ILx1ELx1000000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"]).apply(null, arguments)
            };
            var __ZNKSt3__26chrono10time_pointINS_4__fs10filesystem16_FilesystemClockENS0_8durationInNS_5ratioILx1ELx1000000000EEEEEE16time_since_epochEv = Module["__ZNKSt3__26chrono10time_pointINS_4__fs10filesystem16_FilesystemClockENS0_8durationInNS_5ratioILx1ELx1000000000EEEEEE16time_since_epochEv"] = function() {
                return (__ZNKSt3__26chrono10time_pointINS_4__fs10filesystem16_FilesystemClockENS0_8durationInNS_5ratioILx1ELx1000000000EEEEEE16time_since_epochEv = Module["__ZNKSt3__26chrono10time_pointINS_4__fs10filesystem16_FilesystemClockENS0_8durationInNS_5ratioILx1ELx1000000000EEEEEE16time_since_epochEv"] = Module["asm"]["_ZNKSt3__26chrono10time_pointINS_4__fs10filesystem16_FilesystemClockENS0_8durationInNS_5ratioILx1ELx1000000000EEEEEE16time_since_epochEv"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono13duration_castINS0_8durationInNS_5ratioILx1ELx1EEEEEnNS3_ILx1ELx1000000000EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE = Module["__ZNSt3__26chrono13duration_castINS0_8durationInNS_5ratioILx1ELx1EEEEEnNS3_ILx1ELx1000000000EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"] = function() {
                return (__ZNSt3__26chrono13duration_castINS0_8durationInNS_5ratioILx1ELx1EEEEEnNS3_ILx1ELx1000000000EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE = Module["__ZNSt3__26chrono13duration_castINS0_8durationInNS_5ratioILx1ELx1EEEEEnNS3_ILx1ELx1000000000EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"] = Module["asm"]["_ZNSt3__26chrono13duration_castINS0_8durationInNS_5ratioILx1ELx1EEEEEnNS3_ILx1ELx1000000000EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"]).apply(null, arguments)
            };
            var __ZNSt3__26chronomiInNS_5ratioILx1ELx1000000000EEEnNS2_ILx1ELx1EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_ = Module["__ZNSt3__26chronomiInNS_5ratioILx1ELx1000000000EEEnNS2_ILx1ELx1EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"] = function() {
                return (__ZNSt3__26chronomiInNS_5ratioILx1ELx1000000000EEEnNS2_ILx1ELx1EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_ = Module["__ZNSt3__26chronomiInNS_5ratioILx1ELx1000000000EEEnNS2_ILx1ELx1EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"] = Module["asm"]["_ZNSt3__26chronomiInNS_5ratioILx1ELx1000000000EEEnNS2_ILx1ELx1EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"]).apply(null, arguments)
            };
            var __ZNSt3__26chronoplInNS_5ratioILx1ELx1EEEnS3_EENS_11common_typeIJNS0_8durationIT_T0_EENS5_IT1_T2_EEEE4typeERKS8_RKSB_ = Module["__ZNSt3__26chronoplInNS_5ratioILx1ELx1EEEnS3_EENS_11common_typeIJNS0_8durationIT_T0_EENS5_IT1_T2_EEEE4typeERKS8_RKSB_"] = function() {
                return (__ZNSt3__26chronoplInNS_5ratioILx1ELx1EEEnS3_EENS_11common_typeIJNS0_8durationIT_T0_EENS5_IT1_T2_EEEE4typeERKS8_RKSB_ = Module["__ZNSt3__26chronoplInNS_5ratioILx1ELx1EEEnS3_EENS_11common_typeIJNS0_8durationIT_T0_EENS5_IT1_T2_EEEE4typeERKS8_RKSB_"] = Module["asm"]["_ZNSt3__26chronoplInNS_5ratioILx1ELx1EEEnS3_EENS_11common_typeIJNS0_8durationIT_T0_EENS5_IT1_T2_EEEE4typeERKS8_RKSB_"]).apply(null, arguments)
            };
            var __ZNSt3__26chronoplInNS_5ratioILx1ELx1000000000EEEnNS2_ILx1ELx1EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_ = Module["__ZNSt3__26chronoplInNS_5ratioILx1ELx1000000000EEEnNS2_ILx1ELx1EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"] = function() {
                return (__ZNSt3__26chronoplInNS_5ratioILx1ELx1000000000EEEnNS2_ILx1ELx1EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_ = Module["__ZNSt3__26chronoplInNS_5ratioILx1ELx1000000000EEEnNS2_ILx1ELx1EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"] = Module["asm"]["_ZNSt3__26chronoplInNS_5ratioILx1ELx1000000000EEEnNS2_ILx1ELx1EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"]).apply(null, arguments)
            };
            var __ZNSt3__26chronomiInNS_5ratioILx1ELx1EEEnS3_EENS_11common_typeIJNS0_8durationIT_T0_EENS5_IT1_T2_EEEE4typeERKS8_RKSB_ = Module["__ZNSt3__26chronomiInNS_5ratioILx1ELx1EEEnS3_EENS_11common_typeIJNS0_8durationIT_T0_EENS5_IT1_T2_EEEE4typeERKS8_RKSB_"] = function() {
                return (__ZNSt3__26chronomiInNS_5ratioILx1ELx1EEEnS3_EENS_11common_typeIJNS0_8durationIT_T0_EENS5_IT1_T2_EEEE4typeERKS8_RKSB_ = Module["__ZNSt3__26chronomiInNS_5ratioILx1ELx1EEEnS3_EENS_11common_typeIJNS0_8durationIT_T0_EENS5_IT1_T2_EEEE4typeERKS8_RKSB_"] = Module["asm"]["_ZNSt3__26chronomiInNS_5ratioILx1ELx1EEEnS3_EENS_11common_typeIJNS0_8durationIT_T0_EENS5_IT1_T2_EEEE4typeERKS8_RKSB_"]).apply(null, arguments)
            };
            var __ZNKSt3__26chrono15__duration_castINS0_8durationInNS_5ratioILx1ELx1000000000EEEEENS2_InNS3_ILx1ELx1EEEEES4_Lb1ELb0EEclERKS5_ = Module["__ZNKSt3__26chrono15__duration_castINS0_8durationInNS_5ratioILx1ELx1000000000EEEEENS2_InNS3_ILx1ELx1EEEEES4_Lb1ELb0EEclERKS5_"] = function() {
                return (__ZNKSt3__26chrono15__duration_castINS0_8durationInNS_5ratioILx1ELx1000000000EEEEENS2_InNS3_ILx1ELx1EEEEES4_Lb1ELb0EEclERKS5_ = Module["__ZNKSt3__26chrono15__duration_castINS0_8durationInNS_5ratioILx1ELx1000000000EEEEENS2_InNS3_ILx1ELx1EEEEES4_Lb1ELb0EEclERKS5_"] = Module["asm"]["_ZNKSt3__26chrono15__duration_castINS0_8durationInNS_5ratioILx1ELx1000000000EEEEENS2_InNS3_ILx1ELx1EEEEES4_Lb1ELb0EEclERKS5_"]).apply(null, arguments)
            };
            var __ZNSt3__26chrono8durationInNS_5ratioILx1ELx1EEEEC2InEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_nEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationInNS_5ratioILx1ELx1EEEEC2InEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_nEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"] = function() {
                return (__ZNSt3__26chrono8durationInNS_5ratioILx1ELx1EEEEC2InEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_nEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE = Module["__ZNSt3__26chrono8durationInNS_5ratioILx1ELx1EEEEC2InEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_nEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"] = Module["asm"]["_ZNSt3__26chrono8durationInNS_5ratioILx1ELx1EEEEC2InEERKT_PNS_9enable_ifIXaasr14is_convertibleIS6_nEE5valueooL_ZNS_17integral_constantIbLb0EE5valueEEntsr23treat_as_floating_pointIS6_EE5valueEvE4typeE"]).apply(null, arguments)
            };
            var __ZNKSt3__25arrayI8timespecLm2EE4dataEv = Module["__ZNKSt3__25arrayI8timespecLm2EE4dataEv"] = function() {
                return (__ZNKSt3__25arrayI8timespecLm2EE4dataEv = Module["__ZNKSt3__25arrayI8timespecLm2EE4dataEv"] = Module["asm"]["_ZNKSt3__25arrayI8timespecLm2EE4dataEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE5frontEv = Module["__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE5frontEv"] = function() {
                return (__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE5frontEv = Module["__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE5frontEv"] = Module["asm"]["_ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE5frontEv"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRKNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEOT_RNS_16remove_referenceIS7_E4typeE = Module["__ZNSt3__27forwardIRKNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEOT_RNS_16remove_referenceIS7_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRKNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEOT_RNS_16remove_referenceIS7_E4typeE = Module["__ZNSt3__27forwardIRKNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEOT_RNS_16remove_referenceIS7_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRKNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEOT_RNS_16remove_referenceIS7_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA1_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA1_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA1_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA1_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA1_KcEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE5rfindEcm = Module["__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE5rfindEcm"] = function() {
                return (__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE5rfindEcm = Module["__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE5rfindEcm"] = Module["asm"]["_ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEE5rfindEcm"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEOT_RNS_16remove_referenceIS5_E4typeE = Module["__ZNSt3__27forwardINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEOT_RNS_16remove_referenceIS5_E4typeE"] = function() {
                return (__ZNSt3__27forwardINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEOT_RNS_16remove_referenceIS5_E4typeE = Module["__ZNSt3__27forwardINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEOT_RNS_16remove_referenceIS5_E4typeE"] = Module["asm"]["_ZNSt3__27forwardINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEOT_RNS_16remove_referenceIS5_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE9__end_capEv = Module["__ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE9__end_capEv"] = function() {
                return (__ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE9__end_capEv = Module["__ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE9__end_capEv"] = Module["asm"]["_ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE9__end_capEv"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEOT_RNS_16remove_referenceIS6_E4typeE = Module["__ZNSt3__27forwardIRNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEOT_RNS_16remove_referenceIS6_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEOT_RNS_16remove_referenceIS6_E4typeE = Module["__ZNSt3__27forwardIRNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEOT_RNS_16remove_referenceIS6_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEOT_RNS_16remove_referenceIS6_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRNS_4__fs10filesystem12PathPartKindEEEOT_RNS_16remove_referenceIS5_E4typeE = Module["__ZNSt3__27forwardIRNS_4__fs10filesystem12PathPartKindEEEOT_RNS_16remove_referenceIS5_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRNS_4__fs10filesystem12PathPartKindEEEOT_RNS_16remove_referenceIS5_E4typeE = Module["__ZNSt3__27forwardIRNS_4__fs10filesystem12PathPartKindEEEOT_RNS_16remove_referenceIS5_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRNS_4__fs10filesystem12PathPartKindEEEOT_RNS_16remove_referenceIS5_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE22__construct_one_at_endIJRS5_RS8_EEEvDpOT_ = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE22__construct_one_at_endIJRS5_RS8_EEEvDpOT_"] = function() {
                return (__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE22__construct_one_at_endIJRS5_RS8_EEEvDpOT_ = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE22__construct_one_at_endIJRS5_RS8_EEEvDpOT_"] = Module["asm"]["_ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE22__construct_one_at_endIJRS5_RS8_EEEvDpOT_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE24__emplace_back_slow_pathIJRS5_RS8_EEEvDpOT_ = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE24__emplace_back_slow_pathIJRS5_RS8_EEEvDpOT_"] = function() {
                return (__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE24__emplace_back_slow_pathIJRS5_RS8_EEEvDpOT_ = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE24__emplace_back_slow_pathIJRS5_RS8_EEEvDpOT_"] = Module["asm"]["_ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE24__emplace_back_slow_pathIJRS5_RS8_EEEvDpOT_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE5firstEv = Module["__ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE5firstEv = Module["__ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE21_ConstructTransactionC2ERSC_m = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE21_ConstructTransactionC2ERSC_m"] = function() {
                return (__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE21_ConstructTransactionC2ERSC_m = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE21_ConstructTransactionC2ERSC_m"] = Module["asm"]["_ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE21_ConstructTransactionC2ERSC_m"]).apply(null, arguments)
            };
            var __ZNSt3__212__to_addressINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEPT_SB_ = Module["__ZNSt3__212__to_addressINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEPT_SB_"] = function() {
                return (__ZNSt3__212__to_addressINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEPT_SB_ = Module["__ZNSt3__212__to_addressINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEPT_SB_"] = Module["asm"]["_ZNSt3__212__to_addressINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEPT_SB_"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE9constructISA_JRS6_RS9_EEEvRSB_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE9constructISA_JRS6_RS9_EEEvRSB_PT_DpOT0_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE9constructISA_JRS6_RS9_EEEvRSB_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE9constructISA_JRS6_RS9_EEEvRSB_PT_DpOT0_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE9constructISA_JRS6_RS9_EEEvRSB_PT_DpOT0_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE21_ConstructTransactionD2Ev = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE21_ConstructTransactionD2Ev"] = function() {
                return (__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE21_ConstructTransactionD2Ev = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE21_ConstructTransactionD2Ev"] = Module["asm"]["_ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE21_ConstructTransactionD2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE11__recommendEm = Module["__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE11__recommendEm"] = function() {
                return (__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE11__recommendEm = Module["__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE11__recommendEm"] = Module["asm"]["_ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE11__recommendEm"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEELi0ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEELi0ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE11__constructISA_JRS6_RS9_EEEvNS_17integral_constantIbLb1EEERSB_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE11__constructISA_JRS6_RS9_EEEvNS_17integral_constantIbLb1EEERSB_PT_DpOT0_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE11__constructISA_JRS6_RS9_EEEvNS_17integral_constantIbLb1EEERSB_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE11__constructISA_JRS6_RS9_EEEvNS_17integral_constantIbLb1EEERSB_PT_DpOT0_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE11__constructISA_JRS6_RS9_EEEvNS_17integral_constantIbLb1EEERSB_PT_DpOT0_"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE6secondEv = Module["__ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE6secondEv = Module["__ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE9constructIS9_JRS5_RS8_EEEvPT_DpOT0_ = Module["__ZNSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE9constructIS9_JRS5_RS8_EEEvPT_DpOT0_"] = function() {
                return (__ZNSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE9constructIS9_JRS5_RS8_EEEvPT_DpOT0_ = Module["__ZNSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE9constructIS9_JRS5_RS8_EEEvPT_DpOT0_"] = Module["asm"]["_ZNSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE9constructIS9_JRS5_RS8_EEEvPT_DpOT0_"]).apply(null, arguments)
            };
            var __ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEC2IRS4_RS7_Lb0EEEOT_OT0_ = Module["__ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEC2IRS4_RS7_Lb0EEEOT_OT0_"] = function() {
                return (__ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEC2IRS4_RS7_Lb0EEEOT_OT0_ = Module["__ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEC2IRS4_RS7_Lb0EEEOT_OT0_"] = Module["asm"]["_ZNSt3__24pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEC2IRS4_RS7_Lb0EEEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEELi1ELb1EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEELi1ELb1EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEELi1ELb1EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEELi1ELb1EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEELi1ELb1EE5__getEv"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE8max_sizeEv = Module["__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE8max_sizeEv"] = function() {
                return (__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE8max_sizeEv = Module["__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE8max_sizeEv"] = Module["asm"]["_ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE8max_sizeEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEEC2IDnSD_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEEC2IDnSD_EEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEEC2IDnSD_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEEC2IDnSD_EEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEEC2IDnSD_EEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE7__allocEv = Module["__ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE7__allocEv"] = function() {
                return (__ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE7__allocEv = Module["__ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE7__allocEv"] = Module["asm"]["_ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE7__allocEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE8allocateERSB_m = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE8allocateERSB_m"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE8allocateERSB_m = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE8allocateERSB_m"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE8allocateERSB_m"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE9__end_capEv = Module["__ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE9__end_capEv"] = function() {
                return (__ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE9__end_capEv = Module["__ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE9__end_capEv"] = Module["asm"]["_ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE9__end_capEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE46__construct_backward_with_exception_guaranteesISA_EENS_9enable_ifIXaaooL_ZNS_17integral_constantIbLb1EE5valueEEntsr15__has_constructISB_PT_SH_EE5valuesr31is_trivially_move_constructibleISH_EE5valueEvE4typeERSB_SI_SI_RSI_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE46__construct_backward_with_exception_guaranteesISA_EENS_9enable_ifIXaaooL_ZNS_17integral_constantIbLb1EE5valueEEntsr15__has_constructISB_PT_SH_EE5valuesr31is_trivially_move_constructibleISH_EE5valueEvE4typeERSB_SI_SI_RSI_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE46__construct_backward_with_exception_guaranteesISA_EENS_9enable_ifIXaaooL_ZNS_17integral_constantIbLb1EE5valueEEntsr15__has_constructISB_PT_SH_EE5valuesr31is_trivially_move_constructibleISH_EE5valueEvE4typeERSB_SI_SI_RSI_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE46__construct_backward_with_exception_guaranteesISA_EENS_9enable_ifIXaaooL_ZNS_17integral_constantIbLb1EE5valueEEntsr15__has_constructISB_PT_SH_EE5valuesr31is_trivially_move_constructibleISH_EE5valueEvE4typeERSB_SI_SI_RSI_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE46__construct_backward_with_exception_guaranteesISA_EENS_9enable_ifIXaaooL_ZNS_17integral_constantIbLb1EE5valueEEntsr15__has_constructISB_PT_SH_EE5valuesr31is_trivially_move_constructibleISH_EE5valueEvE4typeERSB_SI_SI_RSI_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableISC_EE5valueEvE4typeERSC_SF_ = Module["__ZNSt3__24swapIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableISC_EE5valueEvE4typeERSC_SF_"] = function() {
                return (__ZNSt3__24swapIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableISC_EE5valueEvE4typeERSC_SF_ = Module["__ZNSt3__24swapIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableISC_EE5valueEvE4typeERSC_SF_"] = Module["asm"]["_ZNSt3__24swapIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableISC_EE5valueEvE4typeERSC_SF_"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE14__annotate_newEm = Module["__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE14__annotate_newEm"] = function() {
                return (__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE14__annotate_newEm = Module["__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE14__annotate_newEm"] = Module["asm"]["_ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE14__annotate_newEm"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE26__invalidate_all_iteratorsEv = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE26__invalidate_all_iteratorsEv"] = function() {
                return (__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE26__invalidate_all_iteratorsEv = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE26__invalidate_all_iteratorsEv"] = Module["asm"]["_ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE26__invalidate_all_iteratorsEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE5clearEv = Module["__ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE5clearEv"] = function() {
                return (__ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE5clearEv = Module["__ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE5clearEv"] = Module["asm"]["_ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE5clearEv"]).apply(null, arguments)
            };
            var __ZNKSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE8capacityEv = Module["__ZNKSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE8capacityEv"] = function() {
                return (__ZNKSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE8capacityEv = Module["__ZNKSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE8capacityEv"] = Module["asm"]["_ZNKSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE8capacityEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE10deallocateERSB_PSA_m = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE10deallocateERSB_PSA_m"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE10deallocateERSB_PSA_m = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE10deallocateERSB_PSA_m"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE10deallocateERSB_PSA_m"]).apply(null, arguments)
            };
            var __ZNKSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE7__allocEv = Module["__ZNKSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE7__allocEv"] = function() {
                return (__ZNKSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE7__allocEv = Module["__ZNKSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE7__allocEv"] = Module["asm"]["_ZNKSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE7__allocEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE8max_sizeERKSB_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE8max_sizeERKSB_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE8max_sizeERKSB_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE8max_sizeERKSB_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE8max_sizeERKSB_"]).apply(null, arguments)
            };
            var __ZNKSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE8capacityEv = Module["__ZNKSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE8capacityEv"] = function() {
                return (__ZNKSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE8capacityEv = Module["__ZNKSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE8capacityEv"] = Module["asm"]["_ZNKSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE8capacityEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE10__max_sizeENS_17integral_constantIbLb1EEERKSB_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE10__max_sizeENS_17integral_constantIbLb1EEERKSB_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE10__max_sizeENS_17integral_constantIbLb1EEERKSB_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE10__max_sizeENS_17integral_constantIbLb1EEERKSB_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE10__max_sizeENS_17integral_constantIbLb1EEERKSB_"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE6secondEv = Module["__ZNKSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE6secondEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE6secondEv = Module["__ZNKSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE6secondEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE6secondEv"]).apply(null, arguments)
            };
            var __ZNKSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE8max_sizeEv = Module["__ZNKSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE8max_sizeEv"] = function() {
                return (__ZNKSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE8max_sizeEv = Module["__ZNKSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE8max_sizeEv"] = Module["asm"]["_ZNKSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE8max_sizeEv"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEELi1ELb1EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEELi1ELb1EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEELi1ELb1EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEELi1ELb1EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEELi1ELb1EE5__getEv"]).apply(null, arguments)
            };
            var __ZNKSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE9__end_capEv = Module["__ZNKSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE9__end_capEv"] = function() {
                return (__ZNKSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE9__end_capEv = Module["__ZNKSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE9__end_capEv"] = Module["asm"]["_ZNKSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE9__end_capEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE5firstEv"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEELi0ELb0EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEELi0ELb0EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEELi0ELb0EEC2IDnvEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEELi0ELb0EEC2IDnvEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEELi0ELb0EEC2IDnvEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEELi0ELb0EEC2IDnvEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEELi0ELb0EEC2IDnvEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRNS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEEEOT_RNS_16remove_referenceISD_E4typeE = Module["__ZNSt3__27forwardIRNS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEEEOT_RNS_16remove_referenceISD_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRNS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEEEOT_RNS_16remove_referenceISD_E4typeE = Module["__ZNSt3__27forwardIRNS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEEEOT_RNS_16remove_referenceISD_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRNS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEEEOT_RNS_16remove_referenceISD_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIRNS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEELi1ELb0EEC2ISC_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIRNS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEELi1ELb0EEC2ISC_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIRNS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEELi1ELb0EEC2ISC_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIRNS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEELi1ELb0EEC2ISC_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIRNS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEELi1ELb0EEC2ISC_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE8allocateEmPKv = Module["__ZNSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE8allocateEmPKv"] = function() {
                return (__ZNSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE8allocateEmPKv = Module["__ZNSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE8allocateEmPKv"] = Module["asm"]["_ZNSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE8allocateEmPKv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE6secondEv = Module["__ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE6secondEv = Module["__ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE5firstEv = Module["__ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE5firstEv = Module["__ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIRNS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIRNS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEELi1ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIRNS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIRNS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEELi1ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIRNS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEELi1ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE4dataEv = Module["__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE4dataEv"] = function() {
                return (__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE4dataEv = Module["__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE4dataEv"] = Module["asm"]["_ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE4dataEv"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE31__annotate_contiguous_containerEPKvSE_SE_SE_ = Module["__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE31__annotate_contiguous_containerEPKvSE_SE_SE_"] = function() {
                return (__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE31__annotate_contiguous_containerEPKvSE_SE_SE_ = Module["__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE31__annotate_contiguous_containerEPKvSE_SE_SE_"] = Module["asm"]["_ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE31__annotate_contiguous_containerEPKvSE_SE_SE_"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEONS_16remove_referenceIT_E4typeEOSD_ = Module["__ZNSt3__24moveIRPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEONS_16remove_referenceIT_E4typeEOSD_"] = function() {
                return (__ZNSt3__24moveIRPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEONS_16remove_referenceIT_E4typeEOSD_ = Module["__ZNSt3__24moveIRPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEONS_16remove_referenceIT_E4typeEOSD_"] = Module["asm"]["_ZNSt3__24moveIRPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEONS_16remove_referenceIT_E4typeEOSD_"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE17__destruct_at_endEPS9_ = Module["__ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE17__destruct_at_endEPS9_"] = function() {
                return (__ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE17__destruct_at_endEPS9_ = Module["__ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE17__destruct_at_endEPS9_"] = Module["asm"]["_ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE17__destruct_at_endEPS9_"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE10deallocateEPS9_m = Module["__ZNSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE10deallocateEPS9_m"] = function() {
                return (__ZNSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE10deallocateEPS9_m = Module["__ZNSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE10deallocateEPS9_m"] = Module["asm"]["_ZNSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE10deallocateEPS9_m"]).apply(null, arguments)
            };
            var __ZNKSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE9__end_capEv = Module["__ZNKSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE9__end_capEv"] = function() {
                return (__ZNKSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE9__end_capEv = Module["__ZNKSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE9__end_capEv"] = Module["asm"]["_ZNKSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE9__end_capEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE17__destruct_at_endEPS9_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE17__destruct_at_endEPS9_NS_17integral_constantIbLb0EEE"] = function() {
                return (__ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE17__destruct_at_endEPS9_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE17__destruct_at_endEPS9_NS_17integral_constantIbLb0EEE"] = Module["asm"]["_ZNSt3__214__split_bufferINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE17__destruct_at_endEPS9_NS_17integral_constantIbLb0EEE"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE7destroyISA_EEvRSB_PT_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE7destroyISA_EEvRSB_PT_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE7destroyISA_EEvRSB_PT_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE7destroyISA_EEvRSB_PT_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE7destroyISA_EEvRSB_PT_"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE9__destroyISA_EEvNS_17integral_constantIbLb1EEERSB_PT_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE9__destroyISA_EEvNS_17integral_constantIbLb1EEERSB_PT_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE9__destroyISA_EEvNS_17integral_constantIbLb1EEERSB_PT_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE9__destroyISA_EEvNS_17integral_constantIbLb1EEERSB_PT_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEEE9__destroyISA_EEvNS_17integral_constantIbLb1EEERSB_PT_"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE7destroyEPS9_ = Module["__ZNSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE7destroyEPS9_"] = function() {
                return (__ZNSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE7destroyEPS9_ = Module["__ZNSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE7destroyEPS9_"] = Module["asm"]["_ZNSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE7destroyEPS9_"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEERNS_9allocatorIS9_EEE5firstEv"]).apply(null, arguments)
            };
            var __ZNKSt3__211__wrap_iterIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE4baseEv = Module["__ZNKSt3__211__wrap_iterIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE4baseEv"] = function() {
                return (__ZNKSt3__211__wrap_iterIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE4baseEv = Module["__ZNKSt3__211__wrap_iterIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE4baseEv"] = Module["asm"]["_ZNKSt3__211__wrap_iterIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEE4baseEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIPcS3_cLb1EE13__range_beginEPKc = Module["__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIPcS3_cLb1EE13__range_beginEPKc"] = function() {
                return (__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIPcS3_cLb1EE13__range_beginEPKc = Module["__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIPcS3_cLb1EE13__range_beginEPKc"] = Module["asm"]["_ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIPcS3_cLb1EE13__range_beginEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIPcS3_cLb1EE11__range_endEPKc = Module["__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIPcS3_cLb1EE11__range_endEPKc"] = function() {
                return (__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIPcS3_cLb1EE11__range_endEPKc = Module["__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIPcS3_cLb1EE11__range_endEPKc"] = Module["asm"]["_ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIPcS3_cLb1EE11__range_endEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_14default_deleteIA_cEELi1ELb1EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_14default_deleteIA_cEELi1ELb1EEC2ENS_18__default_init_tagE"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_14default_deleteIA_cEELi1ELb1EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_14default_deleteIA_cEELi1ELb1EEC2ENS_18__default_init_tagE"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_14default_deleteIA_cEELi1ELb1EEC2ENS_18__default_init_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPcNS_14default_deleteIA_cEEE5firstEv = Module["__ZNSt3__217__compressed_pairIPcNS_14default_deleteIA_cEEE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPcNS_14default_deleteIA_cEEE5firstEv = Module["__ZNSt3__217__compressed_pairIPcNS_14default_deleteIA_cEEE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPcNS_14default_deleteIA_cEEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPcNS_14default_deleteIA_cEEE6secondEv = Module["__ZNSt3__217__compressed_pairIPcNS_14default_deleteIA_cEEE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPcNS_14default_deleteIA_cEEE6secondEv = Module["__ZNSt3__217__compressed_pairIPcNS_14default_deleteIA_cEEE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPcNS_14default_deleteIA_cEEE6secondEv"]).apply(null, arguments)
            };
            var __ZNKSt3__214default_deleteIA_cEclIcEENS2_20_EnableIfConvertibleIT_E4typeEPS5_ = Module["__ZNKSt3__214default_deleteIA_cEclIcEENS2_20_EnableIfConvertibleIT_E4typeEPS5_"] = function() {
                return (__ZNKSt3__214default_deleteIA_cEclIcEENS2_20_EnableIfConvertibleIT_E4typeEPS5_ = Module["__ZNKSt3__214default_deleteIA_cEclIcEENS2_20_EnableIfConvertibleIT_E4typeEPS5_"] = Module["asm"]["_ZNKSt3__214default_deleteIA_cEclIcEENS2_20_EnableIfConvertibleIT_E4typeEPS5_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_14default_deleteIA_cEELi1ELb1EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_14default_deleteIA_cEELi1ELb1EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_14default_deleteIA_cEELi1ELb1EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_14default_deleteIA_cEELi1ELb1EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_14default_deleteIA_cEELi1ELb1EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem20__is_pathable_stringINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEvE13__range_beginERKS8_ = Module["__ZNSt3__24__fs10filesystem20__is_pathable_stringINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEvE13__range_beginERKS8_"] = function() {
                return (__ZNSt3__24__fs10filesystem20__is_pathable_stringINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEvE13__range_beginERKS8_ = Module["__ZNSt3__24__fs10filesystem20__is_pathable_stringINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEvE13__range_beginERKS8_"] = Module["asm"]["_ZNSt3__24__fs10filesystem20__is_pathable_stringINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEvE13__range_beginERKS8_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem20__is_pathable_stringINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEvE11__range_endERKS8_ = Module["__ZNSt3__24__fs10filesystem20__is_pathable_stringINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEvE11__range_endERKS8_"] = function() {
                return (__ZNSt3__24__fs10filesystem20__is_pathable_stringINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEvE11__range_endERKS8_ = Module["__ZNSt3__24__fs10filesystem20__is_pathable_stringINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEvE11__range_endERKS8_"] = Module["asm"]["_ZNSt3__24__fs10filesystem20__is_pathable_stringINS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEvE11__range_endERKS8_"]).apply(null, arguments)
            };
            var __ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6lengthEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6lengthEv"] = function() {
                return (__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6lengthEv = Module["__ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6lengthEv"] = Module["asm"]["_ZNKSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE6lengthEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIPKcS4_cLb1EE13__range_beginES4_ = Module["__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIPKcS4_cLb1EE13__range_beginES4_"] = function() {
                return (__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIPKcS4_cLb1EE13__range_beginES4_ = Module["__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIPKcS4_cLb1EE13__range_beginES4_"] = Module["asm"]["_ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIPKcS4_cLb1EE13__range_beginES4_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIPKcS4_cLb1EE11__range_endES4_ = Module["__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIPKcS4_cLb1EE11__range_endES4_"] = function() {
                return (__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIPKcS4_cLb1EE11__range_endES4_ = Module["__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIPKcS4_cLb1EE11__range_endES4_"] = Module["asm"]["_ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIPKcS4_cLb1EE11__range_endES4_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA1_cPccLb1EE13__range_beginEPKc = Module["__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA1_cPccLb1EE13__range_beginEPKc"] = function() {
                return (__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA1_cPccLb1EE13__range_beginEPKc = Module["__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA1_cPccLb1EE13__range_beginEPKc"] = Module["asm"]["_ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA1_cPccLb1EE13__range_beginEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA1_cPccLb1EE11__range_endEPKc = Module["__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA1_cPccLb1EE11__range_endEPKc"] = function() {
                return (__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA1_cPccLb1EE11__range_endEPKc = Module["__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA1_cPccLb1EE11__range_endEPKc"] = Module["asm"]["_ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA1_cPccLb1EE11__range_endEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEEC2IDnNS_18__default_init_tagEEEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEEC2IDnNS_18__default_init_tagEEEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEEC2IDnNS_18__default_init_tagEEEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEEC2IDnNS_18__default_init_tagEEEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEEC2IDnNS_18__default_init_tagEEEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPNS_17basic_string_viewIcNS_11char_traitsIcEEEELi0ELb0EEC2IDnvEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPNS_17basic_string_viewIcNS_11char_traitsIcEEEELi0ELb0EEC2IDnvEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPNS_17basic_string_viewIcNS_11char_traitsIcEEEELi0ELb0EEC2IDnvEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIPNS_17basic_string_viewIcNS_11char_traitsIcEEEELi0ELb0EEC2IDnvEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPNS_17basic_string_viewIcNS_11char_traitsIcEEEELi0ELb0EEC2IDnvEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEELi1ELb1EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEELi1ELb1EEC2ENS_18__default_init_tagE"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEELi1ELb1EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEELi1ELb1EEC2ENS_18__default_init_tagE"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEELi1ELb1EEC2ENS_18__default_init_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEC2Ev = Module["__ZNSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEC2Ev"] = function() {
                return (__ZNSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEC2Ev = Module["__ZNSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEC2Ev"] = Module["asm"]["_ZNSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEC2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE4dataEv = Module["__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE4dataEv"] = function() {
                return (__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE4dataEv = Module["__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE4dataEv"] = Module["asm"]["_ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE4dataEv"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE8capacityEv = Module["__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE8capacityEv"] = function() {
                return (__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE8capacityEv = Module["__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE8capacityEv"] = Module["asm"]["_ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE8capacityEv"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE4sizeEv = Module["__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE4sizeEv"] = function() {
                return (__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE4sizeEv = Module["__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE4sizeEv"] = Module["asm"]["_ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE4sizeEv"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE31__annotate_contiguous_containerEPKvS9_S9_S9_ = Module["__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE31__annotate_contiguous_containerEPKvS9_S9_S9_"] = function() {
                return (__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE31__annotate_contiguous_containerEPKvS9_S9_S9_ = Module["__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE31__annotate_contiguous_containerEPKvS9_S9_S9_"] = Module["asm"]["_ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE31__annotate_contiguous_containerEPKvS9_S9_S9_"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE5clearEv = Module["__ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE5clearEv"] = function() {
                return (__ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE5clearEv = Module["__ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE5clearEv"] = Module["asm"]["_ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE5clearEv"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE7__allocEv = Module["__ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE7__allocEv"] = function() {
                return (__ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE7__allocEv = Module["__ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE7__allocEv"] = Module["asm"]["_ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE7__allocEv"]).apply(null, arguments)
            };
            var __ZNKSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE8capacityEv = Module["__ZNKSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE8capacityEv"] = function() {
                return (__ZNKSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE8capacityEv = Module["__ZNKSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE8capacityEv"] = Module["asm"]["_ZNKSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE8capacityEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE10deallocateERS6_PS5_m = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE10deallocateERS6_PS5_m"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE10deallocateERS6_PS5_m = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE10deallocateERS6_PS5_m"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE10deallocateERS6_PS5_m"]).apply(null, arguments)
            };
            var __ZNSt3__212__to_addressINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEPT_S6_ = Module["__ZNSt3__212__to_addressINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEPT_S6_"] = function() {
                return (__ZNSt3__212__to_addressINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEPT_S6_ = Module["__ZNSt3__212__to_addressINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEPT_S6_"] = Module["asm"]["_ZNSt3__212__to_addressINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEPT_S6_"]).apply(null, arguments)
            };
            var __ZNKSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE9__end_capEv = Module["__ZNKSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE9__end_capEv"] = function() {
                return (__ZNKSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE9__end_capEv = Module["__ZNKSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE9__end_capEv"] = Module["asm"]["_ZNKSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE9__end_capEv"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE5firstEv"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemIPNS_17basic_string_viewIcNS_11char_traitsIcEEEELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPNS_17basic_string_viewIcNS_11char_traitsIcEEEELi0ELb0EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemIPNS_17basic_string_viewIcNS_11char_traitsIcEEEELi0ELb0EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemIPNS_17basic_string_viewIcNS_11char_traitsIcEEEELi0ELb0EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemIPNS_17basic_string_viewIcNS_11char_traitsIcEEEELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE17__destruct_at_endEPS4_ = Module["__ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE17__destruct_at_endEPS4_"] = function() {
                return (__ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE17__destruct_at_endEPS4_ = Module["__ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE17__destruct_at_endEPS4_"] = Module["asm"]["_ZNSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE17__destruct_at_endEPS4_"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEE10deallocateEPS4_m = Module["__ZNSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEE10deallocateEPS4_m"] = function() {
                return (__ZNSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEE10deallocateEPS4_m = Module["__ZNSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEE10deallocateEPS4_m"] = Module["asm"]["_ZNSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEE10deallocateEPS4_m"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE6secondEv = Module["__ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE6secondEv = Module["__ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE7destroyIS5_EEvRS6_PT_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE7destroyIS5_EEvRS6_PT_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE7destroyIS5_EEvRS6_PT_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE7destroyIS5_EEvRS6_PT_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE7destroyIS5_EEvRS6_PT_"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE9__destroyIS5_EEvNS_17integral_constantIbLb1EEERS6_PT_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE9__destroyIS5_EEvNS_17integral_constantIbLb1EEERS6_PT_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE9__destroyIS5_EEvNS_17integral_constantIbLb1EEERS6_PT_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE9__destroyIS5_EEvNS_17integral_constantIbLb1EEERS6_PT_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE9__destroyIS5_EEvNS_17integral_constantIbLb1EEERS6_PT_"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEE7destroyEPS4_ = Module["__ZNSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEE7destroyEPS4_"] = function() {
                return (__ZNSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEE7destroyEPS4_ = Module["__ZNSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEE7destroyEPS4_"] = Module["asm"]["_ZNSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEE7destroyEPS4_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEELi1ELb1EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEELi1ELb1EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEELi1ELb1EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEELi1ELb1EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEELi1ELb1EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE5firstEv = Module["__ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE5firstEv = Module["__ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE21_ConstructTransactionC2ERS7_m = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE21_ConstructTransactionC2ERS7_m"] = function() {
                return (__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE21_ConstructTransactionC2ERS7_m = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE21_ConstructTransactionC2ERS7_m"] = Module["asm"]["_ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE21_ConstructTransactionC2ERS7_m"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE9constructIS5_JS5_EEEvRS6_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE9constructIS5_JS5_EEEvRS6_PT_DpOT0_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE9constructIS5_JS5_EEEvRS6_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE9constructIS5_JS5_EEEvRS6_PT_DpOT0_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE9constructIS5_JS5_EEEvRS6_PT_DpOT0_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE21_ConstructTransactionD2Ev = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE21_ConstructTransactionD2Ev"] = function() {
                return (__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE21_ConstructTransactionD2Ev = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE21_ConstructTransactionD2Ev"] = Module["asm"]["_ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE21_ConstructTransactionD2Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE11__recommendEm = Module["__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE11__recommendEm"] = function() {
                return (__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE11__recommendEm = Module["__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE11__recommendEm"] = Module["asm"]["_ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE11__recommendEm"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEEC2EmmS7_ = Module["__ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEEC2EmmS7_"] = function() {
                return (__ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEEC2EmmS7_ = Module["__ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEEC2EmmS7_"] = Module["asm"]["_ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEEC2EmmS7_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS4_RS6_EE = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS4_RS6_EE"] = function() {
                return (__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS4_RS6_EE = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS4_RS6_EE"] = Module["asm"]["_ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE26__swap_out_circular_bufferERNS_14__split_bufferIS4_RS6_EE"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEED2Ev = Module["__ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEED2Ev"] = function() {
                return (__ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEED2Ev = Module["__ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEED2Ev"] = Module["asm"]["_ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEED2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIPNS_17basic_string_viewIcNS_11char_traitsIcEEEELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPNS_17basic_string_viewIcNS_11char_traitsIcEEEELi0ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIPNS_17basic_string_viewIcNS_11char_traitsIcEEEELi0ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIPNS_17basic_string_viewIcNS_11char_traitsIcEEEELi0ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIPNS_17basic_string_viewIcNS_11char_traitsIcEEEELi0ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE11__constructIS5_JS5_EEEvNS_17integral_constantIbLb1EEERS6_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE11__constructIS5_JS5_EEEvNS_17integral_constantIbLb1EEERS6_PT_DpOT0_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE11__constructIS5_JS5_EEEvNS_17integral_constantIbLb1EEERS6_PT_DpOT0_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE11__constructIS5_JS5_EEEvNS_17integral_constantIbLb1EEERS6_PT_DpOT0_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE11__constructIS5_JS5_EEEvNS_17integral_constantIbLb1EEERS6_PT_DpOT0_"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEE9constructIS4_JS4_EEEvPT_DpOT0_ = Module["__ZNSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEE9constructIS4_JS4_EEEvPT_DpOT0_"] = function() {
                return (__ZNSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEE9constructIS4_JS4_EEEvPT_DpOT0_ = Module["__ZNSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEE9constructIS4_JS4_EEEvPT_DpOT0_"] = Module["asm"]["_ZNSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEE9constructIS4_JS4_EEEvPT_DpOT0_"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE8max_sizeEv = Module["__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE8max_sizeEv"] = function() {
                return (__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE8max_sizeEv = Module["__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE8max_sizeEv"] = Module["asm"]["_ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE8max_sizeEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEEC2IDnS8_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEEC2IDnS8_EEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEEC2IDnS8_EEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEEC2IDnS8_EEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEEC2IDnS8_EEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE7__allocEv = Module["__ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE7__allocEv"] = function() {
                return (__ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE7__allocEv = Module["__ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE7__allocEv"] = Module["asm"]["_ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE7__allocEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE8allocateERS6_m = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE8allocateERS6_m"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE8allocateERS6_m = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE8allocateERS6_m"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE8allocateERS6_m"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE9__end_capEv = Module["__ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE9__end_capEv"] = function() {
                return (__ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE9__end_capEv = Module["__ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE9__end_capEv"] = Module["asm"]["_ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE9__end_capEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE46__construct_backward_with_exception_guaranteesIS5_EENS_9enable_ifIXaaooL_ZNS_17integral_constantIbLb1EE5valueEEntsr15__has_constructIS6_PT_SC_EE5valuesr31is_trivially_move_constructibleISC_EE5valueEvE4typeERS6_SD_SD_RSD_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE46__construct_backward_with_exception_guaranteesIS5_EENS_9enable_ifIXaaooL_ZNS_17integral_constantIbLb1EE5valueEEntsr15__has_constructIS6_PT_SC_EE5valuesr31is_trivially_move_constructibleISC_EE5valueEvE4typeERS6_SD_SD_RSD_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE46__construct_backward_with_exception_guaranteesIS5_EENS_9enable_ifIXaaooL_ZNS_17integral_constantIbLb1EE5valueEEntsr15__has_constructIS6_PT_SC_EE5valuesr31is_trivially_move_constructibleISC_EE5valueEvE4typeERS6_SD_SD_RSD_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE46__construct_backward_with_exception_guaranteesIS5_EENS_9enable_ifIXaaooL_ZNS_17integral_constantIbLb1EE5valueEEntsr15__has_constructIS6_PT_SC_EE5valuesr31is_trivially_move_constructibleISC_EE5valueEvE4typeERS6_SD_SD_RSD_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE46__construct_backward_with_exception_guaranteesIS5_EENS_9enable_ifIXaaooL_ZNS_17integral_constantIbLb1EE5valueEEntsr15__has_constructIS6_PT_SC_EE5valuesr31is_trivially_move_constructibleISC_EE5valueEvE4typeERS6_SD_SD_RSD_"]).apply(null, arguments)
            };
            var __ZNSt3__24swapIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS7_EE5valueEvE4typeERS7_SA_ = Module["__ZNSt3__24swapIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS7_EE5valueEvE4typeERS7_SA_"] = function() {
                return (__ZNSt3__24swapIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS7_EE5valueEvE4typeERS7_SA_ = Module["__ZNSt3__24swapIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS7_EE5valueEvE4typeERS7_SA_"] = Module["asm"]["_ZNSt3__24swapIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEENS_9enable_ifIXaasr21is_move_constructibleIT_EE5valuesr18is_move_assignableIS7_EE5valueEvE4typeERS7_SA_"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE14__annotate_newEm = Module["__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE14__annotate_newEm"] = function() {
                return (__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE14__annotate_newEm = Module["__ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE14__annotate_newEm"] = Module["asm"]["_ZNKSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE14__annotate_newEm"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE26__invalidate_all_iteratorsEv = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE26__invalidate_all_iteratorsEv"] = function() {
                return (__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE26__invalidate_all_iteratorsEv = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE26__invalidate_all_iteratorsEv"] = Module["asm"]["_ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE26__invalidate_all_iteratorsEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE5clearEv = Module["__ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE5clearEv"] = function() {
                return (__ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE5clearEv = Module["__ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE5clearEv"] = Module["asm"]["_ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE5clearEv"]).apply(null, arguments)
            };
            var __ZNKSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE8capacityEv = Module["__ZNKSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE8capacityEv"] = function() {
                return (__ZNKSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE8capacityEv = Module["__ZNKSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE8capacityEv"] = Module["asm"]["_ZNKSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE8capacityEv"]).apply(null, arguments)
            };
            var __ZNKSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE7__allocEv = Module["__ZNKSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE7__allocEv"] = function() {
                return (__ZNKSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE7__allocEv = Module["__ZNKSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE7__allocEv"] = Module["asm"]["_ZNKSt3__213__vector_baseINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE7__allocEv"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE8max_sizeERKS6_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE8max_sizeERKS6_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE8max_sizeERKS6_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE8max_sizeERKS6_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE8max_sizeERKS6_"]).apply(null, arguments)
            };
            var __ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE10__max_sizeENS_17integral_constantIbLb1EEERKS6_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE10__max_sizeENS_17integral_constantIbLb1EEERKS6_"] = function() {
                return (__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE10__max_sizeENS_17integral_constantIbLb1EEERKS6_ = Module["__ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE10__max_sizeENS_17integral_constantIbLb1EEERKS6_"] = Module["asm"]["_ZNSt3__216allocator_traitsINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEE10__max_sizeENS_17integral_constantIbLb1EEERKS6_"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE6secondEv = Module["__ZNKSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE6secondEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE6secondEv = Module["__ZNKSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE6secondEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE6secondEv"]).apply(null, arguments)
            };
            var __ZNKSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEE8max_sizeEv = Module["__ZNKSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEE8max_sizeEv"] = function() {
                return (__ZNKSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEE8max_sizeEv = Module["__ZNKSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEE8max_sizeEv"] = Module["asm"]["_ZNKSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEE8max_sizeEv"]).apply(null, arguments)
            };
            var __ZNKSt3__222__compressed_pair_elemINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEELi1ELb1EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEELi1ELb1EE5__getEv"] = function() {
                return (__ZNKSt3__222__compressed_pair_elemINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEELi1ELb1EE5__getEv = Module["__ZNKSt3__222__compressed_pair_elemINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEELi1ELb1EE5__getEv"] = Module["asm"]["_ZNKSt3__222__compressed_pair_elemINS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEELi1ELb1EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRNS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEEEOT_RNS_16remove_referenceIS8_E4typeE = Module["__ZNSt3__27forwardIRNS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEEEOT_RNS_16remove_referenceIS8_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRNS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEEEOT_RNS_16remove_referenceIS8_E4typeE = Module["__ZNSt3__27forwardIRNS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEEEOT_RNS_16remove_referenceIS8_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRNS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEEEEOT_RNS_16remove_referenceIS8_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIRNS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEELi1ELb0EEC2IS7_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIRNS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEELi1ELb0EEC2IS7_vEEOT_"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIRNS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEELi1ELb0EEC2IS7_vEEOT_ = Module["__ZNSt3__222__compressed_pair_elemIRNS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEELi1ELb0EEC2IS7_vEEOT_"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIRNS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEELi1ELb0EEC2IS7_vEEOT_"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEE8allocateEmPKv = Module["__ZNSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEE8allocateEmPKv"] = function() {
                return (__ZNSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEE8allocateEmPKv = Module["__ZNSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEE8allocateEmPKv"] = Module["asm"]["_ZNSt3__29allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEE8allocateEmPKv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE6secondEv = Module["__ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE6secondEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE6secondEv = Module["__ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE6secondEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE6secondEv"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE5firstEv = Module["__ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE5firstEv"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE5firstEv = Module["__ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE5firstEv"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemIRNS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIRNS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEELi1ELb0EE5__getEv"] = function() {
                return (__ZNSt3__222__compressed_pair_elemIRNS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEELi1ELb0EE5__getEv = Module["__ZNSt3__222__compressed_pair_elemIRNS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEELi1ELb0EE5__getEv"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemIRNS_9allocatorINS_17basic_string_viewIcNS_11char_traitsIcEEEEEELi1ELb0EE5__getEv"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEONS_16remove_referenceIT_E4typeEOS8_ = Module["__ZNSt3__24moveIRPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEONS_16remove_referenceIT_E4typeEOS8_"] = function() {
                return (__ZNSt3__24moveIRPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEONS_16remove_referenceIT_E4typeEOS8_ = Module["__ZNSt3__24moveIRPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEONS_16remove_referenceIT_E4typeEOS8_"] = Module["asm"]["_ZNSt3__24moveIRPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEEONS_16remove_referenceIT_E4typeEOS8_"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE17__destruct_at_endEPS4_ = Module["__ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE17__destruct_at_endEPS4_"] = function() {
                return (__ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE17__destruct_at_endEPS4_ = Module["__ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE17__destruct_at_endEPS4_"] = Module["asm"]["_ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE17__destruct_at_endEPS4_"]).apply(null, arguments)
            };
            var __ZNKSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE9__end_capEv = Module["__ZNKSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE9__end_capEv"] = function() {
                return (__ZNKSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE9__end_capEv = Module["__ZNKSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE9__end_capEv"] = Module["asm"]["_ZNKSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE9__end_capEv"]).apply(null, arguments)
            };
            var __ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE17__destruct_at_endEPS4_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE17__destruct_at_endEPS4_NS_17integral_constantIbLb0EEE"] = function() {
                return (__ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE17__destruct_at_endEPS4_NS_17integral_constantIbLb0EEE = Module["__ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE17__destruct_at_endEPS4_NS_17integral_constantIbLb0EEE"] = Module["asm"]["_ZNSt3__214__split_bufferINS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE17__destruct_at_endEPS4_NS_17integral_constantIbLb0EEE"]).apply(null, arguments)
            };
            var __ZNKSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE5firstEv"] = function() {
                return (__ZNKSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE5firstEv = Module["__ZNKSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE5firstEv"] = Module["asm"]["_ZNKSt3__217__compressed_pairIPNS_17basic_string_viewIcNS_11char_traitsIcEEEERNS_9allocatorIS4_EEE5firstEv"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE11__make_iterEPS4_ = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE11__make_iterEPS4_"] = function() {
                return (__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE11__make_iterEPS4_ = Module["__ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE11__make_iterEPS4_"] = Module["asm"]["_ZNSt3__26vectorINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_9allocatorIS4_EEE11__make_iterEPS4_"]).apply(null, arguments)
            };
            var __ZNSt3__211__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEC2ES5_ = Module["__ZNSt3__211__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEC2ES5_"] = function() {
                return (__ZNSt3__211__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEC2ES5_ = Module["__ZNSt3__211__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEC2ES5_"] = Module["asm"]["_ZNSt3__211__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEEC2ES5_"]).apply(null, arguments)
            };
            var __ZNSt3__2eqIPNS_17basic_string_viewIcNS_11char_traitsIcEEEES5_EEbRKNS_11__wrap_iterIT_EERKNS6_IT0_EE = Module["__ZNSt3__2eqIPNS_17basic_string_viewIcNS_11char_traitsIcEEEES5_EEbRKNS_11__wrap_iterIT_EERKNS6_IT0_EE"] = function() {
                return (__ZNSt3__2eqIPNS_17basic_string_viewIcNS_11char_traitsIcEEEES5_EEbRKNS_11__wrap_iterIT_EERKNS6_IT0_EE = Module["__ZNSt3__2eqIPNS_17basic_string_viewIcNS_11char_traitsIcEEEES5_EEbRKNS_11__wrap_iterIT_EERKNS6_IT0_EE"] = Module["asm"]["_ZNSt3__2eqIPNS_17basic_string_viewIcNS_11char_traitsIcEEEES5_EEbRKNS_11__wrap_iterIT_EERKNS6_IT0_EE"]).apply(null, arguments)
            };
            var __ZNKSt3__211__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEE4baseEv = Module["__ZNKSt3__211__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEE4baseEv"] = function() {
                return (__ZNKSt3__211__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEE4baseEv = Module["__ZNKSt3__211__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEE4baseEv"] = Module["asm"]["_ZNKSt3__211__wrap_iterIPNS_17basic_string_viewIcNS_11char_traitsIcEEEEE4baseEv"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem20__is_pathable_stringINS_17basic_string_viewIcNS_11char_traitsIcEEEEvE15__first_or_nullERKS6_ = Module["__ZNSt3__24__fs10filesystem20__is_pathable_stringINS_17basic_string_viewIcNS_11char_traitsIcEEEEvE15__first_or_nullERKS6_"] = function() {
                return (__ZNSt3__24__fs10filesystem20__is_pathable_stringINS_17basic_string_viewIcNS_11char_traitsIcEEEEvE15__first_or_nullERKS6_ = Module["__ZNSt3__24__fs10filesystem20__is_pathable_stringINS_17basic_string_viewIcNS_11char_traitsIcEEEEvE15__first_or_nullERKS6_"] = Module["asm"]["_ZNSt3__24__fs10filesystem20__is_pathable_stringINS_17basic_string_viewIcNS_11char_traitsIcEEEEvE15__first_or_nullERKS6_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem4path20__source_is_absoluteIcEEbT_ = Module["__ZNSt3__24__fs10filesystem4path20__source_is_absoluteIcEEbT_"] = function() {
                return (__ZNSt3__24__fs10filesystem4path20__source_is_absoluteIcEEbT_ = Module["__ZNSt3__24__fs10filesystem4path20__source_is_absoluteIcEEbT_"] = Module["asm"]["_ZNSt3__24__fs10filesystem4path20__source_is_absoluteIcEEbT_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem14__is_separatorIcEENS_9enable_ifIXsr18__can_convert_charIT_EE5valueEbE4typeES4_ = Module["__ZNSt3__24__fs10filesystem14__is_separatorIcEENS_9enable_ifIXsr18__can_convert_charIT_EE5valueEbE4typeES4_"] = function() {
                return (__ZNSt3__24__fs10filesystem14__is_separatorIcEENS_9enable_ifIXsr18__can_convert_charIT_EE5valueEbE4typeES4_ = Module["__ZNSt3__24__fs10filesystem14__is_separatorIcEENS_9enable_ifIXsr18__can_convert_charIT_EE5valueEbE4typeES4_"] = Module["asm"]["_ZNSt3__24__fs10filesystem14__is_separatorIcEENS_9enable_ifIXsr18__can_convert_charIT_EE5valueEbE4typeES4_"]).apply(null, arguments)
            };
            var __ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEEixEm = Module["__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEEixEm"] = function() {
                return (__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEEixEm = Module["__ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEEixEm"] = Module["asm"]["_ZNKSt3__217basic_string_viewIcNS_11char_traitsIcEEEixEm"]).apply(null, arguments)
            };
            var __ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEEC2IDnNS_18__default_init_tagEEEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEEC2IDnNS_18__default_init_tagEEEOT_OT0_"] = function() {
                return (__ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEEC2IDnNS_18__default_init_tagEEEOT_OT0_ = Module["__ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEEC2IDnNS_18__default_init_tagEEEOT_OT0_"] = Module["asm"]["_ZNSt3__217__compressed_pairIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEEC2IDnNS_18__default_init_tagEEEOT_OT0_"]).apply(null, arguments)
            };
            var __ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEELi1ELb1EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEELi1ELb1EEC2ENS_18__default_init_tagE"] = function() {
                return (__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEELi1ELb1EEC2ENS_18__default_init_tagE = Module["__ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEELi1ELb1EEC2ENS_18__default_init_tagE"] = Module["asm"]["_ZNSt3__222__compressed_pair_elemINS_9allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEELi1ELb1EEC2ENS_18__default_init_tagE"]).apply(null, arguments)
            };
            var __ZNSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEC2Ev = Module["__ZNSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEC2Ev"] = function() {
                return (__ZNSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEC2Ev = Module["__ZNSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEC2Ev"] = Module["asm"]["_ZNSt3__29allocatorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEC2Ev"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE5clearEv = Module["__ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE5clearEv"] = function() {
                return (__ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE5clearEv = Module["__ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE5clearEv"] = Module["asm"]["_ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE5clearEv"]).apply(null, arguments)
            };
            var __ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE17__destruct_at_endEPS9_ = Module["__ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE17__destruct_at_endEPS9_"] = function() {
                return (__ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE17__destruct_at_endEPS9_ = Module["__ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE17__destruct_at_endEPS9_"] = Module["asm"]["_ZNSt3__213__vector_baseINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE17__destruct_at_endEPS9_"]).apply(null, arguments)
            };
            var __ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE27__invalidate_iterators_pastEPS9_ = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE27__invalidate_iterators_pastEPS9_"] = function() {
                return (__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE27__invalidate_iterators_pastEPS9_ = Module["__ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE27__invalidate_iterators_pastEPS9_"] = Module["asm"]["_ZNSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE27__invalidate_iterators_pastEPS9_"]).apply(null, arguments)
            };
            var __ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE17__annotate_shrinkEm = Module["__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE17__annotate_shrinkEm"] = function() {
                return (__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE17__annotate_shrinkEm = Module["__ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE17__annotate_shrinkEm"] = Module["asm"]["_ZNKSt3__26vectorINS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEENS_9allocatorIS9_EEE17__annotate_shrinkEm"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA2_cPccLb1EE13__range_beginEPKc = Module["__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA2_cPccLb1EE13__range_beginEPKc"] = function() {
                return (__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA2_cPccLb1EE13__range_beginEPKc = Module["__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA2_cPccLb1EE13__range_beginEPKc"] = Module["asm"]["_ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA2_cPccLb1EE13__range_beginEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA2_cPccLb1EE11__range_endEPKc = Module["__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA2_cPccLb1EE11__range_endEPKc"] = function() {
                return (__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA2_cPccLb1EE11__range_endEPKc = Module["__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA2_cPccLb1EE11__range_endEPKc"] = Module["asm"]["_ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA2_cPccLb1EE11__range_endEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__211__wrap_iterIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEC2ESA_ = Module["__ZNSt3__211__wrap_iterIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEC2ESA_"] = function() {
                return (__ZNSt3__211__wrap_iterIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEC2ESA_ = Module["__ZNSt3__211__wrap_iterIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEC2ESA_"] = Module["asm"]["_ZNSt3__211__wrap_iterIPNS_4pairINS_17basic_string_viewIcNS_11char_traitsIcEEEENS_4__fs10filesystem12PathPartKindEEEEC2ESA_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA1_cPccLb1EE15__first_or_nullEPKc = Module["__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA1_cPccLb1EE15__first_or_nullEPKc"] = function() {
                return (__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA1_cPccLb1EE15__first_or_nullEPKc = Module["__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA1_cPccLb1EE15__first_or_nullEPKc"] = Module["asm"]["_ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA1_cPccLb1EE15__first_or_nullEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA3_cPccLb1EE15__first_or_nullEPKc = Module["__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA3_cPccLb1EE15__first_or_nullEPKc"] = function() {
                return (__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA3_cPccLb1EE15__first_or_nullEPKc = Module["__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA3_cPccLb1EE15__first_or_nullEPKc"] = Module["asm"]["_ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA3_cPccLb1EE15__first_or_nullEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceIA3_cEEvRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKT_ = Module["__ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceIA3_cEEvRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKT_"] = function() {
                return (__ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceIA3_cEEvRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKT_ = Module["__ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceIA3_cEEvRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKT_"] = Module["asm"]["_ZNSt3__24__fs10filesystem8_PathCVTIcE15__append_sourceIA3_cEEvRNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEERKT_"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA3_cPccLb1EE13__range_beginEPKc = Module["__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA3_cPccLb1EE13__range_beginEPKc"] = function() {
                return (__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA3_cPccLb1EE13__range_beginEPKc = Module["__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA3_cPccLb1EE13__range_beginEPKc"] = Module["asm"]["_ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA3_cPccLb1EE13__range_beginEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA3_cPccLb1EE11__range_endEPKc = Module["__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA3_cPccLb1EE11__range_endEPKc"] = function() {
                return (__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA3_cPccLb1EE11__range_endEPKc = Module["__ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA3_cPccLb1EE11__range_endEPKc"] = Module["asm"]["_ZNSt3__24__fs10filesystem24__is_pathable_char_arrayIA3_cPccLb1EE11__range_endEPKc"]).apply(null, arguments)
            };
            var __ZNSt3__24__fs10filesystem16filesystem_errorD1Ev = Module["__ZNSt3__24__fs10filesystem16filesystem_errorD1Ev"] = function() {
                return (__ZNSt3__24__fs10filesystem16filesystem_errorD1Ev = Module["__ZNSt3__24__fs10filesystem16filesystem_errorD1Ev"] = Module["asm"]["_ZNSt3__24__fs10filesystem16filesystem_errorD1Ev"]).apply(null, arguments)
            };
            var __ZNSt12experimental15fundamentals_v13pmr19new_delete_resourceEv = Module["__ZNSt12experimental15fundamentals_v13pmr19new_delete_resourceEv"] = function() {
                return (__ZNSt12experimental15fundamentals_v13pmr19new_delete_resourceEv = Module["__ZNSt12experimental15fundamentals_v13pmr19new_delete_resourceEv"] = Module["asm"]["_ZNSt12experimental15fundamentals_v13pmr19new_delete_resourceEv"]).apply(null, arguments)
            };
            var __ZNSt12experimental15fundamentals_v13pmr20null_memory_resourceEv = Module["__ZNSt12experimental15fundamentals_v13pmr20null_memory_resourceEv"] = function() {
                return (__ZNSt12experimental15fundamentals_v13pmr20null_memory_resourceEv = Module["__ZNSt12experimental15fundamentals_v13pmr20null_memory_resourceEv"] = Module["asm"]["_ZNSt12experimental15fundamentals_v13pmr20null_memory_resourceEv"]).apply(null, arguments)
            };
            var __ZNSt12experimental15fundamentals_v13pmr20get_default_resourceEv = Module["__ZNSt12experimental15fundamentals_v13pmr20get_default_resourceEv"] = function() {
                return (__ZNSt12experimental15fundamentals_v13pmr20get_default_resourceEv = Module["__ZNSt12experimental15fundamentals_v13pmr20get_default_resourceEv"] = Module["asm"]["_ZNSt12experimental15fundamentals_v13pmr20get_default_resourceEv"]).apply(null, arguments)
            };
            var __ZNSt3__224atomic_exchange_explicitIPNSt12experimental15fundamentals_v13pmr15memory_resourceEEET_PNS_6atomicIS6_EES6_NS_12memory_orderE = Module["__ZNSt3__224atomic_exchange_explicitIPNSt12experimental15fundamentals_v13pmr15memory_resourceEEET_PNS_6atomicIS6_EES6_NS_12memory_orderE"] = function() {
                return (__ZNSt3__224atomic_exchange_explicitIPNSt12experimental15fundamentals_v13pmr15memory_resourceEEET_PNS_6atomicIS6_EES6_NS_12memory_orderE = Module["__ZNSt3__224atomic_exchange_explicitIPNSt12experimental15fundamentals_v13pmr15memory_resourceEEET_PNS_6atomicIS6_EES6_NS_12memory_orderE"] = Module["asm"]["_ZNSt3__224atomic_exchange_explicitIPNSt12experimental15fundamentals_v13pmr15memory_resourceEEET_PNS_6atomicIS6_EES6_NS_12memory_orderE"]).apply(null, arguments)
            };
            var __ZNSt3__220atomic_load_explicitIPNSt12experimental15fundamentals_v13pmr15memory_resourceEEET_PKNS_6atomicIS6_EENS_12memory_orderE = Module["__ZNSt3__220atomic_load_explicitIPNSt12experimental15fundamentals_v13pmr15memory_resourceEEET_PKNS_6atomicIS6_EENS_12memory_orderE"] = function() {
                return (__ZNSt3__220atomic_load_explicitIPNSt12experimental15fundamentals_v13pmr15memory_resourceEEET_PKNS_6atomicIS6_EENS_12memory_orderE = Module["__ZNSt3__220atomic_load_explicitIPNSt12experimental15fundamentals_v13pmr15memory_resourceEEET_PKNS_6atomicIS6_EENS_12memory_orderE"] = Module["asm"]["_ZNSt3__220atomic_load_explicitIPNSt12experimental15fundamentals_v13pmr15memory_resourceEEET_PKNS_6atomicIS6_EENS_12memory_orderE"]).apply(null, arguments)
            };
            var __ZNSt12experimental15fundamentals_v13pmr20set_default_resourceEPNS1_15memory_resourceE = Module["__ZNSt12experimental15fundamentals_v13pmr20set_default_resourceEPNS1_15memory_resourceE"] = function() {
                return (__ZNSt12experimental15fundamentals_v13pmr20set_default_resourceEPNS1_15memory_resourceE = Module["__ZNSt12experimental15fundamentals_v13pmr20set_default_resourceEPNS1_15memory_resourceE"] = Module["asm"]["_ZNSt12experimental15fundamentals_v13pmr20set_default_resourceEPNS1_15memory_resourceE"]).apply(null, arguments)
            };
            var __ZNSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_impD0Ev = Module["__ZNSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_impD0Ev"] = function() {
                return (__ZNSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_impD0Ev = Module["__ZNSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_impD0Ev"] = Module["asm"]["_ZNSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_impD0Ev"]).apply(null, arguments)
            };
            var __ZNSt12experimental15fundamentals_v13pmr15memory_resourceD2Ev = Module["__ZNSt12experimental15fundamentals_v13pmr15memory_resourceD2Ev"] = function() {
                return (__ZNSt12experimental15fundamentals_v13pmr15memory_resourceD2Ev = Module["__ZNSt12experimental15fundamentals_v13pmr15memory_resourceD2Ev"] = Module["asm"]["_ZNSt12experimental15fundamentals_v13pmr15memory_resourceD2Ev"]).apply(null, arguments)
            };
            var __ZNSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_imp11do_allocateEmm = Module["__ZNSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_imp11do_allocateEmm"] = function() {
                return (__ZNSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_imp11do_allocateEmm = Module["__ZNSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_imp11do_allocateEmm"] = Module["asm"]["_ZNSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_imp11do_allocateEmm"]).apply(null, arguments)
            };
            var __ZNSt3__224__is_overaligned_for_newEm = Module["__ZNSt3__224__is_overaligned_for_newEm"] = function() {
                return (__ZNSt3__224__is_overaligned_for_newEm = Module["__ZNSt3__224__is_overaligned_for_newEm"] = Module["asm"]["_ZNSt3__224__is_overaligned_for_newEm"]).apply(null, arguments)
            };
            var __ZNSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_imp13do_deallocateEPvmm = Module["__ZNSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_imp13do_deallocateEPvmm"] = function() {
                return (__ZNSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_imp13do_deallocateEPvmm = Module["__ZNSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_imp13do_deallocateEPvmm"] = Module["asm"]["_ZNSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_imp13do_deallocateEPvmm"]).apply(null, arguments)
            };
            var __ZNKSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_imp11do_is_equalERKNS1_15memory_resourceE = Module["__ZNKSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_imp11do_is_equalERKNS1_15memory_resourceE"] = function() {
                return (__ZNKSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_imp11do_is_equalERKNS1_15memory_resourceE = Module["__ZNKSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_imp11do_is_equalERKNS1_15memory_resourceE"] = Module["asm"]["_ZNKSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_imp11do_is_equalERKNS1_15memory_resourceE"]).apply(null, arguments)
            };
            var __ZNSt12experimental15fundamentals_v13pmr26__null_memory_resource_impD0Ev = Module["__ZNSt12experimental15fundamentals_v13pmr26__null_memory_resource_impD0Ev"] = function() {
                return (__ZNSt12experimental15fundamentals_v13pmr26__null_memory_resource_impD0Ev = Module["__ZNSt12experimental15fundamentals_v13pmr26__null_memory_resource_impD0Ev"] = Module["asm"]["_ZNSt12experimental15fundamentals_v13pmr26__null_memory_resource_impD0Ev"]).apply(null, arguments)
            };
            var __ZNSt12experimental15fundamentals_v13pmr26__null_memory_resource_imp11do_allocateEmm = Module["__ZNSt12experimental15fundamentals_v13pmr26__null_memory_resource_imp11do_allocateEmm"] = function() {
                return (__ZNSt12experimental15fundamentals_v13pmr26__null_memory_resource_imp11do_allocateEmm = Module["__ZNSt12experimental15fundamentals_v13pmr26__null_memory_resource_imp11do_allocateEmm"] = Module["asm"]["_ZNSt12experimental15fundamentals_v13pmr26__null_memory_resource_imp11do_allocateEmm"]).apply(null, arguments)
            };
            var __ZNSt12experimental15fundamentals_v13pmr26__null_memory_resource_imp13do_deallocateEPvmm = Module["__ZNSt12experimental15fundamentals_v13pmr26__null_memory_resource_imp13do_deallocateEPvmm"] = function() {
                return (__ZNSt12experimental15fundamentals_v13pmr26__null_memory_resource_imp13do_deallocateEPvmm = Module["__ZNSt12experimental15fundamentals_v13pmr26__null_memory_resource_imp13do_deallocateEPvmm"] = Module["asm"]["_ZNSt12experimental15fundamentals_v13pmr26__null_memory_resource_imp13do_deallocateEPvmm"]).apply(null, arguments)
            };
            var __ZNKSt12experimental15fundamentals_v13pmr26__null_memory_resource_imp11do_is_equalERKNS1_15memory_resourceE = Module["__ZNKSt12experimental15fundamentals_v13pmr26__null_memory_resource_imp11do_is_equalERKNS1_15memory_resourceE"] = function() {
                return (__ZNKSt12experimental15fundamentals_v13pmr26__null_memory_resource_imp11do_is_equalERKNS1_15memory_resourceE = Module["__ZNKSt12experimental15fundamentals_v13pmr26__null_memory_resource_imp11do_is_equalERKNS1_15memory_resourceE"] = Module["asm"]["_ZNKSt12experimental15fundamentals_v13pmr26__null_memory_resource_imp11do_is_equalERKNS1_15memory_resourceE"]).apply(null, arguments)
            };
            var __ZNSt3__213__atomic_baseIPNSt12experimental15fundamentals_v13pmr15memory_resourceELb0EE8exchangeES5_NS_12memory_orderE = Module["__ZNSt3__213__atomic_baseIPNSt12experimental15fundamentals_v13pmr15memory_resourceELb0EE8exchangeES5_NS_12memory_orderE"] = function() {
                return (__ZNSt3__213__atomic_baseIPNSt12experimental15fundamentals_v13pmr15memory_resourceELb0EE8exchangeES5_NS_12memory_orderE = Module["__ZNSt3__213__atomic_baseIPNSt12experimental15fundamentals_v13pmr15memory_resourceELb0EE8exchangeES5_NS_12memory_orderE"] = Module["asm"]["_ZNSt3__213__atomic_baseIPNSt12experimental15fundamentals_v13pmr15memory_resourceELb0EE8exchangeES5_NS_12memory_orderE"]).apply(null, arguments)
            };
            var __ZNKSt3__213__atomic_baseIPNSt12experimental15fundamentals_v13pmr15memory_resourceELb0EE4loadENS_12memory_orderE = Module["__ZNKSt3__213__atomic_baseIPNSt12experimental15fundamentals_v13pmr15memory_resourceELb0EE4loadENS_12memory_orderE"] = function() {
                return (__ZNKSt3__213__atomic_baseIPNSt12experimental15fundamentals_v13pmr15memory_resourceELb0EE4loadENS_12memory_orderE = Module["__ZNKSt3__213__atomic_baseIPNSt12experimental15fundamentals_v13pmr15memory_resourceELb0EE4loadENS_12memory_orderE"] = Module["asm"]["_ZNKSt3__213__atomic_baseIPNSt12experimental15fundamentals_v13pmr15memory_resourceELb0EE4loadENS_12memory_orderE"]).apply(null, arguments)
            };
            var __ZNSt3__221__cxx_atomic_exchangeIPNSt12experimental15fundamentals_v13pmr15memory_resourceEEET_PNS_22__cxx_atomic_base_implIS6_EES6_NS_12memory_orderE = Module["__ZNSt3__221__cxx_atomic_exchangeIPNSt12experimental15fundamentals_v13pmr15memory_resourceEEET_PNS_22__cxx_atomic_base_implIS6_EES6_NS_12memory_orderE"] = function() {
                return (__ZNSt3__221__cxx_atomic_exchangeIPNSt12experimental15fundamentals_v13pmr15memory_resourceEEET_PNS_22__cxx_atomic_base_implIS6_EES6_NS_12memory_orderE = Module["__ZNSt3__221__cxx_atomic_exchangeIPNSt12experimental15fundamentals_v13pmr15memory_resourceEEET_PNS_22__cxx_atomic_base_implIS6_EES6_NS_12memory_orderE"] = Module["asm"]["_ZNSt3__221__cxx_atomic_exchangeIPNSt12experimental15fundamentals_v13pmr15memory_resourceEEET_PNS_22__cxx_atomic_base_implIS6_EES6_NS_12memory_orderE"]).apply(null, arguments)
            };
            var __ZNSt3__217__cxx_atomic_loadIPNSt12experimental15fundamentals_v13pmr15memory_resourceEEET_PKNS_22__cxx_atomic_base_implIS6_EENS_12memory_orderE = Module["__ZNSt3__217__cxx_atomic_loadIPNSt12experimental15fundamentals_v13pmr15memory_resourceEEET_PKNS_22__cxx_atomic_base_implIS6_EENS_12memory_orderE"] = function() {
                return (__ZNSt3__217__cxx_atomic_loadIPNSt12experimental15fundamentals_v13pmr15memory_resourceEEET_PKNS_22__cxx_atomic_base_implIS6_EENS_12memory_orderE = Module["__ZNSt3__217__cxx_atomic_loadIPNSt12experimental15fundamentals_v13pmr15memory_resourceEEET_PKNS_22__cxx_atomic_base_implIS6_EENS_12memory_orderE"] = Module["asm"]["_ZNSt3__217__cxx_atomic_loadIPNSt12experimental15fundamentals_v13pmr15memory_resourceEEET_PKNS_22__cxx_atomic_base_implIS6_EENS_12memory_orderE"]).apply(null, arguments)
            };
            var _abort_message = Module["_abort_message"] = function() {
                return (_abort_message = Module["_abort_message"] = Module["asm"]["abort_message"]).apply(null, arguments)
            };
            var ___cxa_bad_cast = Module["___cxa_bad_cast"] = function() {
                return (___cxa_bad_cast = Module["___cxa_bad_cast"] = Module["asm"]["__cxa_bad_cast"]).apply(null, arguments)
            };
            var ___cxa_bad_typeid = Module["___cxa_bad_typeid"] = function() {
                return (___cxa_bad_typeid = Module["___cxa_bad_typeid"] = Module["asm"]["__cxa_bad_typeid"]).apply(null, arguments)
            };
            var ___cxa_throw_bad_array_new_length = Module["___cxa_throw_bad_array_new_length"] = function() {
                return (___cxa_throw_bad_array_new_length = Module["___cxa_throw_bad_array_new_length"] = Module["asm"]["__cxa_throw_bad_array_new_length"]).apply(null, arguments)
            };
            var __ZSt14set_unexpectedPFvvE = Module["__ZSt14set_unexpectedPFvvE"] = function() {
                return (__ZSt14set_unexpectedPFvvE = Module["__ZSt14set_unexpectedPFvvE"] = Module["asm"]["_ZSt14set_unexpectedPFvvE"]).apply(null, arguments)
            };
            var __ZSt13set_terminatePFvvE = Module["__ZSt13set_terminatePFvvE"] = function() {
                return (__ZSt13set_terminatePFvvE = Module["__ZSt13set_terminatePFvvE"] = Module["asm"]["_ZSt13set_terminatePFvvE"]).apply(null, arguments)
            };
            var ___cxa_demangle = Module["___cxa_demangle"] = function() {
                return (___cxa_demangle = Module["___cxa_demangle"] = Module["asm"]["__cxa_demangle"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA34_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA34_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA34_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA34_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA34_KcEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__25equalIPKcS2_EEbT_S3_T0_ = Module["__ZNSt3__25equalIPKcS2_EEbT_S3_T0_"] = function() {
                return (__ZNSt3__25equalIPKcS2_EEbT_S3_T0_ = Module["__ZNSt3__25equalIPKcS2_EEbT_S3_T0_"] = Module["asm"]["_ZNSt3__25equalIPKcS2_EEbT_S3_T0_"]).apply(null, arguments)
            };
            var __ZNSt3__25equalIPKcS2_NS_10__equal_toIccEEEEbT_S5_T0_T1_ = Module["__ZNSt3__25equalIPKcS2_NS_10__equal_toIccEEEEbT_S5_T0_T1_"] = function() {
                return (__ZNSt3__25equalIPKcS2_NS_10__equal_toIccEEEEbT_S5_T0_T1_ = Module["__ZNSt3__25equalIPKcS2_NS_10__equal_toIccEEEEbT_S5_T0_T1_"] = Module["asm"]["_ZNSt3__25equalIPKcS2_NS_10__equal_toIccEEEEbT_S5_T0_T1_"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA12_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA12_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA12_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA12_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA12_KcEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA9_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA9_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA9_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA9_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA9_KcEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA14_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA14_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA14_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA14_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA14_KcEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA19_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA19_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA19_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA19_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA19_KcEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA27_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA27_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA27_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA27_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA27_KcEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA41_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA41_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA41_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA41_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA41_KcEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA18_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA18_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA18_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA18_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA18_KcEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA22_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA22_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA22_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA22_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA22_KcEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA20_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA20_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA20_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA20_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA20_KcEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA25_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA25_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA25_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA25_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA25_KcEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA4_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA4_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA4_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA4_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA4_KcEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRmEEOT_RNS_16remove_referenceIS2_E4typeE = Module["__ZNSt3__27forwardIRmEEOT_RNS_16remove_referenceIS2_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRmEEOT_RNS_16remove_referenceIS2_E4typeE = Module["__ZNSt3__27forwardIRmEEOT_RNS_16remove_referenceIS2_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRmEEOT_RNS_16remove_referenceIS2_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA5_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA5_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA5_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA5_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA5_KcEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRbEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRbEEONS_16remove_referenceIT_E4typeEOS3_"] = function() {
                return (__ZNSt3__24moveIRbEEONS_16remove_referenceIT_E4typeEOS3_ = Module["__ZNSt3__24moveIRbEEONS_16remove_referenceIT_E4typeEOS3_"] = Module["asm"]["_ZNSt3__24moveIRbEEONS_16remove_referenceIT_E4typeEOS3_"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA10_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA10_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA10_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA10_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA10_KcEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA2_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA2_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA2_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA2_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA2_KcEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA11_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA11_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA11_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA11_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA11_KcEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRbEEOT_RNS_16remove_referenceIS2_E4typeE = Module["__ZNSt3__27forwardIRbEEOT_RNS_16remove_referenceIS2_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRbEEOT_RNS_16remove_referenceIS2_E4typeE = Module["__ZNSt3__27forwardIRbEEOT_RNS_16remove_referenceIS2_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRbEEOT_RNS_16remove_referenceIS2_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIbEEOT_RNS_16remove_referenceIS1_E4typeE = Module["__ZNSt3__27forwardIbEEOT_RNS_16remove_referenceIS1_E4typeE"] = function() {
                return (__ZNSt3__27forwardIbEEOT_RNS_16remove_referenceIS1_E4typeE = Module["__ZNSt3__27forwardIbEEOT_RNS_16remove_referenceIS1_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIbEEOT_RNS_16remove_referenceIS1_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA13_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA13_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA13_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA13_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA13_KcEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA3_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA3_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA3_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA3_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA3_KcEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA17_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA17_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA17_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA17_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA17_KcEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA6_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA6_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA6_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA6_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA6_KcEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA8_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA8_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA8_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA8_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA8_KcEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __Z6memchrUa9enable_ifILb1EEPKvim = Module["__Z6memchrUa9enable_ifILb1EEPKvim"] = function() {
                return (__Z6memchrUa9enable_ifILb1EEPKvim = Module["__Z6memchrUa9enable_ifILb1EEPKvim"] = Module["asm"]["_Z6memchrUa9enable_ifILb1EEPKvim"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA16_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA16_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA16_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA16_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA16_KcEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __Z15__libcpp_memchrPKvim = Module["__Z15__libcpp_memchrPKvim"] = function() {
                return (__Z15__libcpp_memchrPKvim = Module["__Z15__libcpp_memchrPKvim"] = Module["asm"]["_Z15__libcpp_memchrPKvim"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRjEEOT_RNS_16remove_referenceIS2_E4typeE = Module["__ZNSt3__27forwardIRjEEOT_RNS_16remove_referenceIS2_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRjEEOT_RNS_16remove_referenceIS2_E4typeE = Module["__ZNSt3__27forwardIRjEEOT_RNS_16remove_referenceIS2_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRjEEOT_RNS_16remove_referenceIS2_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__23endIcLm21EEEPT_RAT0__S1_ = Module["__ZNSt3__23endIcLm21EEEPT_RAT0__S1_"] = function() {
                return (__ZNSt3__23endIcLm21EEEPT_RAT0__S1_ = Module["__ZNSt3__23endIcLm21EEEPT_RAT0__S1_"] = Module["asm"]["_ZNSt3__23endIcLm21EEEPT_RAT0__S1_"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA15_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA15_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA15_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA15_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA15_KcEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRiEEOT_RNS_16remove_referenceIS2_E4typeE = Module["__ZNSt3__27forwardIRiEEOT_RNS_16remove_referenceIS2_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRiEEOT_RNS_16remove_referenceIS2_E4typeE = Module["__ZNSt3__27forwardIRiEEOT_RNS_16remove_referenceIS2_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRiEEOT_RNS_16remove_referenceIS2_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__27forwardIRA7_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA7_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = function() {
                return (__ZNSt3__27forwardIRA7_KcEEOT_RNS_16remove_referenceIS4_E4typeE = Module["__ZNSt3__27forwardIRA7_KcEEOT_RNS_16remove_referenceIS4_E4typeE"] = Module["asm"]["_ZNSt3__27forwardIRA7_KcEEOT_RNS_16remove_referenceIS4_E4typeE"]).apply(null, arguments)
            };
            var __ZNSt3__24moveIRPKcEEONS_16remove_referenceIT_E4typeEOS5_ = Module["__ZNSt3__24moveIRPKcEEONS_16remove_referenceIT_E4typeEOS5_"] = function() {
                return (__ZNSt3__24moveIRPKcEEONS_16remove_referenceIT_E4typeEOS5_ = Module["__ZNSt3__24moveIRPKcEEONS_16remove_referenceIT_E4typeEOS5_"] = Module["asm"]["_ZNSt3__24moveIRPKcEEONS_16remove_referenceIT_E4typeEOS5_"]).apply(null, arguments)
            };
            var ___cxa_get_globals = Module["___cxa_get_globals"] = function() {
                return (___cxa_get_globals = Module["___cxa_get_globals"] = Module["asm"]["__cxa_get_globals"]).apply(null, arguments)
            };
            var ___cxa_get_globals_fast = Module["___cxa_get_globals_fast"] = function() {
                return (___cxa_get_globals_fast = Module["___cxa_get_globals_fast"] = Module["asm"]["__cxa_get_globals_fast"]).apply(null, arguments)
            };
            var ___cxa_guard_abort = Module["___cxa_guard_abort"] = function() {
                return (___cxa_guard_abort = Module["___cxa_guard_abort"] = Module["asm"]["__cxa_guard_abort"]).apply(null, arguments)
            };
            var __ZSt14get_unexpectedv = Module["__ZSt14get_unexpectedv"] = function() {
                return (__ZSt14get_unexpectedv = Module["__ZSt14get_unexpectedv"] = Module["asm"]["_ZSt14get_unexpectedv"]).apply(null, arguments)
            };
            var __ZSt12__unexpectedPFvvE = Module["__ZSt12__unexpectedPFvvE"] = function() {
                return (__ZSt12__unexpectedPFvvE = Module["__ZSt12__unexpectedPFvvE"] = Module["asm"]["_ZSt12__unexpectedPFvvE"]).apply(null, arguments)
            };
            var __ZSt10unexpectedv = Module["__ZSt10unexpectedv"] = function() {
                return (__ZSt10unexpectedv = Module["__ZSt10unexpectedv"] = Module["asm"]["_ZSt10unexpectedv"]).apply(null, arguments)
            };
            var __ZSt13get_terminatev = Module["__ZSt13get_terminatev"] = function() {
                return (__ZSt13get_terminatev = Module["__ZSt13get_terminatev"] = Module["asm"]["_ZSt13get_terminatev"]).apply(null, arguments)
            };
            var __ZSt11__terminatePFvvE = Module["__ZSt11__terminatePFvvE"] = function() {
                return (__ZSt11__terminatePFvvE = Module["__ZSt11__terminatePFvvE"] = Module["asm"]["_ZSt11__terminatePFvvE"]).apply(null, arguments)
            };
            var __ZSt15set_new_handlerPFvvE = Module["__ZSt15set_new_handlerPFvvE"] = function() {
                return (__ZSt15set_new_handlerPFvvE = Module["__ZSt15set_new_handlerPFvvE"] = Module["asm"]["_ZSt15set_new_handlerPFvvE"]).apply(null, arguments)
            };
            var ___cxa_deleted_virtual = Module["___cxa_deleted_virtual"] = function() {
                return (___cxa_deleted_virtual = Module["___cxa_deleted_virtual"] = Module["asm"]["__cxa_deleted_virtual"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv130__aligned_malloc_with_fallbackEm = Module["__ZN10__cxxabiv130__aligned_malloc_with_fallbackEm"] = function() {
                return (__ZN10__cxxabiv130__aligned_malloc_with_fallbackEm = Module["__ZN10__cxxabiv130__aligned_malloc_with_fallbackEm"] = Module["asm"]["_ZN10__cxxabiv130__aligned_malloc_with_fallbackEm"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv122__calloc_with_fallbackEmm = Module["__ZN10__cxxabiv122__calloc_with_fallbackEmm"] = function() {
                return (__ZN10__cxxabiv122__calloc_with_fallbackEmm = Module["__ZN10__cxxabiv122__calloc_with_fallbackEmm"] = Module["asm"]["_ZN10__cxxabiv122__calloc_with_fallbackEmm"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv128__aligned_free_with_fallbackEPv = Module["__ZN10__cxxabiv128__aligned_free_with_fallbackEPv"] = function() {
                return (__ZN10__cxxabiv128__aligned_free_with_fallbackEPv = Module["__ZN10__cxxabiv128__aligned_free_with_fallbackEPv"] = Module["asm"]["_ZN10__cxxabiv128__aligned_free_with_fallbackEPv"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv120__free_with_fallbackEPv = Module["__ZN10__cxxabiv120__free_with_fallbackEPv"] = function() {
                return (__ZN10__cxxabiv120__free_with_fallbackEPv = Module["__ZN10__cxxabiv120__free_with_fallbackEPv"] = Module["asm"]["_ZN10__cxxabiv120__free_with_fallbackEPv"]).apply(null, arguments)
            };
            var __ZNSt9exceptionD0Ev = Module["__ZNSt9exceptionD0Ev"] = function() {
                return (__ZNSt9exceptionD0Ev = Module["__ZNSt9exceptionD0Ev"] = Module["asm"]["_ZNSt9exceptionD0Ev"]).apply(null, arguments)
            };
            var __ZNKSt9exception4whatEv = Module["__ZNKSt9exception4whatEv"] = function() {
                return (__ZNKSt9exception4whatEv = Module["__ZNKSt9exception4whatEv"] = Module["asm"]["_ZNKSt9exception4whatEv"]).apply(null, arguments)
            };
            var __ZNSt13bad_exceptionD0Ev = Module["__ZNSt13bad_exceptionD0Ev"] = function() {
                return (__ZNSt13bad_exceptionD0Ev = Module["__ZNSt13bad_exceptionD0Ev"] = Module["asm"]["_ZNSt13bad_exceptionD0Ev"]).apply(null, arguments)
            };
            var __ZNKSt13bad_exception4whatEv = Module["__ZNKSt13bad_exception4whatEv"] = function() {
                return (__ZNKSt13bad_exception4whatEv = Module["__ZNKSt13bad_exception4whatEv"] = Module["asm"]["_ZNKSt13bad_exception4whatEv"]).apply(null, arguments)
            };
            var __ZNSt9bad_allocC2Ev = Module["__ZNSt9bad_allocC2Ev"] = function() {
                return (__ZNSt9bad_allocC2Ev = Module["__ZNSt9bad_allocC2Ev"] = Module["asm"]["_ZNSt9bad_allocC2Ev"]).apply(null, arguments)
            };
            var __ZNSt9bad_allocD0Ev = Module["__ZNSt9bad_allocD0Ev"] = function() {
                return (__ZNSt9bad_allocD0Ev = Module["__ZNSt9bad_allocD0Ev"] = Module["asm"]["_ZNSt9bad_allocD0Ev"]).apply(null, arguments)
            };
            var __ZNKSt9bad_alloc4whatEv = Module["__ZNKSt9bad_alloc4whatEv"] = function() {
                return (__ZNKSt9bad_alloc4whatEv = Module["__ZNKSt9bad_alloc4whatEv"] = Module["asm"]["_ZNKSt9bad_alloc4whatEv"]).apply(null, arguments)
            };
            var __ZNSt20bad_array_new_lengthC2Ev = Module["__ZNSt20bad_array_new_lengthC2Ev"] = function() {
                return (__ZNSt20bad_array_new_lengthC2Ev = Module["__ZNSt20bad_array_new_lengthC2Ev"] = Module["asm"]["_ZNSt20bad_array_new_lengthC2Ev"]).apply(null, arguments)
            };
            var __ZNSt20bad_array_new_lengthD0Ev = Module["__ZNSt20bad_array_new_lengthD0Ev"] = function() {
                return (__ZNSt20bad_array_new_lengthD0Ev = Module["__ZNSt20bad_array_new_lengthD0Ev"] = Module["asm"]["_ZNSt20bad_array_new_lengthD0Ev"]).apply(null, arguments)
            };
            var __ZNKSt20bad_array_new_length4whatEv = Module["__ZNKSt20bad_array_new_length4whatEv"] = function() {
                return (__ZNKSt20bad_array_new_length4whatEv = Module["__ZNKSt20bad_array_new_length4whatEv"] = Module["asm"]["_ZNKSt20bad_array_new_length4whatEv"]).apply(null, arguments)
            };
            var __ZNSt9exceptionD1Ev = Module["__ZNSt9exceptionD1Ev"] = function() {
                return (__ZNSt9exceptionD1Ev = Module["__ZNSt9exceptionD1Ev"] = Module["asm"]["_ZNSt9exceptionD1Ev"]).apply(null, arguments)
            };
            var __ZNSt13bad_exceptionD2Ev = Module["__ZNSt13bad_exceptionD2Ev"] = function() {
                return (__ZNSt13bad_exceptionD2Ev = Module["__ZNSt13bad_exceptionD2Ev"] = Module["asm"]["_ZNSt13bad_exceptionD2Ev"]).apply(null, arguments)
            };
            var __ZNSt13bad_exceptionD1Ev = Module["__ZNSt13bad_exceptionD1Ev"] = function() {
                return (__ZNSt13bad_exceptionD1Ev = Module["__ZNSt13bad_exceptionD1Ev"] = Module["asm"]["_ZNSt13bad_exceptionD1Ev"]).apply(null, arguments)
            };
            var __ZNSt9bad_allocC1Ev = Module["__ZNSt9bad_allocC1Ev"] = function() {
                return (__ZNSt9bad_allocC1Ev = Module["__ZNSt9bad_allocC1Ev"] = Module["asm"]["_ZNSt9bad_allocC1Ev"]).apply(null, arguments)
            };
            var __ZNSt9bad_allocD2Ev = Module["__ZNSt9bad_allocD2Ev"] = function() {
                return (__ZNSt9bad_allocD2Ev = Module["__ZNSt9bad_allocD2Ev"] = Module["asm"]["_ZNSt9bad_allocD2Ev"]).apply(null, arguments)
            };
            var __ZNSt9bad_allocD1Ev = Module["__ZNSt9bad_allocD1Ev"] = function() {
                return (__ZNSt9bad_allocD1Ev = Module["__ZNSt9bad_allocD1Ev"] = Module["asm"]["_ZNSt9bad_allocD1Ev"]).apply(null, arguments)
            };
            var __ZNSt20bad_array_new_lengthC1Ev = Module["__ZNSt20bad_array_new_lengthC1Ev"] = function() {
                return (__ZNSt20bad_array_new_lengthC1Ev = Module["__ZNSt20bad_array_new_lengthC1Ev"] = Module["asm"]["_ZNSt20bad_array_new_lengthC1Ev"]).apply(null, arguments)
            };
            var __ZNSt20bad_array_new_lengthD2Ev = Module["__ZNSt20bad_array_new_lengthD2Ev"] = function() {
                return (__ZNSt20bad_array_new_lengthD2Ev = Module["__ZNSt20bad_array_new_lengthD2Ev"] = Module["asm"]["_ZNSt20bad_array_new_lengthD2Ev"]).apply(null, arguments)
            };
            var __ZNSt20bad_array_new_lengthD1Ev = Module["__ZNSt20bad_array_new_lengthD1Ev"] = function() {
                return (__ZNSt20bad_array_new_lengthD1Ev = Module["__ZNSt20bad_array_new_lengthD1Ev"] = Module["asm"]["_ZNSt20bad_array_new_lengthD1Ev"]).apply(null, arguments)
            };
            var __ZNSt3__218__libcpp_refstringD2Ev = Module["__ZNSt3__218__libcpp_refstringD2Ev"] = function() {
                return (__ZNSt3__218__libcpp_refstringD2Ev = Module["__ZNSt3__218__libcpp_refstringD2Ev"] = Module["asm"]["_ZNSt3__218__libcpp_refstringD2Ev"]).apply(null, arguments)
            };
            var __ZNSt11logic_errorD0Ev = Module["__ZNSt11logic_errorD0Ev"] = function() {
                return (__ZNSt11logic_errorD0Ev = Module["__ZNSt11logic_errorD0Ev"] = Module["asm"]["_ZNSt11logic_errorD0Ev"]).apply(null, arguments)
            };
            var __ZNKSt3__218__libcpp_refstring5c_strEv = Module["__ZNKSt3__218__libcpp_refstring5c_strEv"] = function() {
                return (__ZNKSt3__218__libcpp_refstring5c_strEv = Module["__ZNKSt3__218__libcpp_refstring5c_strEv"] = Module["asm"]["_ZNKSt3__218__libcpp_refstring5c_strEv"]).apply(null, arguments)
            };
            var __ZNSt13runtime_errorD0Ev = Module["__ZNSt13runtime_errorD0Ev"] = function() {
                return (__ZNSt13runtime_errorD0Ev = Module["__ZNSt13runtime_errorD0Ev"] = Module["asm"]["_ZNSt13runtime_errorD0Ev"]).apply(null, arguments)
            };
            var __ZNSt12domain_errorD0Ev = Module["__ZNSt12domain_errorD0Ev"] = function() {
                return (__ZNSt12domain_errorD0Ev = Module["__ZNSt12domain_errorD0Ev"] = Module["asm"]["_ZNSt12domain_errorD0Ev"]).apply(null, arguments)
            };
            var __ZNSt16invalid_argumentD0Ev = Module["__ZNSt16invalid_argumentD0Ev"] = function() {
                return (__ZNSt16invalid_argumentD0Ev = Module["__ZNSt16invalid_argumentD0Ev"] = Module["asm"]["_ZNSt16invalid_argumentD0Ev"]).apply(null, arguments)
            };
            var __ZNSt12length_errorD0Ev = Module["__ZNSt12length_errorD0Ev"] = function() {
                return (__ZNSt12length_errorD0Ev = Module["__ZNSt12length_errorD0Ev"] = Module["asm"]["_ZNSt12length_errorD0Ev"]).apply(null, arguments)
            };
            var __ZNSt12out_of_rangeD0Ev = Module["__ZNSt12out_of_rangeD0Ev"] = function() {
                return (__ZNSt12out_of_rangeD0Ev = Module["__ZNSt12out_of_rangeD0Ev"] = Module["asm"]["_ZNSt12out_of_rangeD0Ev"]).apply(null, arguments)
            };
            var __ZNSt11range_errorD0Ev = Module["__ZNSt11range_errorD0Ev"] = function() {
                return (__ZNSt11range_errorD0Ev = Module["__ZNSt11range_errorD0Ev"] = Module["asm"]["_ZNSt11range_errorD0Ev"]).apply(null, arguments)
            };
            var __ZNSt14overflow_errorD0Ev = Module["__ZNSt14overflow_errorD0Ev"] = function() {
                return (__ZNSt14overflow_errorD0Ev = Module["__ZNSt14overflow_errorD0Ev"] = Module["asm"]["_ZNSt14overflow_errorD0Ev"]).apply(null, arguments)
            };
            var __ZNSt15underflow_errorD0Ev = Module["__ZNSt15underflow_errorD0Ev"] = function() {
                return (__ZNSt15underflow_errorD0Ev = Module["__ZNSt15underflow_errorD0Ev"] = Module["asm"]["_ZNSt15underflow_errorD0Ev"]).apply(null, arguments)
            };
            var __ZNSt11logic_errorD1Ev = Module["__ZNSt11logic_errorD1Ev"] = function() {
                return (__ZNSt11logic_errorD1Ev = Module["__ZNSt11logic_errorD1Ev"] = Module["asm"]["_ZNSt11logic_errorD1Ev"]).apply(null, arguments)
            };
            var __ZNSt13runtime_errorD1Ev = Module["__ZNSt13runtime_errorD1Ev"] = function() {
                return (__ZNSt13runtime_errorD1Ev = Module["__ZNSt13runtime_errorD1Ev"] = Module["asm"]["_ZNSt13runtime_errorD1Ev"]).apply(null, arguments)
            };
            var __ZNSt12domain_errorD2Ev = Module["__ZNSt12domain_errorD2Ev"] = function() {
                return (__ZNSt12domain_errorD2Ev = Module["__ZNSt12domain_errorD2Ev"] = Module["asm"]["_ZNSt12domain_errorD2Ev"]).apply(null, arguments)
            };
            var __ZNSt12domain_errorD1Ev = Module["__ZNSt12domain_errorD1Ev"] = function() {
                return (__ZNSt12domain_errorD1Ev = Module["__ZNSt12domain_errorD1Ev"] = Module["asm"]["_ZNSt12domain_errorD1Ev"]).apply(null, arguments)
            };
            var __ZNSt16invalid_argumentD2Ev = Module["__ZNSt16invalid_argumentD2Ev"] = function() {
                return (__ZNSt16invalid_argumentD2Ev = Module["__ZNSt16invalid_argumentD2Ev"] = Module["asm"]["_ZNSt16invalid_argumentD2Ev"]).apply(null, arguments)
            };
            var __ZNSt16invalid_argumentD1Ev = Module["__ZNSt16invalid_argumentD1Ev"] = function() {
                return (__ZNSt16invalid_argumentD1Ev = Module["__ZNSt16invalid_argumentD1Ev"] = Module["asm"]["_ZNSt16invalid_argumentD1Ev"]).apply(null, arguments)
            };
            var __ZNSt12length_errorD2Ev = Module["__ZNSt12length_errorD2Ev"] = function() {
                return (__ZNSt12length_errorD2Ev = Module["__ZNSt12length_errorD2Ev"] = Module["asm"]["_ZNSt12length_errorD2Ev"]).apply(null, arguments)
            };
            var __ZNSt12length_errorD1Ev = Module["__ZNSt12length_errorD1Ev"] = function() {
                return (__ZNSt12length_errorD1Ev = Module["__ZNSt12length_errorD1Ev"] = Module["asm"]["_ZNSt12length_errorD1Ev"]).apply(null, arguments)
            };
            var __ZNSt12out_of_rangeD2Ev = Module["__ZNSt12out_of_rangeD2Ev"] = function() {
                return (__ZNSt12out_of_rangeD2Ev = Module["__ZNSt12out_of_rangeD2Ev"] = Module["asm"]["_ZNSt12out_of_rangeD2Ev"]).apply(null, arguments)
            };
            var __ZNSt12out_of_rangeD1Ev = Module["__ZNSt12out_of_rangeD1Ev"] = function() {
                return (__ZNSt12out_of_rangeD1Ev = Module["__ZNSt12out_of_rangeD1Ev"] = Module["asm"]["_ZNSt12out_of_rangeD1Ev"]).apply(null, arguments)
            };
            var __ZNSt11range_errorD2Ev = Module["__ZNSt11range_errorD2Ev"] = function() {
                return (__ZNSt11range_errorD2Ev = Module["__ZNSt11range_errorD2Ev"] = Module["asm"]["_ZNSt11range_errorD2Ev"]).apply(null, arguments)
            };
            var __ZNSt11range_errorD1Ev = Module["__ZNSt11range_errorD1Ev"] = function() {
                return (__ZNSt11range_errorD1Ev = Module["__ZNSt11range_errorD1Ev"] = Module["asm"]["_ZNSt11range_errorD1Ev"]).apply(null, arguments)
            };
            var __ZNSt14overflow_errorD2Ev = Module["__ZNSt14overflow_errorD2Ev"] = function() {
                return (__ZNSt14overflow_errorD2Ev = Module["__ZNSt14overflow_errorD2Ev"] = Module["asm"]["_ZNSt14overflow_errorD2Ev"]).apply(null, arguments)
            };
            var __ZNSt14overflow_errorD1Ev = Module["__ZNSt14overflow_errorD1Ev"] = function() {
                return (__ZNSt14overflow_errorD1Ev = Module["__ZNSt14overflow_errorD1Ev"] = Module["asm"]["_ZNSt14overflow_errorD1Ev"]).apply(null, arguments)
            };
            var __ZNSt15underflow_errorD2Ev = Module["__ZNSt15underflow_errorD2Ev"] = function() {
                return (__ZNSt15underflow_errorD2Ev = Module["__ZNSt15underflow_errorD2Ev"] = Module["asm"]["_ZNSt15underflow_errorD2Ev"]).apply(null, arguments)
            };
            var __ZNSt15underflow_errorD1Ev = Module["__ZNSt15underflow_errorD1Ev"] = function() {
                return (__ZNSt15underflow_errorD1Ev = Module["__ZNSt15underflow_errorD1Ev"] = Module["asm"]["_ZNSt15underflow_errorD1Ev"]).apply(null, arguments)
            };
            var __ZNSt9type_infoD2Ev = Module["__ZNSt9type_infoD2Ev"] = function() {
                return (__ZNSt9type_infoD2Ev = Module["__ZNSt9type_infoD2Ev"] = Module["asm"]["_ZNSt9type_infoD2Ev"]).apply(null, arguments)
            };
            var __ZNSt9type_infoD0Ev = Module["__ZNSt9type_infoD0Ev"] = function() {
                return (__ZNSt9type_infoD0Ev = Module["__ZNSt9type_infoD0Ev"] = Module["asm"]["_ZNSt9type_infoD0Ev"]).apply(null, arguments)
            };
            var __ZNSt8bad_castC2Ev = Module["__ZNSt8bad_castC2Ev"] = function() {
                return (__ZNSt8bad_castC2Ev = Module["__ZNSt8bad_castC2Ev"] = Module["asm"]["_ZNSt8bad_castC2Ev"]).apply(null, arguments)
            };
            var __ZNSt8bad_castD0Ev = Module["__ZNSt8bad_castD0Ev"] = function() {
                return (__ZNSt8bad_castD0Ev = Module["__ZNSt8bad_castD0Ev"] = Module["asm"]["_ZNSt8bad_castD0Ev"]).apply(null, arguments)
            };
            var __ZNKSt8bad_cast4whatEv = Module["__ZNKSt8bad_cast4whatEv"] = function() {
                return (__ZNKSt8bad_cast4whatEv = Module["__ZNKSt8bad_cast4whatEv"] = Module["asm"]["_ZNKSt8bad_cast4whatEv"]).apply(null, arguments)
            };
            var __ZNSt10bad_typeidC2Ev = Module["__ZNSt10bad_typeidC2Ev"] = function() {
                return (__ZNSt10bad_typeidC2Ev = Module["__ZNSt10bad_typeidC2Ev"] = Module["asm"]["_ZNSt10bad_typeidC2Ev"]).apply(null, arguments)
            };
            var __ZNSt10bad_typeidD2Ev = Module["__ZNSt10bad_typeidD2Ev"] = function() {
                return (__ZNSt10bad_typeidD2Ev = Module["__ZNSt10bad_typeidD2Ev"] = Module["asm"]["_ZNSt10bad_typeidD2Ev"]).apply(null, arguments)
            };
            var __ZNSt10bad_typeidD0Ev = Module["__ZNSt10bad_typeidD0Ev"] = function() {
                return (__ZNSt10bad_typeidD0Ev = Module["__ZNSt10bad_typeidD0Ev"] = Module["asm"]["_ZNSt10bad_typeidD0Ev"]).apply(null, arguments)
            };
            var __ZNKSt10bad_typeid4whatEv = Module["__ZNKSt10bad_typeid4whatEv"] = function() {
                return (__ZNKSt10bad_typeid4whatEv = Module["__ZNKSt10bad_typeid4whatEv"] = Module["asm"]["_ZNKSt10bad_typeid4whatEv"]).apply(null, arguments)
            };
            var __ZNSt9type_infoD1Ev = Module["__ZNSt9type_infoD1Ev"] = function() {
                return (__ZNSt9type_infoD1Ev = Module["__ZNSt9type_infoD1Ev"] = Module["asm"]["_ZNSt9type_infoD1Ev"]).apply(null, arguments)
            };
            var __ZNSt8bad_castC1Ev = Module["__ZNSt8bad_castC1Ev"] = function() {
                return (__ZNSt8bad_castC1Ev = Module["__ZNSt8bad_castC1Ev"] = Module["asm"]["_ZNSt8bad_castC1Ev"]).apply(null, arguments)
            };
            var __ZNSt8bad_castD1Ev = Module["__ZNSt8bad_castD1Ev"] = function() {
                return (__ZNSt8bad_castD1Ev = Module["__ZNSt8bad_castD1Ev"] = Module["asm"]["_ZNSt8bad_castD1Ev"]).apply(null, arguments)
            };
            var __ZNSt10bad_typeidC1Ev = Module["__ZNSt10bad_typeidC1Ev"] = function() {
                return (__ZNSt10bad_typeidC1Ev = Module["__ZNSt10bad_typeidC1Ev"] = Module["asm"]["_ZNSt10bad_typeidC1Ev"]).apply(null, arguments)
            };
            var __ZNSt10bad_typeidD1Ev = Module["__ZNSt10bad_typeidD1Ev"] = function() {
                return (__ZNSt10bad_typeidD1Ev = Module["__ZNSt10bad_typeidD1Ev"] = Module["asm"]["_ZNSt10bad_typeidD1Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv116__shim_type_infoD2Ev = Module["__ZN10__cxxabiv116__shim_type_infoD2Ev"] = function() {
                return (__ZN10__cxxabiv116__shim_type_infoD2Ev = Module["__ZN10__cxxabiv116__shim_type_infoD2Ev"] = Module["asm"]["_ZN10__cxxabiv116__shim_type_infoD2Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv116__shim_type_infoD0Ev = Module["__ZN10__cxxabiv116__shim_type_infoD0Ev"] = function() {
                return (__ZN10__cxxabiv116__shim_type_infoD0Ev = Module["__ZN10__cxxabiv116__shim_type_infoD0Ev"] = Module["asm"]["_ZN10__cxxabiv116__shim_type_infoD0Ev"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv116__shim_type_info5noop1Ev = Module["__ZNK10__cxxabiv116__shim_type_info5noop1Ev"] = function() {
                return (__ZNK10__cxxabiv116__shim_type_info5noop1Ev = Module["__ZNK10__cxxabiv116__shim_type_info5noop1Ev"] = Module["asm"]["_ZNK10__cxxabiv116__shim_type_info5noop1Ev"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv116__shim_type_info5noop2Ev = Module["__ZNK10__cxxabiv116__shim_type_info5noop2Ev"] = function() {
                return (__ZNK10__cxxabiv116__shim_type_info5noop2Ev = Module["__ZNK10__cxxabiv116__shim_type_info5noop2Ev"] = Module["asm"]["_ZNK10__cxxabiv116__shim_type_info5noop2Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv123__fundamental_type_infoD0Ev = Module["__ZN10__cxxabiv123__fundamental_type_infoD0Ev"] = function() {
                return (__ZN10__cxxabiv123__fundamental_type_infoD0Ev = Module["__ZN10__cxxabiv123__fundamental_type_infoD0Ev"] = Module["asm"]["_ZN10__cxxabiv123__fundamental_type_infoD0Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv117__array_type_infoD0Ev = Module["__ZN10__cxxabiv117__array_type_infoD0Ev"] = function() {
                return (__ZN10__cxxabiv117__array_type_infoD0Ev = Module["__ZN10__cxxabiv117__array_type_infoD0Ev"] = Module["asm"]["_ZN10__cxxabiv117__array_type_infoD0Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv120__function_type_infoD0Ev = Module["__ZN10__cxxabiv120__function_type_infoD0Ev"] = function() {
                return (__ZN10__cxxabiv120__function_type_infoD0Ev = Module["__ZN10__cxxabiv120__function_type_infoD0Ev"] = Module["asm"]["_ZN10__cxxabiv120__function_type_infoD0Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv116__enum_type_infoD0Ev = Module["__ZN10__cxxabiv116__enum_type_infoD0Ev"] = function() {
                return (__ZN10__cxxabiv116__enum_type_infoD0Ev = Module["__ZN10__cxxabiv116__enum_type_infoD0Ev"] = Module["asm"]["_ZN10__cxxabiv116__enum_type_infoD0Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv117__class_type_infoD0Ev = Module["__ZN10__cxxabiv117__class_type_infoD0Ev"] = function() {
                return (__ZN10__cxxabiv117__class_type_infoD0Ev = Module["__ZN10__cxxabiv117__class_type_infoD0Ev"] = Module["asm"]["_ZN10__cxxabiv117__class_type_infoD0Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv120__si_class_type_infoD0Ev = Module["__ZN10__cxxabiv120__si_class_type_infoD0Ev"] = function() {
                return (__ZN10__cxxabiv120__si_class_type_infoD0Ev = Module["__ZN10__cxxabiv120__si_class_type_infoD0Ev"] = Module["asm"]["_ZN10__cxxabiv120__si_class_type_infoD0Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv121__vmi_class_type_infoD0Ev = Module["__ZN10__cxxabiv121__vmi_class_type_infoD0Ev"] = function() {
                return (__ZN10__cxxabiv121__vmi_class_type_infoD0Ev = Module["__ZN10__cxxabiv121__vmi_class_type_infoD0Ev"] = Module["asm"]["_ZN10__cxxabiv121__vmi_class_type_infoD0Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv117__pbase_type_infoD0Ev = Module["__ZN10__cxxabiv117__pbase_type_infoD0Ev"] = function() {
                return (__ZN10__cxxabiv117__pbase_type_infoD0Ev = Module["__ZN10__cxxabiv117__pbase_type_infoD0Ev"] = Module["asm"]["_ZN10__cxxabiv117__pbase_type_infoD0Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv119__pointer_type_infoD0Ev = Module["__ZN10__cxxabiv119__pointer_type_infoD0Ev"] = function() {
                return (__ZN10__cxxabiv119__pointer_type_infoD0Ev = Module["__ZN10__cxxabiv119__pointer_type_infoD0Ev"] = Module["asm"]["_ZN10__cxxabiv119__pointer_type_infoD0Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv129__pointer_to_member_type_infoD0Ev = Module["__ZN10__cxxabiv129__pointer_to_member_type_infoD0Ev"] = function() {
                return (__ZN10__cxxabiv129__pointer_to_member_type_infoD0Ev = Module["__ZN10__cxxabiv129__pointer_to_member_type_infoD0Ev"] = Module["asm"]["_ZN10__cxxabiv129__pointer_to_member_type_infoD0Ev"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv123__fundamental_type_info9can_catchEPKNS_16__shim_type_infoERPv = Module["__ZNK10__cxxabiv123__fundamental_type_info9can_catchEPKNS_16__shim_type_infoERPv"] = function() {
                return (__ZNK10__cxxabiv123__fundamental_type_info9can_catchEPKNS_16__shim_type_infoERPv = Module["__ZNK10__cxxabiv123__fundamental_type_info9can_catchEPKNS_16__shim_type_infoERPv"] = Module["asm"]["_ZNK10__cxxabiv123__fundamental_type_info9can_catchEPKNS_16__shim_type_infoERPv"]).apply(null, arguments)
            };
            var __ZNKSt9type_info4nameEv = Module["__ZNKSt9type_info4nameEv"] = function() {
                return (__ZNKSt9type_info4nameEv = Module["__ZNKSt9type_info4nameEv"] = Module["asm"]["_ZNKSt9type_info4nameEv"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv117__array_type_info9can_catchEPKNS_16__shim_type_infoERPv = Module["__ZNK10__cxxabiv117__array_type_info9can_catchEPKNS_16__shim_type_infoERPv"] = function() {
                return (__ZNK10__cxxabiv117__array_type_info9can_catchEPKNS_16__shim_type_infoERPv = Module["__ZNK10__cxxabiv117__array_type_info9can_catchEPKNS_16__shim_type_infoERPv"] = Module["asm"]["_ZNK10__cxxabiv117__array_type_info9can_catchEPKNS_16__shim_type_infoERPv"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv120__function_type_info9can_catchEPKNS_16__shim_type_infoERPv = Module["__ZNK10__cxxabiv120__function_type_info9can_catchEPKNS_16__shim_type_infoERPv"] = function() {
                return (__ZNK10__cxxabiv120__function_type_info9can_catchEPKNS_16__shim_type_infoERPv = Module["__ZNK10__cxxabiv120__function_type_info9can_catchEPKNS_16__shim_type_infoERPv"] = Module["asm"]["_ZNK10__cxxabiv120__function_type_info9can_catchEPKNS_16__shim_type_infoERPv"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv116__enum_type_info9can_catchEPKNS_16__shim_type_infoERPv = Module["__ZNK10__cxxabiv116__enum_type_info9can_catchEPKNS_16__shim_type_infoERPv"] = function() {
                return (__ZNK10__cxxabiv116__enum_type_info9can_catchEPKNS_16__shim_type_infoERPv = Module["__ZNK10__cxxabiv116__enum_type_info9can_catchEPKNS_16__shim_type_infoERPv"] = Module["asm"]["_ZNK10__cxxabiv116__enum_type_info9can_catchEPKNS_16__shim_type_infoERPv"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv117__class_type_info9can_catchEPKNS_16__shim_type_infoERPv = Module["__ZNK10__cxxabiv117__class_type_info9can_catchEPKNS_16__shim_type_infoERPv"] = function() {
                return (__ZNK10__cxxabiv117__class_type_info9can_catchEPKNS_16__shim_type_infoERPv = Module["__ZNK10__cxxabiv117__class_type_info9can_catchEPKNS_16__shim_type_infoERPv"] = Module["asm"]["_ZNK10__cxxabiv117__class_type_info9can_catchEPKNS_16__shim_type_infoERPv"]).apply(null, arguments)
            };
            var ___dynamic_cast = Module["___dynamic_cast"] = function() {
                return (___dynamic_cast = Module["___dynamic_cast"] = Module["asm"]["__dynamic_cast"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv117__class_type_info24process_found_base_classEPNS_19__dynamic_cast_infoEPvi = Module["__ZNK10__cxxabiv117__class_type_info24process_found_base_classEPNS_19__dynamic_cast_infoEPvi"] = function() {
                return (__ZNK10__cxxabiv117__class_type_info24process_found_base_classEPNS_19__dynamic_cast_infoEPvi = Module["__ZNK10__cxxabiv117__class_type_info24process_found_base_classEPNS_19__dynamic_cast_infoEPvi"] = Module["asm"]["_ZNK10__cxxabiv117__class_type_info24process_found_base_classEPNS_19__dynamic_cast_infoEPvi"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv117__class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi = Module["__ZNK10__cxxabiv117__class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi"] = function() {
                return (__ZNK10__cxxabiv117__class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi = Module["__ZNK10__cxxabiv117__class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi"] = Module["asm"]["_ZNK10__cxxabiv117__class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv120__si_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi = Module["__ZNK10__cxxabiv120__si_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi"] = function() {
                return (__ZNK10__cxxabiv120__si_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi = Module["__ZNK10__cxxabiv120__si_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi"] = Module["asm"]["_ZNK10__cxxabiv120__si_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv122__base_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi = Module["__ZNK10__cxxabiv122__base_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi"] = function() {
                return (__ZNK10__cxxabiv122__base_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi = Module["__ZNK10__cxxabiv122__base_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi"] = Module["asm"]["_ZNK10__cxxabiv122__base_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv121__vmi_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi = Module["__ZNK10__cxxabiv121__vmi_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi"] = function() {
                return (__ZNK10__cxxabiv121__vmi_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi = Module["__ZNK10__cxxabiv121__vmi_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi"] = Module["asm"]["_ZNK10__cxxabiv121__vmi_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv117__pbase_type_info9can_catchEPKNS_16__shim_type_infoERPv = Module["__ZNK10__cxxabiv117__pbase_type_info9can_catchEPKNS_16__shim_type_infoERPv"] = function() {
                return (__ZNK10__cxxabiv117__pbase_type_info9can_catchEPKNS_16__shim_type_infoERPv = Module["__ZNK10__cxxabiv117__pbase_type_info9can_catchEPKNS_16__shim_type_infoERPv"] = Module["asm"]["_ZNK10__cxxabiv117__pbase_type_info9can_catchEPKNS_16__shim_type_infoERPv"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv119__pointer_type_info9can_catchEPKNS_16__shim_type_infoERPv = Module["__ZNK10__cxxabiv119__pointer_type_info9can_catchEPKNS_16__shim_type_infoERPv"] = function() {
                return (__ZNK10__cxxabiv119__pointer_type_info9can_catchEPKNS_16__shim_type_infoERPv = Module["__ZNK10__cxxabiv119__pointer_type_info9can_catchEPKNS_16__shim_type_infoERPv"] = Module["asm"]["_ZNK10__cxxabiv119__pointer_type_info9can_catchEPKNS_16__shim_type_infoERPv"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv119__pointer_type_info16can_catch_nestedEPKNS_16__shim_type_infoE = Module["__ZNK10__cxxabiv119__pointer_type_info16can_catch_nestedEPKNS_16__shim_type_infoE"] = function() {
                return (__ZNK10__cxxabiv119__pointer_type_info16can_catch_nestedEPKNS_16__shim_type_infoE = Module["__ZNK10__cxxabiv119__pointer_type_info16can_catch_nestedEPKNS_16__shim_type_infoE"] = Module["asm"]["_ZNK10__cxxabiv119__pointer_type_info16can_catch_nestedEPKNS_16__shim_type_infoE"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv129__pointer_to_member_type_info16can_catch_nestedEPKNS_16__shim_type_infoE = Module["__ZNK10__cxxabiv129__pointer_to_member_type_info16can_catch_nestedEPKNS_16__shim_type_infoE"] = function() {
                return (__ZNK10__cxxabiv129__pointer_to_member_type_info16can_catch_nestedEPKNS_16__shim_type_infoE = Module["__ZNK10__cxxabiv129__pointer_to_member_type_info16can_catch_nestedEPKNS_16__shim_type_infoE"] = Module["asm"]["_ZNK10__cxxabiv129__pointer_to_member_type_info16can_catch_nestedEPKNS_16__shim_type_infoE"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv129__pointer_to_member_type_info9can_catchEPKNS_16__shim_type_infoERPv = Module["__ZNK10__cxxabiv129__pointer_to_member_type_info9can_catchEPKNS_16__shim_type_infoERPv"] = function() {
                return (__ZNK10__cxxabiv129__pointer_to_member_type_info9can_catchEPKNS_16__shim_type_infoERPv = Module["__ZNK10__cxxabiv129__pointer_to_member_type_info9can_catchEPKNS_16__shim_type_infoERPv"] = Module["asm"]["_ZNK10__cxxabiv129__pointer_to_member_type_info9can_catchEPKNS_16__shim_type_infoERPv"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv117__class_type_info29process_static_type_above_dstEPNS_19__dynamic_cast_infoEPKvS4_i = Module["__ZNK10__cxxabiv117__class_type_info29process_static_type_above_dstEPNS_19__dynamic_cast_infoEPKvS4_i"] = function() {
                return (__ZNK10__cxxabiv117__class_type_info29process_static_type_above_dstEPNS_19__dynamic_cast_infoEPKvS4_i = Module["__ZNK10__cxxabiv117__class_type_info29process_static_type_above_dstEPNS_19__dynamic_cast_infoEPKvS4_i"] = Module["asm"]["_ZNK10__cxxabiv117__class_type_info29process_static_type_above_dstEPNS_19__dynamic_cast_infoEPKvS4_i"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv117__class_type_info29process_static_type_below_dstEPNS_19__dynamic_cast_infoEPKvi = Module["__ZNK10__cxxabiv117__class_type_info29process_static_type_below_dstEPNS_19__dynamic_cast_infoEPKvi"] = function() {
                return (__ZNK10__cxxabiv117__class_type_info29process_static_type_below_dstEPNS_19__dynamic_cast_infoEPKvi = Module["__ZNK10__cxxabiv117__class_type_info29process_static_type_below_dstEPNS_19__dynamic_cast_infoEPKvi"] = Module["asm"]["_ZNK10__cxxabiv117__class_type_info29process_static_type_below_dstEPNS_19__dynamic_cast_infoEPKvi"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv121__vmi_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib = Module["__ZNK10__cxxabiv121__vmi_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib"] = function() {
                return (__ZNK10__cxxabiv121__vmi_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib = Module["__ZNK10__cxxabiv121__vmi_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib"] = Module["asm"]["_ZNK10__cxxabiv121__vmi_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv122__base_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib = Module["__ZNK10__cxxabiv122__base_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib"] = function() {
                return (__ZNK10__cxxabiv122__base_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib = Module["__ZNK10__cxxabiv122__base_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib"] = Module["asm"]["_ZNK10__cxxabiv122__base_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv122__base_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib = Module["__ZNK10__cxxabiv122__base_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib"] = function() {
                return (__ZNK10__cxxabiv122__base_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib = Module["__ZNK10__cxxabiv122__base_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib"] = Module["asm"]["_ZNK10__cxxabiv122__base_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv120__si_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib = Module["__ZNK10__cxxabiv120__si_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib"] = function() {
                return (__ZNK10__cxxabiv120__si_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib = Module["__ZNK10__cxxabiv120__si_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib"] = Module["asm"]["_ZNK10__cxxabiv120__si_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv117__class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib = Module["__ZNK10__cxxabiv117__class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib"] = function() {
                return (__ZNK10__cxxabiv117__class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib = Module["__ZNK10__cxxabiv117__class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib"] = Module["asm"]["_ZNK10__cxxabiv117__class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv121__vmi_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib = Module["__ZNK10__cxxabiv121__vmi_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib"] = function() {
                return (__ZNK10__cxxabiv121__vmi_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib = Module["__ZNK10__cxxabiv121__vmi_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib"] = Module["asm"]["_ZNK10__cxxabiv121__vmi_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv120__si_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib = Module["__ZNK10__cxxabiv120__si_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib"] = function() {
                return (__ZNK10__cxxabiv120__si_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib = Module["__ZNK10__cxxabiv120__si_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib"] = Module["asm"]["_ZNK10__cxxabiv120__si_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib"]).apply(null, arguments)
            };
            var __ZNK10__cxxabiv117__class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib = Module["__ZNK10__cxxabiv117__class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib"] = function() {
                return (__ZNK10__cxxabiv117__class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib = Module["__ZNK10__cxxabiv117__class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib"] = Module["asm"]["_ZNK10__cxxabiv117__class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib"]).apply(null, arguments)
            };
            var ___cxa_can_catch = Module["___cxa_can_catch"] = function() {
                return (___cxa_can_catch = Module["___cxa_can_catch"] = Module["asm"]["__cxa_can_catch"]).apply(null, arguments)
            };
            var ___cxa_is_pointer_type = Module["___cxa_is_pointer_type"] = function() {
                return (___cxa_is_pointer_type = Module["___cxa_is_pointer_type"] = Module["asm"]["__cxa_is_pointer_type"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv116__shim_type_infoD1Ev = Module["__ZN10__cxxabiv116__shim_type_infoD1Ev"] = function() {
                return (__ZN10__cxxabiv116__shim_type_infoD1Ev = Module["__ZN10__cxxabiv116__shim_type_infoD1Ev"] = Module["asm"]["_ZN10__cxxabiv116__shim_type_infoD1Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv123__fundamental_type_infoD2Ev = Module["__ZN10__cxxabiv123__fundamental_type_infoD2Ev"] = function() {
                return (__ZN10__cxxabiv123__fundamental_type_infoD2Ev = Module["__ZN10__cxxabiv123__fundamental_type_infoD2Ev"] = Module["asm"]["_ZN10__cxxabiv123__fundamental_type_infoD2Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv123__fundamental_type_infoD1Ev = Module["__ZN10__cxxabiv123__fundamental_type_infoD1Ev"] = function() {
                return (__ZN10__cxxabiv123__fundamental_type_infoD1Ev = Module["__ZN10__cxxabiv123__fundamental_type_infoD1Ev"] = Module["asm"]["_ZN10__cxxabiv123__fundamental_type_infoD1Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv117__array_type_infoD2Ev = Module["__ZN10__cxxabiv117__array_type_infoD2Ev"] = function() {
                return (__ZN10__cxxabiv117__array_type_infoD2Ev = Module["__ZN10__cxxabiv117__array_type_infoD2Ev"] = Module["asm"]["_ZN10__cxxabiv117__array_type_infoD2Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv117__array_type_infoD1Ev = Module["__ZN10__cxxabiv117__array_type_infoD1Ev"] = function() {
                return (__ZN10__cxxabiv117__array_type_infoD1Ev = Module["__ZN10__cxxabiv117__array_type_infoD1Ev"] = Module["asm"]["_ZN10__cxxabiv117__array_type_infoD1Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv120__function_type_infoD2Ev = Module["__ZN10__cxxabiv120__function_type_infoD2Ev"] = function() {
                return (__ZN10__cxxabiv120__function_type_infoD2Ev = Module["__ZN10__cxxabiv120__function_type_infoD2Ev"] = Module["asm"]["_ZN10__cxxabiv120__function_type_infoD2Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv120__function_type_infoD1Ev = Module["__ZN10__cxxabiv120__function_type_infoD1Ev"] = function() {
                return (__ZN10__cxxabiv120__function_type_infoD1Ev = Module["__ZN10__cxxabiv120__function_type_infoD1Ev"] = Module["asm"]["_ZN10__cxxabiv120__function_type_infoD1Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv116__enum_type_infoD2Ev = Module["__ZN10__cxxabiv116__enum_type_infoD2Ev"] = function() {
                return (__ZN10__cxxabiv116__enum_type_infoD2Ev = Module["__ZN10__cxxabiv116__enum_type_infoD2Ev"] = Module["asm"]["_ZN10__cxxabiv116__enum_type_infoD2Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv116__enum_type_infoD1Ev = Module["__ZN10__cxxabiv116__enum_type_infoD1Ev"] = function() {
                return (__ZN10__cxxabiv116__enum_type_infoD1Ev = Module["__ZN10__cxxabiv116__enum_type_infoD1Ev"] = Module["asm"]["_ZN10__cxxabiv116__enum_type_infoD1Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv117__class_type_infoD2Ev = Module["__ZN10__cxxabiv117__class_type_infoD2Ev"] = function() {
                return (__ZN10__cxxabiv117__class_type_infoD2Ev = Module["__ZN10__cxxabiv117__class_type_infoD2Ev"] = Module["asm"]["_ZN10__cxxabiv117__class_type_infoD2Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv117__class_type_infoD1Ev = Module["__ZN10__cxxabiv117__class_type_infoD1Ev"] = function() {
                return (__ZN10__cxxabiv117__class_type_infoD1Ev = Module["__ZN10__cxxabiv117__class_type_infoD1Ev"] = Module["asm"]["_ZN10__cxxabiv117__class_type_infoD1Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv120__si_class_type_infoD2Ev = Module["__ZN10__cxxabiv120__si_class_type_infoD2Ev"] = function() {
                return (__ZN10__cxxabiv120__si_class_type_infoD2Ev = Module["__ZN10__cxxabiv120__si_class_type_infoD2Ev"] = Module["asm"]["_ZN10__cxxabiv120__si_class_type_infoD2Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv120__si_class_type_infoD1Ev = Module["__ZN10__cxxabiv120__si_class_type_infoD1Ev"] = function() {
                return (__ZN10__cxxabiv120__si_class_type_infoD1Ev = Module["__ZN10__cxxabiv120__si_class_type_infoD1Ev"] = Module["asm"]["_ZN10__cxxabiv120__si_class_type_infoD1Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv121__vmi_class_type_infoD2Ev = Module["__ZN10__cxxabiv121__vmi_class_type_infoD2Ev"] = function() {
                return (__ZN10__cxxabiv121__vmi_class_type_infoD2Ev = Module["__ZN10__cxxabiv121__vmi_class_type_infoD2Ev"] = Module["asm"]["_ZN10__cxxabiv121__vmi_class_type_infoD2Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv121__vmi_class_type_infoD1Ev = Module["__ZN10__cxxabiv121__vmi_class_type_infoD1Ev"] = function() {
                return (__ZN10__cxxabiv121__vmi_class_type_infoD1Ev = Module["__ZN10__cxxabiv121__vmi_class_type_infoD1Ev"] = Module["asm"]["_ZN10__cxxabiv121__vmi_class_type_infoD1Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv117__pbase_type_infoD2Ev = Module["__ZN10__cxxabiv117__pbase_type_infoD2Ev"] = function() {
                return (__ZN10__cxxabiv117__pbase_type_infoD2Ev = Module["__ZN10__cxxabiv117__pbase_type_infoD2Ev"] = Module["asm"]["_ZN10__cxxabiv117__pbase_type_infoD2Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv117__pbase_type_infoD1Ev = Module["__ZN10__cxxabiv117__pbase_type_infoD1Ev"] = function() {
                return (__ZN10__cxxabiv117__pbase_type_infoD1Ev = Module["__ZN10__cxxabiv117__pbase_type_infoD1Ev"] = Module["asm"]["_ZN10__cxxabiv117__pbase_type_infoD1Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv119__pointer_type_infoD2Ev = Module["__ZN10__cxxabiv119__pointer_type_infoD2Ev"] = function() {
                return (__ZN10__cxxabiv119__pointer_type_infoD2Ev = Module["__ZN10__cxxabiv119__pointer_type_infoD2Ev"] = Module["asm"]["_ZN10__cxxabiv119__pointer_type_infoD2Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv119__pointer_type_infoD1Ev = Module["__ZN10__cxxabiv119__pointer_type_infoD1Ev"] = function() {
                return (__ZN10__cxxabiv119__pointer_type_infoD1Ev = Module["__ZN10__cxxabiv119__pointer_type_infoD1Ev"] = Module["asm"]["_ZN10__cxxabiv119__pointer_type_infoD1Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv129__pointer_to_member_type_infoD2Ev = Module["__ZN10__cxxabiv129__pointer_to_member_type_infoD2Ev"] = function() {
                return (__ZN10__cxxabiv129__pointer_to_member_type_infoD2Ev = Module["__ZN10__cxxabiv129__pointer_to_member_type_infoD2Ev"] = Module["asm"]["_ZN10__cxxabiv129__pointer_to_member_type_infoD2Ev"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv129__pointer_to_member_type_infoD1Ev = Module["__ZN10__cxxabiv129__pointer_to_member_type_infoD1Ev"] = function() {
                return (__ZN10__cxxabiv129__pointer_to_member_type_infoD1Ev = Module["__ZN10__cxxabiv129__pointer_to_member_type_infoD1Ev"] = Module["asm"]["_ZN10__cxxabiv129__pointer_to_member_type_infoD1Ev"]).apply(null, arguments)
            };
            var ___cxa_uncaught_exception = Module["___cxa_uncaught_exception"] = function() {
                return (___cxa_uncaught_exception = Module["___cxa_uncaught_exception"] = Module["asm"]["__cxa_uncaught_exception"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv119__getExceptionClassEPK17_Unwind_Exception = Module["__ZN10__cxxabiv119__getExceptionClassEPK17_Unwind_Exception"] = function() {
                return (__ZN10__cxxabiv119__getExceptionClassEPK17_Unwind_Exception = Module["__ZN10__cxxabiv119__getExceptionClassEPK17_Unwind_Exception"] = Module["asm"]["_ZN10__cxxabiv119__getExceptionClassEPK17_Unwind_Exception"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv119__setExceptionClassEP17_Unwind_Exceptiony = Module["__ZN10__cxxabiv119__setExceptionClassEP17_Unwind_Exceptiony"] = function() {
                return (__ZN10__cxxabiv119__setExceptionClassEP17_Unwind_Exceptiony = Module["__ZN10__cxxabiv119__setExceptionClassEP17_Unwind_Exceptiony"] = Module["asm"]["_ZN10__cxxabiv119__setExceptionClassEP17_Unwind_Exceptiony"]).apply(null, arguments)
            };
            var __ZN10__cxxabiv121__isOurExceptionClassEPK17_Unwind_Exception = Module["__ZN10__cxxabiv121__isOurExceptionClassEPK17_Unwind_Exception"] = function() {
                return (__ZN10__cxxabiv121__isOurExceptionClassEPK17_Unwind_Exception = Module["__ZN10__cxxabiv121__isOurExceptionClassEPK17_Unwind_Exception"] = Module["asm"]["_ZN10__cxxabiv121__isOurExceptionClassEPK17_Unwind_Exception"]).apply(null, arguments)
            };
            var _sbrk = Module["_sbrk"] = function() {
                return (_sbrk = Module["_sbrk"] = Module["asm"]["sbrk"]).apply(null, arguments)
            };
            var _realloc_in_place = Module["_realloc_in_place"] = function() {
                return (_realloc_in_place = Module["_realloc_in_place"] = Module["asm"]["realloc_in_place"]).apply(null, arguments)
            };
            var _memalign = Module["_memalign"] = function() {
                return (_memalign = Module["_memalign"] = Module["asm"]["memalign"]).apply(null, arguments)
            };
            var _valloc = Module["_valloc"] = function() {
                return (_valloc = Module["_valloc"] = Module["asm"]["valloc"]).apply(null, arguments)
            };
            var _pvalloc = Module["_pvalloc"] = function() {
                return (_pvalloc = Module["_pvalloc"] = Module["asm"]["pvalloc"]).apply(null, arguments)
            };
            var _mallinfo = Module["_mallinfo"] = function() {
                return (_mallinfo = Module["_mallinfo"] = Module["asm"]["mallinfo"]).apply(null, arguments)
            };
            var _mallopt = Module["_mallopt"] = function() {
                return (_mallopt = Module["_mallopt"] = Module["asm"]["mallopt"]).apply(null, arguments)
            };
            var _malloc_trim = Module["_malloc_trim"] = function() {
                return (_malloc_trim = Module["_malloc_trim"] = Module["asm"]["malloc_trim"]).apply(null, arguments)
            };
            var _malloc_usable_size = Module["_malloc_usable_size"] = function() {
                return (_malloc_usable_size = Module["_malloc_usable_size"] = Module["asm"]["malloc_usable_size"]).apply(null, arguments)
            };
            var _malloc_footprint = Module["_malloc_footprint"] = function() {
                return (_malloc_footprint = Module["_malloc_footprint"] = Module["asm"]["malloc_footprint"]).apply(null, arguments)
            };
            var _malloc_max_footprint = Module["_malloc_max_footprint"] = function() {
                return (_malloc_max_footprint = Module["_malloc_max_footprint"] = Module["asm"]["malloc_max_footprint"]).apply(null, arguments)
            };
            var _malloc_footprint_limit = Module["_malloc_footprint_limit"] = function() {
                return (_malloc_footprint_limit = Module["_malloc_footprint_limit"] = Module["asm"]["malloc_footprint_limit"]).apply(null, arguments)
            };
            var _malloc_set_footprint_limit = Module["_malloc_set_footprint_limit"] = function() {
                return (_malloc_set_footprint_limit = Module["_malloc_set_footprint_limit"] = Module["asm"]["malloc_set_footprint_limit"]).apply(null, arguments)
            };
            var _independent_calloc = Module["_independent_calloc"] = function() {
                return (_independent_calloc = Module["_independent_calloc"] = Module["asm"]["independent_calloc"]).apply(null, arguments)
            };
            var _independent_comalloc = Module["_independent_comalloc"] = function() {
                return (_independent_comalloc = Module["_independent_comalloc"] = Module["asm"]["independent_comalloc"]).apply(null, arguments)
            };
            var _bulk_free = Module["_bulk_free"] = function() {
                return (_bulk_free = Module["_bulk_free"] = Module["asm"]["bulk_free"]).apply(null, arguments)
            };
            var _emscripten_builtin_malloc = Module["_emscripten_builtin_malloc"] = function() {
                return (_emscripten_builtin_malloc = Module["_emscripten_builtin_malloc"] = Module["asm"]["emscripten_builtin_malloc"]).apply(null, arguments)
            };
            var _emscripten_builtin_free = Module["_emscripten_builtin_free"] = function() {
                return (_emscripten_builtin_free = Module["_emscripten_builtin_free"] = Module["asm"]["emscripten_builtin_free"]).apply(null, arguments)
            };
            var _emscripten_builtin_memalign = Module["_emscripten_builtin_memalign"] = function() {
                return (_emscripten_builtin_memalign = Module["_emscripten_builtin_memalign"] = Module["asm"]["emscripten_builtin_memalign"]).apply(null, arguments)
            };
            var _emscripten_get_sbrk_ptr = Module["_emscripten_get_sbrk_ptr"] = function() {
                return (_emscripten_get_sbrk_ptr = Module["_emscripten_get_sbrk_ptr"] = Module["asm"]["emscripten_get_sbrk_ptr"]).apply(null, arguments)
            };
            var _brk = Module["_brk"] = function() {
                return (_brk = Module["_brk"] = Module["asm"]["brk"]).apply(null, arguments)
            };
            var _fmin = Module["_fmin"] = function() {
                return (_fmin = Module["_fmin"] = Module["asm"]["fmin"]).apply(null, arguments)
            };
            var _fminf = Module["_fminf"] = function() {
                return (_fminf = Module["_fminf"] = Module["asm"]["fminf"]).apply(null, arguments)
            };
            var _fminl = Module["_fminl"] = function() {
                return (_fminl = Module["_fminl"] = Module["asm"]["fminl"]).apply(null, arguments)
            };
            var _fmod = Module["_fmod"] = function() {
                return (_fmod = Module["_fmod"] = Module["asm"]["fmod"]).apply(null, arguments)
            };
            var _fmodf = Module["_fmodf"] = function() {
                return (_fmodf = Module["_fmodf"] = Module["asm"]["fmodf"]).apply(null, arguments)
            };
            var _log2f = Module["_log2f"] = function() {
                return (_log2f = Module["_log2f"] = Module["asm"]["log2f"]).apply(null, arguments)
            };
            var _log10f = Module["_log10f"] = function() {
                return (_log10f = Module["_log10f"] = Module["asm"]["log10f"]).apply(null, arguments)
            };
            var _exp2f = Module["_exp2f"] = function() {
                return (_exp2f = Module["_exp2f"] = Module["asm"]["exp2f"]).apply(null, arguments)
            };
            var _exp10 = Module["_exp10"] = function() {
                return (_exp10 = Module["_exp10"] = Module["asm"]["exp10"]).apply(null, arguments)
            };
            var _pow10 = Module["_pow10"] = function() {
                return (_pow10 = Module["_pow10"] = Module["asm"]["pow10"]).apply(null, arguments)
            };
            var _exp10f = Module["_exp10f"] = function() {
                return (_exp10f = Module["_exp10f"] = Module["asm"]["exp10f"]).apply(null, arguments)
            };
            var _pow10f = Module["_pow10f"] = function() {
                return (_pow10f = Module["_pow10f"] = Module["asm"]["pow10f"]).apply(null, arguments)
            };
            var ___signbitf = Module["___signbitf"] = function() {
                return (___signbitf = Module["___signbitf"] = Module["asm"]["__signbitf"]).apply(null, arguments)
            };
            var ___signbit = Module["___signbit"] = function() {
                return (___signbit = Module["___signbit"] = Module["asm"]["__signbit"]).apply(null, arguments)
            };
            var _emscripten_scan_stack = Module["_emscripten_scan_stack"] = function() {
                return (_emscripten_scan_stack = Module["_emscripten_scan_stack"] = Module["asm"]["emscripten_scan_stack"]).apply(null, arguments)
            };
            var ___towrite = Module["___towrite"] = function() {
                return (___towrite = Module["___towrite"] = Module["asm"]["__towrite"]).apply(null, arguments)
            };
            var ___towrite_needs_stdio_exit = Module["___towrite_needs_stdio_exit"] = function() {
                return (___towrite_needs_stdio_exit = Module["___towrite_needs_stdio_exit"] = Module["asm"]["__towrite_needs_stdio_exit"]).apply(null, arguments)
            };
            var _fwrite_unlocked = Module["_fwrite_unlocked"] = function() {
                return (_fwrite_unlocked = Module["_fwrite_unlocked"] = Module["asm"]["fwrite_unlocked"]).apply(null, arguments)
            };
            var _fputs_unlocked = Module["_fputs_unlocked"] = function() {
                return (_fputs_unlocked = Module["_fputs_unlocked"] = Module["asm"]["fputs_unlocked"]).apply(null, arguments)
            };
            var _printf = Module["_printf"] = function() {
                return (_printf = Module["_printf"] = Module["asm"]["printf"]).apply(null, arguments)
            };
            var _iprintf = Module["_iprintf"] = function() {
                return (_iprintf = Module["_iprintf"] = Module["asm"]["iprintf"]).apply(null, arguments)
            };
            var ___small_printf = Module["___small_printf"] = function() {
                return (___small_printf = Module["___small_printf"] = Module["asm"]["__small_printf"]).apply(null, arguments)
            };
            var _puts = Module["_puts"] = function() {
                return (_puts = Module["_puts"] = Module["asm"]["puts"]).apply(null, arguments)
            };
            var _socketpair = Module["_socketpair"] = function() {
                return (_socketpair = Module["_socketpair"] = Module["asm"]["socketpair"]).apply(null, arguments)
            };
            var _shutdown = Module["_shutdown"] = function() {
                return (_shutdown = Module["_shutdown"] = Module["asm"]["shutdown"]).apply(null, arguments)
            };
            var _listen = Module["_listen"] = function() {
                return (_listen = Module["_listen"] = Module["asm"]["listen"]).apply(null, arguments)
            };
            var _getpeername = Module["_getpeername"] = function() {
                return (_getpeername = Module["_getpeername"] = Module["asm"]["getpeername"]).apply(null, arguments)
            };
            var _sendmsg = Module["_sendmsg"] = function() {
                return (_sendmsg = Module["_sendmsg"] = Module["asm"]["sendmsg"]).apply(null, arguments)
            };
            var _recvmsg = Module["_recvmsg"] = function() {
                return (_recvmsg = Module["_recvmsg"] = Module["asm"]["recvmsg"]).apply(null, arguments)
            };
            var _getsockopt = Module["_getsockopt"] = function() {
                return (_getsockopt = Module["_getsockopt"] = Module["asm"]["getsockopt"]).apply(null, arguments)
            };
            var _freeaddrinfo = Module["_freeaddrinfo"] = function() {
                return (_freeaddrinfo = Module["_freeaddrinfo"] = Module["asm"]["freeaddrinfo"]).apply(null, arguments)
            };
            var ___wasm_apply_data_relocs = Module["___wasm_apply_data_relocs"] = function() {
                return (___wasm_apply_data_relocs = Module["___wasm_apply_data_relocs"] = Module["asm"]["__wasm_apply_data_relocs"]).apply(null, arguments)
            };
            var ___wasm_apply_global_relocs = Module["___wasm_apply_global_relocs"] = function() {
                return (___wasm_apply_global_relocs = Module["___wasm_apply_global_relocs"] = Module["asm"]["__wasm_apply_global_relocs"]).apply(null, arguments)
            };
            var dynCall_jiji = Module["dynCall_jiji"] = function() {
                return (dynCall_jiji = Module["dynCall_jiji"] = Module["asm"]["dynCall_jiji"]).apply(null, arguments)
            };
            var dynCall_iiiiij = Module["dynCall_iiiiij"] = function() {
                return (dynCall_iiiiij = Module["dynCall_iiiiij"] = Module["asm"]["dynCall_iiiiij"]).apply(null, arguments)
            };
            var dynCall_iiiiijj = Module["dynCall_iiiiijj"] = function() {
                return (dynCall_iiiiijj = Module["dynCall_iiiiijj"] = Module["asm"]["dynCall_iiiiijj"]).apply(null, arguments)
            };
            var dynCall_iiiiiijj = Module["dynCall_iiiiiijj"] = function() {
                return (dynCall_iiiiiijj = Module["dynCall_iiiiiijj"] = Module["asm"]["dynCall_iiiiiijj"]).apply(null, arguments)
            };
            var dynCall_viijii = Module["dynCall_viijii"] = function() {
                return (dynCall_viijii = Module["dynCall_viijii"] = Module["asm"]["dynCall_viijii"]).apply(null, arguments)
            };
            var _orig$lockf = Module["_orig$lockf"] = function() {
                return (_orig$lockf = Module["_orig$lockf"] = Module["asm"]["orig$lockf"]).apply(null, arguments)
            };
            var _orig$lockf64 = Module["_orig$lockf64"] = function() {
                return (_orig$lockf64 = Module["_orig$lockf64"] = Module["asm"]["orig$lockf64"]).apply(null, arguments)
            };
            var _orig$ffsll = Module["_orig$ffsll"] = function() {
                return (_orig$ffsll = Module["_orig$ffsll"] = Module["asm"]["orig$ffsll"]).apply(null, arguments)
            };
            var _orig$lseek = Module["_orig$lseek"] = function() {
                return (_orig$lseek = Module["_orig$lseek"] = Module["asm"]["orig$lseek"]).apply(null, arguments)
            };
            var _orig$__rand48_step = Module["_orig$__rand48_step"] = function() {
                return (_orig$__rand48_step = Module["_orig$__rand48_step"] = Module["asm"]["orig$__rand48_step"]).apply(null, arguments)
            };
            var _orig$__mmap = Module["_orig$__mmap"] = function() {
                return (_orig$__mmap = Module["_orig$__mmap"] = Module["asm"]["orig$__mmap"]).apply(null, arguments)
            };
            var _orig$mmap = Module["_orig$mmap"] = function() {
                return (_orig$mmap = Module["_orig$mmap"] = Module["asm"]["orig$mmap"]).apply(null, arguments)
            };
            var _orig$mmap64 = Module["_orig$mmap64"] = function() {
                return (_orig$mmap64 = Module["_orig$mmap64"] = Module["asm"]["orig$mmap64"]).apply(null, arguments)
            };
            var _orig$remquol = Module["_orig$remquol"] = function() {
                return (_orig$remquol = Module["_orig$remquol"] = Module["asm"]["orig$remquol"]).apply(null, arguments)
            };
            var _orig$__eqtf2 = Module["_orig$__eqtf2"] = function() {
                return (_orig$__eqtf2 = Module["_orig$__eqtf2"] = Module["asm"]["orig$__eqtf2"]).apply(null, arguments)
            };
            var _orig$__fpclassifyl = Module["_orig$__fpclassifyl"] = function() {
                return (_orig$__fpclassifyl = Module["_orig$__fpclassifyl"] = Module["asm"]["orig$__fpclassifyl"]).apply(null, arguments)
            };
            var _orig$__multf3 = Module["_orig$__multf3"] = function() {
                return (_orig$__multf3 = Module["_orig$__multf3"] = Module["asm"]["orig$__multf3"]).apply(null, arguments)
            };
            var _orig$__divtf3 = Module["_orig$__divtf3"] = function() {
                return (_orig$__divtf3 = Module["_orig$__divtf3"] = Module["asm"]["orig$__divtf3"]).apply(null, arguments)
            };
            var _orig$__addtf3 = Module["_orig$__addtf3"] = function() {
                return (_orig$__addtf3 = Module["_orig$__addtf3"] = Module["asm"]["orig$__addtf3"]).apply(null, arguments)
            };
            var _orig$__gttf2 = Module["_orig$__gttf2"] = function() {
                return (_orig$__gttf2 = Module["_orig$__gttf2"] = Module["asm"]["orig$__gttf2"]).apply(null, arguments)
            };
            var _orig$__netf2 = Module["_orig$__netf2"] = function() {
                return (_orig$__netf2 = Module["_orig$__netf2"] = Module["asm"]["orig$__netf2"]).apply(null, arguments)
            };
            var _orig$__subtf3 = Module["_orig$__subtf3"] = function() {
                return (_orig$__subtf3 = Module["_orig$__subtf3"] = Module["asm"]["orig$__subtf3"]).apply(null, arguments)
            };
            var _orig$modfl = Module["_orig$modfl"] = function() {
                return (_orig$modfl = Module["_orig$modfl"] = Module["asm"]["orig$modfl"]).apply(null, arguments)
            };
            var _orig$nearbyintl = Module["_orig$nearbyintl"] = function() {
                return (_orig$nearbyintl = Module["_orig$nearbyintl"] = Module["asm"]["orig$nearbyintl"]).apply(null, arguments)
            };
            var _orig$rintl = Module["_orig$rintl"] = function() {
                return (_orig$rintl = Module["_orig$rintl"] = Module["asm"]["orig$rintl"]).apply(null, arguments)
            };
            var _orig$__lgammal_r = Module["_orig$__lgammal_r"] = function() {
                return (_orig$__lgammal_r = Module["_orig$__lgammal_r"] = Module["asm"]["orig$__lgammal_r"]).apply(null, arguments)
            };
            var _orig$__trunctfdf2 = Module["_orig$__trunctfdf2"] = function() {
                return (_orig$__trunctfdf2 = Module["_orig$__trunctfdf2"] = Module["asm"]["orig$__trunctfdf2"]).apply(null, arguments)
            };
            var _orig$lgammal = Module["_orig$lgammal"] = function() {
                return (_orig$lgammal = Module["_orig$lgammal"] = Module["asm"]["orig$lgammal"]).apply(null, arguments)
            };
            var _orig$lgammal_r = Module["_orig$lgammal_r"] = function() {
                return (_orig$lgammal_r = Module["_orig$lgammal_r"] = Module["asm"]["orig$lgammal_r"]).apply(null, arguments)
            };
            var _orig$logbl = Module["_orig$logbl"] = function() {
                return (_orig$logbl = Module["_orig$logbl"] = Module["asm"]["orig$logbl"]).apply(null, arguments)
            };
            var _orig$ilogbl = Module["_orig$ilogbl"] = function() {
                return (_orig$ilogbl = Module["_orig$ilogbl"] = Module["asm"]["orig$ilogbl"]).apply(null, arguments)
            };
            var _orig$sqrtl = Module["_orig$sqrtl"] = function() {
                return (_orig$sqrtl = Module["_orig$sqrtl"] = Module["asm"]["orig$sqrtl"]).apply(null, arguments)
            };
            var _orig$__invtrigl_R = Module["_orig$__invtrigl_R"] = function() {
                return (_orig$__invtrigl_R = Module["_orig$__invtrigl_R"] = Module["asm"]["orig$__invtrigl_R"]).apply(null, arguments)
            };
            var _orig$sincosl = Module["_orig$sincosl"] = function() {
                return (_orig$sincosl = Module["_orig$sincosl"] = Module["asm"]["orig$sincosl"]).apply(null, arguments)
            };
            var _orig$__lttf2 = Module["_orig$__lttf2"] = function() {
                return (_orig$__lttf2 = Module["_orig$__lttf2"] = Module["asm"]["orig$__lttf2"]).apply(null, arguments)
            };
            var _orig$__sinl = Module["_orig$__sinl"] = function() {
                return (_orig$__sinl = Module["_orig$__sinl"] = Module["asm"]["orig$__sinl"]).apply(null, arguments)
            };
            var _orig$__cosl = Module["_orig$__cosl"] = function() {
                return (_orig$__cosl = Module["_orig$__cosl"] = Module["asm"]["orig$__cosl"]).apply(null, arguments)
            };
            var _orig$__rem_pio2l = Module["_orig$__rem_pio2l"] = function() {
                return (_orig$__rem_pio2l = Module["_orig$__rem_pio2l"] = Module["asm"]["orig$__rem_pio2l"]).apply(null, arguments)
            };
            var _orig$log10l = Module["_orig$log10l"] = function() {
                return (_orig$log10l = Module["_orig$log10l"] = Module["asm"]["orig$log10l"]).apply(null, arguments)
            };
            var _orig$powl = Module["_orig$powl"] = function() {
                return (_orig$powl = Module["_orig$powl"] = Module["asm"]["orig$powl"]).apply(null, arguments)
            };
            var _orig$fabsl = Module["_orig$fabsl"] = function() {
                return (_orig$fabsl = Module["_orig$fabsl"] = Module["asm"]["orig$fabsl"]).apply(null, arguments)
            };
            var _orig$cbrtl = Module["_orig$cbrtl"] = function() {
                return (_orig$cbrtl = Module["_orig$cbrtl"] = Module["asm"]["orig$cbrtl"]).apply(null, arguments)
            };
            var _orig$__trunctfsf2 = Module["_orig$__trunctfsf2"] = function() {
                return (_orig$__trunctfsf2 = Module["_orig$__trunctfsf2"] = Module["asm"]["orig$__trunctfsf2"]).apply(null, arguments)
            };
            var _orig$nexttowardl = Module["_orig$nexttowardl"] = function() {
                return (_orig$nexttowardl = Module["_orig$nexttowardl"] = Module["asm"]["orig$nexttowardl"]).apply(null, arguments)
            };
            var _orig$nextafterl = Module["_orig$nextafterl"] = function() {
                return (_orig$nextafterl = Module["_orig$nextafterl"] = Module["asm"]["orig$nextafterl"]).apply(null, arguments)
            };
            var _orig$log1pl = Module["_orig$log1pl"] = function() {
                return (_orig$log1pl = Module["_orig$log1pl"] = Module["asm"]["orig$log1pl"]).apply(null, arguments)
            };
            var _orig$frexpl = Module["_orig$frexpl"] = function() {
                return (_orig$frexpl = Module["_orig$frexpl"] = Module["asm"]["orig$frexpl"]).apply(null, arguments)
            };
            var _orig$sinl = Module["_orig$sinl"] = function() {
                return (_orig$sinl = Module["_orig$sinl"] = Module["asm"]["orig$sinl"]).apply(null, arguments)
            };
            var _orig$logl = Module["_orig$logl"] = function() {
                return (_orig$logl = Module["_orig$logl"] = Module["asm"]["orig$logl"]).apply(null, arguments)
            };
            var _orig$llroundf = Module["_orig$llroundf"] = function() {
                return (_orig$llroundf = Module["_orig$llroundf"] = Module["asm"]["orig$llroundf"]).apply(null, arguments)
            };
            var _orig$acoshl = Module["_orig$acoshl"] = function() {
                return (_orig$acoshl = Module["_orig$acoshl"] = Module["asm"]["orig$acoshl"]).apply(null, arguments)
            };
            var _orig$scalblnl = Module["_orig$scalblnl"] = function() {
                return (_orig$scalblnl = Module["_orig$scalblnl"] = Module["asm"]["orig$scalblnl"]).apply(null, arguments)
            };
            var _orig$scalbnl = Module["_orig$scalbnl"] = function() {
                return (_orig$scalbnl = Module["_orig$scalbnl"] = Module["asm"]["orig$scalbnl"]).apply(null, arguments)
            };
            var _orig$__tanl = Module["_orig$__tanl"] = function() {
                return (_orig$__tanl = Module["_orig$__tanl"] = Module["asm"]["orig$__tanl"]).apply(null, arguments)
            };
            var _orig$__getf2 = Module["_orig$__getf2"] = function() {
                return (_orig$__getf2 = Module["_orig$__getf2"] = Module["asm"]["orig$__getf2"]).apply(null, arguments)
            };
            var _orig$llround = Module["_orig$llround"] = function() {
                return (_orig$llround = Module["_orig$llround"] = Module["asm"]["orig$llround"]).apply(null, arguments)
            };
            var _orig$__fixtfdi = Module["_orig$__fixtfdi"] = function() {
                return (_orig$__fixtfdi = Module["_orig$__fixtfdi"] = Module["asm"]["orig$__fixtfdi"]).apply(null, arguments)
            };
            var _orig$__fixtfsi = Module["_orig$__fixtfsi"] = function() {
                return (_orig$__fixtfsi = Module["_orig$__fixtfsi"] = Module["asm"]["orig$__fixtfsi"]).apply(null, arguments)
            };
            var _orig$llrintf = Module["_orig$llrintf"] = function() {
                return (_orig$llrintf = Module["_orig$llrintf"] = Module["asm"]["orig$llrintf"]).apply(null, arguments)
            };
            var _orig$atanhl = Module["_orig$atanhl"] = function() {
                return (_orig$atanhl = Module["_orig$atanhl"] = Module["asm"]["orig$atanhl"]).apply(null, arguments)
            };
            var _orig$tanl = Module["_orig$tanl"] = function() {
                return (_orig$tanl = Module["_orig$tanl"] = Module["asm"]["orig$tanl"]).apply(null, arguments)
            };
            var _orig$tanhl = Module["_orig$tanhl"] = function() {
                return (_orig$tanhl = Module["_orig$tanhl"] = Module["asm"]["orig$tanhl"]).apply(null, arguments)
            };
            var _orig$coshl = Module["_orig$coshl"] = function() {
                return (_orig$coshl = Module["_orig$coshl"] = Module["asm"]["orig$coshl"]).apply(null, arguments)
            };
            var _orig$fmal = Module["_orig$fmal"] = function() {
                return (_orig$fmal = Module["_orig$fmal"] = Module["asm"]["orig$fmal"]).apply(null, arguments)
            };
            var _orig$copysignl = Module["_orig$copysignl"] = function() {
                return (_orig$copysignl = Module["_orig$copysignl"] = Module["asm"]["orig$copysignl"]).apply(null, arguments)
            };
            var _orig$truncl = Module["_orig$truncl"] = function() {
                return (_orig$truncl = Module["_orig$truncl"] = Module["asm"]["orig$truncl"]).apply(null, arguments)
            };
            var _orig$log2l = Module["_orig$log2l"] = function() {
                return (_orig$log2l = Module["_orig$log2l"] = Module["asm"]["orig$log2l"]).apply(null, arguments)
            };
            var _orig$asinl = Module["_orig$asinl"] = function() {
                return (_orig$asinl = Module["_orig$asinl"] = Module["asm"]["orig$asinl"]).apply(null, arguments)
            };
            var _orig$remainderl = Module["_orig$remainderl"] = function() {
                return (_orig$remainderl = Module["_orig$remainderl"] = Module["asm"]["orig$remainderl"]).apply(null, arguments)
            };
            var _orig$exp10l = Module["_orig$exp10l"] = function() {
                return (_orig$exp10l = Module["_orig$exp10l"] = Module["asm"]["orig$exp10l"]).apply(null, arguments)
            };
            var _orig$exp2l = Module["_orig$exp2l"] = function() {
                return (_orig$exp2l = Module["_orig$exp2l"] = Module["asm"]["orig$exp2l"]).apply(null, arguments)
            };
            var _orig$pow10l = Module["_orig$pow10l"] = function() {
                return (_orig$pow10l = Module["_orig$pow10l"] = Module["asm"]["orig$pow10l"]).apply(null, arguments)
            };
            var _orig$ceill = Module["_orig$ceill"] = function() {
                return (_orig$ceill = Module["_orig$ceill"] = Module["asm"]["orig$ceill"]).apply(null, arguments)
            };
            var _orig$hypotl = Module["_orig$hypotl"] = function() {
                return (_orig$hypotl = Module["_orig$hypotl"] = Module["asm"]["orig$hypotl"]).apply(null, arguments)
            };
            var _orig$lroundl = Module["_orig$lroundl"] = function() {
                return (_orig$lroundl = Module["_orig$lroundl"] = Module["asm"]["orig$lroundl"]).apply(null, arguments)
            };
            var _orig$roundl = Module["_orig$roundl"] = function() {
                return (_orig$roundl = Module["_orig$roundl"] = Module["asm"]["orig$roundl"]).apply(null, arguments)
            };
            var _orig$asinhl = Module["_orig$asinhl"] = function() {
                return (_orig$asinhl = Module["_orig$asinhl"] = Module["asm"]["orig$asinhl"]).apply(null, arguments)
            };
            var _orig$llroundl = Module["_orig$llroundl"] = function() {
                return (_orig$llroundl = Module["_orig$llroundl"] = Module["asm"]["orig$llroundl"]).apply(null, arguments)
            };
            var _orig$erfl = Module["_orig$erfl"] = function() {
                return (_orig$erfl = Module["_orig$erfl"] = Module["asm"]["orig$erfl"]).apply(null, arguments)
            };
            var _orig$erfcl = Module["_orig$erfcl"] = function() {
                return (_orig$erfcl = Module["_orig$erfcl"] = Module["asm"]["orig$erfcl"]).apply(null, arguments)
            };
            var _orig$ldexpl = Module["_orig$ldexpl"] = function() {
                return (_orig$ldexpl = Module["_orig$ldexpl"] = Module["asm"]["orig$ldexpl"]).apply(null, arguments)
            };
            var _orig$atan2l = Module["_orig$atan2l"] = function() {
                return (_orig$atan2l = Module["_orig$atan2l"] = Module["asm"]["orig$atan2l"]).apply(null, arguments)
            };
            var _orig$atanl = Module["_orig$atanl"] = function() {
                return (_orig$atanl = Module["_orig$atanl"] = Module["asm"]["orig$atanl"]).apply(null, arguments)
            };
            var _orig$__polevll = Module["_orig$__polevll"] = function() {
                return (_orig$__polevll = Module["_orig$__polevll"] = Module["asm"]["orig$__polevll"]).apply(null, arguments)
            };
            var _orig$__p1evll = Module["_orig$__p1evll"] = function() {
                return (_orig$__p1evll = Module["_orig$__p1evll"] = Module["asm"]["orig$__p1evll"]).apply(null, arguments)
            };
            var _orig$tgammal = Module["_orig$tgammal"] = function() {
                return (_orig$tgammal = Module["_orig$tgammal"] = Module["asm"]["orig$tgammal"]).apply(null, arguments)
            };
            var _orig$fdiml = Module["_orig$fdiml"] = function() {
                return (_orig$fdiml = Module["_orig$fdiml"] = Module["asm"]["orig$fdiml"]).apply(null, arguments)
            };
            var _orig$acosl = Module["_orig$acosl"] = function() {
                return (_orig$acosl = Module["_orig$acosl"] = Module["asm"]["orig$acosl"]).apply(null, arguments)
            };
            var _orig$sinhl = Module["_orig$sinhl"] = function() {
                return (_orig$sinhl = Module["_orig$sinhl"] = Module["asm"]["orig$sinhl"]).apply(null, arguments)
            };
            var _orig$lrintl = Module["_orig$lrintl"] = function() {
                return (_orig$lrintl = Module["_orig$lrintl"] = Module["asm"]["orig$lrintl"]).apply(null, arguments)
            };
            var _orig$llrintl = Module["_orig$llrintl"] = function() {
                return (_orig$llrintl = Module["_orig$llrintl"] = Module["asm"]["orig$llrintl"]).apply(null, arguments)
            };
            var _orig$expm1l = Module["_orig$expm1l"] = function() {
                return (_orig$expm1l = Module["_orig$expm1l"] = Module["asm"]["orig$expm1l"]).apply(null, arguments)
            };
            var _orig$floorl = Module["_orig$floorl"] = function() {
                return (_orig$floorl = Module["_orig$floorl"] = Module["asm"]["orig$floorl"]).apply(null, arguments)
            };
            var _orig$expl = Module["_orig$expl"] = function() {
                return (_orig$expl = Module["_orig$expl"] = Module["asm"]["orig$expl"]).apply(null, arguments)
            };
            var _orig$cosl = Module["_orig$cosl"] = function() {
                return (_orig$cosl = Module["_orig$cosl"] = Module["asm"]["orig$cosl"]).apply(null, arguments)
            };
            var _orig$nexttowardf = Module["_orig$nexttowardf"] = function() {
                return (_orig$nexttowardf = Module["_orig$nexttowardf"] = Module["asm"]["orig$nexttowardf"]).apply(null, arguments)
            };
            var _orig$__signbitl = Module["_orig$__signbitl"] = function() {
                return (_orig$__signbitl = Module["_orig$__signbitl"] = Module["asm"]["orig$__signbitl"]).apply(null, arguments)
            };
            var _orig$__letf2 = Module["_orig$__letf2"] = function() {
                return (_orig$__letf2 = Module["_orig$__letf2"] = Module["asm"]["orig$__letf2"]).apply(null, arguments)
            };
            var _orig$llrint = Module["_orig$llrint"] = function() {
                return (_orig$llrint = Module["_orig$llrint"] = Module["asm"]["orig$llrint"]).apply(null, arguments)
            };
            var _orig$nexttoward = Module["_orig$nexttoward"] = function() {
                return (_orig$nexttoward = Module["_orig$nexttoward"] = Module["asm"]["orig$nexttoward"]).apply(null, arguments)
            };
            var _orig$__stdio_seek = Module["_orig$__stdio_seek"] = function() {
                return (_orig$__stdio_seek = Module["_orig$__stdio_seek"] = Module["asm"]["orig$__stdio_seek"]).apply(null, arguments)
            };
            var _orig$__fseeko_unlocked = Module["_orig$__fseeko_unlocked"] = function() {
                return (_orig$__fseeko_unlocked = Module["_orig$__fseeko_unlocked"] = Module["asm"]["orig$__fseeko_unlocked"]).apply(null, arguments)
            };
            var _orig$__shlim = Module["_orig$__shlim"] = function() {
                return (_orig$__shlim = Module["_orig$__shlim"] = Module["asm"]["orig$__shlim"]).apply(null, arguments)
            };
            var _orig$__intscan = Module["_orig$__intscan"] = function() {
                return (_orig$__intscan = Module["_orig$__intscan"] = Module["asm"]["orig$__intscan"]).apply(null, arguments)
            };
            var _orig$__ftello = Module["_orig$__ftello"] = function() {
                return (_orig$__ftello = Module["_orig$__ftello"] = Module["asm"]["orig$__ftello"]).apply(null, arguments)
            };
            var _orig$__fseeko = Module["_orig$__fseeko"] = function() {
                return (_orig$__fseeko = Module["_orig$__fseeko"] = Module["asm"]["orig$__fseeko"]).apply(null, arguments)
            };
            var _orig$fseeko = Module["_orig$fseeko"] = function() {
                return (_orig$fseeko = Module["_orig$fseeko"] = Module["asm"]["orig$fseeko"]).apply(null, arguments)
            };
            var _orig$fseeko64 = Module["_orig$fseeko64"] = function() {
                return (_orig$fseeko64 = Module["_orig$fseeko64"] = Module["asm"]["orig$fseeko64"]).apply(null, arguments)
            };
            var _orig$__ftello_unlocked = Module["_orig$__ftello_unlocked"] = function() {
                return (_orig$__ftello_unlocked = Module["_orig$__ftello_unlocked"] = Module["asm"]["orig$__ftello_unlocked"]).apply(null, arguments)
            };
            var _orig$ftello = Module["_orig$ftello"] = function() {
                return (_orig$ftello = Module["_orig$ftello"] = Module["asm"]["orig$ftello"]).apply(null, arguments)
            };
            var _orig$ftello64 = Module["_orig$ftello64"] = function() {
                return (_orig$ftello64 = Module["_orig$ftello64"] = Module["asm"]["orig$ftello64"]).apply(null, arguments)
            };
            var _orig$posix_fallocate = Module["_orig$posix_fallocate"] = function() {
                return (_orig$posix_fallocate = Module["_orig$posix_fallocate"] = Module["asm"]["orig$posix_fallocate"]).apply(null, arguments)
            };
            var _orig$posix_fallocate64 = Module["_orig$posix_fallocate64"] = function() {
                return (_orig$posix_fallocate64 = Module["_orig$posix_fallocate64"] = Module["asm"]["orig$posix_fallocate64"]).apply(null, arguments)
            };
            var _orig$posix_fadvise = Module["_orig$posix_fadvise"] = function() {
                return (_orig$posix_fadvise = Module["_orig$posix_fadvise"] = Module["asm"]["orig$posix_fadvise"]).apply(null, arguments)
            };
            var _orig$posix_fadvise64 = Module["_orig$posix_fadvise64"] = function() {
                return (_orig$posix_fadvise64 = Module["_orig$posix_fadvise64"] = Module["asm"]["orig$posix_fadvise64"]).apply(null, arguments)
            };
            var _orig$lseek64 = Module["_orig$lseek64"] = function() {
                return (_orig$lseek64 = Module["_orig$lseek64"] = Module["asm"]["orig$lseek64"]).apply(null, arguments)
            };
            var _orig$truncate = Module["_orig$truncate"] = function() {
                return (_orig$truncate = Module["_orig$truncate"] = Module["asm"]["orig$truncate"]).apply(null, arguments)
            };
            var _orig$truncate64 = Module["_orig$truncate64"] = function() {
                return (_orig$truncate64 = Module["_orig$truncate64"] = Module["asm"]["orig$truncate64"]).apply(null, arguments)
            };
            var _orig$pwrite = Module["_orig$pwrite"] = function() {
                return (_orig$pwrite = Module["_orig$pwrite"] = Module["asm"]["orig$pwrite"]).apply(null, arguments)
            };
            var _orig$pwrite64 = Module["_orig$pwrite64"] = function() {
                return (_orig$pwrite64 = Module["_orig$pwrite64"] = Module["asm"]["orig$pwrite64"]).apply(null, arguments)
            };
            var _orig$pread = Module["_orig$pread"] = function() {
                return (_orig$pread = Module["_orig$pread"] = Module["asm"]["orig$pread"]).apply(null, arguments)
            };
            var _orig$pread64 = Module["_orig$pread64"] = function() {
                return (_orig$pread64 = Module["_orig$pread64"] = Module["asm"]["orig$pread64"]).apply(null, arguments)
            };
            var _orig$pwritev = Module["_orig$pwritev"] = function() {
                return (_orig$pwritev = Module["_orig$pwritev"] = Module["asm"]["orig$pwritev"]).apply(null, arguments)
            };
            var _orig$pwritev64 = Module["_orig$pwritev64"] = function() {
                return (_orig$pwritev64 = Module["_orig$pwritev64"] = Module["asm"]["orig$pwritev64"]).apply(null, arguments)
            };
            var _orig$preadv = Module["_orig$preadv"] = function() {
                return (_orig$preadv = Module["_orig$preadv"] = Module["asm"]["orig$preadv"]).apply(null, arguments)
            };
            var _orig$preadv64 = Module["_orig$preadv64"] = function() {
                return (_orig$preadv64 = Module["_orig$preadv64"] = Module["asm"]["orig$preadv64"]).apply(null, arguments)
            };
            var _orig$ftruncate = Module["_orig$ftruncate"] = function() {
                return (_orig$ftruncate = Module["_orig$ftruncate"] = Module["asm"]["orig$ftruncate"]).apply(null, arguments)
            };
            var _orig$ftruncate64 = Module["_orig$ftruncate64"] = function() {
                return (_orig$ftruncate64 = Module["_orig$ftruncate64"] = Module["asm"]["orig$ftruncate64"]).apply(null, arguments)
            };
            var _orig$fmodl = Module["_orig$fmodl"] = function() {
                return (_orig$fmodl = Module["_orig$fmodl"] = Module["asm"]["orig$fmodl"]).apply(null, arguments)
            };
            var _orig$__multi3 = Module["_orig$__multi3"] = function() {
                return (_orig$__multi3 = Module["_orig$__multi3"] = Module["asm"]["orig$__multi3"]).apply(null, arguments)
            };
            var _orig$strtoull = Module["_orig$strtoull"] = function() {
                return (_orig$strtoull = Module["_orig$strtoull"] = Module["asm"]["orig$strtoull"]).apply(null, arguments)
            };
            var _orig$__unordtf2 = Module["_orig$__unordtf2"] = function() {
                return (_orig$__unordtf2 = Module["_orig$__unordtf2"] = Module["asm"]["orig$__unordtf2"]).apply(null, arguments)
            };
            var _orig$__multc3 = Module["_orig$__multc3"] = function() {
                return (_orig$__multc3 = Module["_orig$__multc3"] = Module["asm"]["orig$__multc3"]).apply(null, arguments)
            };
            var _orig$llabs = Module["_orig$llabs"] = function() {
                return (_orig$llabs = Module["_orig$llabs"] = Module["asm"]["orig$llabs"]).apply(null, arguments)
            };
            var _orig$imaxabs = Module["_orig$imaxabs"] = function() {
                return (_orig$imaxabs = Module["_orig$imaxabs"] = Module["asm"]["orig$imaxabs"]).apply(null, arguments)
            };
            var _orig$atoll = Module["_orig$atoll"] = function() {
                return (_orig$atoll = Module["_orig$atoll"] = Module["asm"]["orig$atoll"]).apply(null, arguments)
            };
            var _orig$lldiv = Module["_orig$lldiv"] = function() {
                return (_orig$lldiv = Module["_orig$lldiv"] = Module["asm"]["orig$lldiv"]).apply(null, arguments)
            };
            var _orig$wcstoull = Module["_orig$wcstoull"] = function() {
                return (_orig$wcstoull = Module["_orig$wcstoull"] = Module["asm"]["orig$wcstoull"]).apply(null, arguments)
            };
            var _orig$wcstoll = Module["_orig$wcstoll"] = function() {
                return (_orig$wcstoll = Module["_orig$wcstoll"] = Module["asm"]["orig$wcstoll"]).apply(null, arguments)
            };
            var _orig$wcstoimax = Module["_orig$wcstoimax"] = function() {
                return (_orig$wcstoimax = Module["_orig$wcstoimax"] = Module["asm"]["orig$wcstoimax"]).apply(null, arguments)
            };
            var _orig$wcstoumax = Module["_orig$wcstoumax"] = function() {
                return (_orig$wcstoumax = Module["_orig$wcstoumax"] = Module["asm"]["orig$wcstoumax"]).apply(null, arguments)
            };
            var _orig$imaxdiv = Module["_orig$imaxdiv"] = function() {
                return (_orig$imaxdiv = Module["_orig$imaxdiv"] = Module["asm"]["orig$imaxdiv"]).apply(null, arguments)
            };
            var _orig$strtoll = Module["_orig$strtoll"] = function() {
                return (_orig$strtoll = Module["_orig$strtoll"] = Module["asm"]["orig$strtoll"]).apply(null, arguments)
            };
            var _orig$strtoimax = Module["_orig$strtoimax"] = function() {
                return (_orig$strtoimax = Module["_orig$strtoimax"] = Module["asm"]["orig$strtoimax"]).apply(null, arguments)
            };
            var _orig$strtoumax = Module["_orig$strtoumax"] = function() {
                return (_orig$strtoumax = Module["_orig$strtoumax"] = Module["asm"]["orig$strtoumax"]).apply(null, arguments)
            };
            var _orig$__strtoll_internal = Module["_orig$__strtoll_internal"] = function() {
                return (_orig$__strtoll_internal = Module["_orig$__strtoll_internal"] = Module["asm"]["orig$__strtoll_internal"]).apply(null, arguments)
            };
            var _orig$__strtoull_internal = Module["_orig$__strtoull_internal"] = function() {
                return (_orig$__strtoull_internal = Module["_orig$__strtoull_internal"] = Module["asm"]["orig$__strtoull_internal"]).apply(null, arguments)
            };
            var _orig$__strtoimax_internal = Module["_orig$__strtoimax_internal"] = function() {
                return (_orig$__strtoimax_internal = Module["_orig$__strtoimax_internal"] = Module["asm"]["orig$__strtoimax_internal"]).apply(null, arguments)
            };
            var _orig$__strtoumax_internal = Module["_orig$__strtoumax_internal"] = function() {
                return (_orig$__strtoumax_internal = Module["_orig$__strtoumax_internal"] = Module["asm"]["orig$__strtoumax_internal"]).apply(null, arguments)
            };
            var _orig$emscripten_atomic_exchange_u64 = Module["_orig$emscripten_atomic_exchange_u64"] = function() {
                return (_orig$emscripten_atomic_exchange_u64 = Module["_orig$emscripten_atomic_exchange_u64"] = Module["asm"]["orig$emscripten_atomic_exchange_u64"]).apply(null, arguments)
            };
            var _orig$emscripten_atomic_cas_u64 = Module["_orig$emscripten_atomic_cas_u64"] = function() {
                return (_orig$emscripten_atomic_cas_u64 = Module["_orig$emscripten_atomic_cas_u64"] = Module["asm"]["orig$emscripten_atomic_cas_u64"]).apply(null, arguments)
            };
            var _orig$emscripten_atomic_load_u64 = Module["_orig$emscripten_atomic_load_u64"] = function() {
                return (_orig$emscripten_atomic_load_u64 = Module["_orig$emscripten_atomic_load_u64"] = Module["asm"]["orig$emscripten_atomic_load_u64"]).apply(null, arguments)
            };
            var _orig$emscripten_atomic_store_u64 = Module["_orig$emscripten_atomic_store_u64"] = function() {
                return (_orig$emscripten_atomic_store_u64 = Module["_orig$emscripten_atomic_store_u64"] = Module["asm"]["orig$emscripten_atomic_store_u64"]).apply(null, arguments)
            };
            var _orig$emscripten_atomic_add_u64 = Module["_orig$emscripten_atomic_add_u64"] = function() {
                return (_orig$emscripten_atomic_add_u64 = Module["_orig$emscripten_atomic_add_u64"] = Module["asm"]["orig$emscripten_atomic_add_u64"]).apply(null, arguments)
            };
            var _orig$emscripten_atomic_sub_u64 = Module["_orig$emscripten_atomic_sub_u64"] = function() {
                return (_orig$emscripten_atomic_sub_u64 = Module["_orig$emscripten_atomic_sub_u64"] = Module["asm"]["orig$emscripten_atomic_sub_u64"]).apply(null, arguments)
            };
            var _orig$emscripten_atomic_and_u64 = Module["_orig$emscripten_atomic_and_u64"] = function() {
                return (_orig$emscripten_atomic_and_u64 = Module["_orig$emscripten_atomic_and_u64"] = Module["asm"]["orig$emscripten_atomic_and_u64"]).apply(null, arguments)
            };
            var _orig$emscripten_atomic_or_u64 = Module["_orig$emscripten_atomic_or_u64"] = function() {
                return (_orig$emscripten_atomic_or_u64 = Module["_orig$emscripten_atomic_or_u64"] = Module["asm"]["orig$emscripten_atomic_or_u64"]).apply(null, arguments)
            };
            var _orig$emscripten_atomic_xor_u64 = Module["_orig$emscripten_atomic_xor_u64"] = function() {
                return (_orig$emscripten_atomic_xor_u64 = Module["_orig$emscripten_atomic_xor_u64"] = Module["asm"]["orig$emscripten_atomic_xor_u64"]).apply(null, arguments)
            };
            var _orig$strtoull_l = Module["_orig$strtoull_l"] = function() {
                return (_orig$strtoull_l = Module["_orig$strtoull_l"] = Module["asm"]["orig$strtoull_l"]).apply(null, arguments)
            };
            var _orig$strtoll_l = Module["_orig$strtoll_l"] = function() {
                return (_orig$strtoll_l = Module["_orig$strtoll_l"] = Module["asm"]["orig$strtoll_l"]).apply(null, arguments)
            };
            var _orig$__addvdi3 = Module["_orig$__addvdi3"] = function() {
                return (_orig$__addvdi3 = Module["_orig$__addvdi3"] = Module["asm"]["orig$__addvdi3"]).apply(null, arguments)
            };
            var _orig$__umodti3 = Module["_orig$__umodti3"] = function() {
                return (_orig$__umodti3 = Module["_orig$__umodti3"] = Module["asm"]["orig$__umodti3"]).apply(null, arguments)
            };
            var _orig$__udivmodti4 = Module["_orig$__udivmodti4"] = function() {
                return (_orig$__udivmodti4 = Module["_orig$__udivmodti4"] = Module["asm"]["orig$__udivmodti4"]).apply(null, arguments)
            };
            var _orig$__floatdixf = Module["_orig$__floatdixf"] = function() {
                return (_orig$__floatdixf = Module["_orig$__floatdixf"] = Module["asm"]["orig$__floatdixf"]).apply(null, arguments)
            };
            var _orig$__floatdisf = Module["_orig$__floatdisf"] = function() {
                return (_orig$__floatdisf = Module["_orig$__floatdisf"] = Module["asm"]["orig$__floatdisf"]).apply(null, arguments)
            };
            var _orig$__ashlti3 = Module["_orig$__ashlti3"] = function() {
                return (_orig$__ashlti3 = Module["_orig$__ashlti3"] = Module["asm"]["orig$__ashlti3"]).apply(null, arguments)
            };
            var _orig$__paritydi2 = Module["_orig$__paritydi2"] = function() {
                return (_orig$__paritydi2 = Module["_orig$__paritydi2"] = Module["asm"]["orig$__paritydi2"]).apply(null, arguments)
            };
            var _orig$__fixunsxfti = Module["_orig$__fixunsxfti"] = function() {
                return (_orig$__fixunsxfti = Module["_orig$__fixunsxfti"] = Module["asm"]["orig$__fixunsxfti"]).apply(null, arguments)
            };
            var _orig$__lshrti3 = Module["_orig$__lshrti3"] = function() {
                return (_orig$__lshrti3 = Module["_orig$__lshrti3"] = Module["asm"]["orig$__lshrti3"]).apply(null, arguments)
            };
            var _orig$__fixunssfdi = Module["_orig$__fixunssfdi"] = function() {
                return (_orig$__fixunssfdi = Module["_orig$__fixunssfdi"] = Module["asm"]["orig$__fixunssfdi"]).apply(null, arguments)
            };
            var _orig$__floatuntitf = Module["_orig$__floatuntitf"] = function() {
                return (_orig$__floatuntitf = Module["_orig$__floatuntitf"] = Module["asm"]["orig$__floatuntitf"]).apply(null, arguments)
            };
            var _orig$__clzti2 = Module["_orig$__clzti2"] = function() {
                return (_orig$__clzti2 = Module["_orig$__clzti2"] = Module["asm"]["orig$__clzti2"]).apply(null, arguments)
            };
            var _orig$__udivti3 = Module["_orig$__udivti3"] = function() {
                return (_orig$__udivti3 = Module["_orig$__udivti3"] = Module["asm"]["orig$__udivti3"]).apply(null, arguments)
            };
            var _orig$__ctzti2 = Module["_orig$__ctzti2"] = function() {
                return (_orig$__ctzti2 = Module["_orig$__ctzti2"] = Module["asm"]["orig$__ctzti2"]).apply(null, arguments)
            };
            var _orig$__muloti4 = Module["_orig$__muloti4"] = function() {
                return (_orig$__muloti4 = Module["_orig$__muloti4"] = Module["asm"]["orig$__muloti4"]).apply(null, arguments)
            };
            var _orig$__fixtfti = Module["_orig$__fixtfti"] = function() {
                return (_orig$__fixtfti = Module["_orig$__fixtfti"] = Module["asm"]["orig$__fixtfti"]).apply(null, arguments)
            };
            var _orig$__floatuntisf = Module["_orig$__floatuntisf"] = function() {
                return (_orig$__floatuntisf = Module["_orig$__floatuntisf"] = Module["asm"]["orig$__floatuntisf"]).apply(null, arguments)
            };
            var _orig$__floatuntixf = Module["_orig$__floatuntixf"] = function() {
                return (_orig$__floatuntixf = Module["_orig$__floatuntixf"] = Module["asm"]["orig$__floatuntixf"]).apply(null, arguments)
            };
            var _orig$__fixxfti = Module["_orig$__fixxfti"] = function() {
                return (_orig$__fixxfti = Module["_orig$__fixxfti"] = Module["asm"]["orig$__fixxfti"]).apply(null, arguments)
            };
            var _orig$__floattixf = Module["_orig$__floattixf"] = function() {
                return (_orig$__floattixf = Module["_orig$__floattixf"] = Module["asm"]["orig$__floattixf"]).apply(null, arguments)
            };
            var _orig$__udivdi3 = Module["_orig$__udivdi3"] = function() {
                return (_orig$__udivdi3 = Module["_orig$__udivdi3"] = Module["asm"]["orig$__udivdi3"]).apply(null, arguments)
            };
            var _orig$__udivmoddi4 = Module["_orig$__udivmoddi4"] = function() {
                return (_orig$__udivmoddi4 = Module["_orig$__udivmoddi4"] = Module["asm"]["orig$__udivmoddi4"]).apply(null, arguments)
            };
            var _orig$__floatundidf = Module["_orig$__floatundidf"] = function() {
                return (_orig$__floatundidf = Module["_orig$__floatundidf"] = Module["asm"]["orig$__floatundidf"]).apply(null, arguments)
            };
            var _orig$__mulvti3 = Module["_orig$__mulvti3"] = function() {
                return (_orig$__mulvti3 = Module["_orig$__mulvti3"] = Module["asm"]["orig$__mulvti3"]).apply(null, arguments)
            };
            var _orig$__subvdi3 = Module["_orig$__subvdi3"] = function() {
                return (_orig$__subvdi3 = Module["_orig$__subvdi3"] = Module["asm"]["orig$__subvdi3"]).apply(null, arguments)
            };
            var _orig$__floattitf = Module["_orig$__floattitf"] = function() {
                return (_orig$__floattitf = Module["_orig$__floattitf"] = Module["asm"]["orig$__floattitf"]).apply(null, arguments)
            };
            var _orig$__atomic_load_8 = Module["_orig$__atomic_load_8"] = function() {
                return (_orig$__atomic_load_8 = Module["_orig$__atomic_load_8"] = Module["asm"]["orig$__atomic_load_8"]).apply(null, arguments)
            };
            var _orig$__atomic_store_8 = Module["_orig$__atomic_store_8"] = function() {
                return (_orig$__atomic_store_8 = Module["_orig$__atomic_store_8"] = Module["asm"]["orig$__atomic_store_8"]).apply(null, arguments)
            };
            var _orig$__atomic_store_16 = Module["_orig$__atomic_store_16"] = function() {
                return (_orig$__atomic_store_16 = Module["_orig$__atomic_store_16"] = Module["asm"]["orig$__atomic_store_16"]).apply(null, arguments)
            };
            var _orig$__atomic_exchange_8 = Module["_orig$__atomic_exchange_8"] = function() {
                return (_orig$__atomic_exchange_8 = Module["_orig$__atomic_exchange_8"] = Module["asm"]["orig$__atomic_exchange_8"]).apply(null, arguments)
            };
            var _orig$__atomic_exchange_16 = Module["_orig$__atomic_exchange_16"] = function() {
                return (_orig$__atomic_exchange_16 = Module["_orig$__atomic_exchange_16"] = Module["asm"]["orig$__atomic_exchange_16"]).apply(null, arguments)
            };
            var _orig$__atomic_compare_exchange_8 = Module["_orig$__atomic_compare_exchange_8"] = function() {
                return (_orig$__atomic_compare_exchange_8 = Module["_orig$__atomic_compare_exchange_8"] = Module["asm"]["orig$__atomic_compare_exchange_8"]).apply(null, arguments)
            };
            var _orig$__atomic_compare_exchange_16 = Module["_orig$__atomic_compare_exchange_16"] = function() {
                return (_orig$__atomic_compare_exchange_16 = Module["_orig$__atomic_compare_exchange_16"] = Module["asm"]["orig$__atomic_compare_exchange_16"]).apply(null, arguments)
            };
            var _orig$__atomic_fetch_add_8 = Module["_orig$__atomic_fetch_add_8"] = function() {
                return (_orig$__atomic_fetch_add_8 = Module["_orig$__atomic_fetch_add_8"] = Module["asm"]["orig$__atomic_fetch_add_8"]).apply(null, arguments)
            };
            var _orig$__atomic_fetch_add_16 = Module["_orig$__atomic_fetch_add_16"] = function() {
                return (_orig$__atomic_fetch_add_16 = Module["_orig$__atomic_fetch_add_16"] = Module["asm"]["orig$__atomic_fetch_add_16"]).apply(null, arguments)
            };
            var _orig$__atomic_fetch_sub_8 = Module["_orig$__atomic_fetch_sub_8"] = function() {
                return (_orig$__atomic_fetch_sub_8 = Module["_orig$__atomic_fetch_sub_8"] = Module["asm"]["orig$__atomic_fetch_sub_8"]).apply(null, arguments)
            };
            var _orig$__atomic_fetch_sub_16 = Module["_orig$__atomic_fetch_sub_16"] = function() {
                return (_orig$__atomic_fetch_sub_16 = Module["_orig$__atomic_fetch_sub_16"] = Module["asm"]["orig$__atomic_fetch_sub_16"]).apply(null, arguments)
            };
            var _orig$__atomic_fetch_and_8 = Module["_orig$__atomic_fetch_and_8"] = function() {
                return (_orig$__atomic_fetch_and_8 = Module["_orig$__atomic_fetch_and_8"] = Module["asm"]["orig$__atomic_fetch_and_8"]).apply(null, arguments)
            };
            var _orig$__atomic_fetch_and_16 = Module["_orig$__atomic_fetch_and_16"] = function() {
                return (_orig$__atomic_fetch_and_16 = Module["_orig$__atomic_fetch_and_16"] = Module["asm"]["orig$__atomic_fetch_and_16"]).apply(null, arguments)
            };
            var _orig$__atomic_fetch_or_8 = Module["_orig$__atomic_fetch_or_8"] = function() {
                return (_orig$__atomic_fetch_or_8 = Module["_orig$__atomic_fetch_or_8"] = Module["asm"]["orig$__atomic_fetch_or_8"]).apply(null, arguments)
            };
            var _orig$__atomic_fetch_or_16 = Module["_orig$__atomic_fetch_or_16"] = function() {
                return (_orig$__atomic_fetch_or_16 = Module["_orig$__atomic_fetch_or_16"] = Module["asm"]["orig$__atomic_fetch_or_16"]).apply(null, arguments)
            };
            var _orig$__atomic_fetch_xor_8 = Module["_orig$__atomic_fetch_xor_8"] = function() {
                return (_orig$__atomic_fetch_xor_8 = Module["_orig$__atomic_fetch_xor_8"] = Module["asm"]["orig$__atomic_fetch_xor_8"]).apply(null, arguments)
            };
            var _orig$__atomic_fetch_xor_16 = Module["_orig$__atomic_fetch_xor_16"] = function() {
                return (_orig$__atomic_fetch_xor_16 = Module["_orig$__atomic_fetch_xor_16"] = Module["asm"]["orig$__atomic_fetch_xor_16"]).apply(null, arguments)
            };
            var _orig$__fixsfdi = Module["_orig$__fixsfdi"] = function() {
                return (_orig$__fixsfdi = Module["_orig$__fixsfdi"] = Module["asm"]["orig$__fixsfdi"]).apply(null, arguments)
            };
            var _orig$__floatundixf = Module["_orig$__floatundixf"] = function() {
                return (_orig$__floatundixf = Module["_orig$__floatundixf"] = Module["asm"]["orig$__floatundixf"]).apply(null, arguments)
            };
            var _orig$__floatditf = Module["_orig$__floatditf"] = function() {
                return (_orig$__floatditf = Module["_orig$__floatditf"] = Module["asm"]["orig$__floatditf"]).apply(null, arguments)
            };
            var _orig$__mulxc3 = Module["_orig$__mulxc3"] = function() {
                return (_orig$__mulxc3 = Module["_orig$__mulxc3"] = Module["asm"]["orig$__mulxc3"]).apply(null, arguments)
            };
            var _orig$__fixunsdfdi = Module["_orig$__fixunsdfdi"] = function() {
                return (_orig$__fixunsdfdi = Module["_orig$__fixunsdfdi"] = Module["asm"]["orig$__fixunsdfdi"]).apply(null, arguments)
            };
            var _orig$__fixunstfsi = Module["_orig$__fixunstfsi"] = function() {
                return (_orig$__fixunstfsi = Module["_orig$__fixunstfsi"] = Module["asm"]["orig$__fixunstfsi"]).apply(null, arguments)
            };
            var _orig$__floatdidf = Module["_orig$__floatdidf"] = function() {
                return (_orig$__floatdidf = Module["_orig$__floatdidf"] = Module["asm"]["orig$__floatdidf"]).apply(null, arguments)
            };
            var _orig$__absvti2 = Module["_orig$__absvti2"] = function() {
                return (_orig$__absvti2 = Module["_orig$__absvti2"] = Module["asm"]["orig$__absvti2"]).apply(null, arguments)
            };
            var _orig$__negdi2 = Module["_orig$__negdi2"] = function() {
                return (_orig$__negdi2 = Module["_orig$__negdi2"] = Module["asm"]["orig$__negdi2"]).apply(null, arguments)
            };
            var _orig$__parityti2 = Module["_orig$__parityti2"] = function() {
                return (_orig$__parityti2 = Module["_orig$__parityti2"] = Module["asm"]["orig$__parityti2"]).apply(null, arguments)
            };
            var _orig$__fixunsxfsi = Module["_orig$__fixunsxfsi"] = function() {
                return (_orig$__fixunsxfsi = Module["_orig$__fixunsxfsi"] = Module["asm"]["orig$__fixunsxfsi"]).apply(null, arguments)
            };
            var _orig$__fixdfdi = Module["_orig$__fixdfdi"] = function() {
                return (_orig$__fixdfdi = Module["_orig$__fixdfdi"] = Module["asm"]["orig$__fixdfdi"]).apply(null, arguments)
            };
            var _orig$__floatuntidf = Module["_orig$__floatuntidf"] = function() {
                return (_orig$__floatuntidf = Module["_orig$__floatuntidf"] = Module["asm"]["orig$__floatuntidf"]).apply(null, arguments)
            };
            var _orig$__cmpdi2 = Module["_orig$__cmpdi2"] = function() {
                return (_orig$__cmpdi2 = Module["_orig$__cmpdi2"] = Module["asm"]["orig$__cmpdi2"]).apply(null, arguments)
            };
            var _orig$__divti3 = Module["_orig$__divti3"] = function() {
                return (_orig$__divti3 = Module["_orig$__divti3"] = Module["asm"]["orig$__divti3"]).apply(null, arguments)
            };
            var _orig$__absvdi2 = Module["_orig$__absvdi2"] = function() {
                return (_orig$__absvdi2 = Module["_orig$__absvdi2"] = Module["asm"]["orig$__absvdi2"]).apply(null, arguments)
            };
            var _orig$__umoddi3 = Module["_orig$__umoddi3"] = function() {
                return (_orig$__umoddi3 = Module["_orig$__umoddi3"] = Module["asm"]["orig$__umoddi3"]).apply(null, arguments)
            };
            var _orig$__floatundisf = Module["_orig$__floatundisf"] = function() {
                return (_orig$__floatundisf = Module["_orig$__floatundisf"] = Module["asm"]["orig$__floatundisf"]).apply(null, arguments)
            };
            var _orig$__negvti2 = Module["_orig$__negvti2"] = function() {
                return (_orig$__negvti2 = Module["_orig$__negvti2"] = Module["asm"]["orig$__negvti2"]).apply(null, arguments)
            };
            var _orig$__fixunstfdi = Module["_orig$__fixunstfdi"] = function() {
                return (_orig$__fixunstfdi = Module["_orig$__fixunstfdi"] = Module["asm"]["orig$__fixunstfdi"]).apply(null, arguments)
            };
            var _orig$__negti2 = Module["_orig$__negti2"] = function() {
                return (_orig$__negti2 = Module["_orig$__negti2"] = Module["asm"]["orig$__negti2"]).apply(null, arguments)
            };
            var _orig$__ucmpdi2 = Module["_orig$__ucmpdi2"] = function() {
                return (_orig$__ucmpdi2 = Module["_orig$__ucmpdi2"] = Module["asm"]["orig$__ucmpdi2"]).apply(null, arguments)
            };
            var _orig$__ffsti2 = Module["_orig$__ffsti2"] = function() {
                return (_orig$__ffsti2 = Module["_orig$__ffsti2"] = Module["asm"]["orig$__ffsti2"]).apply(null, arguments)
            };
            var _orig$__divtc3 = Module["_orig$__divtc3"] = function() {
                return (_orig$__divtc3 = Module["_orig$__divtc3"] = Module["asm"]["orig$__divtc3"]).apply(null, arguments)
            };
            var _orig$fmaxl = Module["_orig$fmaxl"] = function() {
                return (_orig$fmaxl = Module["_orig$fmaxl"] = Module["asm"]["orig$fmaxl"]).apply(null, arguments)
            };
            var _orig$__moddi3 = Module["_orig$__moddi3"] = function() {
                return (_orig$__moddi3 = Module["_orig$__moddi3"] = Module["asm"]["orig$__moddi3"]).apply(null, arguments)
            };
            var _orig$__popcountti2 = Module["_orig$__popcountti2"] = function() {
                return (_orig$__popcountti2 = Module["_orig$__popcountti2"] = Module["asm"]["orig$__popcountti2"]).apply(null, arguments)
            };
            var _orig$__mulodi4 = Module["_orig$__mulodi4"] = function() {
                return (_orig$__mulodi4 = Module["_orig$__mulodi4"] = Module["asm"]["orig$__mulodi4"]).apply(null, arguments)
            };
            var _orig$__dtoi64 = Module["_orig$__dtoi64"] = function() {
                return (_orig$__dtoi64 = Module["_orig$__dtoi64"] = Module["asm"]["orig$__dtoi64"]).apply(null, arguments)
            };
            var _orig$__stoi64 = Module["_orig$__stoi64"] = function() {
                return (_orig$__stoi64 = Module["_orig$__stoi64"] = Module["asm"]["orig$__stoi64"]).apply(null, arguments)
            };
            var _orig$__dtou64 = Module["_orig$__dtou64"] = function() {
                return (_orig$__dtou64 = Module["_orig$__dtou64"] = Module["asm"]["orig$__dtou64"]).apply(null, arguments)
            };
            var _orig$__stou64 = Module["_orig$__stou64"] = function() {
                return (_orig$__stou64 = Module["_orig$__stou64"] = Module["asm"]["orig$__stou64"]).apply(null, arguments)
            };
            var _orig$__i64tod = Module["_orig$__i64tod"] = function() {
                return (_orig$__i64tod = Module["_orig$__i64tod"] = Module["asm"]["orig$__i64tod"]).apply(null, arguments)
            };
            var _orig$__i64tos = Module["_orig$__i64tos"] = function() {
                return (_orig$__i64tos = Module["_orig$__i64tos"] = Module["asm"]["orig$__i64tos"]).apply(null, arguments)
            };
            var _orig$__u64tod = Module["_orig$__u64tod"] = function() {
                return (_orig$__u64tod = Module["_orig$__u64tod"] = Module["asm"]["orig$__u64tod"]).apply(null, arguments)
            };
            var _orig$__u64tos = Module["_orig$__u64tos"] = function() {
                return (_orig$__u64tos = Module["_orig$__u64tos"] = Module["asm"]["orig$__u64tos"]).apply(null, arguments)
            };
            var _orig$__addvti3 = Module["_orig$__addvti3"] = function() {
                return (_orig$__addvti3 = Module["_orig$__addvti3"] = Module["asm"]["orig$__addvti3"]).apply(null, arguments)
            };
            var _orig$__fixunstfti = Module["_orig$__fixunstfti"] = function() {
                return (_orig$__fixunstfti = Module["_orig$__fixunstfti"] = Module["asm"]["orig$__fixunstfti"]).apply(null, arguments)
            };
            var _orig$__lshrdi3 = Module["_orig$__lshrdi3"] = function() {
                return (_orig$__lshrdi3 = Module["_orig$__lshrdi3"] = Module["asm"]["orig$__lshrdi3"]).apply(null, arguments)
            };
            var _orig$__divmoddi4 = Module["_orig$__divmoddi4"] = function() {
                return (_orig$__divmoddi4 = Module["_orig$__divmoddi4"] = Module["asm"]["orig$__divmoddi4"]).apply(null, arguments)
            };
            var _orig$__divdi3 = Module["_orig$__divdi3"] = function() {
                return (_orig$__divdi3 = Module["_orig$__divdi3"] = Module["asm"]["orig$__divdi3"]).apply(null, arguments)
            };
            var _orig$__divxc3 = Module["_orig$__divxc3"] = function() {
                return (_orig$__divxc3 = Module["_orig$__divxc3"] = Module["asm"]["orig$__divxc3"]).apply(null, arguments)
            };
            var _orig$__muldi3 = Module["_orig$__muldi3"] = function() {
                return (_orig$__muldi3 = Module["_orig$__muldi3"] = Module["asm"]["orig$__muldi3"]).apply(null, arguments)
            };
            var _orig$__ashldi3 = Module["_orig$__ashldi3"] = function() {
                return (_orig$__ashldi3 = Module["_orig$__ashldi3"] = Module["asm"]["orig$__ashldi3"]).apply(null, arguments)
            };
            var _orig$__modti3 = Module["_orig$__modti3"] = function() {
                return (_orig$__modti3 = Module["_orig$__modti3"] = Module["asm"]["orig$__modti3"]).apply(null, arguments)
            };
            var _orig$__powitf2 = Module["_orig$__powitf2"] = function() {
                return (_orig$__powitf2 = Module["_orig$__powitf2"] = Module["asm"]["orig$__powitf2"]).apply(null, arguments)
            };
            var _orig$__ffsdi2 = Module["_orig$__ffsdi2"] = function() {
                return (_orig$__ffsdi2 = Module["_orig$__ffsdi2"] = Module["asm"]["orig$__ffsdi2"]).apply(null, arguments)
            };
            var _orig$__ashrti3 = Module["_orig$__ashrti3"] = function() {
                return (_orig$__ashrti3 = Module["_orig$__ashrti3"] = Module["asm"]["orig$__ashrti3"]).apply(null, arguments)
            };
            var _orig$__clzdi2 = Module["_orig$__clzdi2"] = function() {
                return (_orig$__clzdi2 = Module["_orig$__clzdi2"] = Module["asm"]["orig$__clzdi2"]).apply(null, arguments)
            };
            var _orig$__subvti3 = Module["_orig$__subvti3"] = function() {
                return (_orig$__subvti3 = Module["_orig$__subvti3"] = Module["asm"]["orig$__subvti3"]).apply(null, arguments)
            };
            var _orig$__bswapdi2 = Module["_orig$__bswapdi2"] = function() {
                return (_orig$__bswapdi2 = Module["_orig$__bswapdi2"] = Module["asm"]["orig$__bswapdi2"]).apply(null, arguments)
            };
            var _orig$__cmpti2 = Module["_orig$__cmpti2"] = function() {
                return (_orig$__cmpti2 = Module["_orig$__cmpti2"] = Module["asm"]["orig$__cmpti2"]).apply(null, arguments)
            };
            var _orig$__ucmpti2 = Module["_orig$__ucmpti2"] = function() {
                return (_orig$__ucmpti2 = Module["_orig$__ucmpti2"] = Module["asm"]["orig$__ucmpti2"]).apply(null, arguments)
            };
            var _orig$__fixxfdi = Module["_orig$__fixxfdi"] = function() {
                return (_orig$__fixxfdi = Module["_orig$__fixxfdi"] = Module["asm"]["orig$__fixxfdi"]).apply(null, arguments)
            };
            var _orig$__negvdi2 = Module["_orig$__negvdi2"] = function() {
                return (_orig$__negvdi2 = Module["_orig$__negvdi2"] = Module["asm"]["orig$__negvdi2"]).apply(null, arguments)
            };
            var _orig$__floattidf = Module["_orig$__floattidf"] = function() {
                return (_orig$__floattidf = Module["_orig$__floattidf"] = Module["asm"]["orig$__floattidf"]).apply(null, arguments)
            };
            var _orig$__mulvdi3 = Module["_orig$__mulvdi3"] = function() {
                return (_orig$__mulvdi3 = Module["_orig$__mulvdi3"] = Module["asm"]["orig$__mulvdi3"]).apply(null, arguments)
            };
            var _orig$__powixf2 = Module["_orig$__powixf2"] = function() {
                return (_orig$__powixf2 = Module["_orig$__powixf2"] = Module["asm"]["orig$__powixf2"]).apply(null, arguments)
            };
            var _orig$__fixunsxfdi = Module["_orig$__fixunsxfdi"] = function() {
                return (_orig$__fixunsxfdi = Module["_orig$__fixunsxfdi"] = Module["asm"]["orig$__fixunsxfdi"]).apply(null, arguments)
            };
            var _orig$__popcountdi2 = Module["_orig$__popcountdi2"] = function() {
                return (_orig$__popcountdi2 = Module["_orig$__popcountdi2"] = Module["asm"]["orig$__popcountdi2"]).apply(null, arguments)
            };
            var _orig$__ctzdi2 = Module["_orig$__ctzdi2"] = function() {
                return (_orig$__ctzdi2 = Module["_orig$__ctzdi2"] = Module["asm"]["orig$__ctzdi2"]).apply(null, arguments)
            };
            var _orig$__ashrdi3 = Module["_orig$__ashrdi3"] = function() {
                return (_orig$__ashrdi3 = Module["_orig$__ashrdi3"] = Module["asm"]["orig$__ashrdi3"]).apply(null, arguments)
            };
            var _orig$__floatunditf = Module["_orig$__floatunditf"] = function() {
                return (_orig$__floatunditf = Module["_orig$__floatunditf"] = Module["asm"]["orig$__floatunditf"]).apply(null, arguments)
            };
            var _orig$__floattisf = Module["_orig$__floattisf"] = function() {
                return (_orig$__floattisf = Module["_orig$__floattisf"] = Module["asm"]["orig$__floattisf"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__25stollERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi = Module["_orig$_ZNSt3__25stollERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi"] = function() {
                return (_orig$_ZNSt3__25stollERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi = Module["_orig$_ZNSt3__25stollERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi"] = Module["asm"]["orig$_ZNSt3__25stollERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__25stollERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi = Module["_orig$_ZNSt3__25stollERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi"] = function() {
                return (_orig$_ZNSt3__25stollERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi = Module["_orig$_ZNSt3__25stollERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi"] = Module["asm"]["orig$_ZNSt3__25stollERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__26stoullERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi = Module["_orig$_ZNSt3__26stoullERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi"] = function() {
                return (_orig$_ZNSt3__26stoullERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi = Module["_orig$_ZNSt3__26stoullERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi"] = Module["asm"]["orig$_ZNSt3__26stoullERKNS_12basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEEEPmi"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__26stoullERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi = Module["_orig$_ZNSt3__26stoullERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi"] = function() {
                return (_orig$_ZNSt3__26stoullERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi = Module["_orig$_ZNSt3__26stoullERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi"] = Module["asm"]["orig$_ZNSt3__26stoullERKNS_12basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEEEPmi"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__29to_stringEx = Module["_orig$_ZNSt3__29to_stringEx"] = function() {
                return (_orig$_ZNSt3__29to_stringEx = Module["_orig$_ZNSt3__29to_stringEx"] = Module["asm"]["orig$_ZNSt3__29to_stringEx"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__28to_charsIxLi0EEENS_15to_chars_resultEPcS2_T_ = Module["_orig$_ZNSt3__28to_charsIxLi0EEENS_15to_chars_resultEPcS2_T_"] = function() {
                return (_orig$_ZNSt3__28to_charsIxLi0EEENS_15to_chars_resultEPcS2_T_ = Module["_orig$_ZNSt3__28to_charsIxLi0EEENS_15to_chars_resultEPcS2_T_"] = Module["asm"]["orig$_ZNSt3__28to_charsIxLi0EEENS_15to_chars_resultEPcS2_T_"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__29to_stringEy = Module["_orig$_ZNSt3__29to_stringEy"] = function() {
                return (_orig$_ZNSt3__29to_stringEy = Module["_orig$_ZNSt3__29to_stringEy"] = Module["asm"]["orig$_ZNSt3__29to_stringEy"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__28to_charsIyLi0EEENS_15to_chars_resultEPcS2_T_ = Module["_orig$_ZNSt3__28to_charsIyLi0EEENS_15to_chars_resultEPcS2_T_"] = function() {
                return (_orig$_ZNSt3__28to_charsIyLi0EEENS_15to_chars_resultEPcS2_T_ = Module["_orig$_ZNSt3__28to_charsIyLi0EEENS_15to_chars_resultEPcS2_T_"] = Module["asm"]["orig$_ZNSt3__28to_charsIyLi0EEENS_15to_chars_resultEPcS2_T_"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__210to_wstringEx = Module["_orig$_ZNSt3__210to_wstringEx"] = function() {
                return (_orig$_ZNSt3__210to_wstringEx = Module["_orig$_ZNSt3__210to_wstringEx"] = Module["asm"]["orig$_ZNSt3__210to_wstringEx"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__210to_wstringEy = Module["_orig$_ZNSt3__210to_wstringEy"] = function() {
                return (_orig$_ZNSt3__210to_wstringEy = Module["_orig$_ZNSt3__210to_wstringEy"] = Module["asm"]["orig$_ZNSt3__210to_wstringEy"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__29to_stringEe = Module["_orig$_ZNSt3__29to_stringEe"] = function() {
                return (_orig$_ZNSt3__29to_stringEe = Module["_orig$_ZNSt3__29to_stringEe"] = Module["asm"]["orig$_ZNSt3__29to_stringEe"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__210to_wstringEe = Module["_orig$_ZNSt3__210to_wstringEe"] = function() {
                return (_orig$_ZNSt3__210to_wstringEe = Module["_orig$_ZNSt3__210to_wstringEe"] = Module["asm"]["orig$_ZNSt3__210to_wstringEe"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__215__to_chars_itoaIxEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb1EEE = Module["_orig$_ZNSt3__215__to_chars_itoaIxEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb1EEE"] = function() {
                return (_orig$_ZNSt3__215__to_chars_itoaIxEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb1EEE = Module["_orig$_ZNSt3__215__to_chars_itoaIxEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb1EEE"] = Module["asm"]["orig$_ZNSt3__215__to_chars_itoaIxEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb1EEE"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__213__to_unsignedIxEENS_13make_unsignedIT_E4typeES2_ = Module["_orig$_ZNSt3__213__to_unsignedIxEENS_13make_unsignedIT_E4typeES2_"] = function() {
                return (_orig$_ZNSt3__213__to_unsignedIxEENS_13make_unsignedIT_E4typeES2_ = Module["_orig$_ZNSt3__213__to_unsignedIxEENS_13make_unsignedIT_E4typeES2_"] = Module["asm"]["orig$_ZNSt3__213__to_unsignedIxEENS_13make_unsignedIT_E4typeES2_"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__212__complementIyEET_S1_ = Module["_orig$_ZNSt3__212__complementIyEET_S1_"] = function() {
                return (_orig$_ZNSt3__212__complementIyEET_S1_ = Module["_orig$_ZNSt3__212__complementIyEET_S1_"] = Module["asm"]["orig$_ZNSt3__212__complementIyEET_S1_"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__215__to_chars_itoaIyEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb0EEE = Module["_orig$_ZNSt3__215__to_chars_itoaIyEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb0EEE"] = function() {
                return (_orig$_ZNSt3__215__to_chars_itoaIyEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb0EEE = Module["_orig$_ZNSt3__215__to_chars_itoaIyEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb0EEE"] = Module["asm"]["orig$_ZNSt3__215__to_chars_itoaIyEENS_15to_chars_resultEPcS2_T_NS_17integral_constantIbLb0EEE"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__26__itoa13__traits_baseIyvE7__widthEy = Module["_orig$_ZNSt3__26__itoa13__traits_baseIyvE7__widthEy"] = function() {
                return (_orig$_ZNSt3__26__itoa13__traits_baseIyvE7__widthEy = Module["_orig$_ZNSt3__26__itoa13__traits_baseIyvE7__widthEy"] = Module["asm"]["orig$_ZNSt3__26__itoa13__traits_baseIyvE7__widthEy"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__26__itoa13__traits_baseIyvE9__convertEyPc = Module["_orig$_ZNSt3__26__itoa13__traits_baseIyvE9__convertEyPc"] = function() {
                return (_orig$_ZNSt3__26__itoa13__traits_baseIyvE9__convertEyPc = Module["_orig$_ZNSt3__26__itoa13__traits_baseIyvE9__convertEyPc"] = Module["asm"]["orig$_ZNSt3__26__itoa13__traits_baseIyvE9__convertEyPc"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__26__itoa8__u64toaEyPc = Module["_orig$_ZNSt3__26__itoa8__u64toaEyPc"] = function() {
                return (_orig$_ZNSt3__26__itoa8__u64toaEyPc = Module["_orig$_ZNSt3__26__itoa8__u64toaEyPc"] = Module["asm"]["orig$_ZNSt3__26__itoa8__u64toaEyPc"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__225__num_get_signed_integralIxEET_PKcS3_Rji = Module["_orig$_ZNSt3__225__num_get_signed_integralIxEET_PKcS3_Rji"] = function() {
                return (_orig$_ZNSt3__225__num_get_signed_integralIxEET_PKcS3_Rji = Module["_orig$_ZNSt3__225__num_get_signed_integralIxEET_PKcS3_Rji"] = Module["asm"]["orig$_ZNSt3__225__num_get_signed_integralIxEET_PKcS3_Rji"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__227__num_get_unsigned_integralIyEET_PKcS3_Rji = Module["_orig$_ZNSt3__227__num_get_unsigned_integralIyEET_PKcS3_Rji"] = function() {
                return (_orig$_ZNSt3__227__num_get_unsigned_integralIyEET_PKcS3_Rji = Module["_orig$_ZNSt3__227__num_get_unsigned_integralIyEET_PKcS3_Rji"] = Module["asm"]["orig$_ZNSt3__227__num_get_unsigned_integralIyEET_PKcS3_Rji"]).apply(null, arguments)
            };
            var _orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcx = Module["_orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcx"] = function() {
                return (_orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcx = Module["_orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcx"] = Module["asm"]["orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcx"]).apply(null, arguments)
            };
            var _orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcy = Module["_orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcy"] = function() {
                return (_orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcy = Module["_orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcy"] = Module["asm"]["orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEcy"]).apply(null, arguments)
            };
            var _orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEce = Module["_orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEce"] = function() {
                return (_orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEce = Module["_orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEce"] = Module["asm"]["orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_RNS_8ios_baseEce"]).apply(null, arguments)
            };
            var _orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwx = Module["_orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwx"] = function() {
                return (_orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwx = Module["_orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwx"] = Module["asm"]["orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwx"]).apply(null, arguments)
            };
            var _orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwy = Module["_orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwy"] = function() {
                return (_orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwy = Module["_orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwy"] = Module["asm"]["orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwy"]).apply(null, arguments)
            };
            var _orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwe = Module["_orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwe"] = function() {
                return (_orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwe = Module["_orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwe"] = Module["asm"]["orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_RNS_8ios_baseEwe"]).apply(null, arguments)
            };
            var _orig$_ZNKSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEce = Module["_orig$_ZNKSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEce"] = function() {
                return (_orig$_ZNKSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEce = Module["_orig$_ZNKSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEce"] = Module["asm"]["orig$_ZNKSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE6do_putES4_bRNS_8ios_baseEce"]).apply(null, arguments)
            };
            var _orig$_ZNKSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwe = Module["_orig$_ZNKSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwe"] = function() {
                return (_orig$_ZNKSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwe = Module["_orig$_ZNKSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwe"] = Module["asm"]["orig$_ZNKSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE6do_putES4_bRNS_8ios_baseEwe"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__214numeric_limitsIxE3minEv = Module["_orig$_ZNSt3__214numeric_limitsIxE3minEv"] = function() {
                return (_orig$_ZNSt3__214numeric_limitsIxE3minEv = Module["_orig$_ZNSt3__214numeric_limitsIxE3minEv"] = Module["asm"]["orig$_ZNSt3__214numeric_limitsIxE3minEv"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__214numeric_limitsIxE3maxEv = Module["_orig$_ZNSt3__214numeric_limitsIxE3maxEv"] = function() {
                return (_orig$_ZNSt3__214numeric_limitsIxE3maxEv = Module["_orig$_ZNSt3__214numeric_limitsIxE3maxEv"] = Module["asm"]["orig$_ZNSt3__214numeric_limitsIxE3maxEv"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__223__libcpp_numeric_limitsIxLb1EE3minEv = Module["_orig$_ZNSt3__223__libcpp_numeric_limitsIxLb1EE3minEv"] = function() {
                return (_orig$_ZNSt3__223__libcpp_numeric_limitsIxLb1EE3minEv = Module["_orig$_ZNSt3__223__libcpp_numeric_limitsIxLb1EE3minEv"] = Module["asm"]["orig$_ZNSt3__223__libcpp_numeric_limitsIxLb1EE3minEv"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__223__libcpp_numeric_limitsIxLb1EE3maxEv = Module["_orig$_ZNSt3__223__libcpp_numeric_limitsIxLb1EE3maxEv"] = function() {
                return (_orig$_ZNSt3__223__libcpp_numeric_limitsIxLb1EE3maxEv = Module["_orig$_ZNSt3__223__libcpp_numeric_limitsIxLb1EE3maxEv"] = Module["asm"]["orig$_ZNSt3__223__libcpp_numeric_limitsIxLb1EE3maxEv"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__214numeric_limitsIyE3maxEv = Module["_orig$_ZNSt3__214numeric_limitsIyE3maxEv"] = function() {
                return (_orig$_ZNSt3__214numeric_limitsIyE3maxEv = Module["_orig$_ZNSt3__214numeric_limitsIyE3maxEv"] = Module["asm"]["orig$_ZNSt3__214numeric_limitsIyE3maxEv"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__223__libcpp_numeric_limitsIyLb1EE3maxEv = Module["_orig$_ZNSt3__223__libcpp_numeric_limitsIyLb1EE3maxEv"] = function() {
                return (_orig$_ZNSt3__223__libcpp_numeric_limitsIyLb1EE3maxEv = Module["_orig$_ZNSt3__223__libcpp_numeric_limitsIyLb1EE3maxEv"] = Module["asm"]["orig$_ZNSt3__223__libcpp_numeric_limitsIyLb1EE3maxEv"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__212strstreambuf7seekoffExNS_8ios_base7seekdirEj = Module["_orig$_ZNSt3__212strstreambuf7seekoffExNS_8ios_base7seekdirEj"] = function() {
                return (_orig$_ZNSt3__212strstreambuf7seekoffExNS_8ios_base7seekdirEj = Module["_orig$_ZNSt3__212strstreambuf7seekoffExNS_8ios_base7seekdirEj"] = Module["asm"]["orig$_ZNSt3__212strstreambuf7seekoffExNS_8ios_base7seekdirEj"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__24fposI11__mbstate_tEC2Ex = Module["_orig$_ZNSt3__24fposI11__mbstate_tEC2Ex"] = function() {
                return (_orig$_ZNSt3__24fposI11__mbstate_tEC2Ex = Module["_orig$_ZNSt3__24fposI11__mbstate_tEC2Ex"] = Module["asm"]["orig$_ZNSt3__24fposI11__mbstate_tEC2Ex"]).apply(null, arguments)
            };
            var _orig$_ZNKSt3__24fposI11__mbstate_tEcvxEv = Module["_orig$_ZNKSt3__24fposI11__mbstate_tEcvxEv"] = function() {
                return (_orig$_ZNKSt3__24fposI11__mbstate_tEcvxEv = Module["_orig$_ZNKSt3__24fposI11__mbstate_tEcvxEv"] = Module["asm"]["orig$_ZNKSt3__24fposI11__mbstate_tEcvxEv"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__218condition_variable15__do_timed_waitERNS_11unique_lockINS_5mutexEEENS_6chrono10time_pointINS5_12system_clockENS5_8durationIxNS_5ratioILx1ELx1000000000EEEEEEE = Module["_orig$_ZNSt3__218condition_variable15__do_timed_waitERNS_11unique_lockINS_5mutexEEENS_6chrono10time_pointINS5_12system_clockENS5_8durationIxNS_5ratioILx1ELx1000000000EEEEEEE"] = function() {
                return (_orig$_ZNSt3__218condition_variable15__do_timed_waitERNS_11unique_lockINS_5mutexEEENS_6chrono10time_pointINS5_12system_clockENS5_8durationIxNS_5ratioILx1ELx1000000000EEEEEEE = Module["_orig$_ZNSt3__218condition_variable15__do_timed_waitERNS_11unique_lockINS_5mutexEEENS_6chrono10time_pointINS5_12system_clockENS5_8durationIxNS_5ratioILx1ELx1000000000EEEEEEE"] = Module["asm"]["orig$_ZNSt3__218condition_variable15__do_timed_waitERNS_11unique_lockINS_5mutexEEENS_6chrono10time_pointINS5_12system_clockENS5_8durationIxNS_5ratioILx1ELx1000000000EEEEEEE"]).apply(null, arguments)
            };
            var _orig$_ZNKSt3__26chrono10time_pointINS0_12system_clockENS0_8durationIxNS_5ratioILx1ELx1000000000EEEEEE16time_since_epochEv = Module["_orig$_ZNKSt3__26chrono10time_pointINS0_12system_clockENS0_8durationIxNS_5ratioILx1ELx1000000000EEEEEE16time_since_epochEv"] = function() {
                return (_orig$_ZNKSt3__26chrono10time_pointINS0_12system_clockENS0_8durationIxNS_5ratioILx1ELx1000000000EEEEEE16time_since_epochEv = Module["_orig$_ZNKSt3__26chrono10time_pointINS0_12system_clockENS0_8durationIxNS_5ratioILx1ELx1000000000EEEEEE16time_since_epochEv"] = Module["asm"]["orig$_ZNKSt3__26chrono10time_pointINS0_12system_clockENS0_8durationIxNS_5ratioILx1ELx1000000000EEEEEE16time_since_epochEv"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEExNS3_ILx1ELx1000000000EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE = Module["_orig$_ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEExNS3_ILx1ELx1000000000EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"] = function() {
                return (_orig$_ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEExNS3_ILx1ELx1000000000EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE = Module["_orig$_ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEExNS3_ILx1ELx1000000000EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"] = Module["asm"]["orig$_ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEExNS3_ILx1ELx1000000000EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"]).apply(null, arguments)
            };
            var _orig$_ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1EEEE5countEv = Module["_orig$_ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1EEEE5countEv"] = function() {
                return (_orig$_ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1EEEE5countEv = Module["_orig$_ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1EEEE5countEv"] = Module["asm"]["orig$_ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1EEEE5countEv"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__26chronomiIxNS_5ratioILx1ELx1000000000EEExNS2_ILx1ELx1EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_ = Module["_orig$_ZNSt3__26chronomiIxNS_5ratioILx1ELx1000000000EEExNS2_ILx1ELx1EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"] = function() {
                return (_orig$_ZNSt3__26chronomiIxNS_5ratioILx1ELx1000000000EEExNS2_ILx1ELx1EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_ = Module["_orig$_ZNSt3__26chronomiIxNS_5ratioILx1ELx1000000000EEExNS2_ILx1ELx1EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"] = Module["asm"]["orig$_ZNSt3__26chronomiIxNS_5ratioILx1ELx1000000000EEExNS2_ILx1ELx1EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"]).apply(null, arguments)
            };
            var _orig$_ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEE5countEv = Module["_orig$_ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEE5countEv"] = function() {
                return (_orig$_ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEE5countEv = Module["_orig$_ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEE5countEv"] = Module["asm"]["orig$_ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEE5countEv"]).apply(null, arguments)
            };
            var _orig$_ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1000000000EEEEENS2_IxNS3_ILx1ELx1EEEEES4_Lb1ELb0EEclERKS5_ = Module["_orig$_ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1000000000EEEEENS2_IxNS3_ILx1ELx1EEEEES4_Lb1ELb0EEclERKS5_"] = function() {
                return (_orig$_ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1000000000EEEEENS2_IxNS3_ILx1ELx1EEEEES4_Lb1ELb0EEclERKS5_ = Module["_orig$_ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1000000000EEEEENS2_IxNS3_ILx1ELx1EEEEES4_Lb1ELb0EEclERKS5_"] = Module["asm"]["orig$_ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1000000000EEEEENS2_IxNS3_ILx1ELx1EEEEES4_Lb1ELb0EEclERKS5_"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1000000000EEEEExNS3_ILx1ELx1EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE = Module["_orig$_ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1000000000EEEEExNS3_ILx1ELx1EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"] = function() {
                return (_orig$_ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1000000000EEEEExNS3_ILx1ELx1EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE = Module["_orig$_ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1000000000EEEEExNS3_ILx1ELx1EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"] = Module["asm"]["orig$_ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1000000000EEEEExNS3_ILx1ELx1EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"]).apply(null, arguments)
            };
            var _orig$_ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEENS2_IxNS3_ILx1ELx1000000000EEEEENS3_ILx1000000000ELx1EEELb0ELb1EEclERKS5_ = Module["_orig$_ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEENS2_IxNS3_ILx1ELx1000000000EEEEENS3_ILx1000000000ELx1EEELb0ELb1EEclERKS5_"] = function() {
                return (_orig$_ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEENS2_IxNS3_ILx1ELx1000000000EEEEENS3_ILx1000000000ELx1EEELb0ELb1EEclERKS5_ = Module["_orig$_ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEENS2_IxNS3_ILx1ELx1000000000EEEEENS3_ILx1000000000ELx1EEELb0ELb1EEclERKS5_"] = Module["asm"]["orig$_ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEENS2_IxNS3_ILx1ELx1000000000EEEEENS3_ILx1000000000ELx1EEELb0ELb1EEclERKS5_"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj = Module["_orig$_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj"] = function() {
                return (_orig$_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj = Module["_orig$_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj"] = Module["asm"]["orig$_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7seekoffExNS_8ios_base7seekdirEj = Module["_orig$_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7seekoffExNS_8ios_base7seekdirEj"] = function() {
                return (_orig$_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7seekoffExNS_8ios_base7seekdirEj = Module["_orig$_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7seekoffExNS_8ios_base7seekdirEj"] = Module["asm"]["orig$_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE7seekoffExNS_8ios_base7seekdirEj"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEE4zeroEv = Module["_orig$_ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEE4zeroEv"] = function() {
                return (_orig$_ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEE4zeroEv = Module["_orig$_ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEE4zeroEv"] = Module["asm"]["orig$_ZNSt3__26chrono8durationIxNS_5ratioILx1ELx1000000000EEEE4zeroEv"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__26chrono15duration_valuesIxE4zeroEv = Module["_orig$_ZNSt3__26chrono15duration_valuesIxE4zeroEv"] = function() {
                return (_orig$_ZNSt3__26chrono15duration_valuesIxE4zeroEv = Module["_orig$_ZNSt3__26chrono15duration_valuesIxE4zeroEv"] = Module["asm"]["orig$_ZNSt3__26chrono15duration_valuesIxE4zeroEv"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__26chrono12system_clock3nowEv = Module["_orig$_ZNSt3__26chrono12system_clock3nowEv"] = function() {
                return (_orig$_ZNSt3__26chrono12system_clock3nowEv = Module["_orig$_ZNSt3__26chrono12system_clock3nowEv"] = Module["asm"]["orig$_ZNSt3__26chrono12system_clock3nowEv"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__26chronoplIxNS_5ratioILx1ELx1EEExNS2_ILx1ELx1000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_ = Module["_orig$_ZNSt3__26chronoplIxNS_5ratioILx1ELx1EEExNS2_ILx1ELx1000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"] = function() {
                return (_orig$_ZNSt3__26chronoplIxNS_5ratioILx1ELx1EEExNS2_ILx1ELx1000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_ = Module["_orig$_ZNSt3__26chronoplIxNS_5ratioILx1ELx1EEExNS2_ILx1ELx1000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"] = Module["asm"]["orig$_ZNSt3__26chronoplIxNS_5ratioILx1ELx1EEExNS2_ILx1ELx1000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"]).apply(null, arguments)
            };
            var _orig$_ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1000000EEEE5countEv = Module["_orig$_ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1000000EEEE5countEv"] = function() {
                return (_orig$_ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1000000EEEE5countEv = Module["_orig$_ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1000000EEEE5countEv"] = Module["asm"]["orig$_ZNKSt3__26chrono8durationIxNS_5ratioILx1ELx1000000EEEE5countEv"]).apply(null, arguments)
            };
            var _orig$_ZNKSt3__26chrono10time_pointINS0_12system_clockENS0_8durationIxNS_5ratioILx1ELx1000000EEEEEE16time_since_epochEv = Module["_orig$_ZNKSt3__26chrono10time_pointINS0_12system_clockENS0_8durationIxNS_5ratioILx1ELx1000000EEEEEE16time_since_epochEv"] = function() {
                return (_orig$_ZNKSt3__26chrono10time_pointINS0_12system_clockENS0_8durationIxNS_5ratioILx1ELx1000000EEEEEE16time_since_epochEv = Module["_orig$_ZNKSt3__26chrono10time_pointINS0_12system_clockENS0_8durationIxNS_5ratioILx1ELx1000000EEEEEE16time_since_epochEv"] = Module["asm"]["orig$_ZNKSt3__26chrono10time_pointINS0_12system_clockENS0_8durationIxNS_5ratioILx1ELx1000000EEEEEE16time_since_epochEv"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEExNS3_ILx1ELx1000000EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE = Module["_orig$_ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEExNS3_ILx1ELx1000000EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"] = function() {
                return (_orig$_ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEExNS3_ILx1ELx1000000EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE = Module["_orig$_ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEExNS3_ILx1ELx1000000EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"] = Module["asm"]["orig$_ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEExNS3_ILx1ELx1000000EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"]).apply(null, arguments)
            };
            var _orig$_ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1000000EEEEENS2_IxNS3_ILx1ELx1EEEEES4_Lb1ELb0EEclERKS5_ = Module["_orig$_ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1000000EEEEENS2_IxNS3_ILx1ELx1EEEEES4_Lb1ELb0EEclERKS5_"] = function() {
                return (_orig$_ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1000000EEEEENS2_IxNS3_ILx1ELx1EEEEES4_Lb1ELb0EEclERKS5_ = Module["_orig$_ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1000000EEEEENS2_IxNS3_ILx1ELx1EEEEES4_Lb1ELb0EEclERKS5_"] = Module["asm"]["orig$_ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1000000EEEEENS2_IxNS3_ILx1ELx1EEEEES4_Lb1ELb0EEclERKS5_"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__26chrono12system_clock11from_time_tEl = Module["_orig$_ZNSt3__26chrono12system_clock11from_time_tEl"] = function() {
                return (_orig$_ZNSt3__26chrono12system_clock11from_time_tEl = Module["_orig$_ZNSt3__26chrono12system_clock11from_time_tEl"] = Module["asm"]["orig$_ZNSt3__26chrono12system_clock11from_time_tEl"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1000000EEEEExNS3_ILx1ELx1EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE = Module["_orig$_ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1000000EEEEExNS3_ILx1ELx1EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"] = function() {
                return (_orig$_ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1000000EEEEExNS3_ILx1ELx1EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE = Module["_orig$_ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1000000EEEEExNS3_ILx1ELx1EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"] = Module["asm"]["orig$_ZNSt3__26chrono13duration_castINS0_8durationIxNS_5ratioILx1ELx1000000EEEEExNS3_ILx1ELx1EEEEENS_9enable_ifIXsr13__is_durationIT_EE5valueES8_E4typeERKNS2_IT0_T1_EE"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__26chrono12steady_clock3nowEv = Module["_orig$_ZNSt3__26chrono12steady_clock3nowEv"] = function() {
                return (_orig$_ZNSt3__26chrono12steady_clock3nowEv = Module["_orig$_ZNSt3__26chrono12steady_clock3nowEv"] = Module["asm"]["orig$_ZNSt3__26chrono12steady_clock3nowEv"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__26chronoplIxNS_5ratioILx1ELx1EEExNS2_ILx1ELx1000000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_ = Module["_orig$_ZNSt3__26chronoplIxNS_5ratioILx1ELx1EEExNS2_ILx1ELx1000000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"] = function() {
                return (_orig$_ZNSt3__26chronoplIxNS_5ratioILx1ELx1EEExNS2_ILx1ELx1000000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_ = Module["_orig$_ZNSt3__26chronoplIxNS_5ratioILx1ELx1EEExNS2_ILx1ELx1000000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"] = Module["asm"]["orig$_ZNSt3__26chronoplIxNS_5ratioILx1ELx1EEExNS2_ILx1ELx1000000000EEEEENS_11common_typeIJNS0_8durationIT_T0_EENS6_IT1_T2_EEEE4typeERKS9_RKSC_"]).apply(null, arguments)
            };
            var _orig$_ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEENS2_IxNS3_ILx1ELx1000000EEEEENS3_ILx1000000ELx1EEELb0ELb1EEclERKS5_ = Module["_orig$_ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEENS2_IxNS3_ILx1ELx1000000EEEEENS3_ILx1000000ELx1EEELb0ELb1EEclERKS5_"] = function() {
                return (_orig$_ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEENS2_IxNS3_ILx1ELx1000000EEEEENS3_ILx1000000ELx1EEELb0ELb1EEclERKS5_ = Module["_orig$_ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEENS2_IxNS3_ILx1ELx1000000EEEEENS3_ILx1000000ELx1EEELb0ELb1EEclERKS5_"] = Module["asm"]["orig$_ZNKSt3__26chrono15__duration_castINS0_8durationIxNS_5ratioILx1ELx1EEEEENS2_IxNS3_ILx1ELx1000000EEEEENS3_ILx1000000ELx1EEELb0ELb1EEclERKS5_"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE10pubseekoffExNS_8ios_base7seekdirEj = Module["_orig$_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE10pubseekoffExNS_8ios_base7seekdirEj"] = function() {
                return (_orig$_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE10pubseekoffExNS_8ios_base7seekdirEj = Module["_orig$_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE10pubseekoffExNS_8ios_base7seekdirEj"] = Module["asm"]["orig$_ZNSt3__215basic_streambufIcNS_11char_traitsIcEEE10pubseekoffExNS_8ios_base7seekdirEj"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE5seekgExNS_8ios_base7seekdirE = Module["_orig$_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE5seekgExNS_8ios_base7seekdirE"] = function() {
                return (_orig$_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE5seekgExNS_8ios_base7seekdirE = Module["_orig$_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE5seekgExNS_8ios_base7seekdirE"] = Module["asm"]["orig$_ZNSt3__213basic_istreamIcNS_11char_traitsIcEEE5seekgExNS_8ios_base7seekdirE"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE10pubseekoffExNS_8ios_base7seekdirEj = Module["_orig$_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE10pubseekoffExNS_8ios_base7seekdirEj"] = function() {
                return (_orig$_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE10pubseekoffExNS_8ios_base7seekdirEj = Module["_orig$_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE10pubseekoffExNS_8ios_base7seekdirEj"] = Module["asm"]["orig$_ZNSt3__215basic_streambufIwNS_11char_traitsIwEEE10pubseekoffExNS_8ios_base7seekdirEj"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE5seekgExNS_8ios_base7seekdirE = Module["_orig$_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE5seekgExNS_8ios_base7seekdirE"] = function() {
                return (_orig$_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE5seekgExNS_8ios_base7seekdirE = Module["_orig$_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE5seekgExNS_8ios_base7seekdirE"] = Module["asm"]["orig$_ZNSt3__213basic_istreamIwNS_11char_traitsIwEEE5seekgExNS_8ios_base7seekdirE"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEx = Module["_orig$_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEx"] = function() {
                return (_orig$_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEx = Module["_orig$_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEx"] = Module["asm"]["orig$_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEx"]).apply(null, arguments)
            };
            var _orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcx = Module["_orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcx"] = function() {
                return (_orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcx = Module["_orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcx"] = Module["asm"]["orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcx"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEy = Module["_orig$_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEy"] = function() {
                return (_orig$_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEy = Module["_orig$_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEy"] = Module["asm"]["orig$_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEy"]).apply(null, arguments)
            };
            var _orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcy = Module["_orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcy"] = function() {
                return (_orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcy = Module["_orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcy"] = Module["asm"]["orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEcy"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEe = Module["_orig$_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEe"] = function() {
                return (_orig$_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEe = Module["_orig$_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEe"] = Module["asm"]["orig$_ZNSt3__213basic_ostreamIcNS_11char_traitsIcEEElsEe"]).apply(null, arguments)
            };
            var _orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEce = Module["_orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEce"] = function() {
                return (_orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEce = Module["_orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEce"] = Module["asm"]["orig$_ZNKSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE3putES4_RNS_8ios_baseEce"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEx = Module["_orig$_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEx"] = function() {
                return (_orig$_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEx = Module["_orig$_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEx"] = Module["asm"]["orig$_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEx"]).apply(null, arguments)
            };
            var _orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwx = Module["_orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwx"] = function() {
                return (_orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwx = Module["_orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwx"] = Module["asm"]["orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwx"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEy = Module["_orig$_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEy"] = function() {
                return (_orig$_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEy = Module["_orig$_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEy"] = Module["asm"]["orig$_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEy"]).apply(null, arguments)
            };
            var _orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwy = Module["_orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwy"] = function() {
                return (_orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwy = Module["_orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwy"] = Module["asm"]["orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwy"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEe = Module["_orig$_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEe"] = function() {
                return (_orig$_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEe = Module["_orig$_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEe"] = Module["asm"]["orig$_ZNSt3__213basic_ostreamIwNS_11char_traitsIwEEElsEe"]).apply(null, arguments)
            };
            var _orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwe = Module["_orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwe"] = function() {
                return (_orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwe = Module["_orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwe"] = Module["asm"]["orig$_ZNKSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE3putES4_RNS_8ios_baseEwe"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__24__fs10filesystem11__file_sizeERKNS1_4pathEPNS_10error_codeE = Module["_orig$_ZNSt3__24__fs10filesystem11__file_sizeERKNS1_4pathEPNS_10error_codeE"] = function() {
                return (_orig$_ZNSt3__24__fs10filesystem11__file_sizeERKNS1_4pathEPNS_10error_codeE = Module["_orig$_ZNSt3__24__fs10filesystem11__file_sizeERKNS1_4pathEPNS_10error_codeE"] = Module["asm"]["orig$_ZNSt3__24__fs10filesystem11__file_sizeERKNS1_4pathEPNS_10error_codeE"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__24__fs10filesystem17__hard_link_countERKNS1_4pathEPNS_10error_codeE = Module["_orig$_ZNSt3__24__fs10filesystem17__hard_link_countERKNS1_4pathEPNS_10error_codeE"] = function() {
                return (_orig$_ZNSt3__24__fs10filesystem17__hard_link_countERKNS1_4pathEPNS_10error_codeE = Module["_orig$_ZNSt3__24__fs10filesystem17__hard_link_countERKNS1_4pathEPNS_10error_codeE"] = Module["asm"]["orig$_ZNSt3__24__fs10filesystem17__hard_link_countERKNS1_4pathEPNS_10error_codeE"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__24__fs10filesystem17__last_write_timeERKNS1_4pathENS_6chrono10time_pointINS1_16_FilesystemClockENS5_8durationInNS_5ratioILx1ELx1000000000EEEEEEEPNS_10error_codeE = Module["_orig$_ZNSt3__24__fs10filesystem17__last_write_timeERKNS1_4pathENS_6chrono10time_pointINS1_16_FilesystemClockENS5_8durationInNS_5ratioILx1ELx1000000000EEEEEEEPNS_10error_codeE"] = function() {
                return (_orig$_ZNSt3__24__fs10filesystem17__last_write_timeERKNS1_4pathENS_6chrono10time_pointINS1_16_FilesystemClockENS5_8durationInNS_5ratioILx1ELx1000000000EEEEEEEPNS_10error_codeE = Module["_orig$_ZNSt3__24__fs10filesystem17__last_write_timeERKNS1_4pathENS_6chrono10time_pointINS1_16_FilesystemClockENS5_8durationInNS_5ratioILx1ELx1000000000EEEEEEEPNS_10error_codeE"] = Module["asm"]["orig$_ZNSt3__24__fs10filesystem17__last_write_timeERKNS1_4pathENS_6chrono10time_pointINS1_16_FilesystemClockENS5_8durationInNS_5ratioILx1ELx1000000000EEEEEEEPNS_10error_codeE"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__24__fs10filesystem12__remove_allERKNS1_4pathEPNS_10error_codeE = Module["_orig$_ZNSt3__24__fs10filesystem12__remove_allERKNS1_4pathEPNS_10error_codeE"] = function() {
                return (_orig$_ZNSt3__24__fs10filesystem12__remove_allERKNS1_4pathEPNS_10error_codeE = Module["_orig$_ZNSt3__24__fs10filesystem12__remove_allERKNS1_4pathEPNS_10error_codeE"] = Module["asm"]["orig$_ZNSt3__24__fs10filesystem12__remove_allERKNS1_4pathEPNS_10error_codeE"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__24__fs10filesystem13__resize_fileERKNS1_4pathEyPNS_10error_codeE = Module["_orig$_ZNSt3__24__fs10filesystem13__resize_fileERKNS1_4pathEyPNS_10error_codeE"] = function() {
                return (_orig$_ZNSt3__24__fs10filesystem13__resize_fileERKNS1_4pathEyPNS_10error_codeE = Module["_orig$_ZNSt3__24__fs10filesystem13__resize_fileERKNS1_4pathEyPNS_10error_codeE"] = Module["asm"]["orig$_ZNSt3__24__fs10filesystem13__resize_fileERKNS1_4pathEyPNS_10error_codeE"]).apply(null, arguments)
            };
            var _orig$_ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj = Module["_orig$_ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj"] = function() {
                return (_orig$_ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj = Module["_orig$_ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj"] = Module["asm"]["orig$_ZNSt3__213basic_filebufIcNS_11char_traitsIcEEE7seekoffExNS_8ios_base7seekdirEj"]).apply(null, arguments)
            };
            var _orig$_ZN10__cxxabiv119__getExceptionClassEPK17_Unwind_Exception = Module["_orig$_ZN10__cxxabiv119__getExceptionClassEPK17_Unwind_Exception"] = function() {
                return (_orig$_ZN10__cxxabiv119__getExceptionClassEPK17_Unwind_Exception = Module["_orig$_ZN10__cxxabiv119__getExceptionClassEPK17_Unwind_Exception"] = Module["asm"]["orig$_ZN10__cxxabiv119__getExceptionClassEPK17_Unwind_Exception"]).apply(null, arguments)
            };
            var _orig$_ZN10__cxxabiv119__setExceptionClassEP17_Unwind_Exceptiony = Module["_orig$_ZN10__cxxabiv119__setExceptionClassEP17_Unwind_Exceptiony"] = function() {
                return (_orig$_ZN10__cxxabiv119__setExceptionClassEP17_Unwind_Exceptiony = Module["_orig$_ZN10__cxxabiv119__setExceptionClassEP17_Unwind_Exceptiony"] = Module["asm"]["orig$_ZN10__cxxabiv119__setExceptionClassEP17_Unwind_Exceptiony"]).apply(null, arguments)
            };
            var _orig$fminl = Module["_orig$fminl"] = function() {
                return (_orig$fminl = Module["_orig$fminl"] = Module["asm"]["orig$fminl"]).apply(null, arguments)
            };
            var _eMeans = Module["_eMeans"] = 50880;
            var _stderr = Module["_stderr"] = 255488;
            var _tf_select_table = Module["_tf_select_table"] = 30832;
            var _silk_sign_iCDF = Module["_silk_sign_iCDF"] = 57008;
            var _silk_Quantization_Offsets_Q10 = Module["_silk_Quantization_Offsets_Q10"] = 55606;
            var _silk_LTP_vq_ptrs_Q7 = Module["_silk_LTP_vq_ptrs_Q7"] = 253344;
            var _silk_LTPScales_table_Q14 = Module["_silk_LTPScales_table_Q14"] = 55614;
            var _silk_type_offset_VAD_iCDF = Module["_silk_type_offset_VAD_iCDF"] = 55594;
            var _silk_type_offset_no_VAD_iCDF = Module["_silk_type_offset_no_VAD_iCDF"] = 55598;
            var _silk_delta_gain_iCDF = Module["_silk_delta_gain_iCDF"] = 51472;
            var _silk_gain_iCDF = Module["_silk_gain_iCDF"] = 51440;
            var _silk_uniform8_iCDF = Module["_silk_uniform8_iCDF"] = 55638;
            var _silk_NLSF_EXT_iCDF = Module["_silk_NLSF_EXT_iCDF"] = 55646;
            var _silk_NLSF_interpolation_factor_iCDF = Module["_silk_NLSF_interpolation_factor_iCDF"] = 55600;
            var _silk_pitch_delta_iCDF = Module["_silk_pitch_delta_iCDF"] = 55808;
            var _silk_pitch_lag_iCDF = Module["_silk_pitch_lag_iCDF"] = 55776;
            var _silk_LTP_per_index_iCDF = Module["_silk_LTP_per_index_iCDF"] = 51513;
            var _silk_LTP_gain_iCDF_ptrs = Module["_silk_LTP_gain_iCDF_ptrs"] = 253320;
            var _silk_LTPscale_iCDF = Module["_silk_LTPscale_iCDF"] = 55591;
            var _silk_uniform4_iCDF = Module["_silk_uniform4_iCDF"] = 55623;
            var _silk_rate_levels_iCDF = Module["_silk_rate_levels_iCDF"] = 56272;
            var _silk_pulses_per_block_iCDF = Module["_silk_pulses_per_block_iCDF"] = 55904;
            var _silk_lsb_iCDF = Module["_silk_lsb_iCDF"] = 55589;
            var _silk_pitch_contour_10_ms_iCDF = Module["_silk_pitch_contour_10_ms_iCDF"] = 55885;
            var _silk_pitch_contour_iCDF = Module["_silk_pitch_contour_iCDF"] = 55840;
            var _silk_pitch_contour_10_ms_NB_iCDF = Module["_silk_pitch_contour_10_ms_NB_iCDF"] = 55897;
            var _silk_pitch_contour_NB_iCDF = Module["_silk_pitch_contour_NB_iCDF"] = 55874;
            var _silk_NLSF_CB_WB = Module["_silk_NLSF_CB_WB"] = 253408;
            var _silk_NLSF_CB_NB_MB = Module["_silk_NLSF_CB_NB_MB"] = 253368;
            var _silk_uniform6_iCDF = Module["_silk_uniform6_iCDF"] = 55632;
            var _silk_LBRR_flags_iCDF_ptr = Module["_silk_LBRR_flags_iCDF_ptr"] = 253448;
            var _silk_max_pulses_table = Module["_silk_max_pulses_table"] = 55900;
            var _silk_rate_levels_BITS_Q5 = Module["_silk_rate_levels_BITS_Q5"] = 56304;
            var _silk_pulses_per_block_BITS_Q5 = Module["_silk_pulses_per_block_BITS_Q5"] = 56096;
            var _silk_Transition_LP_B_Q28 = Module["_silk_Transition_LP_B_Q28"] = 55664;
            var _silk_Transition_LP_A_Q28 = Module["_silk_Transition_LP_A_Q28"] = 55728;
            var _silk_shell_code_table_offsets = Module["_silk_shell_code_table_offsets"] = 56976;
            var _silk_shell_code_table3 = Module["_silk_shell_code_table3"] = 56816;
            var _silk_shell_code_table2 = Module["_silk_shell_code_table2"] = 56656;
            var _silk_shell_code_table1 = Module["_silk_shell_code_table1"] = 56496;
            var _silk_shell_code_table0 = Module["_silk_shell_code_table0"] = 56336;
            var _silk_LTP_gain_BITS_Q5_ptrs = Module["_silk_LTP_gain_BITS_Q5_ptrs"] = 253332;
            var _silk_LTP_vq_gain_ptrs_Q7 = Module["_silk_LTP_vq_gain_ptrs_Q7"] = 253356;
            var _silk_LTP_vq_sizes = Module["_silk_LTP_vq_sizes"] = 52e3;
            var _silk_stereo_pred_quant_Q13 = Module["_silk_stereo_pred_quant_Q13"] = 55520;
            var _silk_stereo_pred_joint_iCDF = Module["_silk_stereo_pred_joint_iCDF"] = 55552;
            var _silk_stereo_only_code_mid_iCDF = Module["_silk_stereo_only_code_mid_iCDF"] = 55577;
            var _silk_uniform3_iCDF = Module["_silk_uniform3_iCDF"] = 55620;
            var _silk_uniform5_iCDF = Module["_silk_uniform5_iCDF"] = 55627;
            var _silk_LSFCosTab_FIX_Q12 = Module["_silk_LSFCosTab_FIX_Q12"] = 57536;
            var _silk_CB_lags_stage2 = Module["_silk_CB_lags_stage2"] = 57872;
            var _silk_CB_lags_stage2_10_ms = Module["_silk_CB_lags_stage2_10_ms"] = 57834;
            var _silk_CB_lags_stage3 = Module["_silk_CB_lags_stage3"] = 57920;
            var _silk_CB_lags_stage3_10_ms = Module["_silk_CB_lags_stage3_10_ms"] = 57840;
            var _silk_Lag_range_stage3_10_ms = Module["_silk_Lag_range_stage3_10_ms"] = 57864;
            var _silk_Lag_range_stage3 = Module["_silk_Lag_range_stage3"] = 58064;
            var _silk_nb_cbk_searchs_stage3 = Module["_silk_nb_cbk_searchs_stage3"] = 58088;
            var _silk_Resampler_3_4_COEFS = Module["_silk_Resampler_3_4_COEFS"] = 58128;
            var _silk_Resampler_2_3_COEFS = Module["_silk_Resampler_2_3_COEFS"] = 58192;
            var _silk_Resampler_1_2_COEFS = Module["_silk_Resampler_1_2_COEFS"] = 58240;
            var _silk_Resampler_1_3_COEFS = Module["_silk_Resampler_1_3_COEFS"] = 58272;
            var _silk_Resampler_1_4_COEFS = Module["_silk_Resampler_1_4_COEFS"] = 58320;
            var _silk_Resampler_1_6_COEFS = Module["_silk_Resampler_1_6_COEFS"] = 58368;
            var _silk_Resampler_2_3_COEFS_LQ = Module["_silk_Resampler_2_3_COEFS_LQ"] = 58408;
            var _silk_resampler_frac_FIR_12 = Module["_silk_resampler_frac_FIR_12"] = 58432;
            var _mapping_matrix_foa_mixing = Module["_mapping_matrix_foa_mixing"] = 59092;
            var _mapping_matrix_foa_mixing_data = Module["_mapping_matrix_foa_mixing_data"] = 59104;
            var _mapping_matrix_soa_mixing = Module["_mapping_matrix_soa_mixing"] = 59176;
            var _mapping_matrix_soa_mixing_data = Module["_mapping_matrix_soa_mixing_data"] = 59200;
            var _mapping_matrix_toa_mixing = Module["_mapping_matrix_toa_mixing"] = 59444;
            var _mapping_matrix_toa_mixing_data = Module["_mapping_matrix_toa_mixing_data"] = 59456;
            var _mapping_matrix_foa_demixing = Module["_mapping_matrix_foa_demixing"] = 60104;
            var _mapping_matrix_foa_demixing_data = Module["_mapping_matrix_foa_demixing_data"] = 60128;
            var _mapping_matrix_soa_demixing = Module["_mapping_matrix_soa_demixing"] = 60200;
            var _mapping_matrix_soa_demixing_data = Module["_mapping_matrix_soa_demixing_data"] = 60224;
            var _mapping_matrix_toa_demixing = Module["_mapping_matrix_toa_demixing"] = 60468;
            var _mapping_matrix_toa_demixing_data = Module["_mapping_matrix_toa_demixing_data"] = 60480;
            var _layer0 = Module["_layer0"] = 253504;
            var _layer1 = Module["_layer1"] = 253524;
            var _layer2 = Module["_layer2"] = 253544;
            var ___optreset = Module["___optreset"] = 271428;
            var _optind = Module["_optind"] = 254572;
            var ___optpos = Module["___optpos"] = 271432;
            var _optarg = Module["_optarg"] = 271436;
            var _optopt = Module["_optopt"] = 271440;
            var _opterr = Module["_opterr"] = 254576;
            var _optreset = Module["_optreset"] = 271428;
            var ___libc = Module["___libc"] = 274472;
            var ___c_dot_utf8 = Module["___c_dot_utf8"] = 254688;
            var ___c_dot_utf8_locale = Module["___c_dot_utf8_locale"] = 254716;
            var ___c_locale = Module["___c_locale"] = 206996;
            var ___seed48 = Module["___seed48"] = 254740;
            var ___signgam = Module["___signgam"] = 272256;
            var ___pio2_hi = Module["___pio2_hi"] = 207104;
            var ___pio2_lo = Module["___pio2_lo"] = 207120;
            var _signgam = Module["_signgam"] = 272256;
            var _atanlo = Module["_atanlo"] = 212720;
            var _atanhi = Module["_atanhi"] = 212656;
            var _aT = Module["_aT"] = 212784;
            var _stdout = Module["_stdout"] = 255184;
            var _stdin = Module["_stdin"] = 255336;
            var ___stdout_used = Module["___stdout_used"] = 255188;
            var ___stdin_used = Module["___stdin_used"] = 255340;
            var ___stderr_used = Module["___stderr_used"] = 255492;
            var ___fsmu8 = Module["___fsmu8"] = 232512;
            var ___progname = Module["___progname"] = 274464;
            var ___progname_full = Module["___progname_full"] = 274468;
            var ___hwcap = Module["___hwcap"] = 274536;
            var ___sysinfo = Module["___sysinfo"] = 274540;
            var _program_invocation_short_name = Module["_program_invocation_short_name"] = 274464;
            var _program_invocation_name = Module["_program_invocation_name"] = 274468;
            var __ns_flagdata = Module["__ns_flagdata"] = 235712;
            var _h_errno = Module["_h_errno"] = 275172;
            var ___environ = Module["___environ"] = 275316;
            var ____environ = Module["____environ"] = 275316;
            var __environ = Module["__environ"] = 275316;
            var _environ = Module["_environ"] = 275316;
            var ___env_map = Module["___env_map"] = 275324;
            var _tzname = Module["_tzname"] = 275328;
            var _daylight = Module["_daylight"] = 275336;
            var _timezone = Module["_timezone"] = 275340;
            var ___data_end = Module["___data_end"] = 286800;
            var ___THREW__ = Module["___THREW__"] = 279484;
            var ___threwValue = Module["___threwValue"] = 279488;
            var __ZTVSt16nested_exception = Module["__ZTVSt16nested_exception"] = 255848;
            var __ZTISt16nested_exception = Module["__ZTISt16nested_exception"] = 255864;
            var __ZTSSt16nested_exception = Module["__ZTSSt16nested_exception"] = 236020;
            var __ZTVN10__cxxabiv117__class_type_infoE = Module["__ZTVN10__cxxabiv117__class_type_infoE"] = 270844;
            var __ZNSt3__210defer_lockE = Module["__ZNSt3__210defer_lockE"] = 236041;
            var __ZNSt3__211try_to_lockE = Module["__ZNSt3__211try_to_lockE"] = 236042;
            var __ZNSt3__210adopt_lockE = Module["__ZNSt3__210adopt_lockE"] = 236043;
            var __ZTVSt11logic_error = Module["__ZTVSt11logic_error"] = 269220;
            var __ZTVSt9exception = Module["__ZTVSt9exception"] = 269136;
            var __ZTVSt13runtime_error = Module["__ZTVSt13runtime_error"] = 269240;
            var __ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4nposE = Module["__ZNSt3__212basic_stringIcNS_11char_traitsIcEENS_9allocatorIcEEE4nposE"] = 236044;
            var __ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4nposE = Module["__ZNSt3__212basic_stringIwNS_11char_traitsIwEENS_9allocatorIwEEE4nposE"] = 236048;
            var __ZTVSt19bad_optional_access = Module["__ZTVSt19bad_optional_access"] = 255872;
            var __ZTISt19bad_optional_access = Module["__ZTISt19bad_optional_access"] = 255892;
            var __ZTSSt19bad_optional_access = Module["__ZTSSt19bad_optional_access"] = 236288;
            var __ZTVN10__cxxabiv120__si_class_type_infoE = Module["__ZTVN10__cxxabiv120__si_class_type_infoE"] = 270884;
            var __ZTISt9exception = Module["__ZTISt9exception"] = 269156;
            var __ZTVNSt12experimental19bad_optional_accessE = Module["__ZTVNSt12experimental19bad_optional_accessE"] = 255904;
            var __ZTINSt12experimental19bad_optional_accessE = Module["__ZTINSt12experimental19bad_optional_accessE"] = 255924;
            var __ZTSNSt12experimental19bad_optional_accessE = Module["__ZTSNSt12experimental19bad_optional_accessE"] = 236312;
            var __ZTISt11logic_error = Module["__ZTISt11logic_error"] = 269280;
            var ___dso_handle = Module["___dso_handle"] = 1024;
            var __ZTVNSt3__212future_errorE = Module["__ZTVNSt3__212future_errorE"] = 255976;
            var __ZTVNSt3__217__assoc_sub_stateE = Module["__ZTVNSt3__217__assoc_sub_stateE"] = 255996;
            var __ZTVNSt3__214__shared_countE = Module["__ZTVNSt3__214__shared_countE"] = 257192;
            var __ZTVNSt3__223__future_error_categoryE = Module["__ZTVNSt3__223__future_error_categoryE"] = 255940;
            var __ZTINSt3__223__future_error_categoryE = Module["__ZTINSt3__223__future_error_categoryE"] = 256032;
            var __ZTINSt3__212future_errorE = Module["__ZTINSt3__212future_errorE"] = 256044;
            var __ZTINSt3__217__assoc_sub_stateE = Module["__ZTINSt3__217__assoc_sub_stateE"] = 256020;
            var __ZTSNSt3__217__assoc_sub_stateE = Module["__ZTSNSt3__217__assoc_sub_stateE"] = 236352;
            var __ZTINSt3__214__shared_countE = Module["__ZTINSt3__214__shared_countE"] = 257212;
            var __ZTSNSt3__223__future_error_categoryE = Module["__ZTSNSt3__223__future_error_categoryE"] = 236380;
            var __ZTINSt3__212__do_messageE = Module["__ZTINSt3__212__do_messageE"] = 262396;
            var __ZTSNSt3__212future_errorE = Module["__ZTSNSt3__212future_errorE"] = 236414;
            var __ZTVNSt3__211regex_errorE = Module["__ZTVNSt3__211regex_errorE"] = 256076;
            var __ZTINSt3__211regex_errorE = Module["__ZTINSt3__211regex_errorE"] = 257112;
            var __ZTSNSt3__211regex_errorE = Module["__ZTSNSt3__211regex_errorE"] = 236437;
            var __ZTISt13runtime_error = Module["__ZTISt13runtime_error"] = 269420;
            var __ZNSt3__213allocator_argE = Module["__ZNSt3__213allocator_argE"] = 236664;
            var __ZTSNSt3__214__shared_countE = Module["__ZTSNSt3__214__shared_countE"] = 236665;
            var __ZTVNSt3__219__shared_weak_countE = Module["__ZTVNSt3__219__shared_weak_countE"] = 257220;
            var __ZTINSt3__219__shared_weak_countE = Module["__ZTINSt3__219__shared_weak_countE"] = 257248;
            var __ZTSNSt3__219__shared_weak_countE = Module["__ZTSNSt3__219__shared_weak_countE"] = 236690;
            var __ZTVN10__cxxabiv121__vmi_class_type_infoE = Module["__ZTVN10__cxxabiv121__vmi_class_type_infoE"] = 270936;
            var __ZTVNSt3__212bad_weak_ptrE = Module["__ZTVNSt3__212bad_weak_ptrE"] = 257272;
            var __ZTINSt3__212bad_weak_ptrE = Module["__ZTINSt3__212bad_weak_ptrE"] = 257292;
            var __ZTSNSt3__212bad_weak_ptrE = Module["__ZTSNSt3__212bad_weak_ptrE"] = 236720;
            var __ZNSt3__25ctypeIcE2idE = Module["__ZNSt3__25ctypeIcE2idE"] = 280316;
            var __ZNSt3__28numpunctIcE2idE = Module["__ZNSt3__28numpunctIcE2idE"] = 280356;
            var __ZNSt3__214__num_get_base5__srcE = Module["__ZNSt3__214__num_get_base5__srcE"] = 236752;
            var __ZNSt3__25ctypeIwE2idE = Module["__ZNSt3__25ctypeIwE2idE"] = 280308;
            var __ZNSt3__28numpunctIwE2idE = Module["__ZNSt3__28numpunctIwE2idE"] = 280364;
            var __ZNSt3__210moneypunctIcLb1EE2idE = Module["__ZNSt3__210moneypunctIcLb1EE2idE"] = 280200;
            var __ZNSt3__210moneypunctIcLb0EE2idE = Module["__ZNSt3__210moneypunctIcLb0EE2idE"] = 280192;
            var __ZNSt3__210moneypunctIwLb1EE2idE = Module["__ZNSt3__210moneypunctIwLb1EE2idE"] = 280216;
            var __ZNSt3__210moneypunctIwLb0EE2idE = Module["__ZNSt3__210moneypunctIwLb0EE2idE"] = 280208;
            var __ZTVNSt3__26locale5__impE = Module["__ZTVNSt3__26locale5__impE"] = 257304;
            var __ZTVNSt3__26locale5facetE = Module["__ZTVNSt3__26locale5facetE"] = 257768;
            var __ZNSt3__27collateIcE2idE = Module["__ZNSt3__27collateIcE2idE"] = 280112;
            var __ZNSt3__27collateIwE2idE = Module["__ZNSt3__27collateIwE2idE"] = 280120;
            var __ZNSt3__27codecvtIcc11__mbstate_tE2idE = Module["__ZNSt3__27codecvtIcc11__mbstate_tE2idE"] = 280324;
            var __ZNSt3__27codecvtIwc11__mbstate_tE2idE = Module["__ZNSt3__27codecvtIwc11__mbstate_tE2idE"] = 280332;
            var __ZNSt3__27codecvtIDsc11__mbstate_tE2idE = Module["__ZNSt3__27codecvtIDsc11__mbstate_tE2idE"] = 280340;
            var __ZNSt3__27codecvtIDic11__mbstate_tE2idE = Module["__ZNSt3__27codecvtIDic11__mbstate_tE2idE"] = 280348;
            var __ZNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE2idE = Module["__ZNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE2idE"] = 280128;
            var __ZNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE2idE = Module["__ZNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE2idE"] = 280136;
            var __ZNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE2idE = Module["__ZNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE2idE"] = 280144;
            var __ZNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE2idE = Module["__ZNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE2idE"] = 280152;
            var __ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE2idE = Module["__ZNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE2idE"] = 280224;
            var __ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE2idE = Module["__ZNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE2idE"] = 280232;
            var __ZNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE2idE = Module["__ZNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE2idE"] = 280240;
            var __ZNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE2idE = Module["__ZNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE2idE"] = 280248;
            var __ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE2idE = Module["__ZNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEE2idE"] = 280160;
            var __ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE2idE = Module["__ZNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEE2idE"] = 280168;
            var __ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE2idE = Module["__ZNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEE2idE"] = 280176;
            var __ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE2idE = Module["__ZNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEE2idE"] = 280184;
            var __ZNSt3__28messagesIcE2idE = Module["__ZNSt3__28messagesIcE2idE"] = 280256;
            var __ZNSt3__28messagesIwE2idE = Module["__ZNSt3__28messagesIwE2idE"] = 280264;
            var __ZTVNSt3__214codecvt_bynameIcc11__mbstate_tEE = Module["__ZTVNSt3__214codecvt_bynameIcc11__mbstate_tEE"] = 261760;
            var __ZTVNSt3__214codecvt_bynameIwc11__mbstate_tEE = Module["__ZTVNSt3__214codecvt_bynameIwc11__mbstate_tEE"] = 261820;
            var __ZTVNSt3__214codecvt_bynameIDsc11__mbstate_tEE = Module["__ZTVNSt3__214codecvt_bynameIDsc11__mbstate_tEE"] = 261880;
            var __ZTVNSt3__214codecvt_bynameIDic11__mbstate_tEE = Module["__ZTVNSt3__214codecvt_bynameIDic11__mbstate_tEE"] = 261940;
            var __ZTVNSt3__217moneypunct_bynameIcLb0EEE = Module["__ZTVNSt3__217moneypunct_bynameIcLb0EEE"] = 260992;
            var __ZTVNSt3__217moneypunct_bynameIcLb1EEE = Module["__ZTVNSt3__217moneypunct_bynameIcLb1EEE"] = 261060;
            var __ZTVNSt3__217moneypunct_bynameIwLb0EEE = Module["__ZTVNSt3__217moneypunct_bynameIwLb0EEE"] = 261128;
            var __ZTVNSt3__217moneypunct_bynameIwLb1EEE = Module["__ZTVNSt3__217moneypunct_bynameIwLb1EEE"] = 261196;
            var __ZTVNSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE = Module["__ZTVNSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE"] = 260120;
            var __ZTVNSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE = Module["__ZTVNSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE"] = 260284;
            var __ZTVNSt3__215time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE = Module["__ZTVNSt3__215time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE"] = 260560;
            var __ZTVNSt3__215time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE = Module["__ZTVNSt3__215time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE"] = 260596;
            var __ZTVNSt3__215messages_bynameIcEE = Module["__ZTVNSt3__215messages_bynameIcEE"] = 261672;
            var __ZTVNSt3__215messages_bynameIwEE = Module["__ZTVNSt3__215messages_bynameIwEE"] = 261716;
            var __ZNSt3__26locale2id9__next_idE = Module["__ZNSt3__26locale2id9__next_idE"] = 280304;
            var __ZTVNSt3__214collate_bynameIcEE = Module["__ZTVNSt3__214collate_bynameIcEE"] = 257324;
            var __ZTVNSt3__214collate_bynameIwEE = Module["__ZTVNSt3__214collate_bynameIwEE"] = 257356;
            var __ZTVNSt3__25ctypeIcEE = Module["__ZTVNSt3__25ctypeIcEE"] = 257388;
            var __ZTVNSt3__212ctype_bynameIcEE = Module["__ZTVNSt3__212ctype_bynameIcEE"] = 257440;
            var __ZTVNSt3__212ctype_bynameIwEE = Module["__ZTVNSt3__212ctype_bynameIwEE"] = 257492;
            var __ZTVNSt3__27codecvtIwc11__mbstate_tEE = Module["__ZTVNSt3__27codecvtIwc11__mbstate_tEE"] = 257560;
            var __ZTVNSt3__28numpunctIcEE = Module["__ZTVNSt3__28numpunctIcEE"] = 257608;
            var __ZTVNSt3__28numpunctIwEE = Module["__ZTVNSt3__28numpunctIwEE"] = 257648;
            var __ZTVNSt3__215numpunct_bynameIcEE = Module["__ZTVNSt3__215numpunct_bynameIcEE"] = 257688;
            var __ZTVNSt3__215numpunct_bynameIwEE = Module["__ZTVNSt3__215numpunct_bynameIwEE"] = 257728;
            var __ZTVNSt3__215__time_get_tempIcEE = Module["__ZTVNSt3__215__time_get_tempIcEE"] = 262072;
            var __ZTVNSt3__215__time_get_tempIwEE = Module["__ZTVNSt3__215__time_get_tempIwEE"] = 262136;
            var __ZTVNSt3__27collateIcEE = Module["__ZTVNSt3__27collateIcEE"] = 259312;
            var __ZTVNSt3__27collateIwEE = Module["__ZTVNSt3__27collateIwEE"] = 259344;
            var __ZTVNSt3__25ctypeIwEE = Module["__ZTVNSt3__25ctypeIwEE"] = 257800;
            var __ZTVNSt3__27codecvtIcc11__mbstate_tEE = Module["__ZTVNSt3__27codecvtIcc11__mbstate_tEE"] = 257908;
            var __ZTVNSt3__27codecvtIDsc11__mbstate_tEE = Module["__ZTVNSt3__27codecvtIDsc11__mbstate_tEE"] = 257996;
            var __ZTVNSt3__27codecvtIDic11__mbstate_tEE = Module["__ZTVNSt3__27codecvtIDic11__mbstate_tEE"] = 258076;
            var __ZTVNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE = Module["__ZTVNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE"] = 259376;
            var __ZTVNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE = Module["__ZTVNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE"] = 259504;
            var __ZTVNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE = Module["__ZTVNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE"] = 259624;
            var __ZTVNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE = Module["__ZTVNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE"] = 259740;
            var __ZTVNSt3__210moneypunctIcLb0EEE = Module["__ZTVNSt3__210moneypunctIcLb0EEE"] = 260632;
            var __ZTVNSt3__210moneypunctIcLb1EEE = Module["__ZTVNSt3__210moneypunctIcLb1EEE"] = 260728;
            var __ZTVNSt3__210moneypunctIwLb0EEE = Module["__ZTVNSt3__210moneypunctIwLb0EEE"] = 260816;
            var __ZTVNSt3__210moneypunctIwLb1EEE = Module["__ZTVNSt3__210moneypunctIwLb1EEE"] = 260904;
            var __ZTVNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE = Module["__ZTVNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE"] = 261264;
            var __ZTVNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE = Module["__ZTVNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE"] = 261332;
            var __ZTVNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE = Module["__ZTVNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE"] = 261400;
            var __ZTVNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE = Module["__ZTVNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE"] = 261468;
            var __ZTVNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE = Module["__ZTVNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE"] = 259848;
            var __ZTVNSt3__220__time_get_c_storageIcEE = Module["__ZTVNSt3__220__time_get_c_storageIcEE"] = 262e3;
            var __ZTVNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE = Module["__ZTVNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE"] = 259988;
            var __ZTVNSt3__220__time_get_c_storageIwEE = Module["__ZTVNSt3__220__time_get_c_storageIwEE"] = 262036;
            var __ZTVNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE = Module["__ZTVNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE"] = 260440;
            var __ZTVNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE = Module["__ZTVNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE"] = 260504;
            var __ZTVNSt3__28messagesIcEE = Module["__ZTVNSt3__28messagesIcEE"] = 261536;
            var __ZTVNSt3__28messagesIwEE = Module["__ZTVNSt3__28messagesIwEE"] = 261608;
            var __ZNSt3__210moneypunctIcLb0EE4intlE = Module["__ZNSt3__210moneypunctIcLb0EE4intlE"] = 236992;
            var __ZNSt3__210moneypunctIcLb1EE4intlE = Module["__ZNSt3__210moneypunctIcLb1EE4intlE"] = 236993;
            var __ZNSt3__210moneypunctIwLb0EE4intlE = Module["__ZNSt3__210moneypunctIwLb0EE4intlE"] = 236994;
            var __ZNSt3__210moneypunctIwLb1EE4intlE = Module["__ZNSt3__210moneypunctIwLb1EE4intlE"] = 236995;
            var __ZNSt3__26locale4noneE = Module["__ZNSt3__26locale4noneE"] = 236996;
            var __ZNSt3__26locale7collateE = Module["__ZNSt3__26locale7collateE"] = 237e3;
            var __ZNSt3__26locale5ctypeE = Module["__ZNSt3__26locale5ctypeE"] = 237004;
            var __ZNSt3__26locale8monetaryE = Module["__ZNSt3__26locale8monetaryE"] = 237008;
            var __ZNSt3__26locale7numericE = Module["__ZNSt3__26locale7numericE"] = 237012;
            var __ZNSt3__26locale4timeE = Module["__ZNSt3__26locale4timeE"] = 237016;
            var __ZNSt3__26locale8messagesE = Module["__ZNSt3__26locale8messagesE"] = 237020;
            var __ZNSt3__26locale3allE = Module["__ZNSt3__26locale3allE"] = 237024;
            var __ZTINSt3__26locale5__impE = Module["__ZTINSt3__26locale5__impE"] = 259148;
            var __ZTINSt3__214collate_bynameIcEE = Module["__ZTINSt3__214collate_bynameIcEE"] = 259172;
            var __ZTINSt3__214collate_bynameIwEE = Module["__ZTINSt3__214collate_bynameIwEE"] = 259196;
            var __ZNSt3__210ctype_base5spaceE = Module["__ZNSt3__210ctype_base5spaceE"] = 237028;
            var __ZNSt3__210ctype_base5printE = Module["__ZNSt3__210ctype_base5printE"] = 237030;
            var __ZNSt3__210ctype_base5cntrlE = Module["__ZNSt3__210ctype_base5cntrlE"] = 237032;
            var __ZNSt3__210ctype_base5upperE = Module["__ZNSt3__210ctype_base5upperE"] = 237034;
            var __ZNSt3__210ctype_base5lowerE = Module["__ZNSt3__210ctype_base5lowerE"] = 237036;
            var __ZNSt3__210ctype_base5alphaE = Module["__ZNSt3__210ctype_base5alphaE"] = 237038;
            var __ZNSt3__210ctype_base5digitE = Module["__ZNSt3__210ctype_base5digitE"] = 237040;
            var __ZNSt3__210ctype_base5punctE = Module["__ZNSt3__210ctype_base5punctE"] = 237042;
            var __ZNSt3__210ctype_base6xdigitE = Module["__ZNSt3__210ctype_base6xdigitE"] = 237044;
            var __ZNSt3__210ctype_base5blankE = Module["__ZNSt3__210ctype_base5blankE"] = 237046;
            var __ZNSt3__210ctype_base5alnumE = Module["__ZNSt3__210ctype_base5alnumE"] = 237048;
            var __ZNSt3__210ctype_base5graphE = Module["__ZNSt3__210ctype_base5graphE"] = 237050;
            var __ZTINSt3__25ctypeIcEE = Module["__ZTINSt3__25ctypeIcEE"] = 259208;
            var __ZTINSt3__212ctype_bynameIcEE = Module["__ZTINSt3__212ctype_bynameIcEE"] = 259240;
            var __ZTINSt3__212ctype_bynameIwEE = Module["__ZTINSt3__212ctype_bynameIwEE"] = 259252;
            var __ZTINSt3__27codecvtIwc11__mbstate_tEE = Module["__ZTINSt3__27codecvtIwc11__mbstate_tEE"] = 258444;
            var __ZTINSt3__28numpunctIcEE = Module["__ZTINSt3__28numpunctIcEE"] = 259264;
            var __ZTINSt3__28numpunctIwEE = Module["__ZTINSt3__28numpunctIwEE"] = 259276;
            var __ZTINSt3__215numpunct_bynameIcEE = Module["__ZTINSt3__215numpunct_bynameIcEE"] = 259288;
            var __ZTINSt3__215numpunct_bynameIwEE = Module["__ZTINSt3__215numpunct_bynameIwEE"] = 259300;
            var __ZTINSt3__26locale5facetE = Module["__ZTINSt3__26locale5facetE"] = 257788;
            var __ZTSNSt3__26locale5facetE = Module["__ZTSNSt3__26locale5facetE"] = 237312;
            var __ZTINSt3__25ctypeIwEE = Module["__ZTINSt3__25ctypeIwEE"] = 257876;
            var __ZTSNSt3__25ctypeIwEE = Module["__ZTSNSt3__25ctypeIwEE"] = 237334;
            var __ZTSNSt3__210ctype_baseE = Module["__ZTSNSt3__210ctype_baseE"] = 237352;
            var __ZTINSt3__210ctype_baseE = Module["__ZTINSt3__210ctype_baseE"] = 257868;
            var __ZTINSt3__27codecvtIcc11__mbstate_tEE = Module["__ZTINSt3__27codecvtIcc11__mbstate_tEE"] = 257964;
            var __ZTSNSt3__27codecvtIcc11__mbstate_tEE = Module["__ZTSNSt3__27codecvtIcc11__mbstate_tEE"] = 237373;
            var __ZTSNSt3__212codecvt_baseE = Module["__ZTSNSt3__212codecvt_baseE"] = 237407;
            var __ZTINSt3__212codecvt_baseE = Module["__ZTINSt3__212codecvt_baseE"] = 257956;
            var __ZTINSt3__27codecvtIDsc11__mbstate_tEE = Module["__ZTINSt3__27codecvtIDsc11__mbstate_tEE"] = 258044;
            var __ZTSNSt3__27codecvtIDsc11__mbstate_tEE = Module["__ZTSNSt3__27codecvtIDsc11__mbstate_tEE"] = 237430;
            var __ZTINSt3__27codecvtIDic11__mbstate_tEE = Module["__ZTINSt3__27codecvtIDic11__mbstate_tEE"] = 258124;
            var __ZTSNSt3__27codecvtIDic11__mbstate_tEE = Module["__ZTSNSt3__27codecvtIDic11__mbstate_tEE"] = 237465;
            var __ZTVNSt3__216__narrow_to_utf8ILm16EEE = Module["__ZTVNSt3__216__narrow_to_utf8ILm16EEE"] = 258156;
            var __ZTINSt3__216__narrow_to_utf8ILm16EEE = Module["__ZTINSt3__216__narrow_to_utf8ILm16EEE"] = 258204;
            var __ZTSNSt3__216__narrow_to_utf8ILm16EEE = Module["__ZTSNSt3__216__narrow_to_utf8ILm16EEE"] = 237500;
            var __ZTVNSt3__216__narrow_to_utf8ILm32EEE = Module["__ZTVNSt3__216__narrow_to_utf8ILm32EEE"] = 258216;
            var __ZTINSt3__216__narrow_to_utf8ILm32EEE = Module["__ZTINSt3__216__narrow_to_utf8ILm32EEE"] = 258264;
            var __ZTSNSt3__216__narrow_to_utf8ILm32EEE = Module["__ZTSNSt3__216__narrow_to_utf8ILm32EEE"] = 237534;
            var __ZTVNSt3__217__widen_from_utf8ILm16EEE = Module["__ZTVNSt3__217__widen_from_utf8ILm16EEE"] = 258276;
            var __ZTINSt3__217__widen_from_utf8ILm16EEE = Module["__ZTINSt3__217__widen_from_utf8ILm16EEE"] = 258324;
            var __ZTSNSt3__217__widen_from_utf8ILm16EEE = Module["__ZTSNSt3__217__widen_from_utf8ILm16EEE"] = 237568;
            var __ZTVNSt3__217__widen_from_utf8ILm32EEE = Module["__ZTVNSt3__217__widen_from_utf8ILm32EEE"] = 258336;
            var __ZTINSt3__217__widen_from_utf8ILm32EEE = Module["__ZTINSt3__217__widen_from_utf8ILm32EEE"] = 258384;
            var __ZTSNSt3__217__widen_from_utf8ILm32EEE = Module["__ZTSNSt3__217__widen_from_utf8ILm32EEE"] = 237603;
            var __ZTVNSt3__214__codecvt_utf8IwEE = Module["__ZTVNSt3__214__codecvt_utf8IwEE"] = 258396;
            var __ZTINSt3__214__codecvt_utf8IwEE = Module["__ZTINSt3__214__codecvt_utf8IwEE"] = 258476;
            var __ZTSNSt3__214__codecvt_utf8IwEE = Module["__ZTSNSt3__214__codecvt_utf8IwEE"] = 237638;
            var __ZTSNSt3__27codecvtIwc11__mbstate_tEE = Module["__ZTSNSt3__27codecvtIwc11__mbstate_tEE"] = 237666;
            var __ZTVNSt3__214__codecvt_utf8IDsEE = Module["__ZTVNSt3__214__codecvt_utf8IDsEE"] = 258488;
            var __ZTINSt3__214__codecvt_utf8IDsEE = Module["__ZTINSt3__214__codecvt_utf8IDsEE"] = 258536;
            var __ZTSNSt3__214__codecvt_utf8IDsEE = Module["__ZTSNSt3__214__codecvt_utf8IDsEE"] = 237700;
            var __ZTVNSt3__214__codecvt_utf8IDiEE = Module["__ZTVNSt3__214__codecvt_utf8IDiEE"] = 258548;
            var __ZTINSt3__214__codecvt_utf8IDiEE = Module["__ZTINSt3__214__codecvt_utf8IDiEE"] = 258596;
            var __ZTSNSt3__214__codecvt_utf8IDiEE = Module["__ZTSNSt3__214__codecvt_utf8IDiEE"] = 237729;
            var __ZTVNSt3__215__codecvt_utf16IwLb0EEE = Module["__ZTVNSt3__215__codecvt_utf16IwLb0EEE"] = 258608;
            var __ZTINSt3__215__codecvt_utf16IwLb0EEE = Module["__ZTINSt3__215__codecvt_utf16IwLb0EEE"] = 258656;
            var __ZTSNSt3__215__codecvt_utf16IwLb0EEE = Module["__ZTSNSt3__215__codecvt_utf16IwLb0EEE"] = 237758;
            var __ZTVNSt3__215__codecvt_utf16IwLb1EEE = Module["__ZTVNSt3__215__codecvt_utf16IwLb1EEE"] = 258668;
            var __ZTINSt3__215__codecvt_utf16IwLb1EEE = Module["__ZTINSt3__215__codecvt_utf16IwLb1EEE"] = 258716;
            var __ZTSNSt3__215__codecvt_utf16IwLb1EEE = Module["__ZTSNSt3__215__codecvt_utf16IwLb1EEE"] = 237791;
            var __ZTVNSt3__215__codecvt_utf16IDsLb0EEE = Module["__ZTVNSt3__215__codecvt_utf16IDsLb0EEE"] = 258728;
            var __ZTINSt3__215__codecvt_utf16IDsLb0EEE = Module["__ZTINSt3__215__codecvt_utf16IDsLb0EEE"] = 258776;
            var __ZTSNSt3__215__codecvt_utf16IDsLb0EEE = Module["__ZTSNSt3__215__codecvt_utf16IDsLb0EEE"] = 237824;
            var __ZTVNSt3__215__codecvt_utf16IDsLb1EEE = Module["__ZTVNSt3__215__codecvt_utf16IDsLb1EEE"] = 258788;
            var __ZTINSt3__215__codecvt_utf16IDsLb1EEE = Module["__ZTINSt3__215__codecvt_utf16IDsLb1EEE"] = 258836;
            var __ZTSNSt3__215__codecvt_utf16IDsLb1EEE = Module["__ZTSNSt3__215__codecvt_utf16IDsLb1EEE"] = 237858;
            var __ZTVNSt3__215__codecvt_utf16IDiLb0EEE = Module["__ZTVNSt3__215__codecvt_utf16IDiLb0EEE"] = 258848;
            var __ZTINSt3__215__codecvt_utf16IDiLb0EEE = Module["__ZTINSt3__215__codecvt_utf16IDiLb0EEE"] = 258896;
            var __ZTSNSt3__215__codecvt_utf16IDiLb0EEE = Module["__ZTSNSt3__215__codecvt_utf16IDiLb0EEE"] = 237892;
            var __ZTVNSt3__215__codecvt_utf16IDiLb1EEE = Module["__ZTVNSt3__215__codecvt_utf16IDiLb1EEE"] = 258908;
            var __ZTINSt3__215__codecvt_utf16IDiLb1EEE = Module["__ZTINSt3__215__codecvt_utf16IDiLb1EEE"] = 258956;
            var __ZTSNSt3__215__codecvt_utf16IDiLb1EEE = Module["__ZTSNSt3__215__codecvt_utf16IDiLb1EEE"] = 237926;
            var __ZTVNSt3__220__codecvt_utf8_utf16IwEE = Module["__ZTVNSt3__220__codecvt_utf8_utf16IwEE"] = 258968;
            var __ZTINSt3__220__codecvt_utf8_utf16IwEE = Module["__ZTINSt3__220__codecvt_utf8_utf16IwEE"] = 259016;
            var __ZTSNSt3__220__codecvt_utf8_utf16IwEE = Module["__ZTSNSt3__220__codecvt_utf8_utf16IwEE"] = 237960;
            var __ZTVNSt3__220__codecvt_utf8_utf16IDiEE = Module["__ZTVNSt3__220__codecvt_utf8_utf16IDiEE"] = 259028;
            var __ZTINSt3__220__codecvt_utf8_utf16IDiEE = Module["__ZTINSt3__220__codecvt_utf8_utf16IDiEE"] = 259076;
            var __ZTSNSt3__220__codecvt_utf8_utf16IDiEE = Module["__ZTSNSt3__220__codecvt_utf8_utf16IDiEE"] = 237994;
            var __ZTVNSt3__220__codecvt_utf8_utf16IDsEE = Module["__ZTVNSt3__220__codecvt_utf8_utf16IDsEE"] = 259088;
            var __ZTINSt3__220__codecvt_utf8_utf16IDsEE = Module["__ZTINSt3__220__codecvt_utf8_utf16IDsEE"] = 259136;
            var __ZTSNSt3__220__codecvt_utf8_utf16IDsEE = Module["__ZTSNSt3__220__codecvt_utf8_utf16IDsEE"] = 238029;
            var __ZTSNSt3__26locale5__impE = Module["__ZTSNSt3__26locale5__impE"] = 238064;
            var __ZTSNSt3__214collate_bynameIcEE = Module["__ZTSNSt3__214collate_bynameIcEE"] = 238086;
            var __ZTSNSt3__27collateIcEE = Module["__ZTSNSt3__27collateIcEE"] = 238114;
            var __ZTINSt3__27collateIcEE = Module["__ZTINSt3__27collateIcEE"] = 259160;
            var __ZTSNSt3__214collate_bynameIwEE = Module["__ZTSNSt3__214collate_bynameIwEE"] = 238134;
            var __ZTSNSt3__27collateIwEE = Module["__ZTSNSt3__27collateIwEE"] = 238162;
            var __ZTINSt3__27collateIwEE = Module["__ZTINSt3__27collateIwEE"] = 259184;
            var __ZTSNSt3__25ctypeIcEE = Module["__ZTSNSt3__25ctypeIcEE"] = 238182;
            var __ZTSNSt3__212ctype_bynameIcEE = Module["__ZTSNSt3__212ctype_bynameIcEE"] = 238200;
            var __ZTSNSt3__212ctype_bynameIwEE = Module["__ZTSNSt3__212ctype_bynameIwEE"] = 238226;
            var __ZTSNSt3__28numpunctIcEE = Module["__ZTSNSt3__28numpunctIcEE"] = 238252;
            var __ZTSNSt3__28numpunctIwEE = Module["__ZTSNSt3__28numpunctIwEE"] = 238273;
            var __ZTSNSt3__215numpunct_bynameIcEE = Module["__ZTSNSt3__215numpunct_bynameIcEE"] = 238294;
            var __ZTSNSt3__215numpunct_bynameIwEE = Module["__ZTSNSt3__215numpunct_bynameIwEE"] = 238323;
            var __ZTINSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE = Module["__ZTINSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE"] = 259472;
            var __ZTSNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE = Module["__ZTSNSt3__27num_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE"] = 238352;
            var __ZTSNSt3__29__num_getIcEE = Module["__ZTSNSt3__29__num_getIcEE"] = 238420;
            var __ZTSNSt3__214__num_get_baseE = Module["__ZTSNSt3__214__num_get_baseE"] = 238442;
            var __ZTINSt3__214__num_get_baseE = Module["__ZTINSt3__214__num_get_baseE"] = 259440;
            var __ZTINSt3__29__num_getIcEE = Module["__ZTINSt3__29__num_getIcEE"] = 259448;
            var __ZTINSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE = Module["__ZTINSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE"] = 259592;
            var __ZTSNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE = Module["__ZTSNSt3__27num_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE"] = 238467;
            var __ZTSNSt3__29__num_getIwEE = Module["__ZTSNSt3__29__num_getIwEE"] = 238535;
            var __ZTINSt3__29__num_getIwEE = Module["__ZTINSt3__29__num_getIwEE"] = 259568;
            var __ZTINSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE = Module["__ZTINSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE"] = 259708;
            var __ZTSNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE = Module["__ZTSNSt3__27num_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE"] = 238557;
            var __ZTSNSt3__29__num_putIcEE = Module["__ZTSNSt3__29__num_putIcEE"] = 238625;
            var __ZTSNSt3__214__num_put_baseE = Module["__ZTSNSt3__214__num_put_baseE"] = 238647;
            var __ZTINSt3__214__num_put_baseE = Module["__ZTINSt3__214__num_put_baseE"] = 259676;
            var __ZTINSt3__29__num_putIcEE = Module["__ZTINSt3__29__num_putIcEE"] = 259684;
            var __ZTINSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE = Module["__ZTINSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE"] = 259816;
            var __ZTSNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE = Module["__ZTSNSt3__27num_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE"] = 238672;
            var __ZTSNSt3__29__num_putIwEE = Module["__ZTSNSt3__29__num_putIwEE"] = 238740;
            var __ZTINSt3__29__num_putIwEE = Module["__ZTINSt3__29__num_putIwEE"] = 259792;
            var __ZTINSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE = Module["__ZTINSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE"] = 259948;
            var __ZTSNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE = Module["__ZTSNSt3__28time_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE"] = 238762;
            var __ZTSNSt3__29time_baseE = Module["__ZTSNSt3__29time_baseE"] = 238831;
            var __ZTINSt3__29time_baseE = Module["__ZTINSt3__29time_baseE"] = 259932;
            var __ZTSNSt3__220__time_get_c_storageIcEE = Module["__ZTSNSt3__220__time_get_c_storageIcEE"] = 238850;
            var __ZTINSt3__220__time_get_c_storageIcEE = Module["__ZTINSt3__220__time_get_c_storageIcEE"] = 259940;
            var __ZTINSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE = Module["__ZTINSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE"] = 260080;
            var __ZTSNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE = Module["__ZTSNSt3__28time_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE"] = 238884;
            var __ZTSNSt3__220__time_get_c_storageIwEE = Module["__ZTSNSt3__220__time_get_c_storageIwEE"] = 238953;
            var __ZTINSt3__220__time_get_c_storageIwEE = Module["__ZTINSt3__220__time_get_c_storageIwEE"] = 260072;
            var __ZTINSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE = Module["__ZTINSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE"] = 260252;
            var __ZTSNSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE = Module["__ZTSNSt3__215time_get_bynameIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE"] = 238987;
            var __ZTSNSt3__218__time_get_storageIcEE = Module["__ZTSNSt3__218__time_get_storageIcEE"] = 239064;
            var __ZTSNSt3__210__time_getE = Module["__ZTSNSt3__210__time_getE"] = 239096;
            var __ZTINSt3__210__time_getE = Module["__ZTINSt3__210__time_getE"] = 260232;
            var __ZTINSt3__218__time_get_storageIcEE = Module["__ZTINSt3__218__time_get_storageIcEE"] = 260240;
            var __ZTINSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE = Module["__ZTINSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE"] = 260408;
            var __ZTSNSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE = Module["__ZTSNSt3__215time_get_bynameIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE"] = 239117;
            var __ZTSNSt3__218__time_get_storageIwEE = Module["__ZTSNSt3__218__time_get_storageIwEE"] = 239194;
            var __ZTINSt3__218__time_get_storageIwEE = Module["__ZTINSt3__218__time_get_storageIwEE"] = 260396;
            var __ZTINSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE = Module["__ZTINSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE"] = 260472;
            var __ZTSNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE = Module["__ZTSNSt3__28time_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE"] = 239226;
            var __ZTSNSt3__210__time_putE = Module["__ZTSNSt3__210__time_putE"] = 239295;
            var __ZTINSt3__210__time_putE = Module["__ZTINSt3__210__time_putE"] = 260464;
            var __ZTINSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE = Module["__ZTINSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE"] = 260528;
            var __ZTSNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE = Module["__ZTSNSt3__28time_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE"] = 239316;
            var __ZTINSt3__215time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE = Module["__ZTINSt3__215time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE"] = 260584;
            var __ZTSNSt3__215time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE = Module["__ZTSNSt3__215time_put_bynameIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE"] = 239385;
            var __ZTINSt3__215time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE = Module["__ZTINSt3__215time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE"] = 260620;
            var __ZTSNSt3__215time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE = Module["__ZTSNSt3__215time_put_bynameIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE"] = 239462;
            var __ZTINSt3__210moneypunctIcLb0EEE = Module["__ZTINSt3__210moneypunctIcLb0EEE"] = 260696;
            var __ZTSNSt3__210moneypunctIcLb0EEE = Module["__ZTSNSt3__210moneypunctIcLb0EEE"] = 239539;
            var __ZTSNSt3__210money_baseE = Module["__ZTSNSt3__210money_baseE"] = 239567;
            var __ZTINSt3__210money_baseE = Module["__ZTINSt3__210money_baseE"] = 260688;
            var __ZTINSt3__210moneypunctIcLb1EEE = Module["__ZTINSt3__210moneypunctIcLb1EEE"] = 260784;
            var __ZTSNSt3__210moneypunctIcLb1EEE = Module["__ZTSNSt3__210moneypunctIcLb1EEE"] = 239588;
            var __ZTINSt3__210moneypunctIwLb0EEE = Module["__ZTINSt3__210moneypunctIwLb0EEE"] = 260872;
            var __ZTSNSt3__210moneypunctIwLb0EEE = Module["__ZTSNSt3__210moneypunctIwLb0EEE"] = 239616;
            var __ZTINSt3__210moneypunctIwLb1EEE = Module["__ZTINSt3__210moneypunctIwLb1EEE"] = 260960;
            var __ZTSNSt3__210moneypunctIwLb1EEE = Module["__ZTSNSt3__210moneypunctIwLb1EEE"] = 239644;
            var __ZTINSt3__217moneypunct_bynameIcLb0EEE = Module["__ZTINSt3__217moneypunct_bynameIcLb0EEE"] = 261048;
            var __ZTSNSt3__217moneypunct_bynameIcLb0EEE = Module["__ZTSNSt3__217moneypunct_bynameIcLb0EEE"] = 239672;
            var __ZTINSt3__217moneypunct_bynameIcLb1EEE = Module["__ZTINSt3__217moneypunct_bynameIcLb1EEE"] = 261116;
            var __ZTSNSt3__217moneypunct_bynameIcLb1EEE = Module["__ZTSNSt3__217moneypunct_bynameIcLb1EEE"] = 239707;
            var __ZTINSt3__217moneypunct_bynameIwLb0EEE = Module["__ZTINSt3__217moneypunct_bynameIwLb0EEE"] = 261184;
            var __ZTSNSt3__217moneypunct_bynameIwLb0EEE = Module["__ZTSNSt3__217moneypunct_bynameIwLb0EEE"] = 239742;
            var __ZTINSt3__217moneypunct_bynameIwLb1EEE = Module["__ZTINSt3__217moneypunct_bynameIwLb1EEE"] = 261252;
            var __ZTSNSt3__217moneypunct_bynameIwLb1EEE = Module["__ZTSNSt3__217moneypunct_bynameIwLb1EEE"] = 239777;
            var __ZTINSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE = Module["__ZTINSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE"] = 261300;
            var __ZTSNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE = Module["__ZTSNSt3__29money_getIcNS_19istreambuf_iteratorIcNS_11char_traitsIcEEEEEE"] = 239812;
            var __ZTSNSt3__211__money_getIcEE = Module["__ZTSNSt3__211__money_getIcEE"] = 239882;
            var __ZTINSt3__211__money_getIcEE = Module["__ZTINSt3__211__money_getIcEE"] = 261292;
            var __ZTINSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE = Module["__ZTINSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE"] = 261368;
            var __ZTSNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE = Module["__ZTSNSt3__29money_getIwNS_19istreambuf_iteratorIwNS_11char_traitsIwEEEEEE"] = 239907;
            var __ZTSNSt3__211__money_getIwEE = Module["__ZTSNSt3__211__money_getIwEE"] = 239977;
            var __ZTINSt3__211__money_getIwEE = Module["__ZTINSt3__211__money_getIwEE"] = 261360;
            var __ZTINSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE = Module["__ZTINSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE"] = 261436;
            var __ZTSNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE = Module["__ZTSNSt3__29money_putIcNS_19ostreambuf_iteratorIcNS_11char_traitsIcEEEEEE"] = 240002;
            var __ZTSNSt3__211__money_putIcEE = Module["__ZTSNSt3__211__money_putIcEE"] = 240072;
            var __ZTINSt3__211__money_putIcEE = Module["__ZTINSt3__211__money_putIcEE"] = 261428;
            var __ZTINSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE = Module["__ZTINSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE"] = 261504;
            var __ZTSNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE = Module["__ZTSNSt3__29money_putIwNS_19ostreambuf_iteratorIwNS_11char_traitsIwEEEEEE"] = 240097;
            var __ZTSNSt3__211__money_putIwEE = Module["__ZTSNSt3__211__money_putIwEE"] = 240167;
            var __ZTINSt3__211__money_putIwEE = Module["__ZTINSt3__211__money_putIwEE"] = 261496;
            var __ZTINSt3__28messagesIcEE = Module["__ZTINSt3__28messagesIcEE"] = 261576;
            var __ZTSNSt3__28messagesIcEE = Module["__ZTSNSt3__28messagesIcEE"] = 240192;
            var __ZTSNSt3__213messages_baseE = Module["__ZTSNSt3__213messages_baseE"] = 240213;
            var __ZTINSt3__213messages_baseE = Module["__ZTINSt3__213messages_baseE"] = 261568;
            var __ZTINSt3__28messagesIwEE = Module["__ZTINSt3__28messagesIwEE"] = 261640;
            var __ZTSNSt3__28messagesIwEE = Module["__ZTSNSt3__28messagesIwEE"] = 240237;
            var __ZTINSt3__215messages_bynameIcEE = Module["__ZTINSt3__215messages_bynameIcEE"] = 261704;
            var __ZTSNSt3__215messages_bynameIcEE = Module["__ZTSNSt3__215messages_bynameIcEE"] = 240258;
            var __ZTINSt3__215messages_bynameIwEE = Module["__ZTINSt3__215messages_bynameIwEE"] = 261748;
            var __ZTSNSt3__215messages_bynameIwEE = Module["__ZTSNSt3__215messages_bynameIwEE"] = 240287;
            var __ZTINSt3__214codecvt_bynameIcc11__mbstate_tEE = Module["__ZTINSt3__214codecvt_bynameIcc11__mbstate_tEE"] = 261808;
            var __ZTSNSt3__214codecvt_bynameIcc11__mbstate_tEE = Module["__ZTSNSt3__214codecvt_bynameIcc11__mbstate_tEE"] = 240316;
            var __ZTINSt3__214codecvt_bynameIwc11__mbstate_tEE = Module["__ZTINSt3__214codecvt_bynameIwc11__mbstate_tEE"] = 261868;
            var __ZTSNSt3__214codecvt_bynameIwc11__mbstate_tEE = Module["__ZTSNSt3__214codecvt_bynameIwc11__mbstate_tEE"] = 240358;
            var __ZTINSt3__214codecvt_bynameIDsc11__mbstate_tEE = Module["__ZTINSt3__214codecvt_bynameIDsc11__mbstate_tEE"] = 261928;
            var __ZTSNSt3__214codecvt_bynameIDsc11__mbstate_tEE = Module["__ZTSNSt3__214codecvt_bynameIDsc11__mbstate_tEE"] = 240400;
            var __ZTINSt3__214codecvt_bynameIDic11__mbstate_tEE = Module["__ZTINSt3__214codecvt_bynameIDic11__mbstate_tEE"] = 261988;
            var __ZTSNSt3__214codecvt_bynameIDic11__mbstate_tEE = Module["__ZTSNSt3__214codecvt_bynameIDic11__mbstate_tEE"] = 240443;
            var __ZTINSt3__215__time_get_tempIcEE = Module["__ZTINSt3__215__time_get_tempIcEE"] = 262124;
            var __ZTSNSt3__215__time_get_tempIcEE = Module["__ZTSNSt3__215__time_get_tempIcEE"] = 241372;
            var __ZTINSt3__215__time_get_tempIwEE = Module["__ZTINSt3__215__time_get_tempIwEE"] = 262204;
            var __ZTSNSt3__215__time_get_tempIwEE = Module["__ZTSNSt3__215__time_get_tempIwEE"] = 241401;
            var __ZTVNSt3__212system_errorE = Module["__ZTVNSt3__212system_errorE"] = 262296;
            var __ZTVNSt3__224__generic_error_categoryE = Module["__ZTVNSt3__224__generic_error_categoryE"] = 262220;
            var __ZTINSt3__224__generic_error_categoryE = Module["__ZTINSt3__224__generic_error_categoryE"] = 262408;
            var __ZTVNSt3__223__system_error_categoryE = Module["__ZTVNSt3__223__system_error_categoryE"] = 262260;
            var __ZTINSt3__223__system_error_categoryE = Module["__ZTINSt3__223__system_error_categoryE"] = 262420;
            var __ZTINSt3__212system_errorE = Module["__ZTINSt3__212system_errorE"] = 262432;
            var __ZTVNSt3__214error_categoryE = Module["__ZTVNSt3__214error_categoryE"] = 262316;
            var __ZTINSt3__214error_categoryE = Module["__ZTINSt3__214error_categoryE"] = 262352;
            var __ZTSNSt3__214error_categoryE = Module["__ZTSNSt3__214error_categoryE"] = 241430;
            var __ZTVNSt3__212__do_messageE = Module["__ZTVNSt3__212__do_messageE"] = 262360;
            var __ZTSNSt3__212__do_messageE = Module["__ZTSNSt3__212__do_messageE"] = 241455;
            var __ZTSNSt3__224__generic_error_categoryE = Module["__ZTSNSt3__224__generic_error_categoryE"] = 241478;
            var __ZTSNSt3__223__system_error_categoryE = Module["__ZTSNSt3__223__system_error_categoryE"] = 241513;
            var __ZTSNSt3__212system_errorE = Module["__ZTSNSt3__212system_errorE"] = 241547;
            var __ZNSt3__219piecewise_constructE = Module["__ZNSt3__219piecewise_constructE"] = 241570;
            var __ZTVNSt3__212strstreambufE = Module["__ZTVNSt3__212strstreambufE"] = 262444;
            var __ZTTNSt3__210istrstreamE = Module["__ZTTNSt3__210istrstreamE"] = 262548;
            var __ZTTNSt3__210ostrstreamE = Module["__ZTTNSt3__210ostrstreamE"] = 262604;
            var __ZTTNSt3__29strstreamE = Module["__ZTTNSt3__29strstreamE"] = 262680;
            var __ZTINSt3__212strstreambufE = Module["__ZTINSt3__212strstreambufE"] = 262720;
            var __ZTVNSt3__210istrstreamE = Module["__ZTVNSt3__210istrstreamE"] = 262508;
            var __ZTINSt3__210istrstreamE = Module["__ZTINSt3__210istrstreamE"] = 262772;
            var __ZTCNSt3__210istrstreamE0_NS_13basic_istreamIcNS_11char_traitsIcEEEE = Module["__ZTCNSt3__210istrstreamE0_NS_13basic_istreamIcNS_11char_traitsIcEEEE"] = 262732;
            var __ZTVNSt3__210ostrstreamE = Module["__ZTVNSt3__210ostrstreamE"] = 262564;
            var __ZTINSt3__210ostrstreamE = Module["__ZTINSt3__210ostrstreamE"] = 262824;
            var __ZTCNSt3__210ostrstreamE0_NS_13basic_ostreamIcNS_11char_traitsIcEEEE = Module["__ZTCNSt3__210ostrstreamE0_NS_13basic_ostreamIcNS_11char_traitsIcEEEE"] = 262784;
            var __ZTVNSt3__29strstreamE = Module["__ZTVNSt3__29strstreamE"] = 262620;
            var __ZTINSt3__29strstreamE = Module["__ZTINSt3__29strstreamE"] = 262976;
            var __ZTCNSt3__29strstreamE0_NS_14basic_iostreamIcNS_11char_traitsIcEEEE = Module["__ZTCNSt3__29strstreamE0_NS_14basic_iostreamIcNS_11char_traitsIcEEEE"] = 262836;
            var __ZTCNSt3__29strstreamE0_NS_13basic_istreamIcNS_11char_traitsIcEEEE = Module["__ZTCNSt3__29strstreamE0_NS_13basic_istreamIcNS_11char_traitsIcEEEE"] = 262896;
            var __ZTCNSt3__29strstreamE8_NS_13basic_ostreamIcNS_11char_traitsIcEEEE = Module["__ZTCNSt3__29strstreamE8_NS_13basic_ostreamIcNS_11char_traitsIcEEEE"] = 262936;
            var __ZTSNSt3__212strstreambufE = Module["__ZTSNSt3__212strstreambufE"] = 241571;
            var __ZTINSt3__215basic_streambufIcNS_11char_traitsIcEEEE = Module["__ZTINSt3__215basic_streambufIcNS_11char_traitsIcEEEE"] = 264016;
            var __ZTINSt3__213basic_istreamIcNS_11char_traitsIcEEEE = Module["__ZTINSt3__213basic_istreamIcNS_11char_traitsIcEEEE"] = 264032;
            var __ZTSNSt3__210istrstreamE = Module["__ZTSNSt3__210istrstreamE"] = 241594;
            var __ZTINSt3__213basic_ostreamIcNS_11char_traitsIcEEEE = Module["__ZTINSt3__213basic_ostreamIcNS_11char_traitsIcEEEE"] = 264080;
            var __ZTSNSt3__210ostrstreamE = Module["__ZTSNSt3__210ostrstreamE"] = 241615;
            var __ZTINSt3__214basic_iostreamIcNS_11char_traitsIcEEEE = Module["__ZTINSt3__214basic_iostreamIcNS_11char_traitsIcEEEE"] = 264208;
            var __ZTSNSt3__29strstreamE = Module["__ZTSNSt3__29strstreamE"] = 241636;
            var __ZNSt3__219__start_std_streamsE = Module["__ZNSt3__219__start_std_streamsE"] = 282784;
            var __ZNSt3__23cinE = Module["__ZNSt3__23cinE"] = 282104;
            var __ZNSt3__24wcinE = Module["__ZNSt3__24wcinE"] = 282192;
            var __ZNSt3__24coutE = Module["__ZNSt3__24coutE"] = 282280;
            var __ZNSt3__25wcoutE = Module["__ZNSt3__25wcoutE"] = 282364;
            var __ZNSt3__24cerrE = Module["__ZNSt3__24cerrE"] = 282448;
            var __ZNSt3__24clogE = Module["__ZNSt3__24clogE"] = 282616;
            var __ZNSt3__25wcerrE = Module["__ZNSt3__25wcerrE"] = 282532;
            var __ZNSt3__25wclogE = Module["__ZNSt3__25wclogE"] = 282700;
            var __ZTVNSt3__210__stdinbufIcEE = Module["__ZTVNSt3__210__stdinbufIcEE"] = 262988;
            var __ZTVNSt3__213basic_istreamIcNS_11char_traitsIcEEEE = Module["__ZTVNSt3__213basic_istreamIcNS_11char_traitsIcEEEE"] = 263592;
            var __ZTVNSt3__210__stdinbufIwEE = Module["__ZTVNSt3__210__stdinbufIwEE"] = 263064;
            var __ZTVNSt3__213basic_istreamIwNS_11char_traitsIwEEEE = Module["__ZTVNSt3__213basic_istreamIwNS_11char_traitsIwEEEE"] = 263640;
            var __ZTVNSt3__211__stdoutbufIcEE = Module["__ZTVNSt3__211__stdoutbufIcEE"] = 263140;
            var __ZTVNSt3__213basic_ostreamIcNS_11char_traitsIcEEEE = Module["__ZTVNSt3__213basic_ostreamIcNS_11char_traitsIcEEEE"] = 263688;
            var __ZTVNSt3__211__stdoutbufIwEE = Module["__ZTVNSt3__211__stdoutbufIwEE"] = 263216;
            var __ZTVNSt3__213basic_ostreamIwNS_11char_traitsIwEEEE = Module["__ZTVNSt3__213basic_ostreamIwNS_11char_traitsIwEEEE"] = 263736;
            var __ZTVNSt3__29basic_iosIcNS_11char_traitsIcEEEE = Module["__ZTVNSt3__29basic_iosIcNS_11char_traitsIcEEEE"] = 263960;
            var __ZTVNSt3__28ios_baseE = Module["__ZTVNSt3__28ios_baseE"] = 263932;
            var __ZTVNSt3__29basic_iosIwNS_11char_traitsIwEEEE = Module["__ZTVNSt3__29basic_iosIwNS_11char_traitsIwEEEE"] = 263988;
            var __ZTINSt3__210__stdinbufIcEE = Module["__ZTINSt3__210__stdinbufIcEE"] = 263052;
            var __ZTSNSt3__210__stdinbufIcEE = Module["__ZTSNSt3__210__stdinbufIcEE"] = 241655;
            var __ZTINSt3__210__stdinbufIwEE = Module["__ZTINSt3__210__stdinbufIwEE"] = 263128;
            var __ZTSNSt3__210__stdinbufIwEE = Module["__ZTSNSt3__210__stdinbufIwEE"] = 241679;
            var __ZTINSt3__215basic_streambufIwNS_11char_traitsIwEEEE = Module["__ZTINSt3__215basic_streambufIwNS_11char_traitsIwEEEE"] = 264024;
            var __ZTINSt3__211__stdoutbufIcEE = Module["__ZTINSt3__211__stdoutbufIcEE"] = 263204;
            var __ZTSNSt3__211__stdoutbufIcEE = Module["__ZTSNSt3__211__stdoutbufIcEE"] = 241703;
            var __ZTINSt3__211__stdoutbufIwEE = Module["__ZTINSt3__211__stdoutbufIwEE"] = 263280;
            var __ZTSNSt3__211__stdoutbufIwEE = Module["__ZTSNSt3__211__stdoutbufIwEE"] = 241728;
            var __ZSt7nothrow = Module["__ZSt7nothrow"] = 241753;
            var __ZNSt3__212placeholders2_1E = Module["__ZNSt3__212placeholders2_1E"] = 241754;
            var __ZNSt3__212placeholders2_2E = Module["__ZNSt3__212placeholders2_2E"] = 241755;
            var __ZNSt3__212placeholders2_3E = Module["__ZNSt3__212placeholders2_3E"] = 241756;
            var __ZNSt3__212placeholders2_4E = Module["__ZNSt3__212placeholders2_4E"] = 241757;
            var __ZNSt3__212placeholders2_5E = Module["__ZNSt3__212placeholders2_5E"] = 241758;
            var __ZNSt3__212placeholders2_6E = Module["__ZNSt3__212placeholders2_6E"] = 241759;
            var __ZNSt3__212placeholders2_7E = Module["__ZNSt3__212placeholders2_7E"] = 241760;
            var __ZNSt3__212placeholders2_8E = Module["__ZNSt3__212placeholders2_8E"] = 241761;
            var __ZNSt3__212placeholders2_9E = Module["__ZNSt3__212placeholders2_9E"] = 241762;
            var __ZNSt3__212placeholders3_10E = Module["__ZNSt3__212placeholders3_10E"] = 241763;
            var __ZNSt3__212__rs_default4__c_E = Module["__ZNSt3__212__rs_default4__c_E"] = 283156;
            var __ZTVNSt3__217bad_function_callE = Module["__ZTVNSt3__217bad_function_callE"] = 263292;
            var __ZTINSt3__217bad_function_callE = Module["__ZTINSt3__217bad_function_callE"] = 263312;
            var __ZTSNSt3__217bad_function_callE = Module["__ZTSNSt3__217bad_function_callE"] = 241764;
            var __ZTVSt18bad_variant_access = Module["__ZTVSt18bad_variant_access"] = 263324;
            var __ZTISt18bad_variant_access = Module["__ZTISt18bad_variant_access"] = 263344;
            var __ZTSSt18bad_variant_access = Module["__ZTSSt18bad_variant_access"] = 241792;
            var __ZTVSt12bad_any_cast = Module["__ZTVSt12bad_any_cast"] = 263356;
            var __ZTISt12bad_any_cast = Module["__ZTISt12bad_any_cast"] = 263376;
            var __ZTSSt12bad_any_cast = Module["__ZTSSt12bad_any_cast"] = 242208;
            var __ZTISt8bad_cast = Module["__ZTISt8bad_cast"] = 269572;
            var __ZTVNSt12experimental15fundamentals_v112bad_any_castE = Module["__ZTVNSt12experimental15fundamentals_v112bad_any_castE"] = 263388;
            var __ZTINSt12experimental15fundamentals_v112bad_any_castE = Module["__ZTINSt12experimental15fundamentals_v112bad_any_castE"] = 263408;
            var __ZTSNSt12experimental15fundamentals_v112bad_any_castE = Module["__ZTSNSt12experimental15fundamentals_v112bad_any_castE"] = 242225;
            var __ZNSt3__26chrono12system_clock9is_steadyE = Module["__ZNSt3__26chrono12system_clock9is_steadyE"] = 242275;
            var __ZNSt3__26chrono12steady_clock9is_steadyE = Module["__ZNSt3__26chrono12steady_clock9is_steadyE"] = 242276;
            var __ZNSt3__223__libcpp_debug_functionE = Module["__ZNSt3__223__libcpp_debug_functionE"] = 263420;
            var __ZTVNSt3__28__c_nodeE = Module["__ZTVNSt3__28__c_nodeE"] = 263424;
            var __ZTINSt3__28__c_nodeE = Module["__ZTINSt3__28__c_nodeE"] = 263456;
            var __ZTSNSt3__28__c_nodeE = Module["__ZTSNSt3__28__c_nodeE"] = 242277;
            var __ZTVNSt3__215basic_streambufIcNS_11char_traitsIcEEEE = Module["__ZTVNSt3__215basic_streambufIcNS_11char_traitsIcEEEE"] = 263464;
            var __ZTVNSt3__215basic_streambufIwNS_11char_traitsIwEEEE = Module["__ZTVNSt3__215basic_streambufIwNS_11char_traitsIwEEEE"] = 263528;
            var __ZTTNSt3__213basic_istreamIcNS_11char_traitsIcEEEE = Module["__ZTTNSt3__213basic_istreamIcNS_11char_traitsIcEEEE"] = 263632;
            var __ZTTNSt3__213basic_istreamIwNS_11char_traitsIwEEEE = Module["__ZTTNSt3__213basic_istreamIwNS_11char_traitsIwEEEE"] = 263680;
            var __ZTTNSt3__213basic_ostreamIcNS_11char_traitsIcEEEE = Module["__ZTTNSt3__213basic_ostreamIcNS_11char_traitsIcEEEE"] = 263728;
            var __ZTTNSt3__213basic_ostreamIwNS_11char_traitsIwEEEE = Module["__ZTTNSt3__213basic_ostreamIwNS_11char_traitsIwEEEE"] = 263776;
            var __ZTTNSt3__214basic_iostreamIcNS_11char_traitsIcEEEE = Module["__ZTTNSt3__214basic_iostreamIcNS_11char_traitsIcEEEE"] = 263844;
            var __ZTVNSt3__28ios_base7failureE = Module["__ZTVNSt3__28ios_base7failureE"] = 263912;
            var __ZNSt3__28ios_base9__xindex_E = Module["__ZNSt3__28ios_base9__xindex_E"] = 285752;
            var __ZTINSt3__213basic_istreamIwNS_11char_traitsIwEEEE = Module["__ZTINSt3__213basic_istreamIwNS_11char_traitsIwEEEE"] = 264056;
            var __ZTINSt3__213basic_ostreamIwNS_11char_traitsIwEEEE = Module["__ZTINSt3__213basic_ostreamIwNS_11char_traitsIwEEEE"] = 264104;
            var __ZTVNSt3__214basic_iostreamIcNS_11char_traitsIcEEEE = Module["__ZTVNSt3__214basic_iostreamIcNS_11char_traitsIcEEEE"] = 263784;
            var __ZTCNSt3__214basic_iostreamIcNS_11char_traitsIcEEEE0_NS_13basic_istreamIcS2_EE = Module["__ZTCNSt3__214basic_iostreamIcNS_11char_traitsIcEEEE0_NS_13basic_istreamIcS2_EE"] = 264128;
            var __ZTCNSt3__214basic_iostreamIcNS_11char_traitsIcEEEE8_NS_13basic_ostreamIcS2_EE = Module["__ZTCNSt3__214basic_iostreamIcNS_11char_traitsIcEEEE8_NS_13basic_ostreamIcS2_EE"] = 264168;
            var __ZTVNSt3__219__iostream_categoryE = Module["__ZTVNSt3__219__iostream_categoryE"] = 263876;
            var __ZTINSt3__219__iostream_categoryE = Module["__ZTINSt3__219__iostream_categoryE"] = 264240;
            var __ZTINSt3__28ios_base7failureE = Module["__ZTINSt3__28ios_base7failureE"] = 264252;
            var __ZNSt3__28ios_base9boolalphaE = Module["__ZNSt3__28ios_base9boolalphaE"] = 242296;
            var __ZNSt3__28ios_base3decE = Module["__ZNSt3__28ios_base3decE"] = 242300;
            var __ZNSt3__28ios_base5fixedE = Module["__ZNSt3__28ios_base5fixedE"] = 242304;
            var __ZNSt3__28ios_base3hexE = Module["__ZNSt3__28ios_base3hexE"] = 242308;
            var __ZNSt3__28ios_base8internalE = Module["__ZNSt3__28ios_base8internalE"] = 242312;
            var __ZNSt3__28ios_base4leftE = Module["__ZNSt3__28ios_base4leftE"] = 242316;
            var __ZNSt3__28ios_base3octE = Module["__ZNSt3__28ios_base3octE"] = 242320;
            var __ZNSt3__28ios_base5rightE = Module["__ZNSt3__28ios_base5rightE"] = 242324;
            var __ZNSt3__28ios_base10scientificE = Module["__ZNSt3__28ios_base10scientificE"] = 242328;
            var __ZNSt3__28ios_base8showbaseE = Module["__ZNSt3__28ios_base8showbaseE"] = 242332;
            var __ZNSt3__28ios_base9showpointE = Module["__ZNSt3__28ios_base9showpointE"] = 242336;
            var __ZNSt3__28ios_base7showposE = Module["__ZNSt3__28ios_base7showposE"] = 242340;
            var __ZNSt3__28ios_base6skipwsE = Module["__ZNSt3__28ios_base6skipwsE"] = 242344;
            var __ZNSt3__28ios_base7unitbufE = Module["__ZNSt3__28ios_base7unitbufE"] = 242348;
            var __ZNSt3__28ios_base9uppercaseE = Module["__ZNSt3__28ios_base9uppercaseE"] = 242352;
            var __ZNSt3__28ios_base11adjustfieldE = Module["__ZNSt3__28ios_base11adjustfieldE"] = 242356;
            var __ZNSt3__28ios_base9basefieldE = Module["__ZNSt3__28ios_base9basefieldE"] = 242360;
            var __ZNSt3__28ios_base10floatfieldE = Module["__ZNSt3__28ios_base10floatfieldE"] = 242364;
            var __ZNSt3__28ios_base6badbitE = Module["__ZNSt3__28ios_base6badbitE"] = 242368;
            var __ZNSt3__28ios_base6eofbitE = Module["__ZNSt3__28ios_base6eofbitE"] = 242372;
            var __ZNSt3__28ios_base7failbitE = Module["__ZNSt3__28ios_base7failbitE"] = 242376;
            var __ZNSt3__28ios_base7goodbitE = Module["__ZNSt3__28ios_base7goodbitE"] = 242380;
            var __ZNSt3__28ios_base3appE = Module["__ZNSt3__28ios_base3appE"] = 242384;
            var __ZNSt3__28ios_base3ateE = Module["__ZNSt3__28ios_base3ateE"] = 242388;
            var __ZNSt3__28ios_base6binaryE = Module["__ZNSt3__28ios_base6binaryE"] = 242392;
            var __ZNSt3__28ios_base2inE = Module["__ZNSt3__28ios_base2inE"] = 242396;
            var __ZNSt3__28ios_base3outE = Module["__ZNSt3__28ios_base3outE"] = 242400;
            var __ZNSt3__28ios_base5truncE = Module["__ZNSt3__28ios_base5truncE"] = 242404;
            var __ZTINSt3__28ios_baseE = Module["__ZTINSt3__28ios_baseE"] = 263952;
            var __ZTSNSt3__28ios_baseE = Module["__ZTSNSt3__28ios_baseE"] = 242408;
            var __ZTINSt3__29basic_iosIcNS_11char_traitsIcEEEE = Module["__ZTINSt3__29basic_iosIcNS_11char_traitsIcEEEE"] = 263976;
            var __ZTSNSt3__29basic_iosIcNS_11char_traitsIcEEEE = Module["__ZTSNSt3__29basic_iosIcNS_11char_traitsIcEEEE"] = 242426;
            var __ZTINSt3__29basic_iosIwNS_11char_traitsIwEEEE = Module["__ZTINSt3__29basic_iosIwNS_11char_traitsIwEEEE"] = 264004;
            var __ZTSNSt3__29basic_iosIwNS_11char_traitsIwEEEE = Module["__ZTSNSt3__29basic_iosIwNS_11char_traitsIwEEEE"] = 242468;
            var __ZTSNSt3__215basic_streambufIcNS_11char_traitsIcEEEE = Module["__ZTSNSt3__215basic_streambufIcNS_11char_traitsIcEEEE"] = 242510;
            var __ZTSNSt3__215basic_streambufIwNS_11char_traitsIwEEEE = Module["__ZTSNSt3__215basic_streambufIwNS_11char_traitsIwEEEE"] = 242559;
            var __ZTSNSt3__213basic_istreamIcNS_11char_traitsIcEEEE = Module["__ZTSNSt3__213basic_istreamIcNS_11char_traitsIcEEEE"] = 242608;
            var __ZTSNSt3__213basic_istreamIwNS_11char_traitsIwEEEE = Module["__ZTSNSt3__213basic_istreamIwNS_11char_traitsIwEEEE"] = 242655;
            var __ZTSNSt3__213basic_ostreamIcNS_11char_traitsIcEEEE = Module["__ZTSNSt3__213basic_ostreamIcNS_11char_traitsIcEEEE"] = 242702;
            var __ZTSNSt3__213basic_ostreamIwNS_11char_traitsIwEEEE = Module["__ZTSNSt3__213basic_ostreamIwNS_11char_traitsIwEEEE"] = 242749;
            var __ZTSNSt3__214basic_iostreamIcNS_11char_traitsIcEEEE = Module["__ZTSNSt3__214basic_iostreamIcNS_11char_traitsIcEEEE"] = 242796;
            var __ZTSNSt3__219__iostream_categoryE = Module["__ZTSNSt3__219__iostream_categoryE"] = 242844;
            var __ZTSNSt3__28ios_base7failureE = Module["__ZTSNSt3__28ios_base7failureE"] = 242874;
            var __ZTVNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEE = Module["__ZTVNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEE"] = 264264;
            var __ZTVNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEEE = Module["__ZTVNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEEE"] = 264304;
            var __ZTINSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEE = Module["__ZTINSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEE"] = 264292;
            var __ZTSNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEE = Module["__ZTSNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem12__dir_streamENS_9allocatorIS3_EEEE"] = 242900;
            var __ZTINSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEEE = Module["__ZTINSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEEE"] = 264332;
            var __ZTSNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEEE = Module["__ZTSNSt3__220__shared_ptr_emplaceINS_4__fs10filesystem28recursive_directory_iterator12__shared_impENS_9allocatorIS4_EEEE"] = 242987;
            var __ZTVNSt3__24__fs10filesystem16filesystem_errorE = Module["__ZTVNSt3__24__fs10filesystem16filesystem_errorE"] = 264344;
            var __ZTVNSt3__214basic_ifstreamIcNS_11char_traitsIcEEEE = Module["__ZTVNSt3__214basic_ifstreamIcNS_11char_traitsIcEEEE"] = 264396;
            var __ZTTNSt3__214basic_ifstreamIcNS_11char_traitsIcEEEE = Module["__ZTTNSt3__214basic_ifstreamIcNS_11char_traitsIcEEEE"] = 264436;
            var __ZTVNSt3__214basic_ofstreamIcNS_11char_traitsIcEEEE = Module["__ZTVNSt3__214basic_ofstreamIcNS_11char_traitsIcEEEE"] = 264580;
            var __ZTTNSt3__214basic_ofstreamIcNS_11char_traitsIcEEEE = Module["__ZTTNSt3__214basic_ofstreamIcNS_11char_traitsIcEEEE"] = 264620;
            var __ZTVNSt3__213basic_filebufIcNS_11char_traitsIcEEEE = Module["__ZTVNSt3__213basic_filebufIcNS_11char_traitsIcEEEE"] = 264504;
            var __ZNSt3__24__fs10filesystem16_FilesystemClock9is_steadyE = Module["__ZNSt3__24__fs10filesystem16_FilesystemClock9is_steadyE"] = 243104;
            var __ZTINSt3__24__fs10filesystem16filesystem_errorE = Module["__ZTINSt3__24__fs10filesystem16filesystem_errorE"] = 264384;
            var __ZNSt3__24__fs10filesystem4path19preferred_separatorE = Module["__ZNSt3__24__fs10filesystem4path19preferred_separatorE"] = 243105;
            var __ZTSNSt3__24__fs10filesystem16filesystem_errorE = Module["__ZTSNSt3__24__fs10filesystem16filesystem_errorE"] = 243106;
            var __ZTINSt3__214basic_ifstreamIcNS_11char_traitsIcEEEE = Module["__ZTINSt3__214basic_ifstreamIcNS_11char_traitsIcEEEE"] = 264492;
            var __ZTCNSt3__214basic_ifstreamIcNS_11char_traitsIcEEEE0_NS_13basic_istreamIcS2_EE = Module["__ZTCNSt3__214basic_ifstreamIcNS_11char_traitsIcEEEE0_NS_13basic_istreamIcS2_EE"] = 264452;
            var __ZTSNSt3__214basic_ifstreamIcNS_11char_traitsIcEEEE = Module["__ZTSNSt3__214basic_ifstreamIcNS_11char_traitsIcEEEE"] = 243150;
            var __ZTINSt3__213basic_filebufIcNS_11char_traitsIcEEEE = Module["__ZTINSt3__213basic_filebufIcNS_11char_traitsIcEEEE"] = 264568;
            var __ZTSNSt3__213basic_filebufIcNS_11char_traitsIcEEEE = Module["__ZTSNSt3__213basic_filebufIcNS_11char_traitsIcEEEE"] = 243198;
            var __ZTINSt3__214basic_ofstreamIcNS_11char_traitsIcEEEE = Module["__ZTINSt3__214basic_ofstreamIcNS_11char_traitsIcEEEE"] = 264676;
            var __ZTCNSt3__214basic_ofstreamIcNS_11char_traitsIcEEEE0_NS_13basic_ostreamIcS2_EE = Module["__ZTCNSt3__214basic_ofstreamIcNS_11char_traitsIcEEEE0_NS_13basic_ostreamIcS2_EE"] = 264636;
            var __ZTSNSt3__214basic_ofstreamIcNS_11char_traitsIcEEEE = Module["__ZTSNSt3__214basic_ofstreamIcNS_11char_traitsIcEEEE"] = 243245;
            var __ZTVNSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_impE = Module["__ZTVNSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_impE"] = 264688;
            var __ZTINSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_impE = Module["__ZTINSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_impE"] = 264760;
            var __ZTVNSt12experimental15fundamentals_v13pmr26__null_memory_resource_impE = Module["__ZTVNSt12experimental15fundamentals_v13pmr26__null_memory_resource_impE"] = 264716;
            var __ZTINSt12experimental15fundamentals_v13pmr26__null_memory_resource_impE = Module["__ZTINSt12experimental15fundamentals_v13pmr26__null_memory_resource_impE"] = 264772;
            var __ZTSNSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_impE = Module["__ZTSNSt12experimental15fundamentals_v13pmr32__new_delete_memory_resource_impE"] = 243293;
            var __ZTSNSt12experimental15fundamentals_v13pmr15memory_resourceE = Module["__ZTSNSt12experimental15fundamentals_v13pmr15memory_resourceE"] = 243367;
            var __ZTINSt12experimental15fundamentals_v13pmr15memory_resourceE = Module["__ZTINSt12experimental15fundamentals_v13pmr15memory_resourceE"] = 264752;
            var __ZTSNSt12experimental15fundamentals_v13pmr26__null_memory_resource_impE = Module["__ZTSNSt12experimental15fundamentals_v13pmr26__null_memory_resource_impE"] = 243424;
            var ___cxa_unexpected_handler = Module["___cxa_unexpected_handler"] = 264792;
            var ___cxa_terminate_handler = Module["___cxa_terminate_handler"] = 264788;
            var ___cxa_new_handler = Module["___cxa_new_handler"] = 285772;
            var __ZTVSt9bad_alloc = Module["__ZTVSt9bad_alloc"] = 269096;
            var __ZTVSt20bad_array_new_length = Module["__ZTVSt20bad_array_new_length"] = 269116;
            var __ZTISt9bad_alloc = Module["__ZTISt9bad_alloc"] = 269196;
            var __ZTISt20bad_array_new_length = Module["__ZTISt20bad_array_new_length"] = 269208;
            var __ZTSSt9exception = Module["__ZTSSt9exception"] = 247392;
            var __ZTVSt13bad_exception = Module["__ZTVSt13bad_exception"] = 269164;
            var __ZTISt13bad_exception = Module["__ZTISt13bad_exception"] = 269184;
            var __ZTSSt13bad_exception = Module["__ZTSSt13bad_exception"] = 247405;
            var __ZTSSt9bad_alloc = Module["__ZTSSt9bad_alloc"] = 247423;
            var __ZTSSt20bad_array_new_length = Module["__ZTSSt20bad_array_new_length"] = 247436;
            var __ZTVSt12domain_error = Module["__ZTVSt12domain_error"] = 269260;
            var __ZTISt12domain_error = Module["__ZTISt12domain_error"] = 269292;
            var __ZTSSt12domain_error = Module["__ZTSSt12domain_error"] = 247461;
            var __ZTSSt11logic_error = Module["__ZTSSt11logic_error"] = 247478;
            var __ZTVSt16invalid_argument = Module["__ZTVSt16invalid_argument"] = 269304;
            var __ZTISt16invalid_argument = Module["__ZTISt16invalid_argument"] = 269324;
            var __ZTSSt16invalid_argument = Module["__ZTSSt16invalid_argument"] = 247494;
            var __ZTVSt12length_error = Module["__ZTVSt12length_error"] = 269336;
            var __ZTISt12length_error = Module["__ZTISt12length_error"] = 269356;
            var __ZTSSt12length_error = Module["__ZTSSt12length_error"] = 247515;
            var __ZTVSt12out_of_range = Module["__ZTVSt12out_of_range"] = 269368;
            var __ZTISt12out_of_range = Module["__ZTISt12out_of_range"] = 269388;
            var __ZTSSt12out_of_range = Module["__ZTSSt12out_of_range"] = 247532;
            var __ZTVSt11range_error = Module["__ZTVSt11range_error"] = 269400;
            var __ZTISt11range_error = Module["__ZTISt11range_error"] = 269432;
            var __ZTSSt11range_error = Module["__ZTSSt11range_error"] = 247549;
            var __ZTSSt13runtime_error = Module["__ZTSSt13runtime_error"] = 247565;
            var __ZTVSt14overflow_error = Module["__ZTVSt14overflow_error"] = 269444;
            var __ZTISt14overflow_error = Module["__ZTISt14overflow_error"] = 269464;
            var __ZTSSt14overflow_error = Module["__ZTSSt14overflow_error"] = 247583;
            var __ZTVSt15underflow_error = Module["__ZTVSt15underflow_error"] = 269476;
            var __ZTISt15underflow_error = Module["__ZTISt15underflow_error"] = 269496;
            var __ZTSSt15underflow_error = Module["__ZTSSt15underflow_error"] = 247602;
            var __ZTVSt8bad_cast = Module["__ZTVSt8bad_cast"] = 269508;
            var __ZTVSt10bad_typeid = Module["__ZTVSt10bad_typeid"] = 269528;
            var __ZTISt10bad_typeid = Module["__ZTISt10bad_typeid"] = 269584;
            var __ZTVSt9type_info = Module["__ZTVSt9type_info"] = 269548;
            var __ZTISt9type_info = Module["__ZTISt9type_info"] = 269564;
            var __ZTSSt9type_info = Module["__ZTSSt9type_info"] = 247622;
            var __ZTSSt8bad_cast = Module["__ZTSSt8bad_cast"] = 247635;
            var __ZTSSt10bad_typeid = Module["__ZTSSt10bad_typeid"] = 247647;
            var __ZTIN10__cxxabiv117__class_type_infoE = Module["__ZTIN10__cxxabiv117__class_type_infoE"] = 269608;
            var __ZTIN10__cxxabiv116__shim_type_infoE = Module["__ZTIN10__cxxabiv116__shim_type_infoE"] = 269596;
            var __ZTIN10__cxxabiv117__pbase_type_infoE = Module["__ZTIN10__cxxabiv117__pbase_type_infoE"] = 269620;
            var __ZTIDn = Module["__ZTIDn"] = 269776;
            var __ZTIN10__cxxabiv119__pointer_type_infoE = Module["__ZTIN10__cxxabiv119__pointer_type_infoE"] = 269632;
            var __ZTIv = Module["__ZTIv"] = 269736;
            var __ZTIN10__cxxabiv120__function_type_infoE = Module["__ZTIN10__cxxabiv120__function_type_infoE"] = 269644;
            var __ZTIN10__cxxabiv129__pointer_to_member_type_infoE = Module["__ZTIN10__cxxabiv129__pointer_to_member_type_infoE"] = 269656;
            var __ZTSN10__cxxabiv116__shim_type_infoE = Module["__ZTSN10__cxxabiv116__shim_type_infoE"] = 247662;
            var __ZTSN10__cxxabiv117__class_type_infoE = Module["__ZTSN10__cxxabiv117__class_type_infoE"] = 247695;
            var __ZTSN10__cxxabiv117__pbase_type_infoE = Module["__ZTSN10__cxxabiv117__pbase_type_infoE"] = 247729;
            var __ZTSN10__cxxabiv119__pointer_type_infoE = Module["__ZTSN10__cxxabiv119__pointer_type_infoE"] = 247763;
            var __ZTSN10__cxxabiv120__function_type_infoE = Module["__ZTSN10__cxxabiv120__function_type_infoE"] = 247799;
            var __ZTSN10__cxxabiv129__pointer_to_member_type_infoE = Module["__ZTSN10__cxxabiv129__pointer_to_member_type_infoE"] = 247836;
            var __ZTVN10__cxxabiv116__shim_type_infoE = Module["__ZTVN10__cxxabiv116__shim_type_infoE"] = 269668;
            var __ZTVN10__cxxabiv123__fundamental_type_infoE = Module["__ZTVN10__cxxabiv123__fundamental_type_infoE"] = 269696;
            var __ZTIN10__cxxabiv123__fundamental_type_infoE = Module["__ZTIN10__cxxabiv123__fundamental_type_infoE"] = 269724;
            var __ZTSN10__cxxabiv123__fundamental_type_infoE = Module["__ZTSN10__cxxabiv123__fundamental_type_infoE"] = 247896;
            var __ZTSv = Module["__ZTSv"] = 247936;
            var __ZTSPv = Module["__ZTSPv"] = 247938;
            var __ZTIPv = Module["__ZTIPv"] = 269744;
            var __ZTVN10__cxxabiv119__pointer_type_infoE = Module["__ZTVN10__cxxabiv119__pointer_type_infoE"] = 271016;
            var __ZTSPKv = Module["__ZTSPKv"] = 247941;
            var __ZTIPKv = Module["__ZTIPKv"] = 269760;
            var __ZTSDn = Module["__ZTSDn"] = 247945;
            var __ZTSPDn = Module["__ZTSPDn"] = 247948;
            var __ZTIPDn = Module["__ZTIPDn"] = 269784;
            var __ZTSPKDn = Module["__ZTSPKDn"] = 247952;
            var __ZTIPKDn = Module["__ZTIPKDn"] = 269800;
            var __ZTSb = Module["__ZTSb"] = 247957;
            var __ZTIb = Module["__ZTIb"] = 269816;
            var __ZTSPb = Module["__ZTSPb"] = 247959;
            var __ZTIPb = Module["__ZTIPb"] = 269824;
            var __ZTSPKb = Module["__ZTSPKb"] = 247962;
            var __ZTIPKb = Module["__ZTIPKb"] = 269840;
            var __ZTSw = Module["__ZTSw"] = 247966;
            var __ZTIw = Module["__ZTIw"] = 269856;
            var __ZTSPw = Module["__ZTSPw"] = 247968;
            var __ZTIPw = Module["__ZTIPw"] = 269864;
            var __ZTSPKw = Module["__ZTSPKw"] = 247971;
            var __ZTIPKw = Module["__ZTIPKw"] = 269880;
            var __ZTSc = Module["__ZTSc"] = 247975;
            var __ZTIc = Module["__ZTIc"] = 269896;
            var __ZTSPc = Module["__ZTSPc"] = 247977;
            var __ZTIPc = Module["__ZTIPc"] = 269904;
            var __ZTSPKc = Module["__ZTSPKc"] = 247980;
            var __ZTIPKc = Module["__ZTIPKc"] = 269920;
            var __ZTSh = Module["__ZTSh"] = 247984;
            var __ZTIh = Module["__ZTIh"] = 269936;
            var __ZTSPh = Module["__ZTSPh"] = 247986;
            var __ZTIPh = Module["__ZTIPh"] = 269944;
            var __ZTSPKh = Module["__ZTSPKh"] = 247989;
            var __ZTIPKh = Module["__ZTIPKh"] = 269960;
            var __ZTSa = Module["__ZTSa"] = 247993;
            var __ZTIa = Module["__ZTIa"] = 269976;
            var __ZTSPa = Module["__ZTSPa"] = 247995;
            var __ZTIPa = Module["__ZTIPa"] = 269984;
            var __ZTSPKa = Module["__ZTSPKa"] = 247998;
            var __ZTIPKa = Module["__ZTIPKa"] = 27e4;
            var __ZTSs = Module["__ZTSs"] = 248002;
            var __ZTIs = Module["__ZTIs"] = 270016;
            var __ZTSPs = Module["__ZTSPs"] = 248004;
            var __ZTIPs = Module["__ZTIPs"] = 270024;
            var __ZTSPKs = Module["__ZTSPKs"] = 248007;
            var __ZTIPKs = Module["__ZTIPKs"] = 270040;
            var __ZTSt = Module["__ZTSt"] = 248011;
            var __ZTIt = Module["__ZTIt"] = 270056;
            var __ZTSPt = Module["__ZTSPt"] = 248013;
            var __ZTIPt = Module["__ZTIPt"] = 270064;
            var __ZTSPKt = Module["__ZTSPKt"] = 248016;
            var __ZTIPKt = Module["__ZTIPKt"] = 270080;
            var __ZTSi = Module["__ZTSi"] = 248020;
            var __ZTIi = Module["__ZTIi"] = 270096;
            var __ZTSPi = Module["__ZTSPi"] = 248022;
            var __ZTIPi = Module["__ZTIPi"] = 270104;
            var __ZTSPKi = Module["__ZTSPKi"] = 248025;
            var __ZTIPKi = Module["__ZTIPKi"] = 270120;
            var __ZTSj = Module["__ZTSj"] = 248029;
            var __ZTIj = Module["__ZTIj"] = 270136;
            var __ZTSPj = Module["__ZTSPj"] = 248031;
            var __ZTIPj = Module["__ZTIPj"] = 270144;
            var __ZTSPKj = Module["__ZTSPKj"] = 248034;
            var __ZTIPKj = Module["__ZTIPKj"] = 270160;
            var __ZTSl = Module["__ZTSl"] = 248038;
            var __ZTIl = Module["__ZTIl"] = 270176;
            var __ZTSPl = Module["__ZTSPl"] = 248040;
            var __ZTIPl = Module["__ZTIPl"] = 270184;
            var __ZTSPKl = Module["__ZTSPKl"] = 248043;
            var __ZTIPKl = Module["__ZTIPKl"] = 270200;
            var __ZTSm = Module["__ZTSm"] = 248047;
            var __ZTIm = Module["__ZTIm"] = 270216;
            var __ZTSPm = Module["__ZTSPm"] = 248049;
            var __ZTIPm = Module["__ZTIPm"] = 270224;
            var __ZTSPKm = Module["__ZTSPKm"] = 248052;
            var __ZTIPKm = Module["__ZTIPKm"] = 270240;
            var __ZTSx = Module["__ZTSx"] = 248056;
            var __ZTIx = Module["__ZTIx"] = 270256;
            var __ZTSPx = Module["__ZTSPx"] = 248058;
            var __ZTIPx = Module["__ZTIPx"] = 270264;
            var __ZTSPKx = Module["__ZTSPKx"] = 248061;
            var __ZTIPKx = Module["__ZTIPKx"] = 270280;
            var __ZTSy = Module["__ZTSy"] = 248065;
            var __ZTIy = Module["__ZTIy"] = 270296;
            var __ZTSPy = Module["__ZTSPy"] = 248067;
            var __ZTIPy = Module["__ZTIPy"] = 270304;
            var __ZTSPKy = Module["__ZTSPKy"] = 248070;
            var __ZTIPKy = Module["__ZTIPKy"] = 270320;
            var __ZTSn = Module["__ZTSn"] = 248074;
            var __ZTIn = Module["__ZTIn"] = 270336;
            var __ZTSPn = Module["__ZTSPn"] = 248076;
            var __ZTIPn = Module["__ZTIPn"] = 270344;
            var __ZTSPKn = Module["__ZTSPKn"] = 248079;
            var __ZTIPKn = Module["__ZTIPKn"] = 270360;
            var __ZTSo = Module["__ZTSo"] = 248083;
            var __ZTIo = Module["__ZTIo"] = 270376;
            var __ZTSPo = Module["__ZTSPo"] = 248085;
            var __ZTIPo = Module["__ZTIPo"] = 270384;
            var __ZTSPKo = Module["__ZTSPKo"] = 248088;
            var __ZTIPKo = Module["__ZTIPKo"] = 270400;
            var __ZTSDh = Module["__ZTSDh"] = 248092;
            var __ZTIDh = Module["__ZTIDh"] = 270416;
            var __ZTSPDh = Module["__ZTSPDh"] = 248095;
            var __ZTIPDh = Module["__ZTIPDh"] = 270424;
            var __ZTSPKDh = Module["__ZTSPKDh"] = 248099;
            var __ZTIPKDh = Module["__ZTIPKDh"] = 270440;
            var __ZTSf = Module["__ZTSf"] = 248104;
            var __ZTIf = Module["__ZTIf"] = 270456;
            var __ZTSPf = Module["__ZTSPf"] = 248106;
            var __ZTIPf = Module["__ZTIPf"] = 270464;
            var __ZTSPKf = Module["__ZTSPKf"] = 248109;
            var __ZTIPKf = Module["__ZTIPKf"] = 270480;
            var __ZTSd = Module["__ZTSd"] = 248113;
            var __ZTId = Module["__ZTId"] = 270496;
            var __ZTSPd = Module["__ZTSPd"] = 248115;
            var __ZTIPd = Module["__ZTIPd"] = 270504;
            var __ZTSPKd = Module["__ZTSPKd"] = 248118;
            var __ZTIPKd = Module["__ZTIPKd"] = 270520;
            var __ZTSe = Module["__ZTSe"] = 248122;
            var __ZTIe = Module["__ZTIe"] = 270536;
            var __ZTSPe = Module["__ZTSPe"] = 248124;
            var __ZTIPe = Module["__ZTIPe"] = 270544;
            var __ZTSPKe = Module["__ZTSPKe"] = 248127;
            var __ZTIPKe = Module["__ZTIPKe"] = 270560;
            var __ZTSg = Module["__ZTSg"] = 248131;
            var __ZTIg = Module["__ZTIg"] = 270576;
            var __ZTSPg = Module["__ZTSPg"] = 248133;
            var __ZTIPg = Module["__ZTIPg"] = 270584;
            var __ZTSPKg = Module["__ZTSPKg"] = 248136;
            var __ZTIPKg = Module["__ZTIPKg"] = 270600;
            var __ZTSDu = Module["__ZTSDu"] = 248140;
            var __ZTIDu = Module["__ZTIDu"] = 270616;
            var __ZTSPDu = Module["__ZTSPDu"] = 248143;
            var __ZTIPDu = Module["__ZTIPDu"] = 270624;
            var __ZTSPKDu = Module["__ZTSPKDu"] = 248147;
            var __ZTIPKDu = Module["__ZTIPKDu"] = 270640;
            var __ZTSDs = Module["__ZTSDs"] = 248152;
            var __ZTIDs = Module["__ZTIDs"] = 270656;
            var __ZTSPDs = Module["__ZTSPDs"] = 248155;
            var __ZTIPDs = Module["__ZTIPDs"] = 270664;
            var __ZTSPKDs = Module["__ZTSPKDs"] = 248159;
            var __ZTIPKDs = Module["__ZTIPKDs"] = 270680;
            var __ZTSDi = Module["__ZTSDi"] = 248164;
            var __ZTIDi = Module["__ZTIDi"] = 270696;
            var __ZTSPDi = Module["__ZTSPDi"] = 248167;
            var __ZTIPDi = Module["__ZTIPDi"] = 270704;
            var __ZTSPKDi = Module["__ZTSPKDi"] = 248171;
            var __ZTIPKDi = Module["__ZTIPKDi"] = 270720;
            var __ZTVN10__cxxabiv117__array_type_infoE = Module["__ZTVN10__cxxabiv117__array_type_infoE"] = 270736;
            var __ZTIN10__cxxabiv117__array_type_infoE = Module["__ZTIN10__cxxabiv117__array_type_infoE"] = 270764;
            var __ZTSN10__cxxabiv117__array_type_infoE = Module["__ZTSN10__cxxabiv117__array_type_infoE"] = 248176;
            var __ZTVN10__cxxabiv120__function_type_infoE = Module["__ZTVN10__cxxabiv120__function_type_infoE"] = 270776;
            var __ZTVN10__cxxabiv116__enum_type_infoE = Module["__ZTVN10__cxxabiv116__enum_type_infoE"] = 270804;
            var __ZTIN10__cxxabiv116__enum_type_infoE = Module["__ZTIN10__cxxabiv116__enum_type_infoE"] = 270832;
            var __ZTSN10__cxxabiv116__enum_type_infoE = Module["__ZTSN10__cxxabiv116__enum_type_infoE"] = 248210;
            var __ZTIN10__cxxabiv120__si_class_type_infoE = Module["__ZTIN10__cxxabiv120__si_class_type_infoE"] = 270924;
            var __ZTSN10__cxxabiv120__si_class_type_infoE = Module["__ZTSN10__cxxabiv120__si_class_type_infoE"] = 248243;
            var __ZTIN10__cxxabiv121__vmi_class_type_infoE = Module["__ZTIN10__cxxabiv121__vmi_class_type_infoE"] = 270976;
            var __ZTSN10__cxxabiv121__vmi_class_type_infoE = Module["__ZTSN10__cxxabiv121__vmi_class_type_infoE"] = 248280;
            var __ZTVN10__cxxabiv117__pbase_type_infoE = Module["__ZTVN10__cxxabiv117__pbase_type_infoE"] = 270988;
            var __ZTVN10__cxxabiv129__pointer_to_member_type_infoE = Module["__ZTVN10__cxxabiv129__pointer_to_member_type_infoE"] = 271044;
            var _in6addr_any = Module["_in6addr_any"] = 252860;
            var _in6addr_loopback = Module["_in6addr_loopback"] = 252876;
            Module["allocate"] = allocate;
            var calledRun;

            function ExitStatus(status) {
                this.name = "ExitStatus";
                this.message = "Program terminated with exit(" + status + ")";
                this.status = status
            }
            var calledMain = false;
            dependenciesFulfilled = function runCaller() {
                if (!calledRun) run();
                if (!calledRun) dependenciesFulfilled = runCaller
            };

            function callMain(args) {
                var entryFunction = Module["_main"];
                if (!entryFunction) return;
                args = args || [];
                var argc = args.length + 1;
                var argv = stackAlloc((argc + 1) * 4);
                HEAP32[argv >> 2] = allocateUTF8OnStack(thisProgram);
                for (var i = 1; i < argc; i++) {
                    HEAP32[(argv >> 2) + i] = allocateUTF8OnStack(args[i - 1])
                }
                HEAP32[(argv >> 2) + argc] = 0;
                try {
                    var ret = entryFunction(argc, argv);
                    exit(ret, true)
                } catch (e) {
                    if (e instanceof ExitStatus) {
                        return
                    } else if (e == "unwind") {
                        return
                    } else {
                        var toLog = e;
                        if (e && typeof e === "object" && e.stack) {
                            toLog = [e, e.stack]
                        }
                        err("exception thrown: " + toLog);
                        quit_(1, e)
                    }
                } finally {
                    calledMain = true
                }
            }
            var dylibsLoaded = false;

            function run(args) {
                args = args || arguments_;
                if (runDependencies > 0) {
                    return
                }
                if (!dylibsLoaded) {
                    preloadDylibs();
                    dylibsLoaded = true;
                    if (runDependencies > 0) {
                        return
                    }
                }
                preRun();
                if (runDependencies > 0) {
                    return
                }

                function doRun() {
                    if (calledRun) return;
                    calledRun = true;
                    Module["calledRun"] = true;
                    if (ABORT) return;
                    initRuntime();
                    preMain();
                    readyPromiseResolve(Module);
                    if (Module["onRuntimeInitialized"]) Module["onRuntimeInitialized"]();
                    if (shouldRunNow) callMain(args);
                    postRun()
                }
                if (Module["setStatus"]) {
                    Module["setStatus"]("Running...");
                    setTimeout(function() {
                        setTimeout(function() {
                            Module["setStatus"]("")
                        }, 1);
                        doRun()
                    }, 1)
                } else {
                    doRun()
                }
            }
            Module["run"] = run;

            function exit(status, implicit) {
                EXITSTATUS = status;
                if (implicit && keepRuntimeAlive() && status === 0) {
                    return
                }
                if (keepRuntimeAlive()) {} else {
                    exitRuntime();
                    if (Module["onExit"]) Module["onExit"](status);
                    ABORT = true
                }
                quit_(status, new ExitStatus(status))
            }
            if (Module["preInit"]) {
                if (typeof Module["preInit"] == "function") Module["preInit"] = [Module["preInit"]];
                while (Module["preInit"].length > 0) {
                    Module["preInit"].pop()()
                }
            }
            var shouldRunNow = true;
            if (Module["noInitialRun"]) shouldRunNow = false;
            run();


            return libopus.ready
        }
    );
})();
if (typeof exports === 'object' && typeof module === 'object')
    module.exports = libopus;
else if (typeof define === 'function' && define['amd'])
    define([], function() {
        return libopus;
    });
else if (typeof exports === 'object')
    exports["libopus"] = libopus;